// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.1.0"), "Mismatched Py/WinRT headers.");
#include <winrt/Microsoft.Web.WebView2.Core.h>
#include <winrt/Windows.ApplicationModel.Contacts.h>
#include <winrt/Windows.ApplicationModel.DataTransfer.h>
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.Foundation.Numerics.h>
#include <winrt/Windows.Globalization.NumberFormatting.h>
#include <winrt/Windows.UI.h>
#include <winrt/Windows.UI.Composition.h>
#include <winrt/Windows.UI.Text.h>
#include <winrt/Windows.UI.Xaml.h>
#include <winrt/Windows.UI.Xaml.Controls.h>
#include <winrt/Windows.UI.Xaml.Controls.Primitives.h>
#include <winrt/Windows.UI.Xaml.Input.h>
#include <winrt/Windows.UI.Xaml.Interop.h>
#include <winrt/Windows.UI.Xaml.Media.h>
#include <winrt/Windows.UI.Xaml.Media.Animation.h>

#include <winrt/Microsoft.UI.Xaml.Controls.h>

namespace py::proj::Microsoft::UI::Xaml::Controls
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::ColorPickerHsvChannel> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::ColorSpectrumComponents> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::ColorSpectrumShape> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::ControlsResourcesVersion> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::ElementRealizationOptions> = "I";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::ExpandDirection> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::InfoBarCloseReason> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::InfoBarSeverity> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::NavigationViewBackButtonVisible> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::NavigationViewDisplayMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::NavigationViewOverflowLabelMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::NavigationViewPaneDisplayMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::NavigationViewSelectionFollowsFocus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::NavigationViewShoulderNavigationEnabled> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::NumberBoxSpinButtonPlacementMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::NumberBoxValidationMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::ParallaxSourceOffsetKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::PipsPagerButtonVisibility> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::PlayerAnimationOptimization> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::RefreshPullDirection> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::RefreshVisualizerOrientation> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::RefreshVisualizerState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::SwipeBehaviorOnInvoked> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::SwipeMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::TabViewCloseButtonOverlayMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::TabViewWidthMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::TeachingTipCloseReason> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::TeachingTipHeroContentPlacementMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::TeachingTipPlacementMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::TeachingTipTailVisibility> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::TreeViewSelectionMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::TwoPaneViewMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::TwoPaneViewPriority> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::TwoPaneViewTallModeConfiguration> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::TwoPaneViewWideModeConfiguration> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::UniformGridLayoutItemsJustification> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Controls::UniformGridLayoutItemsStretch> = "i";


    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ColorPickerHsvChannel>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ColorPickerHsvChannel";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ColorPickerHsvChannel";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ColorSpectrumComponents>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ColorSpectrumComponents";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ColorSpectrumComponents";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ColorSpectrumShape>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ColorSpectrumShape";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ColorSpectrumShape";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ControlsResourcesVersion>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ControlsResourcesVersion";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ControlsResourcesVersion";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ElementRealizationOptions>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ElementRealizationOptions";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ElementRealizationOptions";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ExpandDirection>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ExpandDirection";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ExpandDirection";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::InfoBarCloseReason>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.InfoBarCloseReason";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "InfoBarCloseReason";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::InfoBarSeverity>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.InfoBarSeverity";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "InfoBarSeverity";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NavigationViewBackButtonVisible>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NavigationViewBackButtonVisible";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewBackButtonVisible";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NavigationViewDisplayMode>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NavigationViewDisplayMode";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewDisplayMode";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NavigationViewOverflowLabelMode>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NavigationViewOverflowLabelMode";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewOverflowLabelMode";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NavigationViewPaneDisplayMode>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NavigationViewPaneDisplayMode";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewPaneDisplayMode";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NavigationViewSelectionFollowsFocus>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NavigationViewSelectionFollowsFocus";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewSelectionFollowsFocus";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NavigationViewShoulderNavigationEnabled>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NavigationViewShoulderNavigationEnabled";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewShoulderNavigationEnabled";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NumberBoxSpinButtonPlacementMode>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NumberBoxSpinButtonPlacementMode";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NumberBoxSpinButtonPlacementMode";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NumberBoxValidationMode>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NumberBoxValidationMode";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NumberBoxValidationMode";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ParallaxSourceOffsetKind>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ParallaxSourceOffsetKind";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ParallaxSourceOffsetKind";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::PipsPagerButtonVisibility>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.PipsPagerButtonVisibility";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "PipsPagerButtonVisibility";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::PlayerAnimationOptimization>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.PlayerAnimationOptimization";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "PlayerAnimationOptimization";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::RefreshPullDirection>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.RefreshPullDirection";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "RefreshPullDirection";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::RefreshVisualizerOrientation>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.RefreshVisualizerOrientation";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "RefreshVisualizerOrientation";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::RefreshVisualizerState>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.RefreshVisualizerState";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "RefreshVisualizerState";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::SwipeBehaviorOnInvoked>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.SwipeBehaviorOnInvoked";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "SwipeBehaviorOnInvoked";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::SwipeMode>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.SwipeMode";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "SwipeMode";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TabViewCloseButtonOverlayMode>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TabViewCloseButtonOverlayMode";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TabViewCloseButtonOverlayMode";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TabViewWidthMode>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TabViewWidthMode";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TabViewWidthMode";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TeachingTipCloseReason>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TeachingTipCloseReason";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TeachingTipCloseReason";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TeachingTipHeroContentPlacementMode>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TeachingTipHeroContentPlacementMode";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TeachingTipHeroContentPlacementMode";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TeachingTipPlacementMode>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TeachingTipPlacementMode";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TeachingTipPlacementMode";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TeachingTipTailVisibility>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TeachingTipTailVisibility";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TeachingTipTailVisibility";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TreeViewSelectionMode>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TreeViewSelectionMode";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TreeViewSelectionMode";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TwoPaneViewMode>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TwoPaneViewMode";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TwoPaneViewMode";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TwoPaneViewPriority>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TwoPaneViewPriority";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TwoPaneViewPriority";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TwoPaneViewTallModeConfiguration>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TwoPaneViewTallModeConfiguration";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TwoPaneViewTallModeConfiguration";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TwoPaneViewWideModeConfiguration>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TwoPaneViewWideModeConfiguration";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TwoPaneViewWideModeConfiguration";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::UniformGridLayoutItemsJustification>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.UniformGridLayoutItemsJustification";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "UniformGridLayoutItemsJustification";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::UniformGridLayoutItemsStretch>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.UniformGridLayoutItemsStretch";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "UniformGridLayoutItemsStretch";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::AnimatedIcon>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.AnimatedIcon";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "AnimatedIcon";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::AnimatedIconSource>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.AnimatedIconSource";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "AnimatedIconSource";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::AnimatedVisualPlayer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.AnimatedVisualPlayer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "AnimatedVisualPlayer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::BackdropMaterial>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.BackdropMaterial";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "BackdropMaterial";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::BitmapIconSource>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.BitmapIconSource";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "BitmapIconSource";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::BreadcrumbBar>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.BreadcrumbBar";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "BreadcrumbBar";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::BreadcrumbBarItem>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.BreadcrumbBarItem";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "BreadcrumbBarItem";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::BreadcrumbBarItemClickedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.BreadcrumbBarItemClickedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "BreadcrumbBarItemClickedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ColorChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ColorChangedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ColorChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ColorPicker>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ColorPicker";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ColorPicker";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::CommandBarFlyout>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.CommandBarFlyout";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "CommandBarFlyout";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::CoreWebView2InitializedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.CoreWebView2InitializedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "CoreWebView2InitializedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::DropDownButton>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.DropDownButton";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "DropDownButton";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ElementFactory>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ElementFactory";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ElementFactory";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ElementFactoryGetArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ElementFactoryGetArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ElementFactoryGetArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ElementFactoryRecycleArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ElementFactoryRecycleArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ElementFactoryRecycleArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::Expander>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.Expander";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "Expander";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ExpanderCollapsedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ExpanderCollapsedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ExpanderCollapsedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ExpanderExpandingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ExpanderExpandingEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ExpanderExpandingEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ExpanderTemplateSettings>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ExpanderTemplateSettings";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ExpanderTemplateSettings";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::FontIconSource>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.FontIconSource";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "FontIconSource";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::IconSource>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.IconSource";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "IconSource";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ImageIcon>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ImageIcon";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ImageIcon";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ImageIconSource>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ImageIconSource";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ImageIconSource";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::InfoBadge>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.InfoBadge";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "InfoBadge";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::InfoBadgeTemplateSettings>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.InfoBadgeTemplateSettings";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "InfoBadgeTemplateSettings";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::InfoBar>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.InfoBar";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "InfoBar";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::InfoBarClosedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.InfoBarClosedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "InfoBarClosedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::InfoBarClosingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.InfoBarClosingEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "InfoBarClosingEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::InfoBarTemplateSettings>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.InfoBarTemplateSettings";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "InfoBarTemplateSettings";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeater>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ItemsRepeater";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ItemsRepeater";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterElementClearingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ItemsRepeaterElementClearingEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ItemsRepeaterElementClearingEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterElementIndexChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ItemsRepeaterElementIndexChangedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ItemsRepeaterElementIndexChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterElementPreparedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ItemsRepeaterElementPreparedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ItemsRepeaterElementPreparedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterScrollHost>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ItemsRepeaterScrollHost";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ItemsRepeaterScrollHost";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ItemsSourceView>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ItemsSourceView";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ItemsSourceView";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::Layout>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.Layout";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "Layout";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::LayoutContext>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.LayoutContext";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "LayoutContext";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::MenuBar>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.MenuBar";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "MenuBar";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::MenuBarItem>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.MenuBarItem";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "MenuBarItem";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::MenuBarItemFlyout>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.MenuBarItemFlyout";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "MenuBarItemFlyout";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NavigationView>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NavigationView";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationView";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NavigationViewBackRequestedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NavigationViewBackRequestedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewBackRequestedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NavigationViewDisplayModeChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NavigationViewDisplayModeChangedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewDisplayModeChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItem>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NavigationViewItem";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewItem";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemBase>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NavigationViewItemBase";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewItemBase";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemCollapsedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NavigationViewItemCollapsedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewItemCollapsedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemExpandingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NavigationViewItemExpandingEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewItemExpandingEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemHeader>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NavigationViewItemHeader";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewItemHeader";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemInvokedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NavigationViewItemInvokedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewItemInvokedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemSeparator>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NavigationViewItemSeparator";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewItemSeparator";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NavigationViewPaneClosingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NavigationViewPaneClosingEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewPaneClosingEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NavigationViewSelectionChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NavigationViewSelectionChangedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewSelectionChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NavigationViewTemplateSettings>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NavigationViewTemplateSettings";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewTemplateSettings";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NonVirtualizingLayout>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NonVirtualizingLayout";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NonVirtualizingLayout";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NonVirtualizingLayoutContext>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NonVirtualizingLayoutContext";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NonVirtualizingLayoutContext";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NumberBox>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NumberBox";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NumberBox";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::NumberBoxValueChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.NumberBoxValueChangedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "NumberBoxValueChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ParallaxView>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ParallaxView";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ParallaxView";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::PathIconSource>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.PathIconSource";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "PathIconSource";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::PersonPicture>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.PersonPicture";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "PersonPicture";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::PersonPictureTemplateSettings>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.PersonPictureTemplateSettings";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "PersonPictureTemplateSettings";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::PipsPager>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.PipsPager";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "PipsPager";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::PipsPagerSelectedIndexChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.PipsPagerSelectedIndexChangedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "PipsPagerSelectedIndexChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::PipsPagerTemplateSettings>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.PipsPagerTemplateSettings";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "PipsPagerTemplateSettings";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ProgressBar>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ProgressBar";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ProgressBar";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ProgressBarTemplateSettings>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ProgressBarTemplateSettings";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ProgressBarTemplateSettings";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ProgressRing>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ProgressRing";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ProgressRing";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ProgressRingTemplateSettings>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ProgressRingTemplateSettings";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ProgressRingTemplateSettings";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::RadioButtons>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.RadioButtons";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "RadioButtons";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::RadioMenuFlyoutItem>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.RadioMenuFlyoutItem";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "RadioMenuFlyoutItem";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::RatingControl>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.RatingControl";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "RatingControl";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::RatingItemFontInfo>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.RatingItemFontInfo";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "RatingItemFontInfo";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::RatingItemImageInfo>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.RatingItemImageInfo";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "RatingItemImageInfo";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::RatingItemInfo>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.RatingItemInfo";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "RatingItemInfo";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::RefreshContainer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.RefreshContainer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "RefreshContainer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::RefreshInteractionRatioChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.RefreshInteractionRatioChangedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "RefreshInteractionRatioChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::RefreshRequestedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.RefreshRequestedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "RefreshRequestedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::RefreshStateChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.RefreshStateChangedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "RefreshStateChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::RefreshVisualizer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.RefreshVisualizer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "RefreshVisualizer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::RevealListViewItemPresenter>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.RevealListViewItemPresenter";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "RevealListViewItemPresenter";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::SplitButton>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.SplitButton";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "SplitButton";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::SplitButtonClickEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.SplitButtonClickEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "SplitButtonClickEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::StackLayout>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.StackLayout";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "StackLayout";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::SwipeControl>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.SwipeControl";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "SwipeControl";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::SwipeItem>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.SwipeItem";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "SwipeItem";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::SwipeItemInvokedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.SwipeItemInvokedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "SwipeItemInvokedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::SwipeItems>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.SwipeItems";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "SwipeItems";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::SymbolIconSource>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.SymbolIconSource";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "SymbolIconSource";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TabView>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TabView";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TabView";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TabViewItem>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TabViewItem";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TabViewItem";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TabViewItemTemplateSettings>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TabViewItemTemplateSettings";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TabViewItemTemplateSettings";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TabViewTabCloseRequestedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TabViewTabCloseRequestedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TabViewTabCloseRequestedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TabViewTabDragCompletedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TabViewTabDragCompletedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TabViewTabDragCompletedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TabViewTabDragStartingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TabViewTabDragStartingEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TabViewTabDragStartingEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TabViewTabDroppedOutsideEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TabViewTabDroppedOutsideEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TabViewTabDroppedOutsideEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TeachingTip>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TeachingTip";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TeachingTip";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TeachingTipClosedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TeachingTipClosedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TeachingTipClosedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TeachingTipClosingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TeachingTipClosingEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TeachingTipClosingEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TeachingTipTemplateSettings>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TeachingTipTemplateSettings";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TeachingTipTemplateSettings";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TextCommandBarFlyout>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TextCommandBarFlyout";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TextCommandBarFlyout";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ToggleSplitButton>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ToggleSplitButton";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ToggleSplitButton";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::ToggleSplitButtonIsCheckedChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.ToggleSplitButtonIsCheckedChangedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "ToggleSplitButtonIsCheckedChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TreeView>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TreeView";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TreeView";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TreeViewCollapsedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TreeViewCollapsedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TreeViewCollapsedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TreeViewDragItemsCompletedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TreeViewDragItemsCompletedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TreeViewDragItemsCompletedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TreeViewDragItemsStartingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TreeViewDragItemsStartingEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TreeViewDragItemsStartingEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TreeViewExpandingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TreeViewExpandingEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TreeViewExpandingEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TreeViewItem>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TreeViewItem";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TreeViewItem";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TreeViewItemInvokedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TreeViewItemInvokedEventArgs";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TreeViewItemInvokedEventArgs";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TreeViewItemTemplateSettings>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TreeViewItemTemplateSettings";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TreeViewItemTemplateSettings";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TreeViewList>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TreeViewList";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TreeViewList";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TreeViewNode>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TreeViewNode";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TreeViewNode";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::TwoPaneView>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.TwoPaneView";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "TwoPaneView";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::UniformGridLayout>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.UniformGridLayout";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "UniformGridLayout";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::VirtualizingLayout>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.VirtualizingLayout";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "VirtualizingLayout";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::VirtualizingLayoutContext>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.VirtualizingLayoutContext";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "VirtualizingLayoutContext";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::WebView2>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.WebView2";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "WebView2";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::XamlControlsResources>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls.XamlControlsResources";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "XamlControlsResources";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisual>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls._IAnimatedVisual";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "_IAnimatedVisual";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisual2>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls._IAnimatedVisual2";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "_IAnimatedVisual2";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls._IAnimatedVisualSource";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "_IAnimatedVisualSource";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource2>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls._IAnimatedVisualSource2";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "_IAnimatedVisualSource2";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource3>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls._IAnimatedVisualSource3";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "_IAnimatedVisualSource3";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::IDynamicAnimatedVisualSource>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls._IDynamicAnimatedVisualSource";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "_IDynamicAnimatedVisualSource";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Controls::IKeyIndexMapping>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.controls._IKeyIndexMapping";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.controls";
        static constexpr const char* type_name = "_IKeyIndexMapping";
    };
}

#if __has_include("py.Microsoft.Web.WebView2.Core.h")
#include "py.Microsoft.Web.WebView2.Core.h"
#endif

#if __has_include("py.Windows.ApplicationModel.Contacts.h")
#include "py.Windows.ApplicationModel.Contacts.h"
#endif

#if __has_include("py.Windows.ApplicationModel.DataTransfer.h")
#include "py.Windows.ApplicationModel.DataTransfer.h"
#endif

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Foundation.Numerics.h")
#include "py.Windows.Foundation.Numerics.h"
#endif

#if __has_include("py.Windows.Globalization.NumberFormatting.h")
#include "py.Windows.Globalization.NumberFormatting.h"
#endif

#if __has_include("py.Windows.UI.h")
#include "py.Windows.UI.h"
#endif

#if __has_include("py.Windows.UI.Composition.h")
#include "py.Windows.UI.Composition.h"
#endif

#if __has_include("py.Windows.UI.Text.h")
#include "py.Windows.UI.Text.h"
#endif

#if __has_include("py.Windows.UI.Xaml.h")
#include "py.Windows.UI.Xaml.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Controls.h")
#include "py.Windows.UI.Xaml.Controls.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Controls.Primitives.h")
#include "py.Windows.UI.Xaml.Controls.Primitives.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Input.h")
#include "py.Windows.UI.Xaml.Input.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Interop.h")
#include "py.Windows.UI.Xaml.Interop.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Media.h")
#include "py.Windows.UI.Xaml.Media.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Media.Animation.h")
#include "py.Windows.UI.Xaml.Media.Animation.h"
#endif

namespace py::impl::Microsoft::UI::Xaml::Controls
{
}

namespace py::wrapper::Microsoft::UI::Xaml::Controls
{
    using AnimatedIcon = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::AnimatedIcon>;
    using AnimatedIconSource = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::AnimatedIconSource>;
    using AnimatedVisualPlayer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::AnimatedVisualPlayer>;
    using BackdropMaterial = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::BackdropMaterial>;
    using BitmapIconSource = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::BitmapIconSource>;
    using BreadcrumbBar = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::BreadcrumbBar>;
    using BreadcrumbBarItem = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::BreadcrumbBarItem>;
    using BreadcrumbBarItemClickedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::BreadcrumbBarItemClickedEventArgs>;
    using ColorChangedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ColorChangedEventArgs>;
    using ColorPicker = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ColorPicker>;
    using CommandBarFlyout = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::CommandBarFlyout>;
    using CoreWebView2InitializedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::CoreWebView2InitializedEventArgs>;
    using DropDownButton = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::DropDownButton>;
    using ElementFactory = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ElementFactory>;
    using ElementFactoryGetArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ElementFactoryGetArgs>;
    using ElementFactoryRecycleArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ElementFactoryRecycleArgs>;
    using Expander = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::Expander>;
    using ExpanderCollapsedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ExpanderCollapsedEventArgs>;
    using ExpanderExpandingEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ExpanderExpandingEventArgs>;
    using ExpanderTemplateSettings = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ExpanderTemplateSettings>;
    using FontIconSource = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::FontIconSource>;
    using IconSource = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::IconSource>;
    using ImageIcon = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ImageIcon>;
    using ImageIconSource = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ImageIconSource>;
    using InfoBadge = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::InfoBadge>;
    using InfoBadgeTemplateSettings = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::InfoBadgeTemplateSettings>;
    using InfoBar = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::InfoBar>;
    using InfoBarClosedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::InfoBarClosedEventArgs>;
    using InfoBarClosingEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::InfoBarClosingEventArgs>;
    using InfoBarTemplateSettings = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::InfoBarTemplateSettings>;
    using ItemsRepeater = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeater>;
    using ItemsRepeaterElementClearingEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterElementClearingEventArgs>;
    using ItemsRepeaterElementIndexChangedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterElementIndexChangedEventArgs>;
    using ItemsRepeaterElementPreparedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterElementPreparedEventArgs>;
    using ItemsRepeaterScrollHost = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterScrollHost>;
    using ItemsSourceView = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ItemsSourceView>;
    using Layout = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::Layout>;
    using LayoutContext = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::LayoutContext>;
    using MenuBar = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::MenuBar>;
    using MenuBarItem = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::MenuBarItem>;
    using MenuBarItemFlyout = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::MenuBarItemFlyout>;
    using NavigationView = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::NavigationView>;
    using NavigationViewBackRequestedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::NavigationViewBackRequestedEventArgs>;
    using NavigationViewDisplayModeChangedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::NavigationViewDisplayModeChangedEventArgs>;
    using NavigationViewItem = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItem>;
    using NavigationViewItemBase = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemBase>;
    using NavigationViewItemCollapsedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemCollapsedEventArgs>;
    using NavigationViewItemExpandingEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemExpandingEventArgs>;
    using NavigationViewItemHeader = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemHeader>;
    using NavigationViewItemInvokedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemInvokedEventArgs>;
    using NavigationViewItemSeparator = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemSeparator>;
    using NavigationViewPaneClosingEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::NavigationViewPaneClosingEventArgs>;
    using NavigationViewSelectionChangedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::NavigationViewSelectionChangedEventArgs>;
    using NavigationViewTemplateSettings = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::NavigationViewTemplateSettings>;
    using NonVirtualizingLayout = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::NonVirtualizingLayout>;
    using NonVirtualizingLayoutContext = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::NonVirtualizingLayoutContext>;
    using NumberBox = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::NumberBox>;
    using NumberBoxValueChangedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::NumberBoxValueChangedEventArgs>;
    using ParallaxView = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ParallaxView>;
    using PathIconSource = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::PathIconSource>;
    using PersonPicture = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::PersonPicture>;
    using PersonPictureTemplateSettings = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::PersonPictureTemplateSettings>;
    using PipsPager = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::PipsPager>;
    using PipsPagerSelectedIndexChangedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::PipsPagerSelectedIndexChangedEventArgs>;
    using PipsPagerTemplateSettings = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::PipsPagerTemplateSettings>;
    using ProgressBar = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ProgressBar>;
    using ProgressBarTemplateSettings = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ProgressBarTemplateSettings>;
    using ProgressRing = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ProgressRing>;
    using ProgressRingTemplateSettings = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ProgressRingTemplateSettings>;
    using RadioButtons = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::RadioButtons>;
    using RadioMenuFlyoutItem = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::RadioMenuFlyoutItem>;
    using RatingControl = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::RatingControl>;
    using RatingItemFontInfo = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::RatingItemFontInfo>;
    using RatingItemImageInfo = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::RatingItemImageInfo>;
    using RatingItemInfo = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::RatingItemInfo>;
    using RefreshContainer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::RefreshContainer>;
    using RefreshInteractionRatioChangedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::RefreshInteractionRatioChangedEventArgs>;
    using RefreshRequestedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::RefreshRequestedEventArgs>;
    using RefreshStateChangedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::RefreshStateChangedEventArgs>;
    using RefreshVisualizer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::RefreshVisualizer>;
    using RevealListViewItemPresenter = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::RevealListViewItemPresenter>;
    using SplitButton = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::SplitButton>;
    using SplitButtonClickEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::SplitButtonClickEventArgs>;
    using StackLayout = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::StackLayout>;
    using SwipeControl = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::SwipeControl>;
    using SwipeItem = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::SwipeItem>;
    using SwipeItemInvokedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::SwipeItemInvokedEventArgs>;
    using SwipeItems = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::SwipeItems>;
    using SymbolIconSource = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::SymbolIconSource>;
    using TabView = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TabView>;
    using TabViewItem = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TabViewItem>;
    using TabViewItemTemplateSettings = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TabViewItemTemplateSettings>;
    using TabViewTabCloseRequestedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TabViewTabCloseRequestedEventArgs>;
    using TabViewTabDragCompletedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TabViewTabDragCompletedEventArgs>;
    using TabViewTabDragStartingEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TabViewTabDragStartingEventArgs>;
    using TabViewTabDroppedOutsideEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TabViewTabDroppedOutsideEventArgs>;
    using TeachingTip = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TeachingTip>;
    using TeachingTipClosedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TeachingTipClosedEventArgs>;
    using TeachingTipClosingEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TeachingTipClosingEventArgs>;
    using TeachingTipTemplateSettings = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TeachingTipTemplateSettings>;
    using TextCommandBarFlyout = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TextCommandBarFlyout>;
    using ToggleSplitButton = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ToggleSplitButton>;
    using ToggleSplitButtonIsCheckedChangedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::ToggleSplitButtonIsCheckedChangedEventArgs>;
    using TreeView = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TreeView>;
    using TreeViewCollapsedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TreeViewCollapsedEventArgs>;
    using TreeViewDragItemsCompletedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TreeViewDragItemsCompletedEventArgs>;
    using TreeViewDragItemsStartingEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TreeViewDragItemsStartingEventArgs>;
    using TreeViewExpandingEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TreeViewExpandingEventArgs>;
    using TreeViewItem = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TreeViewItem>;
    using TreeViewItemInvokedEventArgs = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TreeViewItemInvokedEventArgs>;
    using TreeViewItemTemplateSettings = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TreeViewItemTemplateSettings>;
    using TreeViewList = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TreeViewList>;
    using TreeViewNode = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TreeViewNode>;
    using TwoPaneView = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::TwoPaneView>;
    using UniformGridLayout = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::UniformGridLayout>;
    using VirtualizingLayout = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::VirtualizingLayout>;
    using VirtualizingLayoutContext = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::VirtualizingLayoutContext>;
    using WebView2 = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::WebView2>;
    using XamlControlsResources = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::XamlControlsResources>;
    using IAnimatedVisual = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisual>;
    using IAnimatedVisual2 = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisual2>;
    using IAnimatedVisualSource = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource>;
    using IAnimatedVisualSource2 = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource2>;
    using IAnimatedVisualSource3 = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource3>;
    using IDynamicAnimatedVisualSource = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::IDynamicAnimatedVisualSource>;
    using IKeyIndexMapping = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Controls::IKeyIndexMapping>;
}

namespace py
{
}
