// WARNING: Please don't edit this file. It was generated by C++/WinRT v2.0.240111.5

#pragma once
#ifndef WINRT_Microsoft_UI_Xaml_Controls_AnimatedVisuals_1_H
#define WINRT_Microsoft_UI_Xaml_Controls_AnimatedVisuals_1_H
#include "winrt/impl/Microsoft.UI.Xaml.Controls.AnimatedVisuals.0.h"
WINRT_EXPORT namespace winrt::Microsoft::UI::Xaml::Controls::AnimatedVisuals
{
}
#endif
