// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.1.0"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.UI.Xaml.Automation.h>
#include <winrt/Windows.UI.Xaml.Automation.Peers.h>
#include <winrt/Microsoft.UI.Xaml.Controls.h>
#include <winrt/Microsoft.UI.Xaml.Controls.Primitives.h>

#include <winrt/Microsoft.UI.Xaml.Automation.Peers.h>

namespace py::proj::Microsoft::UI::Xaml::Automation::Peers
{
}

namespace py
{

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::AnimatedVisualPlayerAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.AnimatedVisualPlayerAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "AnimatedVisualPlayerAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::BreadcrumbBarItemAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.BreadcrumbBarItemAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "BreadcrumbBarItemAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::ColorPickerSliderAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.ColorPickerSliderAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "ColorPickerSliderAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::ColorSpectrumAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.ColorSpectrumAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "ColorSpectrumAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::DropDownButtonAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.DropDownButtonAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "DropDownButtonAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::ExpanderAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.ExpanderAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "ExpanderAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::InfoBarAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.InfoBarAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "InfoBarAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::MenuBarAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.MenuBarAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "MenuBarAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::MenuBarItemAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.MenuBarItemAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "MenuBarItemAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::NavigationViewAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.NavigationViewAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "NavigationViewAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::NavigationViewItemAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.NavigationViewItemAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "NavigationViewItemAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::NumberBoxAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.NumberBoxAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "NumberBoxAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::PersonPictureAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.PersonPictureAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "PersonPictureAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::PipsPagerAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.PipsPagerAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "PipsPagerAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::ProgressBarAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.ProgressBarAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "ProgressBarAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::ProgressRingAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.ProgressRingAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "ProgressRingAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::RadioButtonsAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.RadioButtonsAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "RadioButtonsAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::RatingControlAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.RatingControlAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "RatingControlAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::RepeaterAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.RepeaterAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "RepeaterAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::SplitButtonAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.SplitButtonAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "SplitButtonAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::TabViewAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.TabViewAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "TabViewAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::TabViewItemAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.TabViewItemAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "TabViewItemAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::TeachingTipAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.TeachingTipAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "TeachingTipAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::ToggleSplitButtonAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.ToggleSplitButtonAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "ToggleSplitButtonAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::TreeViewItemAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.TreeViewItemAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "TreeViewItemAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::TreeViewItemDataAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.TreeViewItemDataAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "TreeViewItemDataAutomationPeer";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Automation::Peers::TreeViewListAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.automation.peers.TreeViewListAutomationPeer";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.automation.peers";
        static constexpr const char* type_name = "TreeViewListAutomationPeer";
    };
}

#if __has_include("py.Windows.UI.Xaml.Automation.h")
#include "py.Windows.UI.Xaml.Automation.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Automation.Peers.h")
#include "py.Windows.UI.Xaml.Automation.Peers.h"
#endif

#if __has_include("py.Microsoft.UI.Xaml.Controls.h")
#include "py.Microsoft.UI.Xaml.Controls.h"
#endif

#if __has_include("py.Microsoft.UI.Xaml.Controls.Primitives.h")
#include "py.Microsoft.UI.Xaml.Controls.Primitives.h"
#endif

namespace py::impl::Microsoft::UI::Xaml::Automation::Peers
{
}

namespace py::wrapper::Microsoft::UI::Xaml::Automation::Peers
{
    using AnimatedVisualPlayerAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::AnimatedVisualPlayerAutomationPeer>;
    using BreadcrumbBarItemAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::BreadcrumbBarItemAutomationPeer>;
    using ColorPickerSliderAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::ColorPickerSliderAutomationPeer>;
    using ColorSpectrumAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::ColorSpectrumAutomationPeer>;
    using DropDownButtonAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::DropDownButtonAutomationPeer>;
    using ExpanderAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::ExpanderAutomationPeer>;
    using InfoBarAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::InfoBarAutomationPeer>;
    using MenuBarAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::MenuBarAutomationPeer>;
    using MenuBarItemAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::MenuBarItemAutomationPeer>;
    using NavigationViewAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::NavigationViewAutomationPeer>;
    using NavigationViewItemAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::NavigationViewItemAutomationPeer>;
    using NumberBoxAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::NumberBoxAutomationPeer>;
    using PersonPictureAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::PersonPictureAutomationPeer>;
    using PipsPagerAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::PipsPagerAutomationPeer>;
    using ProgressBarAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::ProgressBarAutomationPeer>;
    using ProgressRingAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::ProgressRingAutomationPeer>;
    using RadioButtonsAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::RadioButtonsAutomationPeer>;
    using RatingControlAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::RatingControlAutomationPeer>;
    using RepeaterAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::RepeaterAutomationPeer>;
    using SplitButtonAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::SplitButtonAutomationPeer>;
    using TabViewAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::TabViewAutomationPeer>;
    using TabViewItemAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::TabViewItemAutomationPeer>;
    using TeachingTipAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::TeachingTipAutomationPeer>;
    using ToggleSplitButtonAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::ToggleSplitButtonAutomationPeer>;
    using TreeViewItemAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::TreeViewItemAutomationPeer>;
    using TreeViewItemDataAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::TreeViewItemDataAutomationPeer>;
    using TreeViewListAutomationPeer = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Automation::Peers::TreeViewListAutomationPeer>;
}

namespace py
{
}
