// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.1.0"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.UI.h>
#include <winrt/Windows.UI.Composition.h>
#include <winrt/Windows.UI.Xaml.h>
#include <winrt/Windows.UI.Xaml.Media.h>

#include <winrt/Microsoft.UI.Xaml.Media.h>

namespace py::proj::Microsoft::UI::Xaml::Media
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Media::AcrylicBackgroundSource> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Microsoft::UI::Xaml::Media::RevealBrushState> = "i";


    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Media::AcrylicBackgroundSource>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.media.AcrylicBackgroundSource";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.media";
        static constexpr const char* type_name = "AcrylicBackgroundSource";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Media::RevealBrushState>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.media.RevealBrushState";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.media";
        static constexpr const char* type_name = "RevealBrushState";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Media::AcrylicBrush>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.media.AcrylicBrush";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.media";
        static constexpr const char* type_name = "AcrylicBrush";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Media::RadialGradientBrush>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.media.RadialGradientBrush";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.media";
        static constexpr const char* type_name = "RadialGradientBrush";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Media::RevealBackgroundBrush>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.media.RevealBackgroundBrush";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.media";
        static constexpr const char* type_name = "RevealBackgroundBrush";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Media::RevealBorderBrush>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.media.RevealBorderBrush";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.media";
        static constexpr const char* type_name = "RevealBorderBrush";
    };

    template<>
    struct py_type<winrt::Microsoft::UI::Xaml::Media::RevealBrush>
    {
        static constexpr std::string_view qualified_name = "winui2.microsoft.ui.xaml.media.RevealBrush";
        static constexpr const char* module_name = "winui2.microsoft.ui.xaml.media";
        static constexpr const char* type_name = "RevealBrush";
    };
}

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.UI.h")
#include "py.Windows.UI.h"
#endif

#if __has_include("py.Windows.UI.Composition.h")
#include "py.Windows.UI.Composition.h"
#endif

#if __has_include("py.Windows.UI.Xaml.h")
#include "py.Windows.UI.Xaml.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Media.h")
#include "py.Windows.UI.Xaml.Media.h"
#endif

namespace py::impl::Microsoft::UI::Xaml::Media
{
}

namespace py::wrapper::Microsoft::UI::Xaml::Media
{
    using AcrylicBrush = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Media::AcrylicBrush>;
    using RadialGradientBrush = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Media::RadialGradientBrush>;
    using RevealBackgroundBrush = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Media::RevealBackgroundBrush>;
    using RevealBorderBrush = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Media::RevealBorderBrush>;
    using RevealBrush = py::winrt_wrapper<winrt::Microsoft::UI::Xaml::Media::RevealBrush>;
}

namespace py
{
}
