// WARNING: Please don't edit this file. It was generated by C++/WinRT v2.0.240111.5

#pragma once
#ifndef WINRT_Microsoft_UI_Xaml_Controls_0_H
#define WINRT_Microsoft_UI_Xaml_Controls_0_H
WINRT_EXPORT namespace winrt::Microsoft::Web::WebView2::Core
{
    struct CoreWebView2;
    struct CoreWebView2NavigationCompletedEventArgs;
    struct CoreWebView2NavigationStartingEventArgs;
    struct CoreWebView2ProcessFailedEventArgs;
    struct CoreWebView2WebMessageReceivedEventArgs;
}
WINRT_EXPORT namespace winrt::Windows::ApplicationModel::Contacts
{
    struct Contact;
}
WINRT_EXPORT namespace winrt::Windows::ApplicationModel::DataTransfer
{
    struct DataPackage;
    enum class DataPackageOperation : uint32_t;
}
WINRT_EXPORT namespace winrt::Windows::Foundation
{
    struct Deferral;
    struct EventRegistrationToken;
    struct HResult;
    struct IAsyncAction;
    template <typename T> struct WINRT_IMPL_EMPTY_BASES IReference;
    struct Point;
    struct Rect;
    struct Size;
    template <typename TSender, typename TResult> struct WINRT_IMPL_EMPTY_BASES TypedEventHandler;
    struct Uri;
}
WINRT_EXPORT namespace winrt::Windows::Foundation::Collections
{
    struct IVectorChangedEventArgs;
}
WINRT_EXPORT namespace winrt::Windows::Foundation::Numerics
{
}
WINRT_EXPORT namespace winrt::Windows::Globalization::NumberFormatting
{
    struct INumberFormatter2;
}
WINRT_EXPORT namespace winrt::Windows::UI
{
    struct Color;
}
WINRT_EXPORT namespace winrt::Windows::UI::Composition
{
    struct CompositionObject;
    struct Compositor;
    struct Visual;
}
WINRT_EXPORT namespace winrt::Windows::UI::Text
{
    enum class FontStyle : int32_t;
    struct FontWeight;
}
WINRT_EXPORT namespace winrt::Windows::UI::Xaml
{
    struct CornerRadius;
    struct DataTemplate;
    struct DependencyObject;
    struct DependencyProperty;
    struct DragEventHandler;
    struct FrameworkElement;
    struct GridLength;
    struct Style;
    enum class TextReadingOrder : int32_t;
    struct Thickness;
    struct UIElement;
    enum class Visibility : int32_t;
}
WINRT_EXPORT namespace winrt::Windows::UI::Xaml::Controls
{
    struct AutoSuggestBox;
    struct Control;
    struct DataTemplateSelector;
    struct IconElement;
    struct MenuFlyoutSubItem;
    enum class Orientation : int32_t;
    struct ScrollViewer;
    struct SelectionChangedEventHandler;
    struct StyleSelector;
    enum class Symbol : int32_t;
}
WINRT_EXPORT namespace winrt::Windows::UI::Xaml::Controls::Primitives
{
    struct ButtonBase;
    struct FlyoutBase;
}
WINRT_EXPORT namespace winrt::Windows::UI::Xaml::Input
{
    struct ICommand;
}
WINRT_EXPORT namespace winrt::Windows::UI::Xaml::Interop
{
    struct NotifyCollectionChangedEventArgs;
}
WINRT_EXPORT namespace winrt::Windows::UI::Xaml::Media
{
    struct Brush;
    struct FontFamily;
    struct Geometry;
    struct ImageBrush;
    struct ImageSource;
    struct RectangleGeometry;
    struct SolidColorBrush;
    enum class Stretch : int32_t;
}
WINRT_EXPORT namespace winrt::Windows::UI::Xaml::Media::Animation
{
    struct NavigationTransitionInfo;
    struct TransitionCollection;
}
WINRT_EXPORT namespace winrt::Microsoft::UI::Xaml::Controls
{
    enum class ColorPickerHsvChannel : int32_t
    {
        Hue = 0,
        Saturation = 1,
        Value = 2,
        Alpha = 3,
    };
    enum class ColorSpectrumComponents : int32_t
    {
        HueValue = 0,
        ValueHue = 1,
        HueSaturation = 2,
        SaturationHue = 3,
        SaturationValue = 4,
        ValueSaturation = 5,
    };
    enum class ColorSpectrumShape : int32_t
    {
        Box = 0,
        Ring = 1,
    };
    enum class ControlsResourcesVersion : int32_t
    {
        Version1 = 1,
        Version2 = 2,
    };
    enum class ElementRealizationOptions : uint32_t
    {
        None = 0,
        ForceCreate = 0x1,
        SuppressAutoRecycle = 0x2,
    };
    enum class ExpandDirection : int32_t
    {
        Down = 0,
        Up = 1,
    };
    enum class InfoBarCloseReason : int32_t
    {
        CloseButton = 0,
        Programmatic = 1,
    };
    enum class InfoBarSeverity : int32_t
    {
        Informational = 0,
        Success = 1,
        Warning = 2,
        Error = 3,
    };
    enum class NavigationViewBackButtonVisible : int32_t
    {
        Collapsed = 0,
        Visible = 1,
        Auto = 2,
    };
    enum class NavigationViewDisplayMode : int32_t
    {
        Minimal = 0,
        Compact = 1,
        Expanded = 2,
    };
    enum class NavigationViewOverflowLabelMode : int32_t
    {
        MoreLabel = 0,
        NoLabel = 1,
    };
    enum class NavigationViewPaneDisplayMode : int32_t
    {
        Auto = 0,
        Left = 1,
        Top = 2,
        LeftCompact = 3,
        LeftMinimal = 4,
    };
    enum class NavigationViewSelectionFollowsFocus : int32_t
    {
        Disabled = 0,
        Enabled = 1,
    };
    enum class NavigationViewShoulderNavigationEnabled : int32_t
    {
        WhenSelectionFollowsFocus = 0,
        Always = 1,
        Never = 2,
    };
    enum class NumberBoxSpinButtonPlacementMode : int32_t
    {
        Hidden = 0,
        Compact = 1,
        Inline = 2,
    };
    enum class NumberBoxValidationMode : int32_t
    {
        InvalidInputOverwritten = 0,
        Disabled = 1,
    };
    enum class ParallaxSourceOffsetKind : int32_t
    {
        Absolute = 0,
        Relative = 1,
    };
    enum class PipsPagerButtonVisibility : int32_t
    {
        Visible = 0,
        VisibleOnPointerOver = 1,
        Collapsed = 2,
    };
    enum class PlayerAnimationOptimization : int32_t
    {
        Latency = 0,
        Resources = 1,
    };
    enum class RefreshPullDirection : int32_t
    {
        LeftToRight = 0,
        TopToBottom = 1,
        RightToLeft = 2,
        BottomToTop = 3,
    };
    enum class RefreshVisualizerOrientation : int32_t
    {
        Auto = 0,
        Normal = 1,
        Rotate90DegreesCounterclockwise = 2,
        Rotate270DegreesCounterclockwise = 3,
    };
    enum class RefreshVisualizerState : int32_t
    {
        Idle = 0,
        Peeking = 1,
        Interacting = 2,
        Pending = 3,
        Refreshing = 4,
    };
    enum class SwipeBehaviorOnInvoked : int32_t
    {
        Auto = 0,
        Close = 1,
        RemainOpen = 2,
    };
    enum class SwipeMode : int32_t
    {
        Reveal = 0,
        Execute = 1,
    };
    enum class TabViewCloseButtonOverlayMode : int32_t
    {
        Auto = 0,
        OnPointerOver = 1,
        Always = 2,
    };
    enum class TabViewWidthMode : int32_t
    {
        Equal = 0,
        SizeToContent = 1,
        Compact = 2,
    };
    enum class TeachingTipCloseReason : int32_t
    {
        CloseButton = 0,
        LightDismiss = 1,
        Programmatic = 2,
    };
    enum class TeachingTipHeroContentPlacementMode : int32_t
    {
        Auto = 0,
        Top = 1,
        Bottom = 2,
    };
    enum class TeachingTipPlacementMode : int32_t
    {
        Auto = 0,
        Top = 1,
        Bottom = 2,
        Left = 3,
        Right = 4,
        TopRight = 5,
        TopLeft = 6,
        BottomRight = 7,
        BottomLeft = 8,
        LeftTop = 9,
        LeftBottom = 10,
        RightTop = 11,
        RightBottom = 12,
        Center = 13,
    };
    enum class TeachingTipTailVisibility : int32_t
    {
        Auto = 0,
        Visible = 1,
        Collapsed = 2,
    };
    enum class TreeViewSelectionMode : int32_t
    {
        None = 0,
        Single = 1,
        Multiple = 2,
    };
    enum class TwoPaneViewMode : int32_t
    {
        SinglePane = 0,
        Wide = 1,
        Tall = 2,
    };
    enum class TwoPaneViewPriority : int32_t
    {
        Pane1 = 0,
        Pane2 = 1,
    };
    enum class TwoPaneViewTallModeConfiguration : int32_t
    {
        SinglePane = 0,
        TopBottom = 1,
        BottomTop = 2,
    };
    enum class TwoPaneViewWideModeConfiguration : int32_t
    {
        SinglePane = 0,
        LeftRight = 1,
        RightLeft = 2,
    };
    enum class UniformGridLayoutItemsJustification : int32_t
    {
        Start = 0,
        Center = 1,
        End = 2,
        SpaceAround = 3,
        SpaceBetween = 4,
        SpaceEvenly = 5,
    };
    enum class UniformGridLayoutItemsStretch : int32_t
    {
        None = 0,
        Fill = 1,
        Uniform = 2,
    };
    struct IAnimatedIcon;
    struct IAnimatedIconFactory;
    struct IAnimatedIconSource;
    struct IAnimatedIconSourceFactory;
    struct IAnimatedIconSourceStatics;
    struct IAnimatedIconStatics;
    struct IAnimatedVisual;
    struct IAnimatedVisual2;
    struct IAnimatedVisualPlayer;
    struct IAnimatedVisualPlayer2;
    struct IAnimatedVisualPlayerFactory;
    struct IAnimatedVisualPlayerStatics;
    struct IAnimatedVisualPlayerStatics2;
    struct IAnimatedVisualSource;
    struct IAnimatedVisualSource2;
    struct IAnimatedVisualSource3;
    struct IBackdropMaterial;
    struct IBackdropMaterialFactory;
    struct IBackdropMaterialStatics;
    struct IBitmapIconSource;
    struct IBitmapIconSourceFactory;
    struct IBitmapIconSourceStatics;
    struct IBreadcrumbBar;
    struct IBreadcrumbBarFactory;
    struct IBreadcrumbBarItem;
    struct IBreadcrumbBarItemClickedEventArgs;
    struct IBreadcrumbBarItemFactory;
    struct IBreadcrumbBarStatics;
    struct IColorChangedEventArgs;
    struct IColorPicker;
    struct IColorPicker2;
    struct IColorPickerFactory;
    struct IColorPickerStatics;
    struct IColorPickerStatics2;
    struct ICommandBarFlyout;
    struct ICommandBarFlyout2;
    struct ICommandBarFlyoutFactory;
    struct ICoreWebView2InitializedEventArgs;
    struct IDropDownButton;
    struct IDropDownButtonFactory;
    struct IDynamicAnimatedVisualSource;
    struct IElementFactory;
    struct IElementFactoryFactory;
    struct IElementFactoryGetArgs;
    struct IElementFactoryOverrides;
    struct IElementFactoryRecycleArgs;
    struct IExpander;
    struct IExpanderCollapsedEventArgs;
    struct IExpanderExpandingEventArgs;
    struct IExpanderFactory;
    struct IExpanderStatics;
    struct IExpanderTemplateSettings;
    struct IFontIconSource;
    struct IFontIconSourceFactory;
    struct IFontIconSourceStatics;
    struct IIconSource;
    struct IIconSourceFactory;
    struct IIconSourceStatics;
    struct IImageIcon;
    struct IImageIconFactory;
    struct IImageIconSource;
    struct IImageIconSourceFactory;
    struct IImageIconSourceStatics;
    struct IImageIconStatics;
    struct IInfoBadge;
    struct IInfoBadgeFactory;
    struct IInfoBadgeStatics;
    struct IInfoBadgeTemplateSettings;
    struct IInfoBadgeTemplateSettingsFactory;
    struct IInfoBadgeTemplateSettingsStatics;
    struct IInfoBar;
    struct IInfoBarClosedEventArgs;
    struct IInfoBarClosedEventArgsFactory;
    struct IInfoBarClosingEventArgs;
    struct IInfoBarClosingEventArgsFactory;
    struct IInfoBarFactory;
    struct IInfoBarStatics;
    struct IInfoBarTemplateSettings;
    struct IInfoBarTemplateSettingsFactory;
    struct IInfoBarTemplateSettingsStatics;
    struct IItemsRepeater;
    struct IItemsRepeaterElementClearingEventArgs;
    struct IItemsRepeaterElementIndexChangedEventArgs;
    struct IItemsRepeaterElementPreparedEventArgs;
    struct IItemsRepeaterFactory;
    struct IItemsRepeaterScrollHost;
    struct IItemsRepeaterStatics;
    struct IItemsSourceView;
    struct IItemsSourceViewFactory;
    struct IKeyIndexMapping;
    struct ILayout;
    struct ILayoutContext;
    struct ILayoutContextFactory;
    struct ILayoutContextOverrides;
    struct ILayoutFactory;
    struct ILayoutProtected;
    struct IMenuBar;
    struct IMenuBarFactory;
    struct IMenuBarItem;
    struct IMenuBarItemFactory;
    struct IMenuBarItemFlyout;
    struct IMenuBarItemFlyoutFactory;
    struct IMenuBarItemStatics;
    struct IMenuBarStatics;
    struct INavigationView;
    struct INavigationView2;
    struct INavigationViewBackRequestedEventArgs;
    struct INavigationViewDisplayModeChangedEventArgs;
    struct INavigationViewFactory;
    struct INavigationViewItem;
    struct INavigationViewItem2;
    struct INavigationViewItem3;
    struct INavigationViewItemBase;
    struct INavigationViewItemBase2;
    struct INavigationViewItemBaseFactory;
    struct INavigationViewItemBaseStatics;
    struct INavigationViewItemCollapsedEventArgs;
    struct INavigationViewItemExpandingEventArgs;
    struct INavigationViewItemFactory;
    struct INavigationViewItemHeader;
    struct INavigationViewItemHeaderFactory;
    struct INavigationViewItemInvokedEventArgs;
    struct INavigationViewItemInvokedEventArgs2;
    struct INavigationViewItemSeparator;
    struct INavigationViewItemSeparatorFactory;
    struct INavigationViewItemStatics;
    struct INavigationViewItemStatics2;
    struct INavigationViewItemStatics3;
    struct INavigationViewPaneClosingEventArgs;
    struct INavigationViewSelectionChangedEventArgs;
    struct INavigationViewSelectionChangedEventArgs2;
    struct INavigationViewStatics;
    struct INavigationViewStatics2;
    struct INavigationViewTemplateSettings;
    struct INavigationViewTemplateSettings2;
    struct INavigationViewTemplateSettingsFactory;
    struct INavigationViewTemplateSettingsStatics;
    struct INavigationViewTemplateSettingsStatics2;
    struct INonVirtualizingLayout;
    struct INonVirtualizingLayoutContext;
    struct INonVirtualizingLayoutContextFactory;
    struct INonVirtualizingLayoutContextOverrides;
    struct INonVirtualizingLayoutFactory;
    struct INonVirtualizingLayoutOverrides;
    struct INumberBox;
    struct INumberBoxFactory;
    struct INumberBoxStatics;
    struct INumberBoxValueChangedEventArgs;
    struct IParallaxView;
    struct IParallaxViewFactory;
    struct IParallaxViewStatics;
    struct IPathIconSource;
    struct IPathIconSourceFactory;
    struct IPathIconSourceStatics;
    struct IPersonPicture;
    struct IPersonPictureFactory;
    struct IPersonPictureStatics;
    struct IPersonPictureTemplateSettings;
    struct IPipsPager;
    struct IPipsPagerFactory;
    struct IPipsPagerSelectedIndexChangedEventArgs;
    struct IPipsPagerStatics;
    struct IPipsPagerTemplateSettings;
    struct IProgressBar;
    struct IProgressBarFactory;
    struct IProgressBarStatics;
    struct IProgressBarTemplateSettings;
    struct IProgressRing;
    struct IProgressRingFactory;
    struct IProgressRingStatics;
    struct IProgressRingTemplateSettings;
    struct IRadioButtons;
    struct IRadioButtonsFactory;
    struct IRadioButtonsStatics;
    struct IRadioMenuFlyoutItem;
    struct IRadioMenuFlyoutItemFactory;
    struct IRadioMenuFlyoutItemStatics;
    struct IRadioMenuFlyoutItemStatics2;
    struct IRatingControl;
    struct IRatingControlFactory;
    struct IRatingControlStatics;
    struct IRatingItemFontInfo;
    struct IRatingItemFontInfoFactory;
    struct IRatingItemFontInfoStatics;
    struct IRatingItemImageInfo;
    struct IRatingItemImageInfoFactory;
    struct IRatingItemImageInfoStatics;
    struct IRatingItemInfo;
    struct IRatingItemInfoFactory;
    struct IRefreshContainer;
    struct IRefreshContainerFactory;
    struct IRefreshContainerStatics;
    struct IRefreshInteractionRatioChangedEventArgs;
    struct IRefreshRequestedEventArgs;
    struct IRefreshStateChangedEventArgs;
    struct IRefreshVisualizer;
    struct IRefreshVisualizerFactory;
    struct IRefreshVisualizerStatics;
    struct IRevealListViewItemPresenter;
    struct IRevealListViewItemPresenterFactory;
    struct ISplitButton;
    struct ISplitButtonClickEventArgs;
    struct ISplitButtonFactory;
    struct ISplitButtonStatics;
    struct IStackLayout;
    struct IStackLayoutFactory;
    struct IStackLayoutStatics;
    struct ISwipeControl;
    struct ISwipeControlFactory;
    struct ISwipeControlStatics;
    struct ISwipeItem;
    struct ISwipeItemFactory;
    struct ISwipeItemInvokedEventArgs;
    struct ISwipeItemStatics;
    struct ISwipeItems;
    struct ISwipeItemsFactory;
    struct ISwipeItemsStatics;
    struct ISymbolIconSource;
    struct ISymbolIconSourceFactory;
    struct ISymbolIconSourceStatics;
    struct ITabView;
    struct ITabViewFactory;
    struct ITabViewItem;
    struct ITabViewItemFactory;
    struct ITabViewItemStatics;
    struct ITabViewItemTemplateSettings;
    struct ITabViewItemTemplateSettings2;
    struct ITabViewItemTemplateSettingsFactory;
    struct ITabViewItemTemplateSettingsStatics;
    struct ITabViewItemTemplateSettingsStatics2;
    struct ITabViewStatics;
    struct ITabViewTabCloseRequestedEventArgs;
    struct ITabViewTabDragCompletedEventArgs;
    struct ITabViewTabDragStartingEventArgs;
    struct ITabViewTabDroppedOutsideEventArgs;
    struct ITeachingTip;
    struct ITeachingTipClosedEventArgs;
    struct ITeachingTipClosingEventArgs;
    struct ITeachingTipFactory;
    struct ITeachingTipStatics;
    struct ITeachingTipTemplateSettings;
    struct ITeachingTipTemplateSettingsFactory;
    struct ITeachingTipTemplateSettingsStatics;
    struct ITextCommandBarFlyout;
    struct ITextCommandBarFlyoutFactory;
    struct IToggleSplitButton;
    struct IToggleSplitButtonFactory;
    struct IToggleSplitButtonIsCheckedChangedEventArgs;
    struct IToggleSplitButtonStatics;
    struct ITreeView;
    struct ITreeView2;
    struct ITreeViewCollapsedEventArgs;
    struct ITreeViewCollapsedEventArgs2;
    struct ITreeViewDragItemsCompletedEventArgs;
    struct ITreeViewDragItemsCompletedEventArgs2;
    struct ITreeViewDragItemsStartingEventArgs;
    struct ITreeViewExpandingEventArgs;
    struct ITreeViewExpandingEventArgs2;
    struct ITreeViewFactory;
    struct ITreeViewItem;
    struct ITreeViewItem2;
    struct ITreeViewItemFactory;
    struct ITreeViewItemInvokedEventArgs;
    struct ITreeViewItemStatics;
    struct ITreeViewItemStatics2;
    struct ITreeViewItemTemplateSettings;
    struct ITreeViewItemTemplateSettingsFactory;
    struct ITreeViewItemTemplateSettingsStatics;
    struct ITreeViewList;
    struct ITreeViewListFactory;
    struct ITreeViewNode;
    struct ITreeViewNodeFactory;
    struct ITreeViewNodeStatics;
    struct ITreeViewStatics;
    struct ITreeViewStatics2;
    struct ITwoPaneView;
    struct ITwoPaneViewFactory;
    struct ITwoPaneViewStatics;
    struct IUniformGridLayout;
    struct IUniformGridLayoutFactory;
    struct IUniformGridLayoutStatics;
    struct IVirtualizingLayout;
    struct IVirtualizingLayoutContext;
    struct IVirtualizingLayoutContextFactory;
    struct IVirtualizingLayoutContextOverrides;
    struct IVirtualizingLayoutFactory;
    struct IVirtualizingLayoutOverrides;
    struct IWebView2;
    struct IWebView2Factory;
    struct IWebView2Statics;
    struct IXamlControlsResources;
    struct IXamlControlsResources3;
    struct IXamlControlsResourcesStatics;
    struct IXamlControlsResourcesStatics3;
    struct AnimatedIcon;
    struct AnimatedIconSource;
    struct AnimatedVisualPlayer;
    struct BackdropMaterial;
    struct BitmapIconSource;
    struct BreadcrumbBar;
    struct BreadcrumbBarItem;
    struct BreadcrumbBarItemClickedEventArgs;
    struct ColorChangedEventArgs;
    struct ColorPicker;
    struct CommandBarFlyout;
    struct CoreWebView2InitializedEventArgs;
    struct DropDownButton;
    struct ElementFactory;
    struct ElementFactoryGetArgs;
    struct ElementFactoryRecycleArgs;
    struct Expander;
    struct ExpanderCollapsedEventArgs;
    struct ExpanderExpandingEventArgs;
    struct ExpanderTemplateSettings;
    struct FontIconSource;
    struct IconSource;
    struct ImageIcon;
    struct ImageIconSource;
    struct InfoBadge;
    struct InfoBadgeTemplateSettings;
    struct InfoBar;
    struct InfoBarClosedEventArgs;
    struct InfoBarClosingEventArgs;
    struct InfoBarTemplateSettings;
    struct ItemsRepeater;
    struct ItemsRepeaterElementClearingEventArgs;
    struct ItemsRepeaterElementIndexChangedEventArgs;
    struct ItemsRepeaterElementPreparedEventArgs;
    struct ItemsRepeaterScrollHost;
    struct ItemsSourceView;
    struct Layout;
    struct LayoutContext;
    struct MenuBar;
    struct MenuBarItem;
    struct MenuBarItemFlyout;
    struct NavigationView;
    struct NavigationViewBackRequestedEventArgs;
    struct NavigationViewDisplayModeChangedEventArgs;
    struct NavigationViewItem;
    struct NavigationViewItemBase;
    struct NavigationViewItemCollapsedEventArgs;
    struct NavigationViewItemExpandingEventArgs;
    struct NavigationViewItemHeader;
    struct NavigationViewItemInvokedEventArgs;
    struct NavigationViewItemSeparator;
    struct NavigationViewPaneClosingEventArgs;
    struct NavigationViewSelectionChangedEventArgs;
    struct NavigationViewTemplateSettings;
    struct NonVirtualizingLayout;
    struct NonVirtualizingLayoutContext;
    struct NumberBox;
    struct NumberBoxValueChangedEventArgs;
    struct ParallaxView;
    struct PathIconSource;
    struct PersonPicture;
    struct PersonPictureTemplateSettings;
    struct PipsPager;
    struct PipsPagerSelectedIndexChangedEventArgs;
    struct PipsPagerTemplateSettings;
    struct ProgressBar;
    struct ProgressBarTemplateSettings;
    struct ProgressRing;
    struct ProgressRingTemplateSettings;
    struct RadioButtons;
    struct RadioMenuFlyoutItem;
    struct RatingControl;
    struct RatingItemFontInfo;
    struct RatingItemImageInfo;
    struct RatingItemInfo;
    struct RefreshContainer;
    struct RefreshInteractionRatioChangedEventArgs;
    struct RefreshRequestedEventArgs;
    struct RefreshStateChangedEventArgs;
    struct RefreshVisualizer;
    struct RevealListViewItemPresenter;
    struct SplitButton;
    struct SplitButtonClickEventArgs;
    struct StackLayout;
    struct SwipeControl;
    struct SwipeItem;
    struct SwipeItemInvokedEventArgs;
    struct SwipeItems;
    struct SymbolIconSource;
    struct TabView;
    struct TabViewItem;
    struct TabViewItemTemplateSettings;
    struct TabViewTabCloseRequestedEventArgs;
    struct TabViewTabDragCompletedEventArgs;
    struct TabViewTabDragStartingEventArgs;
    struct TabViewTabDroppedOutsideEventArgs;
    struct TeachingTip;
    struct TeachingTipClosedEventArgs;
    struct TeachingTipClosingEventArgs;
    struct TeachingTipTemplateSettings;
    struct TextCommandBarFlyout;
    struct ToggleSplitButton;
    struct ToggleSplitButtonIsCheckedChangedEventArgs;
    struct TreeView;
    struct TreeViewCollapsedEventArgs;
    struct TreeViewDragItemsCompletedEventArgs;
    struct TreeViewDragItemsStartingEventArgs;
    struct TreeViewExpandingEventArgs;
    struct TreeViewItem;
    struct TreeViewItemInvokedEventArgs;
    struct TreeViewItemTemplateSettings;
    struct TreeViewList;
    struct TreeViewNode;
    struct TwoPaneView;
    struct UniformGridLayout;
    struct VirtualizingLayout;
    struct VirtualizingLayoutContext;
    struct WebView2;
    struct XamlControlsResources;
}
namespace winrt::impl
{
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIcon>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconSource>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconSourceFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconSourceStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisual>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisual2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayer>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayer2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayerFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayerStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayerStatics2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource3>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IBackdropMaterial>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IBackdropMaterialFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IBackdropMaterialStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IBitmapIconSource>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IBitmapIconSourceFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IBitmapIconSourceStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBar>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarItem>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarItemClickedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarItemFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IColorChangedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IColorPicker>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IColorPicker2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IColorPickerFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IColorPickerStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IColorPickerStatics2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ICommandBarFlyout>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ICommandBarFlyout2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ICommandBarFlyoutFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ICoreWebView2InitializedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IDropDownButton>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IDropDownButtonFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IDynamicAnimatedVisualSource>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IElementFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IElementFactoryFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IElementFactoryGetArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IElementFactoryOverrides>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IElementFactoryRecycleArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IExpander>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IExpanderCollapsedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IExpanderExpandingEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IExpanderFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IExpanderStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IExpanderTemplateSettings>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IFontIconSource>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IFontIconSourceFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IFontIconSourceStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IIconSource>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IIconSourceFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IIconSourceStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IImageIcon>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IImageIconFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IImageIconSource>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IImageIconSourceFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IImageIconSourceStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IImageIconStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IInfoBadge>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeTemplateSettings>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeTemplateSettingsFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeTemplateSettingsStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IInfoBar>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosedEventArgsFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosingEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosingEventArgsFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IInfoBarFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IInfoBarStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IInfoBarTemplateSettings>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IInfoBarTemplateSettingsFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IInfoBarTemplateSettingsStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeater>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterElementClearingEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterElementIndexChangedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterElementPreparedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterScrollHost>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IItemsSourceView>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IItemsSourceViewFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IKeyIndexMapping>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ILayout>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ILayoutContext>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ILayoutContextFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ILayoutContextOverrides>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ILayoutFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ILayoutProtected>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IMenuBar>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IMenuBarFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItem>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItemFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItemFlyout>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItemFlyoutFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItemStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IMenuBarStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationView>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationView2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewBackRequestedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewDisplayModeChangedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItem>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItem2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItem3>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemBase>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemBase2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemBaseFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemBaseStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemCollapsedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemExpandingEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemHeader>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemHeaderFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemInvokedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemInvokedEventArgs2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemSeparator>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemSeparatorFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemStatics2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemStatics3>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewPaneClosingEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewSelectionChangedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewSelectionChangedEventArgs2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewStatics2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettings>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettings2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettingsFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettingsStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettingsStatics2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayout>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutContext>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutContextFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutContextOverrides>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutOverrides>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INumberBox>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INumberBoxFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INumberBoxStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::INumberBoxValueChangedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IParallaxView>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IParallaxViewFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IParallaxViewStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IPathIconSource>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IPathIconSourceFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IPathIconSourceStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IPersonPicture>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IPersonPictureFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IPersonPictureStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IPersonPictureTemplateSettings>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IPipsPager>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IPipsPagerFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IPipsPagerSelectedIndexChangedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IPipsPagerStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IPipsPagerTemplateSettings>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IProgressBar>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IProgressBarFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IProgressBarStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IProgressBarTemplateSettings>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IProgressRing>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IProgressRingFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IProgressRingStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IProgressRingTemplateSettings>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRadioButtons>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRadioButtonsFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRadioButtonsStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRadioMenuFlyoutItem>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRadioMenuFlyoutItemFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRadioMenuFlyoutItemStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRadioMenuFlyoutItemStatics2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRatingControl>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRatingControlFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRatingControlStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRatingItemFontInfo>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRatingItemFontInfoFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRatingItemFontInfoStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRatingItemImageInfo>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRatingItemImageInfoFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRatingItemImageInfoStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRatingItemInfo>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRatingItemInfoFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRefreshContainer>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRefreshContainerFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRefreshContainerStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRefreshInteractionRatioChangedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRefreshRequestedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRefreshStateChangedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRefreshVisualizer>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRefreshVisualizerFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRefreshVisualizerStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRevealListViewItemPresenter>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IRevealListViewItemPresenterFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ISplitButton>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ISplitButtonClickEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ISplitButtonFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ISplitButtonStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IStackLayout>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IStackLayoutFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IStackLayoutStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ISwipeControl>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ISwipeControlFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ISwipeControlStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ISwipeItem>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemInvokedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ISwipeItems>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemsFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemsStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ISymbolIconSource>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ISymbolIconSourceFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ISymbolIconSourceStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITabView>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITabViewFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITabViewItem>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettings>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettings2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettingsFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettingsStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettingsStatics2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITabViewStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITabViewTabCloseRequestedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITabViewTabDragCompletedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITabViewTabDragStartingEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITabViewTabDroppedOutsideEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITeachingTip>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipClosedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipClosingEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipTemplateSettings>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipTemplateSettingsFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipTemplateSettingsStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITextCommandBarFlyout>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITextCommandBarFlyoutFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButton>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButtonFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButtonIsCheckedChangedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButtonStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeView>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeView2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewCollapsedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewCollapsedEventArgs2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewDragItemsCompletedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewDragItemsCompletedEventArgs2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewDragItemsStartingEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewExpandingEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewExpandingEventArgs2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItem>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItem2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemInvokedEventArgs>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemStatics2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemTemplateSettings>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemTemplateSettingsFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemTemplateSettingsStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewList>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewListFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewNode>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewNodeFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewNodeStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITreeViewStatics2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITwoPaneView>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITwoPaneViewFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ITwoPaneViewStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IUniformGridLayout>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IUniformGridLayoutFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IUniformGridLayoutStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayout>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutContext>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutContextFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutContextOverrides>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutFactory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutOverrides>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IWebView2>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IWebView2Factory>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IWebView2Statics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IXamlControlsResources>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IXamlControlsResources3>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IXamlControlsResourcesStatics>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IXamlControlsResourcesStatics3>{ using type = interface_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::AnimatedIcon>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::AnimatedIconSource>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::AnimatedVisualPlayer>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::BackdropMaterial>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::BitmapIconSource>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::BreadcrumbBar>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::BreadcrumbBarItem>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::BreadcrumbBarItemClickedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ColorChangedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ColorPicker>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::CommandBarFlyout>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::CoreWebView2InitializedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::DropDownButton>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ElementFactory>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ElementFactoryGetArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ElementFactoryRecycleArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::Expander>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ExpanderCollapsedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ExpanderExpandingEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ExpanderTemplateSettings>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::FontIconSource>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::IconSource>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ImageIcon>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ImageIconSource>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::InfoBadge>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::InfoBadgeTemplateSettings>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::InfoBar>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::InfoBarClosedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::InfoBarClosingEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::InfoBarTemplateSettings>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeater>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterElementClearingEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterElementIndexChangedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterElementPreparedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterScrollHost>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ItemsSourceView>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::Layout>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::LayoutContext>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::MenuBar>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::MenuBarItem>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::MenuBarItemFlyout>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NavigationView>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NavigationViewBackRequestedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NavigationViewDisplayModeChangedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItem>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemBase>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemCollapsedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemExpandingEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemHeader>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemInvokedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemSeparator>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NavigationViewPaneClosingEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NavigationViewSelectionChangedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NavigationViewTemplateSettings>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NonVirtualizingLayout>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NonVirtualizingLayoutContext>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NumberBox>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NumberBoxValueChangedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ParallaxView>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::PathIconSource>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::PersonPicture>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::PersonPictureTemplateSettings>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::PipsPager>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::PipsPagerSelectedIndexChangedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::PipsPagerTemplateSettings>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ProgressBar>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ProgressBarTemplateSettings>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ProgressRing>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ProgressRingTemplateSettings>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::RadioButtons>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::RadioMenuFlyoutItem>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::RatingControl>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::RatingItemFontInfo>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::RatingItemImageInfo>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::RatingItemInfo>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::RefreshContainer>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::RefreshInteractionRatioChangedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::RefreshRequestedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::RefreshStateChangedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::RefreshVisualizer>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::RevealListViewItemPresenter>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::SplitButton>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::SplitButtonClickEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::StackLayout>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::SwipeControl>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::SwipeItem>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::SwipeItemInvokedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::SwipeItems>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::SymbolIconSource>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TabView>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TabViewItem>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TabViewItemTemplateSettings>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TabViewTabCloseRequestedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TabViewTabDragCompletedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TabViewTabDragStartingEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TabViewTabDroppedOutsideEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TeachingTip>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TeachingTipClosedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TeachingTipClosingEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TeachingTipTemplateSettings>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TextCommandBarFlyout>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ToggleSplitButton>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ToggleSplitButtonIsCheckedChangedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TreeView>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TreeViewCollapsedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TreeViewDragItemsCompletedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TreeViewDragItemsStartingEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TreeViewExpandingEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TreeViewItem>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TreeViewItemInvokedEventArgs>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TreeViewItemTemplateSettings>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TreeViewList>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TreeViewNode>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TwoPaneView>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::UniformGridLayout>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::VirtualizingLayout>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::VirtualizingLayoutContext>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::WebView2>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::XamlControlsResources>{ using type = class_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ColorPickerHsvChannel>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ColorSpectrumComponents>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ColorSpectrumShape>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ControlsResourcesVersion>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ElementRealizationOptions>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ExpandDirection>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::InfoBarCloseReason>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::InfoBarSeverity>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NavigationViewBackButtonVisible>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NavigationViewDisplayMode>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NavigationViewOverflowLabelMode>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NavigationViewPaneDisplayMode>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NavigationViewSelectionFollowsFocus>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NavigationViewShoulderNavigationEnabled>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NumberBoxSpinButtonPlacementMode>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::NumberBoxValidationMode>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::ParallaxSourceOffsetKind>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::PipsPagerButtonVisibility>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::PlayerAnimationOptimization>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::RefreshPullDirection>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::RefreshVisualizerOrientation>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::RefreshVisualizerState>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::SwipeBehaviorOnInvoked>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::SwipeMode>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TabViewCloseButtonOverlayMode>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TabViewWidthMode>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TeachingTipCloseReason>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TeachingTipHeroContentPlacementMode>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TeachingTipPlacementMode>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TeachingTipTailVisibility>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TreeViewSelectionMode>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TwoPaneViewMode>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TwoPaneViewPriority>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TwoPaneViewTallModeConfiguration>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::TwoPaneViewWideModeConfiguration>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::UniformGridLayoutItemsJustification>{ using type = enum_category; };
    template <> struct category<winrt::Microsoft::UI::Xaml::Controls::UniformGridLayoutItemsStretch>{ using type = enum_category; };
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::AnimatedIcon> = L"Microsoft.UI.Xaml.Controls.AnimatedIcon";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::AnimatedIconSource> = L"Microsoft.UI.Xaml.Controls.AnimatedIconSource";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::AnimatedVisualPlayer> = L"Microsoft.UI.Xaml.Controls.AnimatedVisualPlayer";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::BackdropMaterial> = L"Microsoft.UI.Xaml.Controls.BackdropMaterial";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::BitmapIconSource> = L"Microsoft.UI.Xaml.Controls.BitmapIconSource";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::BreadcrumbBar> = L"Microsoft.UI.Xaml.Controls.BreadcrumbBar";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::BreadcrumbBarItem> = L"Microsoft.UI.Xaml.Controls.BreadcrumbBarItem";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::BreadcrumbBarItemClickedEventArgs> = L"Microsoft.UI.Xaml.Controls.BreadcrumbBarItemClickedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ColorChangedEventArgs> = L"Microsoft.UI.Xaml.Controls.ColorChangedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ColorPicker> = L"Microsoft.UI.Xaml.Controls.ColorPicker";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::CommandBarFlyout> = L"Microsoft.UI.Xaml.Controls.CommandBarFlyout";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::CoreWebView2InitializedEventArgs> = L"Microsoft.UI.Xaml.Controls.CoreWebView2InitializedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::DropDownButton> = L"Microsoft.UI.Xaml.Controls.DropDownButton";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ElementFactory> = L"Microsoft.UI.Xaml.Controls.ElementFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ElementFactoryGetArgs> = L"Microsoft.UI.Xaml.Controls.ElementFactoryGetArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ElementFactoryRecycleArgs> = L"Microsoft.UI.Xaml.Controls.ElementFactoryRecycleArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::Expander> = L"Microsoft.UI.Xaml.Controls.Expander";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ExpanderCollapsedEventArgs> = L"Microsoft.UI.Xaml.Controls.ExpanderCollapsedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ExpanderExpandingEventArgs> = L"Microsoft.UI.Xaml.Controls.ExpanderExpandingEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ExpanderTemplateSettings> = L"Microsoft.UI.Xaml.Controls.ExpanderTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::FontIconSource> = L"Microsoft.UI.Xaml.Controls.FontIconSource";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IconSource> = L"Microsoft.UI.Xaml.Controls.IconSource";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ImageIcon> = L"Microsoft.UI.Xaml.Controls.ImageIcon";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ImageIconSource> = L"Microsoft.UI.Xaml.Controls.ImageIconSource";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::InfoBadge> = L"Microsoft.UI.Xaml.Controls.InfoBadge";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::InfoBadgeTemplateSettings> = L"Microsoft.UI.Xaml.Controls.InfoBadgeTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::InfoBar> = L"Microsoft.UI.Xaml.Controls.InfoBar";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::InfoBarClosedEventArgs> = L"Microsoft.UI.Xaml.Controls.InfoBarClosedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::InfoBarClosingEventArgs> = L"Microsoft.UI.Xaml.Controls.InfoBarClosingEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::InfoBarTemplateSettings> = L"Microsoft.UI.Xaml.Controls.InfoBarTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeater> = L"Microsoft.UI.Xaml.Controls.ItemsRepeater";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterElementClearingEventArgs> = L"Microsoft.UI.Xaml.Controls.ItemsRepeaterElementClearingEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterElementIndexChangedEventArgs> = L"Microsoft.UI.Xaml.Controls.ItemsRepeaterElementIndexChangedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterElementPreparedEventArgs> = L"Microsoft.UI.Xaml.Controls.ItemsRepeaterElementPreparedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterScrollHost> = L"Microsoft.UI.Xaml.Controls.ItemsRepeaterScrollHost";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ItemsSourceView> = L"Microsoft.UI.Xaml.Controls.ItemsSourceView";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::Layout> = L"Microsoft.UI.Xaml.Controls.Layout";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::LayoutContext> = L"Microsoft.UI.Xaml.Controls.LayoutContext";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::MenuBar> = L"Microsoft.UI.Xaml.Controls.MenuBar";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::MenuBarItem> = L"Microsoft.UI.Xaml.Controls.MenuBarItem";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::MenuBarItemFlyout> = L"Microsoft.UI.Xaml.Controls.MenuBarItemFlyout";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NavigationView> = L"Microsoft.UI.Xaml.Controls.NavigationView";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NavigationViewBackRequestedEventArgs> = L"Microsoft.UI.Xaml.Controls.NavigationViewBackRequestedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NavigationViewDisplayModeChangedEventArgs> = L"Microsoft.UI.Xaml.Controls.NavigationViewDisplayModeChangedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItem> = L"Microsoft.UI.Xaml.Controls.NavigationViewItem";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemBase> = L"Microsoft.UI.Xaml.Controls.NavigationViewItemBase";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemCollapsedEventArgs> = L"Microsoft.UI.Xaml.Controls.NavigationViewItemCollapsedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemExpandingEventArgs> = L"Microsoft.UI.Xaml.Controls.NavigationViewItemExpandingEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemHeader> = L"Microsoft.UI.Xaml.Controls.NavigationViewItemHeader";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemInvokedEventArgs> = L"Microsoft.UI.Xaml.Controls.NavigationViewItemInvokedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemSeparator> = L"Microsoft.UI.Xaml.Controls.NavigationViewItemSeparator";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NavigationViewPaneClosingEventArgs> = L"Microsoft.UI.Xaml.Controls.NavigationViewPaneClosingEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NavigationViewSelectionChangedEventArgs> = L"Microsoft.UI.Xaml.Controls.NavigationViewSelectionChangedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NavigationViewTemplateSettings> = L"Microsoft.UI.Xaml.Controls.NavigationViewTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NonVirtualizingLayout> = L"Microsoft.UI.Xaml.Controls.NonVirtualizingLayout";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NonVirtualizingLayoutContext> = L"Microsoft.UI.Xaml.Controls.NonVirtualizingLayoutContext";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NumberBox> = L"Microsoft.UI.Xaml.Controls.NumberBox";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NumberBoxValueChangedEventArgs> = L"Microsoft.UI.Xaml.Controls.NumberBoxValueChangedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ParallaxView> = L"Microsoft.UI.Xaml.Controls.ParallaxView";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::PathIconSource> = L"Microsoft.UI.Xaml.Controls.PathIconSource";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::PersonPicture> = L"Microsoft.UI.Xaml.Controls.PersonPicture";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::PersonPictureTemplateSettings> = L"Microsoft.UI.Xaml.Controls.PersonPictureTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::PipsPager> = L"Microsoft.UI.Xaml.Controls.PipsPager";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::PipsPagerSelectedIndexChangedEventArgs> = L"Microsoft.UI.Xaml.Controls.PipsPagerSelectedIndexChangedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::PipsPagerTemplateSettings> = L"Microsoft.UI.Xaml.Controls.PipsPagerTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ProgressBar> = L"Microsoft.UI.Xaml.Controls.ProgressBar";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ProgressBarTemplateSettings> = L"Microsoft.UI.Xaml.Controls.ProgressBarTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ProgressRing> = L"Microsoft.UI.Xaml.Controls.ProgressRing";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ProgressRingTemplateSettings> = L"Microsoft.UI.Xaml.Controls.ProgressRingTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::RadioButtons> = L"Microsoft.UI.Xaml.Controls.RadioButtons";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::RadioMenuFlyoutItem> = L"Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::RatingControl> = L"Microsoft.UI.Xaml.Controls.RatingControl";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::RatingItemFontInfo> = L"Microsoft.UI.Xaml.Controls.RatingItemFontInfo";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::RatingItemImageInfo> = L"Microsoft.UI.Xaml.Controls.RatingItemImageInfo";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::RatingItemInfo> = L"Microsoft.UI.Xaml.Controls.RatingItemInfo";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::RefreshContainer> = L"Microsoft.UI.Xaml.Controls.RefreshContainer";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::RefreshInteractionRatioChangedEventArgs> = L"Microsoft.UI.Xaml.Controls.RefreshInteractionRatioChangedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::RefreshRequestedEventArgs> = L"Microsoft.UI.Xaml.Controls.RefreshRequestedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::RefreshStateChangedEventArgs> = L"Microsoft.UI.Xaml.Controls.RefreshStateChangedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::RefreshVisualizer> = L"Microsoft.UI.Xaml.Controls.RefreshVisualizer";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::RevealListViewItemPresenter> = L"Microsoft.UI.Xaml.Controls.RevealListViewItemPresenter";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::SplitButton> = L"Microsoft.UI.Xaml.Controls.SplitButton";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::SplitButtonClickEventArgs> = L"Microsoft.UI.Xaml.Controls.SplitButtonClickEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::StackLayout> = L"Microsoft.UI.Xaml.Controls.StackLayout";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::SwipeControl> = L"Microsoft.UI.Xaml.Controls.SwipeControl";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::SwipeItem> = L"Microsoft.UI.Xaml.Controls.SwipeItem";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::SwipeItemInvokedEventArgs> = L"Microsoft.UI.Xaml.Controls.SwipeItemInvokedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::SwipeItems> = L"Microsoft.UI.Xaml.Controls.SwipeItems";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::SymbolIconSource> = L"Microsoft.UI.Xaml.Controls.SymbolIconSource";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TabView> = L"Microsoft.UI.Xaml.Controls.TabView";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TabViewItem> = L"Microsoft.UI.Xaml.Controls.TabViewItem";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TabViewItemTemplateSettings> = L"Microsoft.UI.Xaml.Controls.TabViewItemTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TabViewTabCloseRequestedEventArgs> = L"Microsoft.UI.Xaml.Controls.TabViewTabCloseRequestedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TabViewTabDragCompletedEventArgs> = L"Microsoft.UI.Xaml.Controls.TabViewTabDragCompletedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TabViewTabDragStartingEventArgs> = L"Microsoft.UI.Xaml.Controls.TabViewTabDragStartingEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TabViewTabDroppedOutsideEventArgs> = L"Microsoft.UI.Xaml.Controls.TabViewTabDroppedOutsideEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TeachingTip> = L"Microsoft.UI.Xaml.Controls.TeachingTip";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TeachingTipClosedEventArgs> = L"Microsoft.UI.Xaml.Controls.TeachingTipClosedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TeachingTipClosingEventArgs> = L"Microsoft.UI.Xaml.Controls.TeachingTipClosingEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TeachingTipTemplateSettings> = L"Microsoft.UI.Xaml.Controls.TeachingTipTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TextCommandBarFlyout> = L"Microsoft.UI.Xaml.Controls.TextCommandBarFlyout";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ToggleSplitButton> = L"Microsoft.UI.Xaml.Controls.ToggleSplitButton";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ToggleSplitButtonIsCheckedChangedEventArgs> = L"Microsoft.UI.Xaml.Controls.ToggleSplitButtonIsCheckedChangedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TreeView> = L"Microsoft.UI.Xaml.Controls.TreeView";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TreeViewCollapsedEventArgs> = L"Microsoft.UI.Xaml.Controls.TreeViewCollapsedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TreeViewDragItemsCompletedEventArgs> = L"Microsoft.UI.Xaml.Controls.TreeViewDragItemsCompletedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TreeViewDragItemsStartingEventArgs> = L"Microsoft.UI.Xaml.Controls.TreeViewDragItemsStartingEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TreeViewExpandingEventArgs> = L"Microsoft.UI.Xaml.Controls.TreeViewExpandingEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TreeViewItem> = L"Microsoft.UI.Xaml.Controls.TreeViewItem";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TreeViewItemInvokedEventArgs> = L"Microsoft.UI.Xaml.Controls.TreeViewItemInvokedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TreeViewItemTemplateSettings> = L"Microsoft.UI.Xaml.Controls.TreeViewItemTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TreeViewList> = L"Microsoft.UI.Xaml.Controls.TreeViewList";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TreeViewNode> = L"Microsoft.UI.Xaml.Controls.TreeViewNode";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TwoPaneView> = L"Microsoft.UI.Xaml.Controls.TwoPaneView";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::UniformGridLayout> = L"Microsoft.UI.Xaml.Controls.UniformGridLayout";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::VirtualizingLayout> = L"Microsoft.UI.Xaml.Controls.VirtualizingLayout";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::VirtualizingLayoutContext> = L"Microsoft.UI.Xaml.Controls.VirtualizingLayoutContext";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::WebView2> = L"Microsoft.UI.Xaml.Controls.WebView2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::XamlControlsResources> = L"Microsoft.UI.Xaml.Controls.XamlControlsResources";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ColorPickerHsvChannel> = L"Microsoft.UI.Xaml.Controls.ColorPickerHsvChannel";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ColorSpectrumComponents> = L"Microsoft.UI.Xaml.Controls.ColorSpectrumComponents";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ColorSpectrumShape> = L"Microsoft.UI.Xaml.Controls.ColorSpectrumShape";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ControlsResourcesVersion> = L"Microsoft.UI.Xaml.Controls.ControlsResourcesVersion";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ElementRealizationOptions> = L"Microsoft.UI.Xaml.Controls.ElementRealizationOptions";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ExpandDirection> = L"Microsoft.UI.Xaml.Controls.ExpandDirection";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::InfoBarCloseReason> = L"Microsoft.UI.Xaml.Controls.InfoBarCloseReason";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::InfoBarSeverity> = L"Microsoft.UI.Xaml.Controls.InfoBarSeverity";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NavigationViewBackButtonVisible> = L"Microsoft.UI.Xaml.Controls.NavigationViewBackButtonVisible";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NavigationViewDisplayMode> = L"Microsoft.UI.Xaml.Controls.NavigationViewDisplayMode";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NavigationViewOverflowLabelMode> = L"Microsoft.UI.Xaml.Controls.NavigationViewOverflowLabelMode";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NavigationViewPaneDisplayMode> = L"Microsoft.UI.Xaml.Controls.NavigationViewPaneDisplayMode";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NavigationViewSelectionFollowsFocus> = L"Microsoft.UI.Xaml.Controls.NavigationViewSelectionFollowsFocus";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NavigationViewShoulderNavigationEnabled> = L"Microsoft.UI.Xaml.Controls.NavigationViewShoulderNavigationEnabled";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NumberBoxSpinButtonPlacementMode> = L"Microsoft.UI.Xaml.Controls.NumberBoxSpinButtonPlacementMode";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::NumberBoxValidationMode> = L"Microsoft.UI.Xaml.Controls.NumberBoxValidationMode";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ParallaxSourceOffsetKind> = L"Microsoft.UI.Xaml.Controls.ParallaxSourceOffsetKind";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::PipsPagerButtonVisibility> = L"Microsoft.UI.Xaml.Controls.PipsPagerButtonVisibility";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::PlayerAnimationOptimization> = L"Microsoft.UI.Xaml.Controls.PlayerAnimationOptimization";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::RefreshPullDirection> = L"Microsoft.UI.Xaml.Controls.RefreshPullDirection";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::RefreshVisualizerOrientation> = L"Microsoft.UI.Xaml.Controls.RefreshVisualizerOrientation";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::RefreshVisualizerState> = L"Microsoft.UI.Xaml.Controls.RefreshVisualizerState";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::SwipeBehaviorOnInvoked> = L"Microsoft.UI.Xaml.Controls.SwipeBehaviorOnInvoked";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::SwipeMode> = L"Microsoft.UI.Xaml.Controls.SwipeMode";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TabViewCloseButtonOverlayMode> = L"Microsoft.UI.Xaml.Controls.TabViewCloseButtonOverlayMode";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TabViewWidthMode> = L"Microsoft.UI.Xaml.Controls.TabViewWidthMode";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TeachingTipCloseReason> = L"Microsoft.UI.Xaml.Controls.TeachingTipCloseReason";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TeachingTipHeroContentPlacementMode> = L"Microsoft.UI.Xaml.Controls.TeachingTipHeroContentPlacementMode";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TeachingTipPlacementMode> = L"Microsoft.UI.Xaml.Controls.TeachingTipPlacementMode";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TeachingTipTailVisibility> = L"Microsoft.UI.Xaml.Controls.TeachingTipTailVisibility";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TreeViewSelectionMode> = L"Microsoft.UI.Xaml.Controls.TreeViewSelectionMode";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TwoPaneViewMode> = L"Microsoft.UI.Xaml.Controls.TwoPaneViewMode";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TwoPaneViewPriority> = L"Microsoft.UI.Xaml.Controls.TwoPaneViewPriority";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TwoPaneViewTallModeConfiguration> = L"Microsoft.UI.Xaml.Controls.TwoPaneViewTallModeConfiguration";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::TwoPaneViewWideModeConfiguration> = L"Microsoft.UI.Xaml.Controls.TwoPaneViewWideModeConfiguration";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::UniformGridLayoutItemsJustification> = L"Microsoft.UI.Xaml.Controls.UniformGridLayoutItemsJustification";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::UniformGridLayoutItemsStretch> = L"Microsoft.UI.Xaml.Controls.UniformGridLayoutItemsStretch";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIcon> = L"Microsoft.UI.Xaml.Controls.IAnimatedIcon";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconFactory> = L"Microsoft.UI.Xaml.Controls.IAnimatedIconFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconSource> = L"Microsoft.UI.Xaml.Controls.IAnimatedIconSource";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconSourceFactory> = L"Microsoft.UI.Xaml.Controls.IAnimatedIconSourceFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconSourceStatics> = L"Microsoft.UI.Xaml.Controls.IAnimatedIconSourceStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconStatics> = L"Microsoft.UI.Xaml.Controls.IAnimatedIconStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisual> = L"Microsoft.UI.Xaml.Controls.IAnimatedVisual";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisual2> = L"Microsoft.UI.Xaml.Controls.IAnimatedVisual2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayer> = L"Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayer2> = L"Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayerFactory> = L"Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayerFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayerStatics> = L"Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayerStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayerStatics2> = L"Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayerStatics2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource> = L"Microsoft.UI.Xaml.Controls.IAnimatedVisualSource";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource2> = L"Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource3> = L"Microsoft.UI.Xaml.Controls.IAnimatedVisualSource3";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IBackdropMaterial> = L"Microsoft.UI.Xaml.Controls.IBackdropMaterial";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IBackdropMaterialFactory> = L"Microsoft.UI.Xaml.Controls.IBackdropMaterialFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IBackdropMaterialStatics> = L"Microsoft.UI.Xaml.Controls.IBackdropMaterialStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IBitmapIconSource> = L"Microsoft.UI.Xaml.Controls.IBitmapIconSource";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IBitmapIconSourceFactory> = L"Microsoft.UI.Xaml.Controls.IBitmapIconSourceFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IBitmapIconSourceStatics> = L"Microsoft.UI.Xaml.Controls.IBitmapIconSourceStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBar> = L"Microsoft.UI.Xaml.Controls.IBreadcrumbBar";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarFactory> = L"Microsoft.UI.Xaml.Controls.IBreadcrumbBarFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarItem> = L"Microsoft.UI.Xaml.Controls.IBreadcrumbBarItem";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarItemClickedEventArgs> = L"Microsoft.UI.Xaml.Controls.IBreadcrumbBarItemClickedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarItemFactory> = L"Microsoft.UI.Xaml.Controls.IBreadcrumbBarItemFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarStatics> = L"Microsoft.UI.Xaml.Controls.IBreadcrumbBarStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IColorChangedEventArgs> = L"Microsoft.UI.Xaml.Controls.IColorChangedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IColorPicker> = L"Microsoft.UI.Xaml.Controls.IColorPicker";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IColorPicker2> = L"Microsoft.UI.Xaml.Controls.IColorPicker2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IColorPickerFactory> = L"Microsoft.UI.Xaml.Controls.IColorPickerFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IColorPickerStatics> = L"Microsoft.UI.Xaml.Controls.IColorPickerStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IColorPickerStatics2> = L"Microsoft.UI.Xaml.Controls.IColorPickerStatics2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ICommandBarFlyout> = L"Microsoft.UI.Xaml.Controls.ICommandBarFlyout";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ICommandBarFlyout2> = L"Microsoft.UI.Xaml.Controls.ICommandBarFlyout2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ICommandBarFlyoutFactory> = L"Microsoft.UI.Xaml.Controls.ICommandBarFlyoutFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ICoreWebView2InitializedEventArgs> = L"Microsoft.UI.Xaml.Controls.ICoreWebView2InitializedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IDropDownButton> = L"Microsoft.UI.Xaml.Controls.IDropDownButton";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IDropDownButtonFactory> = L"Microsoft.UI.Xaml.Controls.IDropDownButtonFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IDynamicAnimatedVisualSource> = L"Microsoft.UI.Xaml.Controls.IDynamicAnimatedVisualSource";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IElementFactory> = L"Microsoft.UI.Xaml.Controls.IElementFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IElementFactoryFactory> = L"Microsoft.UI.Xaml.Controls.IElementFactoryFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IElementFactoryGetArgs> = L"Microsoft.UI.Xaml.Controls.IElementFactoryGetArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IElementFactoryOverrides> = L"Microsoft.UI.Xaml.Controls.IElementFactoryOverrides";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IElementFactoryRecycleArgs> = L"Microsoft.UI.Xaml.Controls.IElementFactoryRecycleArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IExpander> = L"Microsoft.UI.Xaml.Controls.IExpander";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IExpanderCollapsedEventArgs> = L"Microsoft.UI.Xaml.Controls.IExpanderCollapsedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IExpanderExpandingEventArgs> = L"Microsoft.UI.Xaml.Controls.IExpanderExpandingEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IExpanderFactory> = L"Microsoft.UI.Xaml.Controls.IExpanderFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IExpanderStatics> = L"Microsoft.UI.Xaml.Controls.IExpanderStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IExpanderTemplateSettings> = L"Microsoft.UI.Xaml.Controls.IExpanderTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IFontIconSource> = L"Microsoft.UI.Xaml.Controls.IFontIconSource";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IFontIconSourceFactory> = L"Microsoft.UI.Xaml.Controls.IFontIconSourceFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IFontIconSourceStatics> = L"Microsoft.UI.Xaml.Controls.IFontIconSourceStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IIconSource> = L"Microsoft.UI.Xaml.Controls.IIconSource";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IIconSourceFactory> = L"Microsoft.UI.Xaml.Controls.IIconSourceFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IIconSourceStatics> = L"Microsoft.UI.Xaml.Controls.IIconSourceStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IImageIcon> = L"Microsoft.UI.Xaml.Controls.IImageIcon";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IImageIconFactory> = L"Microsoft.UI.Xaml.Controls.IImageIconFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IImageIconSource> = L"Microsoft.UI.Xaml.Controls.IImageIconSource";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IImageIconSourceFactory> = L"Microsoft.UI.Xaml.Controls.IImageIconSourceFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IImageIconSourceStatics> = L"Microsoft.UI.Xaml.Controls.IImageIconSourceStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IImageIconStatics> = L"Microsoft.UI.Xaml.Controls.IImageIconStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBadge> = L"Microsoft.UI.Xaml.Controls.IInfoBadge";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeFactory> = L"Microsoft.UI.Xaml.Controls.IInfoBadgeFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeStatics> = L"Microsoft.UI.Xaml.Controls.IInfoBadgeStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeTemplateSettings> = L"Microsoft.UI.Xaml.Controls.IInfoBadgeTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeTemplateSettingsFactory> = L"Microsoft.UI.Xaml.Controls.IInfoBadgeTemplateSettingsFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeTemplateSettingsStatics> = L"Microsoft.UI.Xaml.Controls.IInfoBadgeTemplateSettingsStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBar> = L"Microsoft.UI.Xaml.Controls.IInfoBar";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosedEventArgs> = L"Microsoft.UI.Xaml.Controls.IInfoBarClosedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosedEventArgsFactory> = L"Microsoft.UI.Xaml.Controls.IInfoBarClosedEventArgsFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosingEventArgs> = L"Microsoft.UI.Xaml.Controls.IInfoBarClosingEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosingEventArgsFactory> = L"Microsoft.UI.Xaml.Controls.IInfoBarClosingEventArgsFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBarFactory> = L"Microsoft.UI.Xaml.Controls.IInfoBarFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBarStatics> = L"Microsoft.UI.Xaml.Controls.IInfoBarStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBarTemplateSettings> = L"Microsoft.UI.Xaml.Controls.IInfoBarTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBarTemplateSettingsFactory> = L"Microsoft.UI.Xaml.Controls.IInfoBarTemplateSettingsFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBarTemplateSettingsStatics> = L"Microsoft.UI.Xaml.Controls.IInfoBarTemplateSettingsStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeater> = L"Microsoft.UI.Xaml.Controls.IItemsRepeater";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterElementClearingEventArgs> = L"Microsoft.UI.Xaml.Controls.IItemsRepeaterElementClearingEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterElementIndexChangedEventArgs> = L"Microsoft.UI.Xaml.Controls.IItemsRepeaterElementIndexChangedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterElementPreparedEventArgs> = L"Microsoft.UI.Xaml.Controls.IItemsRepeaterElementPreparedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterFactory> = L"Microsoft.UI.Xaml.Controls.IItemsRepeaterFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterScrollHost> = L"Microsoft.UI.Xaml.Controls.IItemsRepeaterScrollHost";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterStatics> = L"Microsoft.UI.Xaml.Controls.IItemsRepeaterStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IItemsSourceView> = L"Microsoft.UI.Xaml.Controls.IItemsSourceView";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IItemsSourceViewFactory> = L"Microsoft.UI.Xaml.Controls.IItemsSourceViewFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IKeyIndexMapping> = L"Microsoft.UI.Xaml.Controls.IKeyIndexMapping";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ILayout> = L"Microsoft.UI.Xaml.Controls.ILayout";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ILayoutContext> = L"Microsoft.UI.Xaml.Controls.ILayoutContext";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ILayoutContextFactory> = L"Microsoft.UI.Xaml.Controls.ILayoutContextFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ILayoutContextOverrides> = L"Microsoft.UI.Xaml.Controls.ILayoutContextOverrides";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ILayoutFactory> = L"Microsoft.UI.Xaml.Controls.ILayoutFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ILayoutProtected> = L"Microsoft.UI.Xaml.Controls.ILayoutProtected";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IMenuBar> = L"Microsoft.UI.Xaml.Controls.IMenuBar";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IMenuBarFactory> = L"Microsoft.UI.Xaml.Controls.IMenuBarFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItem> = L"Microsoft.UI.Xaml.Controls.IMenuBarItem";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItemFactory> = L"Microsoft.UI.Xaml.Controls.IMenuBarItemFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItemFlyout> = L"Microsoft.UI.Xaml.Controls.IMenuBarItemFlyout";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItemFlyoutFactory> = L"Microsoft.UI.Xaml.Controls.IMenuBarItemFlyoutFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItemStatics> = L"Microsoft.UI.Xaml.Controls.IMenuBarItemStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IMenuBarStatics> = L"Microsoft.UI.Xaml.Controls.IMenuBarStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationView> = L"Microsoft.UI.Xaml.Controls.INavigationView";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationView2> = L"Microsoft.UI.Xaml.Controls.INavigationView2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewBackRequestedEventArgs> = L"Microsoft.UI.Xaml.Controls.INavigationViewBackRequestedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewDisplayModeChangedEventArgs> = L"Microsoft.UI.Xaml.Controls.INavigationViewDisplayModeChangedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewFactory> = L"Microsoft.UI.Xaml.Controls.INavigationViewFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItem> = L"Microsoft.UI.Xaml.Controls.INavigationViewItem";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItem2> = L"Microsoft.UI.Xaml.Controls.INavigationViewItem2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItem3> = L"Microsoft.UI.Xaml.Controls.INavigationViewItem3";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemBase> = L"Microsoft.UI.Xaml.Controls.INavigationViewItemBase";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemBase2> = L"Microsoft.UI.Xaml.Controls.INavigationViewItemBase2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemBaseFactory> = L"Microsoft.UI.Xaml.Controls.INavigationViewItemBaseFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemBaseStatics> = L"Microsoft.UI.Xaml.Controls.INavigationViewItemBaseStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemCollapsedEventArgs> = L"Microsoft.UI.Xaml.Controls.INavigationViewItemCollapsedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemExpandingEventArgs> = L"Microsoft.UI.Xaml.Controls.INavigationViewItemExpandingEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemFactory> = L"Microsoft.UI.Xaml.Controls.INavigationViewItemFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemHeader> = L"Microsoft.UI.Xaml.Controls.INavigationViewItemHeader";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemHeaderFactory> = L"Microsoft.UI.Xaml.Controls.INavigationViewItemHeaderFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemInvokedEventArgs> = L"Microsoft.UI.Xaml.Controls.INavigationViewItemInvokedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemInvokedEventArgs2> = L"Microsoft.UI.Xaml.Controls.INavigationViewItemInvokedEventArgs2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemSeparator> = L"Microsoft.UI.Xaml.Controls.INavigationViewItemSeparator";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemSeparatorFactory> = L"Microsoft.UI.Xaml.Controls.INavigationViewItemSeparatorFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemStatics> = L"Microsoft.UI.Xaml.Controls.INavigationViewItemStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemStatics2> = L"Microsoft.UI.Xaml.Controls.INavigationViewItemStatics2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemStatics3> = L"Microsoft.UI.Xaml.Controls.INavigationViewItemStatics3";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewPaneClosingEventArgs> = L"Microsoft.UI.Xaml.Controls.INavigationViewPaneClosingEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewSelectionChangedEventArgs> = L"Microsoft.UI.Xaml.Controls.INavigationViewSelectionChangedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewSelectionChangedEventArgs2> = L"Microsoft.UI.Xaml.Controls.INavigationViewSelectionChangedEventArgs2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewStatics> = L"Microsoft.UI.Xaml.Controls.INavigationViewStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewStatics2> = L"Microsoft.UI.Xaml.Controls.INavigationViewStatics2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettings> = L"Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettings2> = L"Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettings2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettingsFactory> = L"Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettingsFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettingsStatics> = L"Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettingsStatics2> = L"Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayout> = L"Microsoft.UI.Xaml.Controls.INonVirtualizingLayout";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutContext> = L"Microsoft.UI.Xaml.Controls.INonVirtualizingLayoutContext";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutContextFactory> = L"Microsoft.UI.Xaml.Controls.INonVirtualizingLayoutContextFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutContextOverrides> = L"Microsoft.UI.Xaml.Controls.INonVirtualizingLayoutContextOverrides";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutFactory> = L"Microsoft.UI.Xaml.Controls.INonVirtualizingLayoutFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutOverrides> = L"Microsoft.UI.Xaml.Controls.INonVirtualizingLayoutOverrides";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INumberBox> = L"Microsoft.UI.Xaml.Controls.INumberBox";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INumberBoxFactory> = L"Microsoft.UI.Xaml.Controls.INumberBoxFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INumberBoxStatics> = L"Microsoft.UI.Xaml.Controls.INumberBoxStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::INumberBoxValueChangedEventArgs> = L"Microsoft.UI.Xaml.Controls.INumberBoxValueChangedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IParallaxView> = L"Microsoft.UI.Xaml.Controls.IParallaxView";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IParallaxViewFactory> = L"Microsoft.UI.Xaml.Controls.IParallaxViewFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IParallaxViewStatics> = L"Microsoft.UI.Xaml.Controls.IParallaxViewStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IPathIconSource> = L"Microsoft.UI.Xaml.Controls.IPathIconSource";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IPathIconSourceFactory> = L"Microsoft.UI.Xaml.Controls.IPathIconSourceFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IPathIconSourceStatics> = L"Microsoft.UI.Xaml.Controls.IPathIconSourceStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IPersonPicture> = L"Microsoft.UI.Xaml.Controls.IPersonPicture";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IPersonPictureFactory> = L"Microsoft.UI.Xaml.Controls.IPersonPictureFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IPersonPictureStatics> = L"Microsoft.UI.Xaml.Controls.IPersonPictureStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IPersonPictureTemplateSettings> = L"Microsoft.UI.Xaml.Controls.IPersonPictureTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IPipsPager> = L"Microsoft.UI.Xaml.Controls.IPipsPager";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IPipsPagerFactory> = L"Microsoft.UI.Xaml.Controls.IPipsPagerFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IPipsPagerSelectedIndexChangedEventArgs> = L"Microsoft.UI.Xaml.Controls.IPipsPagerSelectedIndexChangedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IPipsPagerStatics> = L"Microsoft.UI.Xaml.Controls.IPipsPagerStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IPipsPagerTemplateSettings> = L"Microsoft.UI.Xaml.Controls.IPipsPagerTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IProgressBar> = L"Microsoft.UI.Xaml.Controls.IProgressBar";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IProgressBarFactory> = L"Microsoft.UI.Xaml.Controls.IProgressBarFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IProgressBarStatics> = L"Microsoft.UI.Xaml.Controls.IProgressBarStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IProgressBarTemplateSettings> = L"Microsoft.UI.Xaml.Controls.IProgressBarTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IProgressRing> = L"Microsoft.UI.Xaml.Controls.IProgressRing";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IProgressRingFactory> = L"Microsoft.UI.Xaml.Controls.IProgressRingFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IProgressRingStatics> = L"Microsoft.UI.Xaml.Controls.IProgressRingStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IProgressRingTemplateSettings> = L"Microsoft.UI.Xaml.Controls.IProgressRingTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRadioButtons> = L"Microsoft.UI.Xaml.Controls.IRadioButtons";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRadioButtonsFactory> = L"Microsoft.UI.Xaml.Controls.IRadioButtonsFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRadioButtonsStatics> = L"Microsoft.UI.Xaml.Controls.IRadioButtonsStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRadioMenuFlyoutItem> = L"Microsoft.UI.Xaml.Controls.IRadioMenuFlyoutItem";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRadioMenuFlyoutItemFactory> = L"Microsoft.UI.Xaml.Controls.IRadioMenuFlyoutItemFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRadioMenuFlyoutItemStatics> = L"Microsoft.UI.Xaml.Controls.IRadioMenuFlyoutItemStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRadioMenuFlyoutItemStatics2> = L"Microsoft.UI.Xaml.Controls.IRadioMenuFlyoutItemStatics2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRatingControl> = L"Microsoft.UI.Xaml.Controls.IRatingControl";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRatingControlFactory> = L"Microsoft.UI.Xaml.Controls.IRatingControlFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRatingControlStatics> = L"Microsoft.UI.Xaml.Controls.IRatingControlStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRatingItemFontInfo> = L"Microsoft.UI.Xaml.Controls.IRatingItemFontInfo";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRatingItemFontInfoFactory> = L"Microsoft.UI.Xaml.Controls.IRatingItemFontInfoFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRatingItemFontInfoStatics> = L"Microsoft.UI.Xaml.Controls.IRatingItemFontInfoStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRatingItemImageInfo> = L"Microsoft.UI.Xaml.Controls.IRatingItemImageInfo";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRatingItemImageInfoFactory> = L"Microsoft.UI.Xaml.Controls.IRatingItemImageInfoFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRatingItemImageInfoStatics> = L"Microsoft.UI.Xaml.Controls.IRatingItemImageInfoStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRatingItemInfo> = L"Microsoft.UI.Xaml.Controls.IRatingItemInfo";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRatingItemInfoFactory> = L"Microsoft.UI.Xaml.Controls.IRatingItemInfoFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRefreshContainer> = L"Microsoft.UI.Xaml.Controls.IRefreshContainer";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRefreshContainerFactory> = L"Microsoft.UI.Xaml.Controls.IRefreshContainerFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRefreshContainerStatics> = L"Microsoft.UI.Xaml.Controls.IRefreshContainerStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRefreshInteractionRatioChangedEventArgs> = L"Microsoft.UI.Xaml.Controls.IRefreshInteractionRatioChangedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRefreshRequestedEventArgs> = L"Microsoft.UI.Xaml.Controls.IRefreshRequestedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRefreshStateChangedEventArgs> = L"Microsoft.UI.Xaml.Controls.IRefreshStateChangedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRefreshVisualizer> = L"Microsoft.UI.Xaml.Controls.IRefreshVisualizer";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRefreshVisualizerFactory> = L"Microsoft.UI.Xaml.Controls.IRefreshVisualizerFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRefreshVisualizerStatics> = L"Microsoft.UI.Xaml.Controls.IRefreshVisualizerStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRevealListViewItemPresenter> = L"Microsoft.UI.Xaml.Controls.IRevealListViewItemPresenter";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IRevealListViewItemPresenterFactory> = L"Microsoft.UI.Xaml.Controls.IRevealListViewItemPresenterFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ISplitButton> = L"Microsoft.UI.Xaml.Controls.ISplitButton";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ISplitButtonClickEventArgs> = L"Microsoft.UI.Xaml.Controls.ISplitButtonClickEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ISplitButtonFactory> = L"Microsoft.UI.Xaml.Controls.ISplitButtonFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ISplitButtonStatics> = L"Microsoft.UI.Xaml.Controls.ISplitButtonStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IStackLayout> = L"Microsoft.UI.Xaml.Controls.IStackLayout";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IStackLayoutFactory> = L"Microsoft.UI.Xaml.Controls.IStackLayoutFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IStackLayoutStatics> = L"Microsoft.UI.Xaml.Controls.IStackLayoutStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ISwipeControl> = L"Microsoft.UI.Xaml.Controls.ISwipeControl";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ISwipeControlFactory> = L"Microsoft.UI.Xaml.Controls.ISwipeControlFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ISwipeControlStatics> = L"Microsoft.UI.Xaml.Controls.ISwipeControlStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ISwipeItem> = L"Microsoft.UI.Xaml.Controls.ISwipeItem";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemFactory> = L"Microsoft.UI.Xaml.Controls.ISwipeItemFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemInvokedEventArgs> = L"Microsoft.UI.Xaml.Controls.ISwipeItemInvokedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemStatics> = L"Microsoft.UI.Xaml.Controls.ISwipeItemStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ISwipeItems> = L"Microsoft.UI.Xaml.Controls.ISwipeItems";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemsFactory> = L"Microsoft.UI.Xaml.Controls.ISwipeItemsFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemsStatics> = L"Microsoft.UI.Xaml.Controls.ISwipeItemsStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ISymbolIconSource> = L"Microsoft.UI.Xaml.Controls.ISymbolIconSource";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ISymbolIconSourceFactory> = L"Microsoft.UI.Xaml.Controls.ISymbolIconSourceFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ISymbolIconSourceStatics> = L"Microsoft.UI.Xaml.Controls.ISymbolIconSourceStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITabView> = L"Microsoft.UI.Xaml.Controls.ITabView";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewFactory> = L"Microsoft.UI.Xaml.Controls.ITabViewFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewItem> = L"Microsoft.UI.Xaml.Controls.ITabViewItem";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemFactory> = L"Microsoft.UI.Xaml.Controls.ITabViewItemFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemStatics> = L"Microsoft.UI.Xaml.Controls.ITabViewItemStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettings> = L"Microsoft.UI.Xaml.Controls.ITabViewItemTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettings2> = L"Microsoft.UI.Xaml.Controls.ITabViewItemTemplateSettings2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettingsFactory> = L"Microsoft.UI.Xaml.Controls.ITabViewItemTemplateSettingsFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettingsStatics> = L"Microsoft.UI.Xaml.Controls.ITabViewItemTemplateSettingsStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettingsStatics2> = L"Microsoft.UI.Xaml.Controls.ITabViewItemTemplateSettingsStatics2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewStatics> = L"Microsoft.UI.Xaml.Controls.ITabViewStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewTabCloseRequestedEventArgs> = L"Microsoft.UI.Xaml.Controls.ITabViewTabCloseRequestedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewTabDragCompletedEventArgs> = L"Microsoft.UI.Xaml.Controls.ITabViewTabDragCompletedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewTabDragStartingEventArgs> = L"Microsoft.UI.Xaml.Controls.ITabViewTabDragStartingEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewTabDroppedOutsideEventArgs> = L"Microsoft.UI.Xaml.Controls.ITabViewTabDroppedOutsideEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITeachingTip> = L"Microsoft.UI.Xaml.Controls.ITeachingTip";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipClosedEventArgs> = L"Microsoft.UI.Xaml.Controls.ITeachingTipClosedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipClosingEventArgs> = L"Microsoft.UI.Xaml.Controls.ITeachingTipClosingEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipFactory> = L"Microsoft.UI.Xaml.Controls.ITeachingTipFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipStatics> = L"Microsoft.UI.Xaml.Controls.ITeachingTipStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipTemplateSettings> = L"Microsoft.UI.Xaml.Controls.ITeachingTipTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipTemplateSettingsFactory> = L"Microsoft.UI.Xaml.Controls.ITeachingTipTemplateSettingsFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipTemplateSettingsStatics> = L"Microsoft.UI.Xaml.Controls.ITeachingTipTemplateSettingsStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITextCommandBarFlyout> = L"Microsoft.UI.Xaml.Controls.ITextCommandBarFlyout";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITextCommandBarFlyoutFactory> = L"Microsoft.UI.Xaml.Controls.ITextCommandBarFlyoutFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButton> = L"Microsoft.UI.Xaml.Controls.IToggleSplitButton";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButtonFactory> = L"Microsoft.UI.Xaml.Controls.IToggleSplitButtonFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButtonIsCheckedChangedEventArgs> = L"Microsoft.UI.Xaml.Controls.IToggleSplitButtonIsCheckedChangedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButtonStatics> = L"Microsoft.UI.Xaml.Controls.IToggleSplitButtonStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeView> = L"Microsoft.UI.Xaml.Controls.ITreeView";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeView2> = L"Microsoft.UI.Xaml.Controls.ITreeView2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewCollapsedEventArgs> = L"Microsoft.UI.Xaml.Controls.ITreeViewCollapsedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewCollapsedEventArgs2> = L"Microsoft.UI.Xaml.Controls.ITreeViewCollapsedEventArgs2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewDragItemsCompletedEventArgs> = L"Microsoft.UI.Xaml.Controls.ITreeViewDragItemsCompletedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewDragItemsCompletedEventArgs2> = L"Microsoft.UI.Xaml.Controls.ITreeViewDragItemsCompletedEventArgs2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewDragItemsStartingEventArgs> = L"Microsoft.UI.Xaml.Controls.ITreeViewDragItemsStartingEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewExpandingEventArgs> = L"Microsoft.UI.Xaml.Controls.ITreeViewExpandingEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewExpandingEventArgs2> = L"Microsoft.UI.Xaml.Controls.ITreeViewExpandingEventArgs2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewFactory> = L"Microsoft.UI.Xaml.Controls.ITreeViewFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItem> = L"Microsoft.UI.Xaml.Controls.ITreeViewItem";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItem2> = L"Microsoft.UI.Xaml.Controls.ITreeViewItem2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemFactory> = L"Microsoft.UI.Xaml.Controls.ITreeViewItemFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemInvokedEventArgs> = L"Microsoft.UI.Xaml.Controls.ITreeViewItemInvokedEventArgs";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemStatics> = L"Microsoft.UI.Xaml.Controls.ITreeViewItemStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemStatics2> = L"Microsoft.UI.Xaml.Controls.ITreeViewItemStatics2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemTemplateSettings> = L"Microsoft.UI.Xaml.Controls.ITreeViewItemTemplateSettings";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemTemplateSettingsFactory> = L"Microsoft.UI.Xaml.Controls.ITreeViewItemTemplateSettingsFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemTemplateSettingsStatics> = L"Microsoft.UI.Xaml.Controls.ITreeViewItemTemplateSettingsStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewList> = L"Microsoft.UI.Xaml.Controls.ITreeViewList";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewListFactory> = L"Microsoft.UI.Xaml.Controls.ITreeViewListFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewNode> = L"Microsoft.UI.Xaml.Controls.ITreeViewNode";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewNodeFactory> = L"Microsoft.UI.Xaml.Controls.ITreeViewNodeFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewNodeStatics> = L"Microsoft.UI.Xaml.Controls.ITreeViewNodeStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewStatics> = L"Microsoft.UI.Xaml.Controls.ITreeViewStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewStatics2> = L"Microsoft.UI.Xaml.Controls.ITreeViewStatics2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITwoPaneView> = L"Microsoft.UI.Xaml.Controls.ITwoPaneView";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITwoPaneViewFactory> = L"Microsoft.UI.Xaml.Controls.ITwoPaneViewFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::ITwoPaneViewStatics> = L"Microsoft.UI.Xaml.Controls.ITwoPaneViewStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IUniformGridLayout> = L"Microsoft.UI.Xaml.Controls.IUniformGridLayout";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IUniformGridLayoutFactory> = L"Microsoft.UI.Xaml.Controls.IUniformGridLayoutFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IUniformGridLayoutStatics> = L"Microsoft.UI.Xaml.Controls.IUniformGridLayoutStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayout> = L"Microsoft.UI.Xaml.Controls.IVirtualizingLayout";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutContext> = L"Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContext";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutContextFactory> = L"Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContextFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutContextOverrides> = L"Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContextOverrides";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutFactory> = L"Microsoft.UI.Xaml.Controls.IVirtualizingLayoutFactory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutOverrides> = L"Microsoft.UI.Xaml.Controls.IVirtualizingLayoutOverrides";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IWebView2> = L"Microsoft.UI.Xaml.Controls.IWebView2";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IWebView2Factory> = L"Microsoft.UI.Xaml.Controls.IWebView2Factory";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IWebView2Statics> = L"Microsoft.UI.Xaml.Controls.IWebView2Statics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IXamlControlsResources> = L"Microsoft.UI.Xaml.Controls.IXamlControlsResources";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IXamlControlsResources3> = L"Microsoft.UI.Xaml.Controls.IXamlControlsResources3";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IXamlControlsResourcesStatics> = L"Microsoft.UI.Xaml.Controls.IXamlControlsResourcesStatics";
    template <> inline constexpr auto& name_v<winrt::Microsoft::UI::Xaml::Controls::IXamlControlsResourcesStatics3> = L"Microsoft.UI.Xaml.Controls.IXamlControlsResourcesStatics3";
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIcon>{ 0xF705DFDA,0x8196,0x56D0,{ 0x8D,0xCF,0x2B,0x66,0xC2,0xAE,0xD7,0x91 } }; // F705DFDA-8196-56D0-8DCF-2B66C2AED791
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconFactory>{ 0x3356E0D1,0xD82F,0x5FC1,{ 0x81,0x65,0x9B,0x9D,0x1B,0x9D,0x95,0x14 } }; // 3356E0D1-D82F-5FC1-8165-9B9D1B9D9514
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconSource>{ 0x2846A198,0x731B,0x5379,{ 0x85,0xAC,0x8F,0x28,0x02,0x7F,0x71,0x83 } }; // 2846A198-731B-5379-85AC-8F28027F7183
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconSourceFactory>{ 0xAE8FB7DE,0x7EC2,0x5AE2,{ 0xB4,0x61,0xBE,0xAD,0x57,0x04,0x20,0xFA } }; // AE8FB7DE-7EC2-5AE2-B461-BEAD570420FA
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconSourceStatics>{ 0x6E0F1325,0xDBD8,0x51B3,{ 0xB4,0xBD,0x2D,0x5B,0x7C,0xCF,0x51,0x78 } }; // 6E0F1325-DBD8-51B3-B4BD-2D5B7CCF5178
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconStatics>{ 0x381896A8,0xEE9F,0x5823,{ 0xAB,0xF1,0xB5,0x96,0xAD,0xCC,0x77,0xD1 } }; // 381896A8-EE9F-5823-ABF1-B596ADCC77D1
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisual>{ 0x84100919,0x9E15,0x5106,{ 0x96,0x47,0x96,0x54,0xED,0xE3,0x35,0xDE } }; // 84100919-9E15-5106-9647-9654EDE335DE
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisual2>{ 0x763A3F0B,0x95CC,0x59EF,{ 0x98,0x90,0x14,0x78,0x68,0x59,0x9D,0xE9 } }; // 763A3F0B-95CC-59EF-9890-147868599DE9
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayer>{ 0xBF7F8865,0x7B79,0x5354,{ 0x97,0x88,0xC2,0x1E,0x52,0x35,0x91,0xEA } }; // BF7F8865-7B79-5354-9788-C21E523591EA
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayer2>{ 0xDB33DB95,0x9404,0x5385,{ 0xAE,0x32,0x67,0x3E,0x7C,0x35,0x8A,0xD3 } }; // DB33DB95-9404-5385-AE32-673E7C358AD3
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayerFactory>{ 0xEBC0C6E6,0xC91A,0x5025,{ 0xB4,0xA4,0xE7,0x86,0xD8,0x3B,0xE1,0xD8 } }; // EBC0C6E6-C91A-5025-B4A4-E786D83BE1D8
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayerStatics>{ 0xA4ADBA25,0xA34C,0x5D7A,{ 0xBD,0x40,0x61,0xE0,0xDD,0xCA,0x12,0x98 } }; // A4ADBA25-A34C-5D7A-BD40-61E0DDCA1298
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayerStatics2>{ 0xDF134B95,0xE168,0x599E,{ 0x85,0x99,0x9B,0x67,0xB0,0x56,0x47,0x9D } }; // DF134B95-E168-599E-8599-9B67B056479D
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource>{ 0x57AF690E,0xB331,0x5462,{ 0x8C,0xC6,0xC5,0x29,0xA5,0xDA,0x41,0x23 } }; // 57AF690E-B331-5462-8CC6-C529A5DA4123
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource2>{ 0x1A3B53A7,0xA8FE,0x59A1,{ 0xB5,0x44,0x43,0xA4,0xD9,0xC8,0x1E,0xF2 } }; // 1A3B53A7-A8FE-59A1-B544-43A4D9C81EF2
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource3>{ 0xD84D1178,0x8C0D,0x5A23,{ 0xA9,0x2F,0x6A,0xE5,0xC5,0x7B,0x70,0x1B } }; // D84D1178-8C0D-5A23-A92F-6AE5C57B701B
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IBackdropMaterial>{ 0x00D918AA,0x9B55,0x5841,{ 0x9A,0xF5,0x63,0x7D,0xE7,0x98,0x2E,0xA7 } }; // 00D918AA-9B55-5841-9AF5-637DE7982EA7
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IBackdropMaterialFactory>{ 0x1D1F674F,0xCB53,0x5C41,{ 0xAA,0x3E,0x15,0xF3,0x0C,0x8E,0xF7,0xA5 } }; // 1D1F674F-CB53-5C41-AA3E-15F30C8EF7A5
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IBackdropMaterialStatics>{ 0x707F26F5,0x042D,0x5BA6,{ 0xA1,0xC8,0xCB,0xC6,0x62,0x46,0xF7,0xA1 } }; // 707F26F5-042D-5BA6-A1C8-CBC66246F7A1
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IBitmapIconSource>{ 0xA6B6CCCC,0xEA8F,0x53CA,{ 0x83,0x1F,0x2A,0xBE,0x85,0xCD,0x6D,0x8C } }; // A6B6CCCC-EA8F-53CA-831F-2ABE85CD6D8C
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IBitmapIconSourceFactory>{ 0x7D484C14,0xF5F6,0x5E39,{ 0xB4,0xE4,0xB6,0x10,0x8D,0x2E,0xE0,0x95 } }; // 7D484C14-F5F6-5E39-B4E4-B6108D2EE095
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IBitmapIconSourceStatics>{ 0x7E603B56,0x5580,0x5A9B,{ 0x90,0x0D,0x05,0x64,0x16,0x2A,0x5F,0x37 } }; // 7E603B56-5580-5A9B-900D-0564162A5F37
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBar>{ 0x2E47B7D6,0x5FBD,0x54C7,{ 0xB0,0xB1,0xCE,0xFF,0x4A,0x19,0xC7,0x44 } }; // 2E47B7D6-5FBD-54C7-B0B1-CEFF4A19C744
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarFactory>{ 0xD5B6A6D9,0x3148,0x5CBC,{ 0xA6,0xAE,0x0F,0x44,0xCD,0xE4,0x19,0x52 } }; // D5B6A6D9-3148-5CBC-A6AE-0F44CDE41952
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarItem>{ 0x34582DE4,0x6BEF,0x5BA0,{ 0x86,0xCA,0x7C,0xC1,0xA3,0xDB,0x37,0xEE } }; // 34582DE4-6BEF-5BA0-86CA-7CC1A3DB37EE
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarItemClickedEventArgs>{ 0x1CEEA503,0x365E,0x580D,{ 0xBC,0xD4,0xE9,0xAD,0x02,0x48,0xF6,0xB5 } }; // 1CEEA503-365E-580D-BCD4-E9AD0248F6B5
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarItemFactory>{ 0x186C3BD3,0x7008,0x5544,{ 0x8D,0x3A,0x65,0xAF,0x8F,0xE9,0xFE,0x69 } }; // 186C3BD3-7008-5544-8D3A-65AF8FE9FE69
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarStatics>{ 0x95DAAAEC,0xE224,0x56AC,{ 0x97,0x49,0x4E,0xDD,0xAC,0x0C,0x30,0x43 } }; // 95DAAAEC-E224-56AC-9749-4EDDAC0C3043
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IColorChangedEventArgs>{ 0x148D57A2,0xB1CB,0x5F5D,{ 0xB6,0xB5,0x51,0x28,0x05,0xD7,0x17,0x61 } }; // 148D57A2-B1CB-5F5D-B6B5-512805D71761
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IColorPicker>{ 0xAE72B24B,0xF93F,0x5A19,{ 0x8C,0xE4,0xA1,0x8B,0x73,0xC3,0x35,0x6D } }; // AE72B24B-F93F-5A19-8CE4-A18B73C3356D
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IColorPicker2>{ 0x1ED6D5F5,0x1972,0x55C6,{ 0xB1,0x9F,0x57,0xFA,0x1E,0x81,0x61,0xFE } }; // 1ED6D5F5-1972-55C6-B19F-57FA1E8161FE
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IColorPickerFactory>{ 0x72C350E2,0x0A20,0x5B9B,{ 0xAC,0x54,0x63,0x3B,0x97,0xD7,0xFF,0xDE } }; // 72C350E2-0A20-5B9B-AC54-633B97D7FFDE
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IColorPickerStatics>{ 0xAF1E1848,0x98DE,0x569E,{ 0xA8,0x4B,0x1C,0x88,0xBB,0xD0,0xD4,0x79 } }; // AF1E1848-98DE-569E-A84B-1C88BBD0D479
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IColorPickerStatics2>{ 0x98EE8031,0x972D,0x5DD3,{ 0xB7,0xE6,0x2B,0x7A,0x15,0x4E,0xA2,0x5E } }; // 98EE8031-972D-5DD3-B7E6-2B7A154EA25E
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ICommandBarFlyout>{ 0xF8F5B8BC,0x8D67,0x5FA9,{ 0x8F,0xB0,0xC2,0xC3,0x31,0x1E,0x1B,0x7C } }; // F8F5B8BC-8D67-5FA9-8FB0-C2C3311E1B7C
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ICommandBarFlyout2>{ 0x5F81EC9E,0xA9D2,0x5F04,{ 0xB5,0xB1,0x01,0x3D,0xAE,0xF0,0x26,0xDD } }; // 5F81EC9E-A9D2-5F04-B5B1-013DAEF026DD
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ICommandBarFlyoutFactory>{ 0xA194DBE6,0x4311,0x5BD2,{ 0xA8,0xEB,0xB4,0x9C,0x47,0x33,0xA3,0x3C } }; // A194DBE6-4311-5BD2-A8EB-B49C4733A33C
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ICoreWebView2InitializedEventArgs>{ 0xEE59D277,0x8B2E,0x57AB,{ 0x86,0x31,0x91,0xD2,0x7B,0x12,0xEB,0xD9 } }; // EE59D277-8B2E-57AB-8631-91D27B12EBD9
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IDropDownButton>{ 0xC1E9FA91,0x4F95,0x5796,{ 0x8A,0x7B,0x3B,0x75,0x94,0xA1,0x2C,0x69 } }; // C1E9FA91-4F95-5796-8A7B-3B7594A12C69
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IDropDownButtonFactory>{ 0x7CF3E13B,0x668D,0x57E7,{ 0xB5,0xD6,0xF5,0xCA,0x3D,0xBC,0x80,0xBD } }; // 7CF3E13B-668D-57E7-B5D6-F5CA3DBC80BD
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IDynamicAnimatedVisualSource>{ 0xAB00E5CF,0x1BE6,0x559C,{ 0xAD,0x5B,0x02,0x53,0xBB,0x17,0xC0,0xF7 } }; // AB00E5CF-1BE6-559C-AD5B-0253BB17C0F7
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IElementFactory>{ 0x122278A6,0x3E28,0x5644,{ 0xBE,0x8E,0x10,0x52,0xE3,0xAE,0x4E,0xC9 } }; // 122278A6-3E28-5644-BE8E-1052E3AE4EC9
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IElementFactoryFactory>{ 0xD892556F,0xA875,0x534F,{ 0x8D,0x7F,0x68,0x18,0x03,0x34,0x27,0x32 } }; // D892556F-A875-534F-8D7F-681803342732
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IElementFactoryGetArgs>{ 0x909791CE,0x213D,0x5075,{ 0xA2,0x3C,0xBF,0xE4,0x6C,0x16,0xB3,0x4D } }; // 909791CE-213D-5075-A23C-BFE46C16B34D
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IElementFactoryOverrides>{ 0xBDDC3E33,0xDA7D,0x5F43,{ 0x8D,0x07,0x75,0xFB,0x50,0x06,0xCF,0x5D } }; // BDDC3E33-DA7D-5F43-8D07-75FB5006CF5D
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IElementFactoryRecycleArgs>{ 0xC7386123,0x7139,0x509C,{ 0x88,0x6B,0x9D,0x74,0xCB,0xA9,0x56,0xDE } }; // C7386123-7139-509C-886B-9D74CBA956DE
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IExpander>{ 0xCD1D4EDE,0x8D39,0x5BEF,{ 0xA7,0x35,0x9F,0xDF,0x60,0x38,0xE8,0x6B } }; // CD1D4EDE-8D39-5BEF-A735-9FDF6038E86B
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IExpanderCollapsedEventArgs>{ 0x968A6870,0x7426,0x535E,{ 0xA5,0x26,0x27,0x9E,0x6E,0xED,0xEC,0xD0 } }; // 968A6870-7426-535E-A526-279E6EEDECD0
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IExpanderExpandingEventArgs>{ 0x433F2E36,0x19E7,0x579C,{ 0xB4,0xCE,0x9C,0xE5,0xD5,0x10,0xD0,0x01 } }; // 433F2E36-19E7-579C-B4CE-9CE5D510D001
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IExpanderFactory>{ 0x51A5AFC2,0xB16D,0x516E,{ 0x83,0xAE,0x5A,0x10,0x47,0x6B,0x13,0xAF } }; // 51A5AFC2-B16D-516E-83AE-5A10476B13AF
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IExpanderStatics>{ 0xC83ECF19,0xCADC,0x5C26,{ 0xB6,0x08,0x11,0x64,0xAC,0x46,0xC1,0xF5 } }; // C83ECF19-CADC-5C26-B608-1164AC46C1F5
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IExpanderTemplateSettings>{ 0x8F959018,0xF6B8,0x5C02,{ 0xBE,0x08,0xCD,0x19,0x6C,0x9F,0xCD,0x2D } }; // 8F959018-F6B8-5C02-BE08-CD196C9FCD2D
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IFontIconSource>{ 0xDDF34704,0xC53D,0x571C,{ 0x89,0x0F,0x3B,0x5E,0x30,0x5D,0xDC,0x69 } }; // DDF34704-C53D-571C-890F-3B5E305DDC69
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IFontIconSourceFactory>{ 0xBB40EEEE,0x64D1,0x5133,{ 0xB1,0xD6,0xAE,0x13,0xC2,0x1B,0x66,0x78 } }; // BB40EEEE-64D1-5133-B1D6-AE13C21B6678
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IFontIconSourceStatics>{ 0x12C4716A,0x31C1,0x510A,{ 0x95,0x26,0x01,0xAB,0x3E,0x2B,0x07,0x38 } }; // 12C4716A-31C1-510A-9526-01AB3E2B0738
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IIconSource>{ 0x6E3501ED,0xDD31,0x51E9,{ 0x8F,0x14,0x25,0x61,0xF9,0x9C,0x8A,0x8F } }; // 6E3501ED-DD31-51E9-8F14-2561F99C8A8F
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IIconSourceFactory>{ 0xE8BC19C6,0x9A64,0x5C54,{ 0x93,0x38,0xE1,0x8E,0x07,0x68,0x75,0xBF } }; // E8BC19C6-9A64-5C54-9338-E18E076875BF
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IIconSourceStatics>{ 0x4DA53AB6,0x8945,0x562B,{ 0xA1,0xA5,0xFA,0xB5,0xE2,0xE8,0xD5,0x75 } }; // 4DA53AB6-8945-562B-A1A5-FAB5E2E8D575
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IImageIcon>{ 0xE30C7C6C,0x2026,0x5E76,{ 0xA2,0x71,0x1B,0x9F,0xAB,0x3F,0x84,0x9D } }; // E30C7C6C-2026-5E76-A271-1B9FAB3F849D
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IImageIconFactory>{ 0x235E0279,0xA7D0,0x5FDA,{ 0xA3,0x08,0x9B,0x7C,0xB9,0xC4,0xC9,0x12 } }; // 235E0279-A7D0-5FDA-A308-9B7CB9C4C912
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IImageIconSource>{ 0xC789D80C,0x0494,0x54BE,{ 0xB9,0x41,0x75,0x7D,0x3F,0x72,0x30,0x03 } }; // C789D80C-0494-54BE-B941-757D3F723003
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IImageIconSourceFactory>{ 0x24F76321,0x71BD,0x530A,{ 0x8C,0xC8,0x3F,0x61,0x5C,0xD1,0x43,0x7A } }; // 24F76321-71BD-530A-8CC8-3F615CD1437A
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IImageIconSourceStatics>{ 0x9AD9935A,0x8D99,0x562A,{ 0x85,0x6A,0xC8,0xBA,0x17,0x82,0x3D,0x23 } }; // 9AD9935A-8D99-562A-856A-C8BA17823D23
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IImageIconStatics>{ 0x0A74C66E,0xF1B7,0x5254,{ 0x91,0x35,0x26,0x27,0xEE,0xC5,0x15,0x6C } }; // 0A74C66E-F1B7-5254-9135-2627EEC5156C
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBadge>{ 0x82104D7F,0x03D4,0x5EA4,{ 0x87,0x2E,0xF9,0xEC,0xAB,0x75,0x86,0x01 } }; // 82104D7F-03D4-5EA4-872E-F9ECAB758601
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeFactory>{ 0xFB498205,0x2DE0,0x5986,{ 0x8A,0xEC,0x2C,0x46,0xAC,0x23,0x50,0x87 } }; // FB498205-2DE0-5986-8AEC-2C46AC235087
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeStatics>{ 0x64E214C3,0xF566,0x57BC,{ 0xB2,0x21,0x8E,0x9B,0x25,0xE3,0x45,0x72 } }; // 64E214C3-F566-57BC-B221-8E9B25E34572
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeTemplateSettings>{ 0x01051F06,0x1CE9,0x569D,{ 0x84,0xF0,0x09,0xDC,0xEF,0x30,0xC9,0x77 } }; // 01051F06-1CE9-569D-84F0-09DCEF30C977
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeTemplateSettingsFactory>{ 0x5D366775,0x1F6E,0x558C,{ 0xAA,0xB4,0x66,0x77,0x04,0xB3,0x07,0x0C } }; // 5D366775-1F6E-558C-AAB4-667704B3070C
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeTemplateSettingsStatics>{ 0xFE785851,0x5534,0x5AE7,{ 0xB1,0x11,0xB1,0xDA,0x78,0x0F,0xAC,0x3E } }; // FE785851-5534-5AE7-B111-B1DA780FAC3E
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBar>{ 0x273FFDE8,0x9324,0x55B7,{ 0x9F,0xFE,0x7D,0x99,0x5A,0x8A,0xF5,0x6B } }; // 273FFDE8-9324-55B7-9FFE-7D995A8AF56B
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosedEventArgs>{ 0x593AF0B3,0xBDED,0x53DA,{ 0x8F,0x56,0x80,0xED,0x3C,0x64,0x32,0x2C } }; // 593AF0B3-BDED-53DA-8F56-80ED3C64322C
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosedEventArgsFactory>{ 0x42FE1F7E,0x6D68,0x5A85,{ 0x8A,0x5C,0xAB,0xB7,0xEF,0xFC,0xDF,0x26 } }; // 42FE1F7E-6D68-5A85-8A5C-ABB7EFFCDF26
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosingEventArgs>{ 0x062D01D6,0x61AF,0x5435,{ 0x8C,0x4B,0xC5,0x11,0x06,0x58,0x3B,0x5B } }; // 062D01D6-61AF-5435-8C4B-C51106583B5B
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosingEventArgsFactory>{ 0xD6CFCC14,0x5206,0x5C9D,{ 0x80,0x1C,0x3A,0x90,0xB4,0xE2,0xEB,0xE4 } }; // D6CFCC14-5206-5C9D-801C-3A90B4E2EBE4
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBarFactory>{ 0x60618A60,0x9BE7,0x5DF5,{ 0xBE,0x0D,0x93,0x3D,0x34,0xDD,0xB4,0x4C } }; // 60618A60-9BE7-5DF5-BE0D-933D34DDB44C
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBarStatics>{ 0x9CE6008A,0x54F4,0x5500,{ 0xA7,0x3D,0x8D,0x01,0x02,0x50,0xE4,0xDA } }; // 9CE6008A-54F4-5500-A73D-8D010250E4DA
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBarTemplateSettings>{ 0x04686C8F,0xEC5D,0x58AB,{ 0x83,0xF9,0x3F,0x17,0x11,0x3C,0xEC,0x18 } }; // 04686C8F-EC5D-58AB-83F9-3F17113CEC18
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBarTemplateSettingsFactory>{ 0x29517DAF,0xC763,0x56CE,{ 0x8D,0x54,0xEE,0xFC,0xAF,0x7F,0x2E,0x01 } }; // 29517DAF-C763-56CE-8D54-EEFCAF7F2E01
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IInfoBarTemplateSettingsStatics>{ 0xCD900277,0xE17A,0x52C9,{ 0x80,0x94,0x0F,0xB4,0xF5,0xCC,0x19,0xB8 } }; // CD900277-E17A-52C9-8094-0FB4F5CC19B8
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeater>{ 0x0BD894F2,0xEDFC,0x5DDF,{ 0xA1,0x66,0x2D,0xB1,0x4B,0xBF,0xDF,0x35 } }; // 0BD894F2-EDFC-5DDF-A166-2DB14BBFDF35
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterElementClearingEventArgs>{ 0x1E30B4C7,0xF1BC,0x5A6F,{ 0x8A,0x5B,0x8C,0x54,0xAD,0xAC,0x5F,0x80 } }; // 1E30B4C7-F1BC-5A6F-8A5B-8C54ADAC5F80
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterElementIndexChangedEventArgs>{ 0x995EE1FD,0xE2C3,0x5FE3,{ 0x94,0x43,0xA9,0x5A,0x3F,0xAD,0x5A,0x9F } }; // 995EE1FD-E2C3-5FE3-9443-A95A3FAD5A9F
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterElementPreparedEventArgs>{ 0xA56D3912,0xEE00,0x560E,{ 0x8D,0x3E,0x0E,0xDF,0xD8,0xD5,0x66,0x91 } }; // A56D3912-EE00-560E-8D3E-0EDFD8D56691
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterFactory>{ 0xC3C1F244,0x67A8,0x568F,{ 0xA6,0xF7,0x5D,0xA8,0xB0,0xEA,0xDD,0x49 } }; // C3C1F244-67A8-568F-A6F7-5DA8B0EADD49
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterScrollHost>{ 0xA29B4785,0x8210,0x5E6E,{ 0xA4,0x0C,0x36,0xA8,0x2B,0x78,0x7B,0x4F } }; // A29B4785-8210-5E6E-A40C-36A82B787B4F
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterStatics>{ 0x0B85268A,0x6714,0x5D24,{ 0xA8,0x50,0xD4,0x33,0x8E,0x6A,0x91,0xA8 } }; // 0B85268A-6714-5D24-A850-D4338E6A91A8
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IItemsSourceView>{ 0xF7F802DE,0xE79C,0x5C5F,{ 0xAB,0xF8,0xCC,0xBD,0x48,0x6B,0x89,0xD6 } }; // F7F802DE-E79C-5C5F-ABF8-CCBD486B89D6
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IItemsSourceViewFactory>{ 0xAADC6FDD,0xEB00,0x5E58,{ 0xB9,0x5D,0x12,0x0F,0x89,0x1D,0x73,0x3F } }; // AADC6FDD-EB00-5E58-B95D-120F891D733F
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IKeyIndexMapping>{ 0xB1F3BBA0,0x108E,0x560D,{ 0x96,0x81,0x26,0x39,0x1B,0x4B,0xC3,0x0D } }; // B1F3BBA0-108E-560D-9681-26391B4BC30D
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ILayout>{ 0x24E50C1C,0x9C51,0x5144,{ 0x9D,0xDC,0x3F,0x50,0x01,0x91,0xC2,0x62 } }; // 24E50C1C-9C51-5144-9DDC-3F500191C262
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ILayoutContext>{ 0xB45A2E55,0x2ECC,0x5462,{ 0xBB,0x26,0xD4,0x7C,0x45,0x5B,0xB4,0x8E } }; // B45A2E55-2ECC-5462-BB26-D47C455BB48E
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ILayoutContextFactory>{ 0xF7664771,0x9242,0x599E,{ 0xA7,0xDD,0x07,0x05,0x56,0x5D,0xEF,0x98 } }; // F7664771-9242-599E-A7DD-0705565DEF98
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ILayoutContextOverrides>{ 0xFDA70E44,0x6526,0x5535,{ 0xBE,0x2B,0xEC,0x27,0x43,0x67,0x0A,0xE2 } }; // FDA70E44-6526-5535-BE2B-EC2743670AE2
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ILayoutFactory>{ 0xEAF956B4,0x59C9,0x5E13,{ 0xA4,0x9D,0xF3,0x5B,0x17,0x1D,0x8F,0xC9 } }; // EAF956B4-59C9-5E13-A49D-F35B171D8FC9
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ILayoutProtected>{ 0xE46FF416,0x741E,0x5176,{ 0xA1,0xD4,0x57,0x18,0xD2,0x34,0x22,0x43 } }; // E46FF416-741E-5176-A1D4-5718D2342243
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IMenuBar>{ 0xBA97F337,0x8F1E,0x5141,{ 0xB5,0x3F,0xE7,0x7A,0x8B,0xA3,0xEB,0xBD } }; // BA97F337-8F1E-5141-B53F-E77A8BA3EBBD
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IMenuBarFactory>{ 0x76AA8759,0x04EE,0x5A4C,{ 0xB9,0x8C,0xD0,0x37,0x42,0xD4,0x7C,0xDB } }; // 76AA8759-04EE-5A4C-B98C-D03742D47CDB
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItem>{ 0x9CAA4261,0x3A0C,0x5A59,{ 0x8C,0xFE,0x39,0x17,0x44,0xC3,0xF8,0x15 } }; // 9CAA4261-3A0C-5A59-8CFE-391744C3F815
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItemFactory>{ 0x87D02172,0x83CB,0x5459,{ 0x94,0x0F,0x17,0x3F,0x75,0x01,0xB3,0x00 } }; // 87D02172-83CB-5459-940F-173F7501B300
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItemFlyout>{ 0xA412AE4F,0xC3BC,0x5679,{ 0x8D,0x5F,0x86,0x5E,0xB9,0x7E,0x83,0xCD } }; // A412AE4F-C3BC-5679-8D5F-865EB97E83CD
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItemFlyoutFactory>{ 0xF895123E,0xED54,0x5A96,{ 0x84,0x18,0xF3,0x5E,0x48,0x50,0x5D,0x43 } }; // F895123E-ED54-5A96-8418-F35E48505D43
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItemStatics>{ 0x6282E536,0x1CFC,0x5D26,{ 0x9F,0x6D,0x8F,0x33,0x4D,0xAF,0x99,0x7E } }; // 6282E536-1CFC-5D26-9F6D-8F334DAF997E
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IMenuBarStatics>{ 0x10CB12F4,0xDCE0,0x514F,{ 0xAC,0xD1,0x0D,0x53,0xFA,0x02,0x75,0xD1 } }; // 10CB12F4-DCE0-514F-ACD1-0D53FA0275D1
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationView>{ 0xB00EB54C,0x9174,0x5D84,{ 0x96,0x78,0x56,0xC9,0x80,0x16,0xE6,0x89 } }; // B00EB54C-9174-5D84-9678-56C98016E689
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationView2>{ 0x5BA2EEFC,0x3736,0x5E42,{ 0xAC,0x56,0x9D,0x0B,0xE5,0x52,0x3D,0x40 } }; // 5BA2EEFC-3736-5E42-AC56-9D0BE5523D40
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewBackRequestedEventArgs>{ 0xAE752207,0xBD1B,0x5AFA,{ 0xA8,0x72,0xE9,0xBB,0xAE,0xEA,0x0E,0xDE } }; // AE752207-BD1B-5AFA-A872-E9BBAEEA0EDE
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewDisplayModeChangedEventArgs>{ 0x58DCF1EA,0x9E56,0x522C,{ 0xB3,0xF8,0x34,0xBD,0x55,0xEC,0xAC,0xA4 } }; // 58DCF1EA-9E56-522C-B3F8-34BD55ECACA4
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewFactory>{ 0xFFEA1ADA,0x9232,0x5507,{ 0xA3,0x20,0xED,0x2F,0xAD,0xBE,0x61,0x27 } }; // FFEA1ADA-9232-5507-A320-ED2FADBE6127
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItem>{ 0x143324CB,0xBB4C,0x5261,{ 0xAD,0x98,0xA3,0x1B,0x4B,0x57,0xA0,0xCC } }; // 143324CB-BB4C-5261-AD98-A31B4B57A0CC
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItem2>{ 0x2D5BD889,0x9DAC,0x5675,{ 0xB2,0x54,0x68,0x22,0x6F,0x07,0x7A,0x61 } }; // 2D5BD889-9DAC-5675-B254-68226F077A61
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItem3>{ 0xC6AA3120,0xD888,0x5C32,{ 0x8B,0xB7,0x49,0x0E,0xC9,0x1B,0x1A,0xEC } }; // C6AA3120-D888-5C32-8BB7-490EC91B1AEC
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemBase>{ 0x33586494,0xAF48,0x513F,{ 0xBE,0x4D,0xF6,0x45,0xE8,0xC8,0x90,0x05 } }; // 33586494-AF48-513F-BE4D-F645E8C89005
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemBase2>{ 0xD94EE683,0xD437,0x5523,{ 0x9C,0x5C,0x11,0xD4,0x80,0x4E,0x47,0x1E } }; // D94EE683-D437-5523-9C5C-11D4804E471E
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemBaseFactory>{ 0x31B9D7B1,0x7C38,0x5916,{ 0x99,0xC6,0xC7,0x1F,0x6B,0x01,0x2B,0x1B } }; // 31B9D7B1-7C38-5916-99C6-C71F6B012B1B
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemBaseStatics>{ 0x02B75190,0xE038,0x5233,{ 0x9D,0x7D,0xA6,0x00,0x99,0xDE,0xB5,0x8B } }; // 02B75190-E038-5233-9D7D-A60099DEB58B
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemCollapsedEventArgs>{ 0xB546F6A1,0xC66F,0x5DED,{ 0xB5,0xD7,0xBE,0xD0,0xA2,0x61,0x97,0xE3 } }; // B546F6A1-C66F-5DED-B5D7-BED0A26197E3
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemExpandingEventArgs>{ 0x6F0941BE,0xE991,0x52F8,{ 0x83,0x15,0xF0,0x83,0x89,0x49,0x79,0x76 } }; // 6F0941BE-E991-52F8-8315-F08389497976
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemFactory>{ 0xDE60A001,0x9385,0x5535,{ 0x80,0xE1,0x2B,0x68,0xF4,0xBF,0xDE,0x26 } }; // DE60A001-9385-5535-80E1-2B68F4BFDE26
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemHeader>{ 0x432BC062,0x45BC,0x57EF,{ 0xA2,0xD3,0x11,0x85,0x1A,0x56,0xA8,0x82 } }; // 432BC062-45BC-57EF-A2D3-11851A56A882
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemHeaderFactory>{ 0x6A5447CD,0x2918,0x5FE3,{ 0x89,0x9B,0x93,0xD6,0x96,0x12,0x85,0xE6 } }; // 6A5447CD-2918-5FE3-899B-93D6961285E6
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemInvokedEventArgs>{ 0x074CEBAA,0x5D05,0x547B,{ 0x8C,0xD6,0xD1,0x9A,0xC2,0xD9,0xBB,0x3B } }; // 074CEBAA-5D05-547B-8CD6-D19AC2D9BB3B
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemInvokedEventArgs2>{ 0xF4B3EDA4,0x3333,0x51ED,{ 0x92,0x51,0x9C,0xF4,0x79,0xF1,0x55,0xC3 } }; // F4B3EDA4-3333-51ED-9251-9CF479F155C3
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemSeparator>{ 0xE3C35630,0x1D5F,0x5689,{ 0xA0,0xCB,0x87,0x94,0x48,0x5C,0xAA,0xCF } }; // E3C35630-1D5F-5689-A0CB-8794485CAACF
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemSeparatorFactory>{ 0x181266A1,0xD4F8,0x5AF7,{ 0x81,0x0B,0xAE,0xE8,0xA1,0xD4,0x52,0xED } }; // 181266A1-D4F8-5AF7-810B-AEE8A1D452ED
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemStatics>{ 0x00336D86,0xC1C5,0x55BF,{ 0xA2,0x0D,0xA9,0xF4,0x51,0x23,0x63,0xEF } }; // 00336D86-C1C5-55BF-A20D-A9F4512363EF
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemStatics2>{ 0x3F9F2A50,0x0737,0x5F45,{ 0x80,0x84,0x90,0xFD,0x62,0x8F,0xDB,0x13 } }; // 3F9F2A50-0737-5F45-8084-90FD628FDB13
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemStatics3>{ 0xA1524411,0x3ED8,0x55D3,{ 0x90,0x4A,0x0E,0x8F,0x2E,0x87,0x90,0x7E } }; // A1524411-3ED8-55D3-904A-0E8F2E87907E
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewPaneClosingEventArgs>{ 0xE8643304,0x6DB4,0x5AF5,{ 0xBA,0xC2,0x62,0x73,0x3C,0xA0,0x37,0xDA } }; // E8643304-6DB4-5AF5-BAC2-62733CA037DA
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewSelectionChangedEventArgs>{ 0x14A064A5,0xC79D,0x5F63,{ 0xAC,0x6E,0x1C,0x31,0x3F,0xE6,0x35,0x66 } }; // 14A064A5-C79D-5F63-AC6E-1C313FE63566
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewSelectionChangedEventArgs2>{ 0x38DAEB2B,0x5363,0x51E3,{ 0xBE,0xD4,0x65,0x36,0x41,0xB5,0x63,0x36 } }; // 38DAEB2B-5363-51E3-BED4-653641B56336
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewStatics>{ 0x21DE4B8B,0x3809,0x5E91,{ 0x85,0x06,0x68,0x22,0x2B,0xEF,0x82,0xE8 } }; // 21DE4B8B-3809-5E91-8506-68222BEF82E8
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewStatics2>{ 0x23D94681,0x6EBC,0x583B,{ 0xA7,0x70,0xA4,0x47,0x5A,0x74,0x41,0xCF } }; // 23D94681-6EBC-583B-A770-A4475A7441CF
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettings>{ 0xAE37A75D,0x4C4F,0x504D,{ 0x83,0xDC,0xA8,0x94,0xF4,0x08,0xF8,0x7C } }; // AE37A75D-4C4F-504D-83DC-A894F408F87C
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettings2>{ 0x56BEC72F,0x1DE1,0x5060,{ 0xA4,0x4C,0x18,0x78,0x85,0xDF,0x29,0x73 } }; // 56BEC72F-1DE1-5060-A44C-187885DF2973
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettingsFactory>{ 0x34FF6C94,0x6465,0x5F3E,{ 0xB0,0xA5,0x4F,0x1E,0xEA,0x48,0xE7,0x43 } }; // 34FF6C94-6465-5F3E-B0A5-4F1EEA48E743
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettingsStatics>{ 0xB25095FF,0xB7FE,0x5AAE,{ 0x99,0x9B,0x1F,0x1F,0x01,0xD5,0xFA,0x12 } }; // B25095FF-B7FE-5AAE-999B-1F1F01D5FA12
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettingsStatics2>{ 0xBFDF3AF6,0xD37D,0x53CE,{ 0x97,0x93,0xCC,0xCF,0x7E,0x92,0x6D,0xF9 } }; // BFDF3AF6-D37D-53CE-9793-CCCF7E926DF9
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayout>{ 0x0C24DEFD,0xF68F,0x51D9,{ 0x99,0x8E,0x4C,0xBA,0xD4,0x8B,0xE0,0x12 } }; // 0C24DEFD-F68F-51D9-998E-4CBAD48BE012
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutContext>{ 0x0BA9C1BB,0x651C,0x5F63,{ 0xBC,0xBB,0x7B,0xDF,0xE7,0x4B,0x7B,0x38 } }; // 0BA9C1BB-651C-5F63-BCBB-7BDFE74B7B38
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutContextFactory>{ 0xDABAC020,0x189C,0x5BBF,{ 0xA4,0xDC,0x97,0xDA,0x11,0x99,0xF5,0x77 } }; // DABAC020-189C-5BBF-A4DC-97DA1199F577
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutContextOverrides>{ 0xF8D4589F,0xB38B,0x5C09,{ 0x83,0x56,0xC7,0x3E,0xCF,0xB6,0xEE,0xD8 } }; // F8D4589F-B38B-5C09-8356-C73ECFB6EED8
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutFactory>{ 0xA16D2D12,0xDBAC,0x5CE0,{ 0xAE,0xF5,0x09,0x17,0x1A,0x4D,0x35,0x71 } }; // A16D2D12-DBAC-5CE0-AEF5-09171A4D3571
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutOverrides>{ 0x3C28B831,0x35C1,0x5182,{ 0xA8,0x43,0xA4,0x3F,0x33,0x9B,0x66,0x87 } }; // 3C28B831-35C1-5182-A843-A43F339B6687
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INumberBox>{ 0x22C43A67,0xD393,0x56A9,{ 0x80,0x1A,0x2D,0xEA,0x91,0x87,0x7D,0xE6 } }; // 22C43A67-D393-56A9-801A-2DEA91877DE6
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INumberBoxFactory>{ 0x6B81F3CB,0x45A4,0x5D19,{ 0x9B,0xBB,0xA9,0xFE,0x46,0x56,0xAC,0x4D } }; // 6B81F3CB-45A4-5D19-9BBB-A9FE4656AC4D
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INumberBoxStatics>{ 0x7C58A821,0x453D,0x556D,{ 0xA2,0x25,0x57,0x50,0x51,0x3F,0x71,0x79 } }; // 7C58A821-453D-556D-A225-5750513F7179
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::INumberBoxValueChangedEventArgs>{ 0xC66CF16E,0x7C8A,0x532E,{ 0x9D,0x23,0x05,0x8C,0x1C,0x98,0xDD,0x50 } }; // C66CF16E-7C8A-532E-9D23-058C1C98DD50
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IParallaxView>{ 0x692E1E53,0x4231,0x5DE0,{ 0xAC,0xB4,0x85,0x9E,0x49,0x4D,0xAB,0x73 } }; // 692E1E53-4231-5DE0-ACB4-859E494DAB73
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IParallaxViewFactory>{ 0x61DC973D,0xC595,0x5261,{ 0xA9,0xB7,0x35,0xF4,0x10,0x42,0xEB,0x00 } }; // 61DC973D-C595-5261-A9B7-35F41042EB00
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IParallaxViewStatics>{ 0xB17A0882,0xE92E,0x5AA0,{ 0x92,0xD5,0x3D,0xE6,0x9F,0x0E,0x6A,0xA8 } }; // B17A0882-E92E-5AA0-92D5-3DE69F0E6AA8
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IPathIconSource>{ 0x3C89356E,0x0A21,0x5E5E,{ 0xA2,0xBA,0xD8,0x83,0x73,0x65,0x14,0x3B } }; // 3C89356E-0A21-5E5E-A2BA-D8837365143B
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IPathIconSourceFactory>{ 0x9FEFE31E,0x5AB6,0x5394,{ 0xA6,0xEF,0x67,0x2F,0x17,0x4D,0x33,0x3B } }; // 9FEFE31E-5AB6-5394-A6EF-672F174D333B
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IPathIconSourceStatics>{ 0x1CA1C9F2,0x2E93,0x5877,{ 0xB6,0x40,0x83,0x61,0x42,0xC2,0xFA,0xC0 } }; // 1CA1C9F2-2E93-5877-B640-836142C2FAC0
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IPersonPicture>{ 0x976B210A,0xDDFF,0x5E30,{ 0x9F,0xBD,0x95,0x12,0x3B,0xE9,0xAA,0xAC } }; // 976B210A-DDFF-5E30-9FBD-95123BE9AAAC
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IPersonPictureFactory>{ 0x7EC0794C,0xF2CC,0x5282,{ 0xA8,0x9D,0xCD,0x3B,0xB7,0x65,0xB7,0x1A } }; // 7EC0794C-F2CC-5282-A89D-CD3BB765B71A
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IPersonPictureStatics>{ 0xD1AFCF40,0xB7BB,0x5873,{ 0x9A,0xB5,0x9E,0xE6,0xF0,0x65,0xDD,0x1E } }; // D1AFCF40-B7BB-5873-9AB5-9EE6F065DD1E
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IPersonPictureTemplateSettings>{ 0x9FB4BA10,0xCBF8,0x5DBF,{ 0x91,0x8A,0x83,0x23,0xDA,0xA4,0xF7,0xE4 } }; // 9FB4BA10-CBF8-5DBF-918A-8323DAA4F7E4
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IPipsPager>{ 0xDB89F276,0xC9D8,0x5BC2,{ 0xB9,0xAD,0xAB,0x8E,0xF3,0x3E,0xD8,0xE1 } }; // DB89F276-C9D8-5BC2-B9AD-AB8EF33ED8E1
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IPipsPagerFactory>{ 0x020722CD,0x813A,0x5165,{ 0xA8,0x99,0x3D,0xF9,0xAD,0xCD,0x80,0x5E } }; // 020722CD-813A-5165-A899-3DF9ADCD805E
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IPipsPagerSelectedIndexChangedEventArgs>{ 0x6C2CE4FC,0xBF52,0x5CA6,{ 0x9D,0xA4,0xB0,0xBD,0x5B,0x92,0x8D,0x97 } }; // 6C2CE4FC-BF52-5CA6-9DA4-B0BD5B928D97
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IPipsPagerStatics>{ 0xB04C8DE3,0x8FFA,0x5F7D,{ 0xBF,0x1C,0xB4,0x3A,0x35,0x3E,0x19,0x53 } }; // B04C8DE3-8FFA-5F7D-BF1C-B43A353E1953
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IPipsPagerTemplateSettings>{ 0x9D8C1252,0x56C5,0x57AF,{ 0x9A,0x3A,0x08,0xE9,0xB9,0x47,0xE5,0xFA } }; // 9D8C1252-56C5-57AF-9A3A-08E9B947E5FA
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IProgressBar>{ 0x87555C8C,0x0AAF,0x52C1,{ 0x83,0x90,0x0D,0xB1,0x7F,0x40,0x43,0x8E } }; // 87555C8C-0AAF-52C1-8390-0DB17F40438E
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IProgressBarFactory>{ 0x189826AD,0xF6F2,0x533E,{ 0x9D,0xDB,0xB6,0x60,0x0E,0x88,0x67,0x5B } }; // 189826AD-F6F2-533E-9DDB-B6600E88675B
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IProgressBarStatics>{ 0x72A634C1,0xB22D,0x55FA,{ 0x90,0x9D,0x7B,0x74,0x58,0xAB,0x14,0xE2 } }; // 72A634C1-B22D-55FA-909D-7B7458AB14E2
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IProgressBarTemplateSettings>{ 0x20D22A89,0x59F1,0x5E47,{ 0x8C,0x88,0xF0,0x6F,0x95,0x92,0x9E,0xEC } }; // 20D22A89-59F1-5E47-8C88-F06F95929EEC
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IProgressRing>{ 0x2670D03F,0xE28C,0x5652,{ 0xBE,0xE2,0xB5,0x21,0x2E,0xBD,0xF7,0xFF } }; // 2670D03F-E28C-5652-BEE2-B5212EBDF7FF
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IProgressRingFactory>{ 0x092FA98C,0x62A7,0x5DBC,{ 0x9A,0x85,0x3E,0x55,0x6B,0xA8,0x1F,0x79 } }; // 092FA98C-62A7-5DBC-9A85-3E556BA81F79
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IProgressRingStatics>{ 0x3D02672D,0x8803,0x5F31,{ 0x9B,0x8E,0x1B,0xE1,0xA8,0xA0,0xD5,0xE1 } }; // 3D02672D-8803-5F31-9B8E-1BE1A8A0D5E1
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IProgressRingTemplateSettings>{ 0xD1B7AACA,0x07A0,0x55EF,{ 0xA9,0xC5,0x8E,0x44,0xED,0xAD,0x74,0x99 } }; // D1B7AACA-07A0-55EF-A9C5-8E44EDAD7499
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRadioButtons>{ 0xDD372D64,0xB740,0x5739,{ 0x8D,0x24,0xB6,0xDE,0xCC,0x91,0xF4,0x08 } }; // DD372D64-B740-5739-8D24-B6DECC91F408
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRadioButtonsFactory>{ 0x2CF95EFB,0xA7A2,0x5D85,{ 0x8E,0xAD,0xEA,0x22,0x2B,0xAA,0x3C,0x55 } }; // 2CF95EFB-A7A2-5D85-8EAD-EA222BAA3C55
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRadioButtonsStatics>{ 0x106FBFBD,0x4304,0x5D4D,{ 0x8E,0x6A,0xC4,0xC1,0x5A,0xBB,0xBB,0xEF } }; // 106FBFBD-4304-5D4D-8E6A-C4C15ABBBBEF
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRadioMenuFlyoutItem>{ 0x9D6F45F5,0x5532,0x5669,{ 0x8F,0x02,0x05,0x73,0x59,0x53,0x02,0x6A } }; // 9D6F45F5-5532-5669-8F02-05735953026A
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRadioMenuFlyoutItemFactory>{ 0x113822D2,0x35A3,0x5B0D,{ 0x9D,0x0D,0xC3,0x83,0x0E,0xC1,0x97,0x3B } }; // 113822D2-35A3-5B0D-9D0D-C3830EC1973B
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRadioMenuFlyoutItemStatics>{ 0x2C8FD4AA,0xB8D8,0x543C,{ 0xA1,0xBE,0x9E,0x00,0x87,0x27,0xC1,0x58 } }; // 2C8FD4AA-B8D8-543C-A1BE-9E008727C158
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRadioMenuFlyoutItemStatics2>{ 0x074EF4E9,0x26B3,0x5897,{ 0xAC,0x6F,0x10,0xCF,0x09,0x47,0xAA,0xDA } }; // 074EF4E9-26B3-5897-AC6F-10CF0947AADA
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRatingControl>{ 0x5488193B,0xEA4B,0x52C6,{ 0x85,0x44,0xC0,0x63,0x21,0x9B,0xCD,0x90 } }; // 5488193B-EA4B-52C6-8544-C063219BCD90
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRatingControlFactory>{ 0xA53B9B73,0xBFF9,0x548D,{ 0xA2,0x94,0xAC,0x63,0xD8,0x19,0xF7,0x8A } }; // A53B9B73-BFF9-548D-A294-AC63D819F78A
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRatingControlStatics>{ 0x3752A048,0xF3F2,0x5EF6,{ 0x87,0x8D,0x49,0x95,0x72,0xF0,0x52,0x9B } }; // 3752A048-F3F2-5EF6-878D-499572F0529B
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRatingItemFontInfo>{ 0x995A16DC,0x3A0F,0x5727,{ 0x9F,0x38,0x52,0xCF,0xC8,0x14,0x36,0x54 } }; // 995A16DC-3A0F-5727-9F38-52CFC8143654
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRatingItemFontInfoFactory>{ 0x109C6541,0x706E,0x5FD7,{ 0xBA,0xAE,0x02,0x0B,0x24,0x89,0x9F,0x61 } }; // 109C6541-706E-5FD7-BAAE-020B24899F61
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRatingItemFontInfoStatics>{ 0x7C626902,0xA13F,0x5470,{ 0xA5,0x22,0xBD,0x54,0x14,0xDF,0x8E,0xD3 } }; // 7C626902-A13F-5470-A522-BD5414DF8ED3
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRatingItemImageInfo>{ 0x610268E4,0xAF6E,0x5C1C,{ 0x8D,0x0F,0xBB,0x46,0xC0,0x6D,0x67,0x82 } }; // 610268E4-AF6E-5C1C-8D0F-BB46C06D6782
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRatingItemImageInfoFactory>{ 0x4ACC8CAC,0xBCA8,0x5380,{ 0x95,0xE4,0x34,0x5C,0x1B,0xE2,0x56,0xB2 } }; // 4ACC8CAC-BCA8-5380-95E4-345C1BE256B2
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRatingItemImageInfoStatics>{ 0xB8E6F05B,0x0AF5,0x5AA8,{ 0x8E,0x85,0xFD,0x02,0x2D,0x4C,0x69,0x08 } }; // B8E6F05B-0AF5-5AA8-8E85-FD022D4C6908
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRatingItemInfo>{ 0x801E924E,0x3613,0x55DD,{ 0x83,0x21,0x9E,0xBA,0xBB,0xED,0x0B,0x8A } }; // 801E924E-3613-55DD-8321-9EBABBED0B8A
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRatingItemInfoFactory>{ 0x61F13480,0xCD0C,0x556A,{ 0xB5,0x32,0xA0,0xCF,0x53,0xE3,0xCD,0xA0 } }; // 61F13480-CD0C-556A-B532-A0CF53E3CDA0
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRefreshContainer>{ 0x1C9778E8,0xA427,0x5F86,{ 0x9D,0x5E,0x02,0xDB,0x9B,0x2C,0x40,0x93 } }; // 1C9778E8-A427-5F86-9D5E-02DB9B2C4093
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRefreshContainerFactory>{ 0x5F228FA1,0x2EA2,0x52B5,{ 0xB7,0x8A,0x0C,0x13,0x3F,0x86,0xF0,0x20 } }; // 5F228FA1-2EA2-52B5-B78A-0C133F86F020
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRefreshContainerStatics>{ 0x1F2BC1C8,0x5C8F,0x5B46,{ 0x8B,0x0F,0xE0,0x06,0xDB,0x4E,0xC6,0xE1 } }; // 1F2BC1C8-5C8F-5B46-8B0F-E006DB4EC6E1
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRefreshInteractionRatioChangedEventArgs>{ 0x790B70E0,0xF199,0x552B,{ 0xB1,0x26,0x6C,0xB4,0x5C,0x2D,0xE8,0xF9 } }; // 790B70E0-F199-552B-B126-6CB45C2DE8F9
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRefreshRequestedEventArgs>{ 0xED97A956,0x6019,0x5329,{ 0x93,0x12,0xF8,0x85,0xB5,0xC7,0x74,0xCD } }; // ED97A956-6019-5329-9312-F885B5C774CD
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRefreshStateChangedEventArgs>{ 0x7BE897CE,0x17C4,0x5FDF,{ 0xB4,0x41,0xC6,0xEF,0x33,0x01,0xE0,0xF6 } }; // 7BE897CE-17C4-5FDF-B441-C6EF3301E0F6
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRefreshVisualizer>{ 0xA000AFD1,0xD2FC,0x5391,{ 0xB4,0x21,0xEE,0x5C,0x97,0x5A,0xC9,0x45 } }; // A000AFD1-D2FC-5391-B421-EE5C975AC945
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRefreshVisualizerFactory>{ 0x9D6F2BF2,0x6628,0x582A,{ 0x89,0x2B,0x68,0xC2,0x77,0x0C,0x17,0x3C } }; // 9D6F2BF2-6628-582A-892B-68C2770C173C
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRefreshVisualizerStatics>{ 0x7E9E32AB,0x3C39,0x58AC,{ 0x9D,0x0D,0x46,0x48,0xBE,0x22,0x0B,0xDC } }; // 7E9E32AB-3C39-58AC-9D0D-4648BE220BDC
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRevealListViewItemPresenter>{ 0x365FDBAC,0x3989,0x559C,{ 0xBE,0xA9,0x76,0x45,0x61,0x88,0x1C,0x96 } }; // 365FDBAC-3989-559C-BEA9-764561881C96
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IRevealListViewItemPresenterFactory>{ 0xE730C53B,0x8F94,0x55B3,{ 0x8B,0xC1,0x98,0xF7,0x7C,0x57,0x66,0xBD } }; // E730C53B-8F94-55B3-8BC1-98F77C5766BD
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ISplitButton>{ 0x8B09006A,0x6241,0x594F,{ 0x93,0xE4,0x8B,0xF0,0x51,0xD7,0xBA,0x8F } }; // 8B09006A-6241-594F-93E4-8BF051D7BA8F
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ISplitButtonClickEventArgs>{ 0x6AF896C2,0xE65A,0x5998,{ 0x9C,0x82,0x2A,0xF8,0xF3,0xE0,0x74,0x1F } }; // 6AF896C2-E65A-5998-9C82-2AF8F3E0741F
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ISplitButtonFactory>{ 0x07510092,0x2612,0x55E7,{ 0x98,0x1C,0xA5,0x36,0xDD,0xD4,0x57,0x0E } }; // 07510092-2612-55E7-981C-A536DDD4570E
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ISplitButtonStatics>{ 0x7262C1E0,0x97CD,0x5561,{ 0xB6,0xE7,0x5E,0x2E,0xCE,0xA4,0x6A,0xC2 } }; // 7262C1E0-97CD-5561-B6E7-5E2ECEA46AC2
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IStackLayout>{ 0x6BF7F61B,0x0CEF,0x5D92,{ 0xA8,0x28,0x93,0xEF,0xBD,0x6D,0xF4,0xC1 } }; // 6BF7F61B-0CEF-5D92-A828-93EFBD6DF4C1
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IStackLayoutFactory>{ 0xEA606F86,0x21A1,0x5C35,{ 0x91,0x1E,0x4A,0x1D,0xE8,0xBC,0x69,0xD9 } }; // EA606F86-21A1-5C35-911E-4A1DE8BC69D9
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IStackLayoutStatics>{ 0xF69CAEFE,0x9D6F,0x5B90,{ 0x9D,0x3D,0xF4,0x7E,0xCE,0xB5,0x5D,0x20 } }; // F69CAEFE-9D6F-5B90-9D3D-F47ECEB55D20
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ISwipeControl>{ 0x337800FE,0xF51D,0x5F6B,{ 0x9D,0x35,0xE7,0xF5,0xDE,0x10,0xA9,0x7C } }; // 337800FE-F51D-5F6B-9D35-E7F5DE10A97C
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ISwipeControlFactory>{ 0x6E9213F4,0x30C1,0x56CA,{ 0x99,0x05,0x46,0xAA,0x1A,0x83,0xDF,0xC1 } }; // 6E9213F4-30C1-56CA-9905-46AA1A83DFC1
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ISwipeControlStatics>{ 0xBE0EB518,0x40B4,0x5CED,{ 0x8D,0xFB,0x6C,0xA0,0x18,0xF1,0xCA,0xCA } }; // BE0EB518-40B4-5CED-8DFB-6CA018F1CACA
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ISwipeItem>{ 0x560FE6C5,0x109F,0x5866,{ 0xB0,0x2E,0x31,0xE4,0xFA,0x93,0x0E,0xD0 } }; // 560FE6C5-109F-5866-B02E-31E4FA930ED0
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemFactory>{ 0x011513E1,0x1ADC,0x5A69,{ 0xA7,0x4F,0x62,0x3F,0xCC,0x18,0xA5,0x1C } }; // 011513E1-1ADC-5A69-A74F-623FCC18A51C
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemInvokedEventArgs>{ 0x7BF51C95,0x53A2,0x5A0D,{ 0xBB,0x32,0x2B,0x4B,0x1F,0x7D,0x2F,0x20 } }; // 7BF51C95-53A2-5A0D-BB32-2B4B1F7D2F20
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemStatics>{ 0x793256E1,0x27C7,0x5387,{ 0xBB,0x27,0x53,0xD0,0x72,0x72,0x36,0x25 } }; // 793256E1-27C7-5387-BB27-53D072723625
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ISwipeItems>{ 0x40D3022B,0xC82B,0x5565,{ 0xA4,0xE4,0xAD,0x9D,0x7A,0x66,0xB1,0xA9 } }; // 40D3022B-C82B-5565-A4E4-AD9D7A66B1A9
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemsFactory>{ 0x9A5D7D77,0x39BD,0x5B81,{ 0xAB,0x4E,0xF4,0x4A,0xCA,0x6E,0xDE,0x3F } }; // 9A5D7D77-39BD-5B81-AB4E-F44ACA6EDE3F
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemsStatics>{ 0x78D47697,0xEAF2,0x5652,{ 0x9A,0xFC,0xD7,0x13,0xCA,0x10,0x34,0x88 } }; // 78D47697-EAF2-5652-9AFC-D713CA103488
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ISymbolIconSource>{ 0x1F8098D4,0xF3EA,0x5360,{ 0xB0,0xAA,0x80,0x65,0xBB,0x72,0x26,0xAE } }; // 1F8098D4-F3EA-5360-B0AA-8065BB7226AE
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ISymbolIconSourceFactory>{ 0xAFBF55FA,0xFF79,0x552A,{ 0xA3,0xA1,0x48,0xE2,0xEF,0x17,0x15,0x2A } }; // AFBF55FA-FF79-552A-A3A1-48E2EF17152A
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ISymbolIconSourceStatics>{ 0x967C25AF,0x2A94,0x5E50,{ 0xA9,0x21,0x58,0x7D,0x8F,0xE8,0x11,0x43 } }; // 967C25AF-2A94-5E50-A921-587D8FE81143
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITabView>{ 0x6AA787AB,0x5A30,0x5EA2,{ 0xBE,0x5B,0xAE,0xD8,0x68,0x38,0x17,0x56 } }; // 6AA787AB-5A30-5EA2-BE5B-AED868381756
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewFactory>{ 0xE7E83685,0xEEDF,0x5106,{ 0x94,0x29,0x88,0x44,0x35,0xAB,0x16,0x6B } }; // E7E83685-EEDF-5106-9429-884435AB166B
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewItem>{ 0x291F3E98,0x4F17,0x5021,{ 0x94,0xF0,0x6A,0x5B,0x30,0x43,0x12,0xB6 } }; // 291F3E98-4F17-5021-94F0-6A5B304312B6
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemFactory>{ 0xB64C2423,0x7E56,0x5D41,{ 0x8A,0x84,0x1E,0xE2,0x8F,0x98,0x26,0xA4 } }; // B64C2423-7E56-5D41-8A84-1EE28F9826A4
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemStatics>{ 0x0A4FA876,0xDC4A,0x5648,{ 0x91,0x14,0xC3,0xB3,0x92,0xDE,0x31,0x29 } }; // 0A4FA876-DC4A-5648-9114-C3B392DE3129
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettings>{ 0xD1B2D760,0xCC38,0x5A96,{ 0xBC,0x92,0x10,0xEE,0x3B,0x36,0x98,0x8C } }; // D1B2D760-CC38-5A96-BC92-10EE3B36988C
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettings2>{ 0xA6366FF2,0x2C7A,0x535A,{ 0xB2,0xA2,0xBB,0x5F,0xB5,0x76,0x5F,0xD9 } }; // A6366FF2-2C7A-535A-B2A2-BB5FB5765FD9
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettingsFactory>{ 0xCBA3E467,0x4C98,0x5885,{ 0xBA,0x24,0x6F,0xA6,0x99,0xCC,0x8E,0xDD } }; // CBA3E467-4C98-5885-BA24-6FA699CC8EDD
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettingsStatics>{ 0x40A40ABA,0x9EC2,0x5B55,{ 0xB6,0xE4,0x75,0x56,0xA5,0xA0,0x60,0x18 } }; // 40A40ABA-9EC2-5B55-B6E4-7556A5A06018
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettingsStatics2>{ 0x112CEB32,0x4125,0x551E,{ 0xAF,0x86,0xB1,0x65,0x1C,0x78,0xBB,0x34 } }; // 112CEB32-4125-551E-AF86-B1651C78BB34
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewStatics>{ 0x3FCAB90C,0xDDAC,0x53E5,{ 0x83,0xAB,0x7A,0x8E,0x9E,0xE9,0x38,0x89 } }; // 3FCAB90C-DDAC-53E5-83AB-7A8E9EE93889
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewTabCloseRequestedEventArgs>{ 0xD56AB9B2,0xE264,0x5C7E,{ 0xA1,0xCB,0xE4,0x1A,0x16,0xA6,0xC6,0xC6 } }; // D56AB9B2-E264-5C7E-A1CB-E41A16A6C6C6
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewTabDragCompletedEventArgs>{ 0x791FC623,0xC8F6,0x5102,{ 0x81,0xBD,0x18,0x69,0xCD,0xE8,0x22,0x84 } }; // 791FC623-C8F6-5102-81BD-1869CDE82284
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewTabDragStartingEventArgs>{ 0x97682812,0x1A7B,0x53FD,{ 0x8B,0x4E,0xC2,0xF7,0x0D,0x2A,0xD2,0x50 } }; // 97682812-1A7B-53FD-8B4E-C2F70D2AD250
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITabViewTabDroppedOutsideEventArgs>{ 0x1F1F4D5D,0x0FB1,0x51AB,{ 0xB6,0x6F,0xF7,0xA3,0x22,0xBF,0x2D,0x13 } }; // 1F1F4D5D-0FB1-51AB-B66F-F7A322BF2D13
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITeachingTip>{ 0x5B200440,0x4FCC,0x5FDB,{ 0xB4,0x18,0xB5,0x79,0x7B,0x08,0x74,0xAD } }; // 5B200440-4FCC-5FDB-B418-B5797B0874AD
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipClosedEventArgs>{ 0x2536F506,0x4038,0x59DB,{ 0x9E,0x35,0xA9,0x25,0x2F,0xB5,0xAD,0xB2 } }; // 2536F506-4038-59DB-9E35-A9252FB5ADB2
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipClosingEventArgs>{ 0x16F53512,0x3C55,0x5636,{ 0xA8,0x56,0x22,0x9D,0x97,0x68,0xD6,0x4E } }; // 16F53512-3C55-5636-A856-229D9768D64E
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipFactory>{ 0xA3ECD47D,0x2972,0x5D19,{ 0xA6,0x2E,0xDD,0xFB,0xC5,0xE1,0xAD,0x57 } }; // A3ECD47D-2972-5D19-A62E-DDFBC5E1AD57
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipStatics>{ 0xC8723FEB,0xBDC8,0x566E,{ 0xAD,0x5C,0x6F,0x07,0x25,0x4A,0xF9,0x37 } }; // C8723FEB-BDC8-566E-AD5C-6F07254AF937
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipTemplateSettings>{ 0x677A43E5,0x8FF2,0x51CD,{ 0x97,0x42,0xA2,0x15,0x5E,0x20,0xD7,0x72 } }; // 677A43E5-8FF2-51CD-9742-A2155E20D772
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipTemplateSettingsFactory>{ 0x63210545,0xE195,0x56CD,{ 0xBC,0xCD,0x16,0x92,0x55,0xE1,0x34,0xE3 } }; // 63210545-E195-56CD-BCCD-169255E134E3
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipTemplateSettingsStatics>{ 0x6295DAC8,0x7102,0x5602,{ 0xB8,0xF9,0xE5,0x00,0xE5,0x98,0x44,0x8F } }; // 6295DAC8-7102-5602-B8F9-E500E598448F
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITextCommandBarFlyout>{ 0x6D0F38A5,0x0EB3,0x5D73,{ 0x81,0x95,0xD2,0xD8,0x9B,0x76,0xB0,0xF7 } }; // 6D0F38A5-0EB3-5D73-8195-D2D89B76B0F7
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITextCommandBarFlyoutFactory>{ 0x5C56A34F,0x621F,0x55F2,{ 0x8D,0x71,0x3E,0x3A,0x6E,0x69,0x06,0xBD } }; // 5C56A34F-621F-55F2-8D71-3E3A6E6906BD
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButton>{ 0x5C0F247B,0xBD00,0x5509,{ 0x88,0xA8,0xB0,0x90,0x07,0xAE,0x22,0xB0 } }; // 5C0F247B-BD00-5509-88A8-B09007AE22B0
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButtonFactory>{ 0x25459D02,0x0FFC,0x5C7C,{ 0xAF,0x56,0xF5,0x5A,0xAD,0x6D,0xB5,0xE7 } }; // 25459D02-0FFC-5C7C-AF56-F55AAD6DB5E7
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButtonIsCheckedChangedEventArgs>{ 0x6CAB1E15,0xC017,0x5760,{ 0x82,0x8B,0xDA,0xFC,0x21,0xD5,0x4E,0xB2 } }; // 6CAB1E15-C017-5760-828B-DAFC21D54EB2
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButtonStatics>{ 0xCEE1275D,0xF1DC,0x5CD5,{ 0xA3,0xD4,0xE5,0x6B,0xCE,0xEE,0xFA,0x88 } }; // CEE1275D-F1DC-5CD5-A3D4-E56BCEEEFA88
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeView>{ 0x1BEF9AF4,0x712C,0x50EF,{ 0x9B,0xB4,0x88,0x1B,0x97,0x52,0x32,0xAB } }; // 1BEF9AF4-712C-50EF-9BB4-881B975232AB
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeView2>{ 0xA8AEAAC2,0x8D43,0x58DE,{ 0xA7,0x35,0x62,0x68,0xB7,0xAC,0x95,0x47 } }; // A8AEAAC2-8D43-58DE-A735-6268B7AC9547
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewCollapsedEventArgs>{ 0x8EE00B59,0x42C6,0x5D73,{ 0x80,0x9F,0x68,0x71,0x00,0x88,0xE5,0xA5 } }; // 8EE00B59-42C6-5D73-809F-68710088E5A5
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewCollapsedEventArgs2>{ 0x77804A23,0x9FEB,0x5C57,{ 0x9C,0x95,0x4D,0xD9,0x84,0x26,0x72,0x17 } }; // 77804A23-9FEB-5C57-9C95-4DD984267217
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewDragItemsCompletedEventArgs>{ 0xE5B8547E,0xF839,0x55DB,{ 0x9C,0x26,0x2A,0x95,0xF5,0x7A,0x60,0xDC } }; // E5B8547E-F839-55DB-9C26-2A95F57A60DC
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewDragItemsCompletedEventArgs2>{ 0x060D3921,0x57A0,0x5BC5,{ 0xBE,0x26,0x32,0x0B,0xD9,0xC1,0xA6,0xE8 } }; // 060D3921-57A0-5BC5-BE26-320BD9C1A6E8
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewDragItemsStartingEventArgs>{ 0x1B6C4FFC,0xCD32,0x5E06,{ 0xB7,0x82,0xDF,0x9F,0x07,0x75,0x46,0xC7 } }; // 1B6C4FFC-CD32-5E06-B782-DF9F077546C7
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewExpandingEventArgs>{ 0xBD769EF7,0xCADC,0x5334,{ 0x93,0xAD,0xC9,0xBB,0xE8,0x20,0x64,0x3D } }; // BD769EF7-CADC-5334-93AD-C9BBE820643D
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewExpandingEventArgs2>{ 0xED7840E5,0xDBF5,0x5937,{ 0x89,0xDD,0x99,0x7A,0x6F,0xDE,0x0D,0x5C } }; // ED7840E5-DBF5-5937-89DD-997A6FDE0D5C
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewFactory>{ 0x9C6220BE,0xF9EB,0x518A,{ 0xB3,0x0E,0x7E,0x41,0xDE,0x5E,0xFD,0xA9 } }; // 9C6220BE-F9EB-518A-B30E-7E41DE5EFDA9
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItem>{ 0xBDBE765C,0x5747,0x516A,{ 0x9E,0x0D,0xB1,0xCD,0x20,0x99,0x38,0x4C } }; // BDBE765C-5747-516A-9E0D-B1CD2099384C
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItem2>{ 0xB1B70143,0x3F5B,0x54F4,{ 0x8B,0xD7,0x41,0xDC,0x15,0xCF,0x45,0xA9 } }; // B1B70143-3F5B-54F4-8BD7-41DC15CF45A9
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemFactory>{ 0x878FD918,0xE77E,0x5BE8,{ 0x8C,0x8A,0xB7,0x9B,0x27,0xB0,0x8D,0x9B } }; // 878FD918-E77E-5BE8-8C8A-B79B27B08D9B
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemInvokedEventArgs>{ 0x1A05853C,0xB101,0x542C,{ 0x9A,0x1E,0x77,0x5A,0x04,0x4C,0x46,0x52 } }; // 1A05853C-B101-542C-9A1E-775A044C4652
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemStatics>{ 0x1EF541D8,0xF94D,0x5F82,{ 0x9F,0x43,0x1A,0x54,0xEC,0xEA,0xD4,0x4D } }; // 1EF541D8-F94D-5F82-9F43-1A54ECEAD44D
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemStatics2>{ 0x773CEF85,0x6D1B,0x5A6C,{ 0x80,0x1D,0xF4,0x22,0xB1,0xA8,0x1F,0x98 } }; // 773CEF85-6D1B-5A6C-801D-F422B1A81F98
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemTemplateSettings>{ 0x35B92371,0x3A10,0x5F55,{ 0x89,0xEA,0x59,0xDB,0x9A,0x1D,0x02,0xCD } }; // 35B92371-3A10-5F55-89EA-59DB9A1D02CD
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemTemplateSettingsFactory>{ 0x1D1A66E3,0xF56D,0x5D7F,{ 0x94,0x2C,0xF3,0xA8,0x7F,0x5C,0x55,0x2E } }; // 1D1A66E3-F56D-5D7F-942C-F3A87F5C552E
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemTemplateSettingsStatics>{ 0x1E4667C8,0x459A,0x5A36,{ 0xB1,0x31,0x21,0x59,0xCC,0x2F,0xE5,0x43 } }; // 1E4667C8-459A-5A36-B131-2159CC2FE543
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewList>{ 0x94CEE57B,0x7085,0x5A6A,{ 0xAA,0xC3,0x18,0x45,0x09,0xB8,0xEC,0xE0 } }; // 94CEE57B-7085-5A6A-AAC3-184509B8ECE0
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewListFactory>{ 0x461499A0,0x68CF,0x5B81,{ 0xB0,0xE4,0xB1,0xAF,0x92,0x9B,0x0B,0x12 } }; // 461499A0-68CF-5B81-B0E4-B1AF929B0B12
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewNode>{ 0x00378A74,0x790B,0x5328,{ 0x8A,0xFA,0x7D,0x65,0xE2,0x2D,0xA4,0x26 } }; // 00378A74-790B-5328-8AFA-7D65E22DA426
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewNodeFactory>{ 0xC105A5E5,0xCEA8,0x5EFD,{ 0x8B,0xE8,0x3D,0x89,0xB5,0x4C,0xBD,0x5F } }; // C105A5E5-CEA8-5EFD-8BE8-3D89B54CBD5F
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewNodeStatics>{ 0x1FEF99A7,0x988F,0x503C,{ 0xA9,0x19,0x87,0xD5,0x5D,0xC9,0x0D,0xF8 } }; // 1FEF99A7-988F-503C-A919-87D55DC90DF8
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewStatics>{ 0xC7808774,0x7BA4,0x54FF,{ 0x9D,0x3A,0x4C,0xB8,0x92,0x72,0x9A,0xD7 } }; // C7808774-7BA4-54FF-9D3A-4CB892729AD7
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITreeViewStatics2>{ 0x4F87BC2D,0xC640,0x50D0,{ 0x8F,0x0E,0x23,0x59,0x9F,0x99,0x58,0xAF } }; // 4F87BC2D-C640-50D0-8F0E-23599F9958AF
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITwoPaneView>{ 0x85EDC585,0x1481,0x5477,{ 0xBB,0x12,0x2A,0x18,0xA3,0x2B,0x83,0x4E } }; // 85EDC585-1481-5477-BB12-2A18A32B834E
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITwoPaneViewFactory>{ 0x0F1AF0CD,0xF3DC,0x52F6,{ 0xB6,0x32,0x39,0x67,0x42,0x53,0x32,0x31 } }; // 0F1AF0CD-F3DC-52F6-B632-396742533231
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::ITwoPaneViewStatics>{ 0x3275839B,0x59C2,0x5403,{ 0xA6,0xB7,0x8B,0x21,0xEC,0xD6,0xAB,0xA3 } }; // 3275839B-59C2-5403-A6B7-8B21ECD6ABA3
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IUniformGridLayout>{ 0x86B441FD,0x35EE,0x5164,{ 0x9E,0xC7,0xB9,0x25,0x42,0x64,0x8B,0x4B } }; // 86B441FD-35EE-5164-9EC7-B92542648B4B
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IUniformGridLayoutFactory>{ 0x0D9ED808,0xF3F9,0x5034,{ 0x96,0x27,0x15,0x2B,0x91,0xE9,0x1B,0x4B } }; // 0D9ED808-F3F9-5034-9627-152B91E91B4B
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IUniformGridLayoutStatics>{ 0xE1059BCE,0x59D9,0x52C9,{ 0x8C,0x0D,0xC5,0xFB,0x86,0xE8,0x33,0xA1 } }; // E1059BCE-59D9-52C9-8C0D-C5FB86E833A1
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayout>{ 0x54857CE0,0xB9E6,0x51A3,{ 0xBF,0xA8,0xDC,0xD8,0xEE,0x30,0x6D,0x5C } }; // 54857CE0-B9E6-51A3-BFA8-DCD8EE306D5C
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutContext>{ 0x283143F4,0x3716,0x5001,{ 0x90,0xAD,0x10,0x79,0xF2,0x0D,0xF4,0xBA } }; // 283143F4-3716-5001-90AD-1079F20DF4BA
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutContextFactory>{ 0x3F790B67,0xFDFB,0x505A,{ 0x8B,0x85,0x62,0x10,0x50,0x6D,0xF3,0x11 } }; // 3F790B67-FDFB-505A-8B85-6210506DF311
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutContextOverrides>{ 0x99CFBBD0,0xAC69,0x54EC,{ 0x91,0xEE,0x27,0xD4,0x86,0x4D,0xE4,0x0F } }; // 99CFBBD0-AC69-54EC-91EE-27D4864DE40F
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutFactory>{ 0xC7C128E1,0x5DF7,0x5345,{ 0xB5,0xCD,0x43,0xAF,0xDF,0xA9,0x48,0xB4 } }; // C7C128E1-5DF7-5345-B5CD-43AFDFA948B4
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutOverrides>{ 0xD9996F1E,0x62BE,0x515E,{ 0x84,0x3D,0x08,0x35,0x06,0xDF,0x3E,0x7D } }; // D9996F1E-62BE-515E-843D-083506DF3E7D
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IWebView2>{ 0x04C2C789,0x3936,0x542F,{ 0x87,0x06,0x87,0xB1,0x99,0xA7,0x3F,0xEB } }; // 04C2C789-3936-542F-8706-87B199A73FEB
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IWebView2Factory>{ 0xFB4EC2CE,0x3074,0x5C42,{ 0xB6,0x55,0x64,0xFB,0x81,0xFB,0xD0,0x40 } }; // FB4EC2CE-3074-5C42-B655-64FB81FBD040
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IWebView2Statics>{ 0x048C21AB,0x4300,0x5908,{ 0x88,0xA2,0x7F,0xB8,0xF2,0xA8,0x25,0x22 } }; // 048C21AB-4300-5908-88A2-7FB8F2A82522
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IXamlControlsResources>{ 0x0E35A094,0x868E,0x5FBE,{ 0xA9,0x2E,0x2E,0x22,0x4A,0x78,0x1D,0xD5 } }; // 0E35A094-868E-5FBE-A92E-2E224A781DD5
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IXamlControlsResources3>{ 0x3BA1468F,0x22AB,0x520B,{ 0x8D,0x17,0x9C,0xBB,0x3E,0xEE,0x95,0x0C } }; // 3BA1468F-22AB-520B-8D17-9CBB3EEE950C
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IXamlControlsResourcesStatics>{ 0x8FB9EB9B,0x850A,0x5225,{ 0x96,0xCF,0xA7,0x20,0x36,0x04,0x33,0x42 } }; // 8FB9EB9B-850A-5225-96CF-A72036043342
    template <> inline constexpr guid guid_v<winrt::Microsoft::UI::Xaml::Controls::IXamlControlsResourcesStatics3>{ 0x50356110,0x0B91,0x52EE,{ 0x98,0x4E,0x56,0x2A,0xFF,0x98,0x19,0x62 } }; // 50356110-0B91-52EE-984E-562AFF981962
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::AnimatedIcon>{ using type = winrt::Microsoft::UI::Xaml::Controls::IAnimatedIcon; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::AnimatedIconSource>{ using type = winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconSource; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::AnimatedVisualPlayer>{ using type = winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayer; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::BackdropMaterial>{ using type = winrt::Microsoft::UI::Xaml::Controls::IBackdropMaterial; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::BitmapIconSource>{ using type = winrt::Microsoft::UI::Xaml::Controls::IBitmapIconSource; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::BreadcrumbBar>{ using type = winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBar; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::BreadcrumbBarItem>{ using type = winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarItem; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::BreadcrumbBarItemClickedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarItemClickedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ColorChangedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::IColorChangedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ColorPicker>{ using type = winrt::Microsoft::UI::Xaml::Controls::IColorPicker; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::CommandBarFlyout>{ using type = winrt::Microsoft::UI::Xaml::Controls::ICommandBarFlyout; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::CoreWebView2InitializedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::ICoreWebView2InitializedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::DropDownButton>{ using type = winrt::Microsoft::UI::Xaml::Controls::IDropDownButton; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ElementFactory>{ using type = winrt::Microsoft::UI::Xaml::Controls::IElementFactory; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ElementFactoryGetArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::IElementFactoryGetArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ElementFactoryRecycleArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::IElementFactoryRecycleArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::Expander>{ using type = winrt::Microsoft::UI::Xaml::Controls::IExpander; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ExpanderCollapsedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::IExpanderCollapsedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ExpanderExpandingEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::IExpanderExpandingEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ExpanderTemplateSettings>{ using type = winrt::Microsoft::UI::Xaml::Controls::IExpanderTemplateSettings; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::FontIconSource>{ using type = winrt::Microsoft::UI::Xaml::Controls::IFontIconSource; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::IconSource>{ using type = winrt::Microsoft::UI::Xaml::Controls::IIconSource; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ImageIcon>{ using type = winrt::Microsoft::UI::Xaml::Controls::IImageIcon; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ImageIconSource>{ using type = winrt::Microsoft::UI::Xaml::Controls::IImageIconSource; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::InfoBadge>{ using type = winrt::Microsoft::UI::Xaml::Controls::IInfoBadge; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::InfoBadgeTemplateSettings>{ using type = winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeTemplateSettings; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::InfoBar>{ using type = winrt::Microsoft::UI::Xaml::Controls::IInfoBar; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::InfoBarClosedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::InfoBarClosingEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosingEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::InfoBarTemplateSettings>{ using type = winrt::Microsoft::UI::Xaml::Controls::IInfoBarTemplateSettings; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeater>{ using type = winrt::Microsoft::UI::Xaml::Controls::IItemsRepeater; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterElementClearingEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterElementClearingEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterElementIndexChangedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterElementIndexChangedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterElementPreparedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterElementPreparedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterScrollHost>{ using type = winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterScrollHost; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ItemsSourceView>{ using type = winrt::Microsoft::UI::Xaml::Controls::IItemsSourceView; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::Layout>{ using type = winrt::Microsoft::UI::Xaml::Controls::ILayout; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::LayoutContext>{ using type = winrt::Microsoft::UI::Xaml::Controls::ILayoutContext; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::MenuBar>{ using type = winrt::Microsoft::UI::Xaml::Controls::IMenuBar; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::MenuBarItem>{ using type = winrt::Microsoft::UI::Xaml::Controls::IMenuBarItem; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::MenuBarItemFlyout>{ using type = winrt::Microsoft::UI::Xaml::Controls::IMenuBarItemFlyout; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::NavigationView>{ using type = winrt::Microsoft::UI::Xaml::Controls::INavigationView; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::NavigationViewBackRequestedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::INavigationViewBackRequestedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::NavigationViewDisplayModeChangedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::INavigationViewDisplayModeChangedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItem>{ using type = winrt::Microsoft::UI::Xaml::Controls::INavigationViewItem; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemBase>{ using type = winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemBase; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemCollapsedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemCollapsedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemExpandingEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemExpandingEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemHeader>{ using type = winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemHeader; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemInvokedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemInvokedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemSeparator>{ using type = winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemSeparator; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::NavigationViewPaneClosingEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::INavigationViewPaneClosingEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::NavigationViewSelectionChangedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::INavigationViewSelectionChangedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::NavigationViewTemplateSettings>{ using type = winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettings; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::NonVirtualizingLayout>{ using type = winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayout; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::NonVirtualizingLayoutContext>{ using type = winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutContext; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::NumberBox>{ using type = winrt::Microsoft::UI::Xaml::Controls::INumberBox; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::NumberBoxValueChangedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::INumberBoxValueChangedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ParallaxView>{ using type = winrt::Microsoft::UI::Xaml::Controls::IParallaxView; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::PathIconSource>{ using type = winrt::Microsoft::UI::Xaml::Controls::IPathIconSource; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::PersonPicture>{ using type = winrt::Microsoft::UI::Xaml::Controls::IPersonPicture; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::PersonPictureTemplateSettings>{ using type = winrt::Microsoft::UI::Xaml::Controls::IPersonPictureTemplateSettings; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::PipsPager>{ using type = winrt::Microsoft::UI::Xaml::Controls::IPipsPager; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::PipsPagerSelectedIndexChangedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::IPipsPagerSelectedIndexChangedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::PipsPagerTemplateSettings>{ using type = winrt::Microsoft::UI::Xaml::Controls::IPipsPagerTemplateSettings; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ProgressBar>{ using type = winrt::Microsoft::UI::Xaml::Controls::IProgressBar; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ProgressBarTemplateSettings>{ using type = winrt::Microsoft::UI::Xaml::Controls::IProgressBarTemplateSettings; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ProgressRing>{ using type = winrt::Microsoft::UI::Xaml::Controls::IProgressRing; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ProgressRingTemplateSettings>{ using type = winrt::Microsoft::UI::Xaml::Controls::IProgressRingTemplateSettings; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::RadioButtons>{ using type = winrt::Microsoft::UI::Xaml::Controls::IRadioButtons; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::RadioMenuFlyoutItem>{ using type = winrt::Microsoft::UI::Xaml::Controls::IRadioMenuFlyoutItem; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::RatingControl>{ using type = winrt::Microsoft::UI::Xaml::Controls::IRatingControl; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::RatingItemFontInfo>{ using type = winrt::Microsoft::UI::Xaml::Controls::IRatingItemFontInfo; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::RatingItemImageInfo>{ using type = winrt::Microsoft::UI::Xaml::Controls::IRatingItemImageInfo; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::RatingItemInfo>{ using type = winrt::Microsoft::UI::Xaml::Controls::IRatingItemInfo; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::RefreshContainer>{ using type = winrt::Microsoft::UI::Xaml::Controls::IRefreshContainer; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::RefreshInteractionRatioChangedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::IRefreshInteractionRatioChangedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::RefreshRequestedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::IRefreshRequestedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::RefreshStateChangedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::IRefreshStateChangedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::RefreshVisualizer>{ using type = winrt::Microsoft::UI::Xaml::Controls::IRefreshVisualizer; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::RevealListViewItemPresenter>{ using type = winrt::Microsoft::UI::Xaml::Controls::IRevealListViewItemPresenter; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::SplitButton>{ using type = winrt::Microsoft::UI::Xaml::Controls::ISplitButton; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::SplitButtonClickEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::ISplitButtonClickEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::StackLayout>{ using type = winrt::Microsoft::UI::Xaml::Controls::IStackLayout; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::SwipeControl>{ using type = winrt::Microsoft::UI::Xaml::Controls::ISwipeControl; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::SwipeItem>{ using type = winrt::Microsoft::UI::Xaml::Controls::ISwipeItem; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::SwipeItemInvokedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::ISwipeItemInvokedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::SwipeItems>{ using type = winrt::Microsoft::UI::Xaml::Controls::ISwipeItems; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::SymbolIconSource>{ using type = winrt::Microsoft::UI::Xaml::Controls::ISymbolIconSource; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TabView>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITabView; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TabViewItem>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITabViewItem; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TabViewItemTemplateSettings>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettings; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TabViewTabCloseRequestedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITabViewTabCloseRequestedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TabViewTabDragCompletedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITabViewTabDragCompletedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TabViewTabDragStartingEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITabViewTabDragStartingEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TabViewTabDroppedOutsideEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITabViewTabDroppedOutsideEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TeachingTip>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITeachingTip; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TeachingTipClosedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITeachingTipClosedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TeachingTipClosingEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITeachingTipClosingEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TeachingTipTemplateSettings>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITeachingTipTemplateSettings; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TextCommandBarFlyout>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITextCommandBarFlyout; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ToggleSplitButton>{ using type = winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButton; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::ToggleSplitButtonIsCheckedChangedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButtonIsCheckedChangedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TreeView>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITreeView; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TreeViewCollapsedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITreeViewCollapsedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TreeViewDragItemsCompletedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITreeViewDragItemsCompletedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TreeViewDragItemsStartingEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITreeViewDragItemsStartingEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TreeViewExpandingEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITreeViewExpandingEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TreeViewItem>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITreeViewItem; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TreeViewItemInvokedEventArgs>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemInvokedEventArgs; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TreeViewItemTemplateSettings>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemTemplateSettings; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TreeViewList>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITreeViewList; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TreeViewNode>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITreeViewNode; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::TwoPaneView>{ using type = winrt::Microsoft::UI::Xaml::Controls::ITwoPaneView; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::UniformGridLayout>{ using type = winrt::Microsoft::UI::Xaml::Controls::IUniformGridLayout; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::VirtualizingLayout>{ using type = winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayout; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::VirtualizingLayoutContext>{ using type = winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutContext; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::WebView2>{ using type = winrt::Microsoft::UI::Xaml::Controls::IWebView2; };
    template <> struct default_interface<winrt::Microsoft::UI::Xaml::Controls::XamlControlsResources>{ using type = winrt::Microsoft::UI::Xaml::Controls::IXamlControlsResources; };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIcon>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Source(void**) noexcept = 0;
            virtual int32_t __stdcall put_Source(void*) noexcept = 0;
            virtual int32_t __stdcall get_FallbackIconSource(void**) noexcept = 0;
            virtual int32_t __stdcall put_FallbackIconSource(void*) noexcept = 0;
            virtual int32_t __stdcall get_MirroredWhenRightToLeft(bool*) noexcept = 0;
            virtual int32_t __stdcall put_MirroredWhenRightToLeft(bool) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconSource>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Source(void**) noexcept = 0;
            virtual int32_t __stdcall put_Source(void*) noexcept = 0;
            virtual int32_t __stdcall get_FallbackIconSource(void**) noexcept = 0;
            virtual int32_t __stdcall put_FallbackIconSource(void*) noexcept = 0;
            virtual int32_t __stdcall get_MirroredWhenRightToLeft(bool*) noexcept = 0;
            virtual int32_t __stdcall put_MirroredWhenRightToLeft(bool) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconSourceFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconSourceStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_SourceProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_FallbackIconSourceProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MirroredWhenRightToLeftProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_StateProperty(void**) noexcept = 0;
            virtual int32_t __stdcall SetState(void*, void*) noexcept = 0;
            virtual int32_t __stdcall GetState(void*, void**) noexcept = 0;
            virtual int32_t __stdcall get_SourceProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_FallbackIconSourceProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MirroredWhenRightToLeftProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisual>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_RootVisual(void**) noexcept = 0;
            virtual int32_t __stdcall get_Size(winrt::Windows::Foundation::Numerics::float2*) noexcept = 0;
            virtual int32_t __stdcall get_Duration(int64_t*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisual2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateAnimations() noexcept = 0;
            virtual int32_t __stdcall DestroyAnimations() noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayer>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Diagnostics(void**) noexcept = 0;
            virtual int32_t __stdcall get_Duration(int64_t*) noexcept = 0;
            virtual int32_t __stdcall get_Source(void**) noexcept = 0;
            virtual int32_t __stdcall put_Source(void*) noexcept = 0;
            virtual int32_t __stdcall get_FallbackContent(void**) noexcept = 0;
            virtual int32_t __stdcall put_FallbackContent(void*) noexcept = 0;
            virtual int32_t __stdcall get_AutoPlay(bool*) noexcept = 0;
            virtual int32_t __stdcall put_AutoPlay(bool) noexcept = 0;
            virtual int32_t __stdcall get_IsAnimatedVisualLoaded(bool*) noexcept = 0;
            virtual int32_t __stdcall get_IsPlaying(bool*) noexcept = 0;
            virtual int32_t __stdcall get_PlaybackRate(double*) noexcept = 0;
            virtual int32_t __stdcall put_PlaybackRate(double) noexcept = 0;
            virtual int32_t __stdcall get_ProgressObject(void**) noexcept = 0;
            virtual int32_t __stdcall get_Stretch(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_Stretch(int32_t) noexcept = 0;
            virtual int32_t __stdcall Pause() noexcept = 0;
            virtual int32_t __stdcall PlayAsync(double, double, bool, void**) noexcept = 0;
            virtual int32_t __stdcall Resume() noexcept = 0;
            virtual int32_t __stdcall SetProgress(double) noexcept = 0;
            virtual int32_t __stdcall Stop() noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayer2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_AnimationOptimization(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_AnimationOptimization(int32_t) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayerFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayerStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_AutoPlayProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_DiagnosticsProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_DurationProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_FallbackContentProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsAnimatedVisualLoadedProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsPlayingProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PlaybackRateProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_SourceProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_StretchProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayerStatics2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_AnimationOptimizationProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall TryCreateAnimatedVisual(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Markers(void**) noexcept = 0;
            virtual int32_t __stdcall SetColorProperty(void*, struct struct_Windows_UI_Color) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource3>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall TryCreateAnimatedVisual(void*, void**, bool, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IBackdropMaterial>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IBackdropMaterialFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IBackdropMaterialStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ApplyToRootOrPageBackgroundProperty(void**) noexcept = 0;
            virtual int32_t __stdcall SetApplyToRootOrPageBackground(void*, bool) noexcept = 0;
            virtual int32_t __stdcall GetApplyToRootOrPageBackground(void*, bool*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IBitmapIconSource>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_UriSource(void**) noexcept = 0;
            virtual int32_t __stdcall put_UriSource(void*) noexcept = 0;
            virtual int32_t __stdcall get_ShowAsMonochrome(bool*) noexcept = 0;
            virtual int32_t __stdcall put_ShowAsMonochrome(bool) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IBitmapIconSourceFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IBitmapIconSourceStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_UriSourceProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ShowAsMonochromeProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBar>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ItemsSource(void**) noexcept = 0;
            virtual int32_t __stdcall put_ItemsSource(void*) noexcept = 0;
            virtual int32_t __stdcall get_ItemTemplate(void**) noexcept = 0;
            virtual int32_t __stdcall put_ItemTemplate(void*) noexcept = 0;
            virtual int32_t __stdcall add_ItemClicked(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_ItemClicked(winrt::event_token) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarItem>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarItemClickedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Index(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_Item(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarItemFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ItemsSourceProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ItemTemplateProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IColorChangedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_OldColor(struct struct_Windows_UI_Color*) noexcept = 0;
            virtual int32_t __stdcall get_NewColor(struct struct_Windows_UI_Color*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IColorPicker>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Color(struct struct_Windows_UI_Color*) noexcept = 0;
            virtual int32_t __stdcall put_Color(struct struct_Windows_UI_Color) noexcept = 0;
            virtual int32_t __stdcall get_PreviousColor(void**) noexcept = 0;
            virtual int32_t __stdcall put_PreviousColor(void*) noexcept = 0;
            virtual int32_t __stdcall get_IsAlphaEnabled(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsAlphaEnabled(bool) noexcept = 0;
            virtual int32_t __stdcall get_IsColorSpectrumVisible(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsColorSpectrumVisible(bool) noexcept = 0;
            virtual int32_t __stdcall get_IsColorPreviewVisible(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsColorPreviewVisible(bool) noexcept = 0;
            virtual int32_t __stdcall get_IsColorSliderVisible(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsColorSliderVisible(bool) noexcept = 0;
            virtual int32_t __stdcall get_IsAlphaSliderVisible(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsAlphaSliderVisible(bool) noexcept = 0;
            virtual int32_t __stdcall get_IsMoreButtonVisible(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsMoreButtonVisible(bool) noexcept = 0;
            virtual int32_t __stdcall get_IsColorChannelTextInputVisible(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsColorChannelTextInputVisible(bool) noexcept = 0;
            virtual int32_t __stdcall get_IsAlphaTextInputVisible(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsAlphaTextInputVisible(bool) noexcept = 0;
            virtual int32_t __stdcall get_IsHexInputVisible(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsHexInputVisible(bool) noexcept = 0;
            virtual int32_t __stdcall get_MinHue(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_MinHue(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_MaxHue(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_MaxHue(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_MinSaturation(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_MinSaturation(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_MaxSaturation(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_MaxSaturation(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_MinValue(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_MinValue(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_MaxValue(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_MaxValue(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_ColorSpectrumShape(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_ColorSpectrumShape(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_ColorSpectrumComponents(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_ColorSpectrumComponents(int32_t) noexcept = 0;
            virtual int32_t __stdcall add_ColorChanged(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_ColorChanged(winrt::event_token) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IColorPicker2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Orientation(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_Orientation(int32_t) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IColorPickerFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IColorPickerStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ColorProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PreviousColorProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsAlphaEnabledProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsColorSpectrumVisibleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsColorPreviewVisibleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsColorSliderVisibleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsAlphaSliderVisibleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsMoreButtonVisibleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsColorChannelTextInputVisibleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsAlphaTextInputVisibleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsHexInputVisibleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MinHueProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MaxHueProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MinSaturationProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MaxSaturationProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MinValueProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MaxValueProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ColorSpectrumShapeProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ColorSpectrumComponentsProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IColorPickerStatics2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_OrientationProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ICommandBarFlyout>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_PrimaryCommands(void**) noexcept = 0;
            virtual int32_t __stdcall get_SecondaryCommands(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ICommandBarFlyout2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_AlwaysExpanded(bool*) noexcept = 0;
            virtual int32_t __stdcall put_AlwaysExpanded(bool) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ICommandBarFlyoutFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ICoreWebView2InitializedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Exception(winrt::hresult*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IDropDownButton>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IDropDownButtonFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IDynamicAnimatedVisualSource>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall add_AnimatedVisualInvalidated(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_AnimatedVisualInvalidated(winrt::event_token) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IElementFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IElementFactoryFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IElementFactoryGetArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Data(void**) noexcept = 0;
            virtual int32_t __stdcall put_Data(void*) noexcept = 0;
            virtual int32_t __stdcall get_Parent(void**) noexcept = 0;
            virtual int32_t __stdcall put_Parent(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IElementFactoryOverrides>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall GetElementCore(void*, void**) noexcept = 0;
            virtual int32_t __stdcall RecycleElementCore(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IElementFactoryRecycleArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Element(void**) noexcept = 0;
            virtual int32_t __stdcall put_Element(void*) noexcept = 0;
            virtual int32_t __stdcall get_Parent(void**) noexcept = 0;
            virtual int32_t __stdcall put_Parent(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IExpander>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Header(void**) noexcept = 0;
            virtual int32_t __stdcall put_Header(void*) noexcept = 0;
            virtual int32_t __stdcall get_HeaderTemplate(void**) noexcept = 0;
            virtual int32_t __stdcall put_HeaderTemplate(void*) noexcept = 0;
            virtual int32_t __stdcall get_HeaderTemplateSelector(void**) noexcept = 0;
            virtual int32_t __stdcall put_HeaderTemplateSelector(void*) noexcept = 0;
            virtual int32_t __stdcall get_IsExpanded(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsExpanded(bool) noexcept = 0;
            virtual int32_t __stdcall get_ExpandDirection(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_ExpandDirection(int32_t) noexcept = 0;
            virtual int32_t __stdcall add_Expanding(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_Expanding(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_Collapsed(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_Collapsed(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall get_TemplateSettings(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IExpanderCollapsedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IExpanderExpandingEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IExpanderFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IExpanderStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_HeaderProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_HeaderTemplateProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_HeaderTemplateSelectorProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsExpandedProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ExpandDirectionProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IExpanderTemplateSettings>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ContentHeight(double*) noexcept = 0;
            virtual int32_t __stdcall get_NegativeContentHeight(double*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IFontIconSource>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Glyph(void**) noexcept = 0;
            virtual int32_t __stdcall put_Glyph(void*) noexcept = 0;
            virtual int32_t __stdcall get_FontSize(double*) noexcept = 0;
            virtual int32_t __stdcall put_FontSize(double) noexcept = 0;
            virtual int32_t __stdcall get_FontFamily(void**) noexcept = 0;
            virtual int32_t __stdcall put_FontFamily(void*) noexcept = 0;
            virtual int32_t __stdcall get_FontWeight(struct struct_Windows_UI_Text_FontWeight*) noexcept = 0;
            virtual int32_t __stdcall put_FontWeight(struct struct_Windows_UI_Text_FontWeight) noexcept = 0;
            virtual int32_t __stdcall get_FontStyle(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_FontStyle(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_IsTextScaleFactorEnabled(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsTextScaleFactorEnabled(bool) noexcept = 0;
            virtual int32_t __stdcall get_MirroredWhenRightToLeft(bool*) noexcept = 0;
            virtual int32_t __stdcall put_MirroredWhenRightToLeft(bool) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IFontIconSourceFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IFontIconSourceStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_GlyphProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_FontSizeProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_FontFamilyProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_FontWeightProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_FontStyleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsTextScaleFactorEnabledProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MirroredWhenRightToLeftProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IIconSource>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateIconElement(void**) noexcept = 0;
            virtual int32_t __stdcall get_Foreground(void**) noexcept = 0;
            virtual int32_t __stdcall put_Foreground(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IIconSourceFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IIconSourceStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ForegroundProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IImageIcon>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Source(void**) noexcept = 0;
            virtual int32_t __stdcall put_Source(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IImageIconFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IImageIconSource>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ImageSource(void**) noexcept = 0;
            virtual int32_t __stdcall put_ImageSource(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IImageIconSourceFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IImageIconSourceStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ImageSourceProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IImageIconStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_SourceProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IInfoBadge>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Value(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_Value(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_IconSource(void**) noexcept = 0;
            virtual int32_t __stdcall put_IconSource(void*) noexcept = 0;
            virtual int32_t __stdcall get_TemplateSettings(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ValueProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IconSourceProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TemplateSettingsProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeTemplateSettings>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_InfoBadgeCornerRadius(struct struct_Windows_UI_Xaml_CornerRadius*) noexcept = 0;
            virtual int32_t __stdcall put_InfoBadgeCornerRadius(struct struct_Windows_UI_Xaml_CornerRadius) noexcept = 0;
            virtual int32_t __stdcall get_IconElement(void**) noexcept = 0;
            virtual int32_t __stdcall put_IconElement(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeTemplateSettingsFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeTemplateSettingsStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_InfoBadgeCornerRadiusProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IconElementProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IInfoBar>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IsOpen(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsOpen(bool) noexcept = 0;
            virtual int32_t __stdcall get_Title(void**) noexcept = 0;
            virtual int32_t __stdcall put_Title(void*) noexcept = 0;
            virtual int32_t __stdcall get_Message(void**) noexcept = 0;
            virtual int32_t __stdcall put_Message(void*) noexcept = 0;
            virtual int32_t __stdcall get_Severity(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_Severity(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_IconSource(void**) noexcept = 0;
            virtual int32_t __stdcall put_IconSource(void*) noexcept = 0;
            virtual int32_t __stdcall get_IsIconVisible(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsIconVisible(bool) noexcept = 0;
            virtual int32_t __stdcall get_IsClosable(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsClosable(bool) noexcept = 0;
            virtual int32_t __stdcall get_CloseButtonStyle(void**) noexcept = 0;
            virtual int32_t __stdcall put_CloseButtonStyle(void*) noexcept = 0;
            virtual int32_t __stdcall get_CloseButtonCommand(void**) noexcept = 0;
            virtual int32_t __stdcall put_CloseButtonCommand(void*) noexcept = 0;
            virtual int32_t __stdcall get_CloseButtonCommandParameter(void**) noexcept = 0;
            virtual int32_t __stdcall put_CloseButtonCommandParameter(void*) noexcept = 0;
            virtual int32_t __stdcall get_ActionButton(void**) noexcept = 0;
            virtual int32_t __stdcall put_ActionButton(void*) noexcept = 0;
            virtual int32_t __stdcall get_Content(void**) noexcept = 0;
            virtual int32_t __stdcall put_Content(void*) noexcept = 0;
            virtual int32_t __stdcall get_ContentTemplate(void**) noexcept = 0;
            virtual int32_t __stdcall put_ContentTemplate(void*) noexcept = 0;
            virtual int32_t __stdcall get_TemplateSettings(void**) noexcept = 0;
            virtual int32_t __stdcall add_CloseButtonClick(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_CloseButtonClick(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_Closing(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_Closing(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_Closed(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_Closed(winrt::event_token) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Reason(int32_t*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosedEventArgsFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosingEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Reason(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_Cancel(bool*) noexcept = 0;
            virtual int32_t __stdcall put_Cancel(bool) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosingEventArgsFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IInfoBarFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IInfoBarStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IsOpenProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TitleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MessageProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_SeverityProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IconSourceProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsIconVisibleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsClosableProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CloseButtonStyleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CloseButtonCommandProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CloseButtonCommandParameterProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ActionButtonProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ContentProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ContentTemplateProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TemplateSettingsProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IInfoBarTemplateSettings>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IconElement(void**) noexcept = 0;
            virtual int32_t __stdcall put_IconElement(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IInfoBarTemplateSettingsFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IInfoBarTemplateSettingsStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IconElementProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeater>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ItemsSource(void**) noexcept = 0;
            virtual int32_t __stdcall put_ItemsSource(void*) noexcept = 0;
            virtual int32_t __stdcall get_ItemsSourceView(void**) noexcept = 0;
            virtual int32_t __stdcall get_ItemTemplate(void**) noexcept = 0;
            virtual int32_t __stdcall put_ItemTemplate(void*) noexcept = 0;
            virtual int32_t __stdcall get_Layout(void**) noexcept = 0;
            virtual int32_t __stdcall put_Layout(void*) noexcept = 0;
            virtual int32_t __stdcall get_HorizontalCacheLength(double*) noexcept = 0;
            virtual int32_t __stdcall put_HorizontalCacheLength(double) noexcept = 0;
            virtual int32_t __stdcall get_VerticalCacheLength(double*) noexcept = 0;
            virtual int32_t __stdcall put_VerticalCacheLength(double) noexcept = 0;
            virtual int32_t __stdcall get_Background(void**) noexcept = 0;
            virtual int32_t __stdcall put_Background(void*) noexcept = 0;
            virtual int32_t __stdcall GetElementIndex(void*, int32_t*) noexcept = 0;
            virtual int32_t __stdcall TryGetElement(int32_t, void**) noexcept = 0;
            virtual int32_t __stdcall GetOrCreateElement(int32_t, void**) noexcept = 0;
            virtual int32_t __stdcall add_ElementPrepared(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_ElementPrepared(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_ElementClearing(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_ElementClearing(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_ElementIndexChanged(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_ElementIndexChanged(winrt::event_token) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterElementClearingEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Element(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterElementIndexChangedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Element(void**) noexcept = 0;
            virtual int32_t __stdcall get_OldIndex(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_NewIndex(int32_t*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterElementPreparedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Element(void**) noexcept = 0;
            virtual int32_t __stdcall get_Index(int32_t*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterScrollHost>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ScrollViewer(void**) noexcept = 0;
            virtual int32_t __stdcall put_ScrollViewer(void*) noexcept = 0;
            virtual int32_t __stdcall get_CurrentAnchor(void**) noexcept = 0;
            virtual int32_t __stdcall get_HorizontalAnchorRatio(double*) noexcept = 0;
            virtual int32_t __stdcall put_HorizontalAnchorRatio(double) noexcept = 0;
            virtual int32_t __stdcall get_VerticalAnchorRatio(double*) noexcept = 0;
            virtual int32_t __stdcall put_VerticalAnchorRatio(double) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ItemsSourceProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ItemTemplateProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_LayoutProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_HorizontalCacheLengthProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_VerticalCacheLengthProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_BackgroundProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IItemsSourceView>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Count(int32_t*) noexcept = 0;
            virtual int32_t __stdcall GetAt(int32_t, void**) noexcept = 0;
            virtual int32_t __stdcall get_HasKeyIndexMapping(bool*) noexcept = 0;
            virtual int32_t __stdcall KeyFromIndex(int32_t, void**) noexcept = 0;
            virtual int32_t __stdcall IndexFromKey(void*, int32_t*) noexcept = 0;
            virtual int32_t __stdcall IndexOf(void*, int32_t*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IItemsSourceViewFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IKeyIndexMapping>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall KeyFromIndex(int32_t, void**) noexcept = 0;
            virtual int32_t __stdcall IndexFromKey(void*, int32_t*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ILayout>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall InitializeForContext(void*) noexcept = 0;
            virtual int32_t __stdcall UninitializeForContext(void*) noexcept = 0;
            virtual int32_t __stdcall Measure(void*, winrt::Windows::Foundation::Size, winrt::Windows::Foundation::Size*) noexcept = 0;
            virtual int32_t __stdcall Arrange(void*, winrt::Windows::Foundation::Size, winrt::Windows::Foundation::Size*) noexcept = 0;
            virtual int32_t __stdcall add_MeasureInvalidated(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_MeasureInvalidated(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_ArrangeInvalidated(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_ArrangeInvalidated(winrt::event_token) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ILayoutContext>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_LayoutState(void**) noexcept = 0;
            virtual int32_t __stdcall put_LayoutState(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ILayoutContextFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ILayoutContextOverrides>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_LayoutStateCore(void**) noexcept = 0;
            virtual int32_t __stdcall put_LayoutStateCore(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ILayoutFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ILayoutProtected>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall InvalidateMeasure() noexcept = 0;
            virtual int32_t __stdcall InvalidateArrange() noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IMenuBar>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Items(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IMenuBarFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItem>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Title(void**) noexcept = 0;
            virtual int32_t __stdcall put_Title(void*) noexcept = 0;
            virtual int32_t __stdcall get_Items(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItemFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItemFlyout>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItemFlyoutFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItemStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_TitleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ItemsProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IMenuBarStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ItemsProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationView>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IsPaneOpen(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsPaneOpen(bool) noexcept = 0;
            virtual int32_t __stdcall get_CompactModeThresholdWidth(double*) noexcept = 0;
            virtual int32_t __stdcall put_CompactModeThresholdWidth(double) noexcept = 0;
            virtual int32_t __stdcall get_ExpandedModeThresholdWidth(double*) noexcept = 0;
            virtual int32_t __stdcall put_ExpandedModeThresholdWidth(double) noexcept = 0;
            virtual int32_t __stdcall get_FooterMenuItems(void**) noexcept = 0;
            virtual int32_t __stdcall get_FooterMenuItemsSource(void**) noexcept = 0;
            virtual int32_t __stdcall put_FooterMenuItemsSource(void*) noexcept = 0;
            virtual int32_t __stdcall get_PaneFooter(void**) noexcept = 0;
            virtual int32_t __stdcall put_PaneFooter(void*) noexcept = 0;
            virtual int32_t __stdcall get_Header(void**) noexcept = 0;
            virtual int32_t __stdcall put_Header(void*) noexcept = 0;
            virtual int32_t __stdcall get_HeaderTemplate(void**) noexcept = 0;
            virtual int32_t __stdcall put_HeaderTemplate(void*) noexcept = 0;
            virtual int32_t __stdcall get_DisplayMode(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_IsSettingsVisible(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsSettingsVisible(bool) noexcept = 0;
            virtual int32_t __stdcall get_IsPaneToggleButtonVisible(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsPaneToggleButtonVisible(bool) noexcept = 0;
            virtual int32_t __stdcall get_AlwaysShowHeader(bool*) noexcept = 0;
            virtual int32_t __stdcall put_AlwaysShowHeader(bool) noexcept = 0;
            virtual int32_t __stdcall get_CompactPaneLength(double*) noexcept = 0;
            virtual int32_t __stdcall put_CompactPaneLength(double) noexcept = 0;
            virtual int32_t __stdcall get_OpenPaneLength(double*) noexcept = 0;
            virtual int32_t __stdcall put_OpenPaneLength(double) noexcept = 0;
            virtual int32_t __stdcall get_PaneToggleButtonStyle(void**) noexcept = 0;
            virtual int32_t __stdcall put_PaneToggleButtonStyle(void*) noexcept = 0;
            virtual int32_t __stdcall get_SelectedItem(void**) noexcept = 0;
            virtual int32_t __stdcall put_SelectedItem(void*) noexcept = 0;
            virtual int32_t __stdcall get_MenuItems(void**) noexcept = 0;
            virtual int32_t __stdcall get_MenuItemsSource(void**) noexcept = 0;
            virtual int32_t __stdcall put_MenuItemsSource(void*) noexcept = 0;
            virtual int32_t __stdcall get_SettingsItem(void**) noexcept = 0;
            virtual int32_t __stdcall get_AutoSuggestBox(void**) noexcept = 0;
            virtual int32_t __stdcall put_AutoSuggestBox(void*) noexcept = 0;
            virtual int32_t __stdcall get_MenuItemTemplate(void**) noexcept = 0;
            virtual int32_t __stdcall put_MenuItemTemplate(void*) noexcept = 0;
            virtual int32_t __stdcall get_MenuItemTemplateSelector(void**) noexcept = 0;
            virtual int32_t __stdcall put_MenuItemTemplateSelector(void*) noexcept = 0;
            virtual int32_t __stdcall get_MenuItemContainerStyle(void**) noexcept = 0;
            virtual int32_t __stdcall put_MenuItemContainerStyle(void*) noexcept = 0;
            virtual int32_t __stdcall get_MenuItemContainerStyleSelector(void**) noexcept = 0;
            virtual int32_t __stdcall put_MenuItemContainerStyleSelector(void*) noexcept = 0;
            virtual int32_t __stdcall MenuItemFromContainer(void*, void**) noexcept = 0;
            virtual int32_t __stdcall ContainerFromMenuItem(void*, void**) noexcept = 0;
            virtual int32_t __stdcall add_SelectionChanged(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_SelectionChanged(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_ItemInvoked(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_ItemInvoked(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_DisplayModeChanged(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_DisplayModeChanged(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall get_IsTitleBarAutoPaddingEnabled(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsTitleBarAutoPaddingEnabled(bool) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationView2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IsBackButtonVisible(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_IsBackButtonVisible(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_IsBackEnabled(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsBackEnabled(bool) noexcept = 0;
            virtual int32_t __stdcall get_PaneTitle(void**) noexcept = 0;
            virtual int32_t __stdcall put_PaneTitle(void*) noexcept = 0;
            virtual int32_t __stdcall add_BackRequested(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_BackRequested(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_PaneClosed(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_PaneClosed(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_PaneClosing(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_PaneClosing(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_PaneOpened(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_PaneOpened(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_PaneOpening(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_PaneOpening(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall get_PaneDisplayMode(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_PaneDisplayMode(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_PaneHeader(void**) noexcept = 0;
            virtual int32_t __stdcall put_PaneHeader(void*) noexcept = 0;
            virtual int32_t __stdcall get_PaneCustomContent(void**) noexcept = 0;
            virtual int32_t __stdcall put_PaneCustomContent(void*) noexcept = 0;
            virtual int32_t __stdcall get_ContentOverlay(void**) noexcept = 0;
            virtual int32_t __stdcall put_ContentOverlay(void*) noexcept = 0;
            virtual int32_t __stdcall get_IsPaneVisible(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsPaneVisible(bool) noexcept = 0;
            virtual int32_t __stdcall get_SelectionFollowsFocus(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_SelectionFollowsFocus(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_TemplateSettings(void**) noexcept = 0;
            virtual int32_t __stdcall get_ShoulderNavigationEnabled(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_ShoulderNavigationEnabled(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_OverflowLabelMode(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_OverflowLabelMode(int32_t) noexcept = 0;
            virtual int32_t __stdcall add_Expanding(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_Expanding(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_Collapsed(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_Collapsed(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall Expand(void*) noexcept = 0;
            virtual int32_t __stdcall Collapse(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewBackRequestedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewDisplayModeChangedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_DisplayMode(int32_t*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItem>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Icon(void**) noexcept = 0;
            virtual int32_t __stdcall put_Icon(void*) noexcept = 0;
            virtual int32_t __stdcall get_CompactPaneLength(double*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItem2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_SelectsOnInvoked(bool*) noexcept = 0;
            virtual int32_t __stdcall put_SelectsOnInvoked(bool) noexcept = 0;
            virtual int32_t __stdcall get_IsExpanded(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsExpanded(bool) noexcept = 0;
            virtual int32_t __stdcall get_HasUnrealizedChildren(bool*) noexcept = 0;
            virtual int32_t __stdcall put_HasUnrealizedChildren(bool) noexcept = 0;
            virtual int32_t __stdcall get_IsChildSelected(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsChildSelected(bool) noexcept = 0;
            virtual int32_t __stdcall get_MenuItems(void**) noexcept = 0;
            virtual int32_t __stdcall get_MenuItemsSource(void**) noexcept = 0;
            virtual int32_t __stdcall put_MenuItemsSource(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItem3>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_InfoBadge(void**) noexcept = 0;
            virtual int32_t __stdcall put_InfoBadge(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemBase>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemBase2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IsSelected(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsSelected(bool) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemBaseFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemBaseStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IsSelectedProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemCollapsedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_CollapsedItemContainer(void**) noexcept = 0;
            virtual int32_t __stdcall get_CollapsedItem(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemExpandingEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ExpandingItemContainer(void**) noexcept = 0;
            virtual int32_t __stdcall get_ExpandingItem(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemHeader>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemHeaderFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemInvokedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_InvokedItem(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsSettingsInvoked(bool*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemInvokedEventArgs2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_InvokedItemContainer(void**) noexcept = 0;
            virtual int32_t __stdcall get_RecommendedNavigationTransitionInfo(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemSeparator>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemSeparatorFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IconProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CompactPaneLengthProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemStatics2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_SelectsOnInvokedProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsExpandedProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_HasUnrealizedChildrenProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsChildSelectedProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MenuItemsProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MenuItemsSourceProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemStatics3>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_InfoBadgeProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewPaneClosingEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Cancel(bool*) noexcept = 0;
            virtual int32_t __stdcall put_Cancel(bool) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewSelectionChangedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_SelectedItem(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsSettingsSelected(bool*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewSelectionChangedEventArgs2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_SelectedItemContainer(void**) noexcept = 0;
            virtual int32_t __stdcall get_RecommendedNavigationTransitionInfo(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IsPaneOpenProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CompactModeThresholdWidthProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ExpandedModeThresholdWidthProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_FooterMenuItemsProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_FooterMenuItemsSourceProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PaneFooterProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_HeaderProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_HeaderTemplateProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_DisplayModeProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsSettingsVisibleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsPaneToggleButtonVisibleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_AlwaysShowHeaderProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CompactPaneLengthProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_OpenPaneLengthProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PaneToggleButtonStyleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MenuItemsProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MenuItemsSourceProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_SelectedItemProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_SettingsItemProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_AutoSuggestBoxProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MenuItemTemplateProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MenuItemTemplateSelectorProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MenuItemContainerStyleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MenuItemContainerStyleSelectorProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsTitleBarAutoPaddingEnabledProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewStatics2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IsBackButtonVisibleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsBackEnabledProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PaneTitleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PaneDisplayModeProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PaneHeaderProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PaneCustomContentProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ContentOverlayProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsPaneVisibleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_SelectionFollowsFocusProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TemplateSettingsProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ShoulderNavigationEnabledProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_OverflowLabelModeProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettings>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_TopPadding(double*) noexcept = 0;
            virtual int32_t __stdcall get_OverflowButtonVisibility(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_PaneToggleButtonVisibility(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_BackButtonVisibility(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_TopPaneVisibility(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_LeftPaneVisibility(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_SingleSelectionFollowsFocus(bool*) noexcept = 0;
            virtual int32_t __stdcall get_PaneToggleButtonWidth(double*) noexcept = 0;
            virtual int32_t __stdcall get_SmallerPaneToggleButtonWidth(double*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettings2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_OpenPaneLength(double*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettingsFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettingsStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_TopPaddingProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_OverflowButtonVisibilityProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PaneToggleButtonVisibilityProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_BackButtonVisibilityProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TopPaneVisibilityProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_LeftPaneVisibilityProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_SingleSelectionFollowsFocusProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PaneToggleButtonWidthProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_SmallerPaneToggleButtonWidthProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettingsStatics2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_OpenPaneLengthProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayout>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutContext>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Children(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutContextFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutContextOverrides>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ChildrenCore(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutOverrides>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall InitializeForContextCore(void*) noexcept = 0;
            virtual int32_t __stdcall UninitializeForContextCore(void*) noexcept = 0;
            virtual int32_t __stdcall MeasureOverride(void*, winrt::Windows::Foundation::Size, winrt::Windows::Foundation::Size*) noexcept = 0;
            virtual int32_t __stdcall ArrangeOverride(void*, winrt::Windows::Foundation::Size, winrt::Windows::Foundation::Size*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INumberBox>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Minimum(double*) noexcept = 0;
            virtual int32_t __stdcall put_Minimum(double) noexcept = 0;
            virtual int32_t __stdcall get_Maximum(double*) noexcept = 0;
            virtual int32_t __stdcall put_Maximum(double) noexcept = 0;
            virtual int32_t __stdcall get_Value(double*) noexcept = 0;
            virtual int32_t __stdcall put_Value(double) noexcept = 0;
            virtual int32_t __stdcall get_SmallChange(double*) noexcept = 0;
            virtual int32_t __stdcall put_SmallChange(double) noexcept = 0;
            virtual int32_t __stdcall get_LargeChange(double*) noexcept = 0;
            virtual int32_t __stdcall put_LargeChange(double) noexcept = 0;
            virtual int32_t __stdcall get_Text(void**) noexcept = 0;
            virtual int32_t __stdcall put_Text(void*) noexcept = 0;
            virtual int32_t __stdcall get_Header(void**) noexcept = 0;
            virtual int32_t __stdcall put_Header(void*) noexcept = 0;
            virtual int32_t __stdcall get_HeaderTemplate(void**) noexcept = 0;
            virtual int32_t __stdcall put_HeaderTemplate(void*) noexcept = 0;
            virtual int32_t __stdcall get_PlaceholderText(void**) noexcept = 0;
            virtual int32_t __stdcall put_PlaceholderText(void*) noexcept = 0;
            virtual int32_t __stdcall get_SelectionFlyout(void**) noexcept = 0;
            virtual int32_t __stdcall put_SelectionFlyout(void*) noexcept = 0;
            virtual int32_t __stdcall get_SelectionHighlightColor(void**) noexcept = 0;
            virtual int32_t __stdcall put_SelectionHighlightColor(void*) noexcept = 0;
            virtual int32_t __stdcall get_TextReadingOrder(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_TextReadingOrder(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_PreventKeyboardDisplayOnProgrammaticFocus(bool*) noexcept = 0;
            virtual int32_t __stdcall put_PreventKeyboardDisplayOnProgrammaticFocus(bool) noexcept = 0;
            virtual int32_t __stdcall get_Description(void**) noexcept = 0;
            virtual int32_t __stdcall put_Description(void*) noexcept = 0;
            virtual int32_t __stdcall get_ValidationMode(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_ValidationMode(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_SpinButtonPlacementMode(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_SpinButtonPlacementMode(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_IsWrapEnabled(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsWrapEnabled(bool) noexcept = 0;
            virtual int32_t __stdcall get_AcceptsExpression(bool*) noexcept = 0;
            virtual int32_t __stdcall put_AcceptsExpression(bool) noexcept = 0;
            virtual int32_t __stdcall get_NumberFormatter(void**) noexcept = 0;
            virtual int32_t __stdcall put_NumberFormatter(void*) noexcept = 0;
            virtual int32_t __stdcall add_ValueChanged(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_ValueChanged(winrt::event_token) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INumberBoxFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INumberBoxStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_MinimumProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MaximumProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ValueProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_SmallChangeProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_LargeChangeProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TextProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_HeaderProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_HeaderTemplateProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PlaceholderTextProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_SelectionFlyoutProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_SelectionHighlightColorProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TextReadingOrderProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PreventKeyboardDisplayOnProgrammaticFocusProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_DescriptionProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ValidationModeProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_SpinButtonPlacementModeProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsWrapEnabledProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_AcceptsExpressionProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_NumberFormatterProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::INumberBoxValueChangedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_OldValue(double*) noexcept = 0;
            virtual int32_t __stdcall get_NewValue(double*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IParallaxView>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Child(void**) noexcept = 0;
            virtual int32_t __stdcall put_Child(void*) noexcept = 0;
            virtual int32_t __stdcall get_HorizontalShift(double*) noexcept = 0;
            virtual int32_t __stdcall put_HorizontalShift(double) noexcept = 0;
            virtual int32_t __stdcall get_HorizontalSourceEndOffset(double*) noexcept = 0;
            virtual int32_t __stdcall put_HorizontalSourceEndOffset(double) noexcept = 0;
            virtual int32_t __stdcall get_HorizontalSourceOffsetKind(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_HorizontalSourceOffsetKind(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_HorizontalSourceStartOffset(double*) noexcept = 0;
            virtual int32_t __stdcall put_HorizontalSourceStartOffset(double) noexcept = 0;
            virtual int32_t __stdcall get_IsHorizontalShiftClamped(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsHorizontalShiftClamped(bool) noexcept = 0;
            virtual int32_t __stdcall get_IsVerticalShiftClamped(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsVerticalShiftClamped(bool) noexcept = 0;
            virtual int32_t __stdcall get_MaxHorizontalShiftRatio(double*) noexcept = 0;
            virtual int32_t __stdcall put_MaxHorizontalShiftRatio(double) noexcept = 0;
            virtual int32_t __stdcall get_MaxVerticalShiftRatio(double*) noexcept = 0;
            virtual int32_t __stdcall put_MaxVerticalShiftRatio(double) noexcept = 0;
            virtual int32_t __stdcall get_Source(void**) noexcept = 0;
            virtual int32_t __stdcall put_Source(void*) noexcept = 0;
            virtual int32_t __stdcall get_VerticalShift(double*) noexcept = 0;
            virtual int32_t __stdcall put_VerticalShift(double) noexcept = 0;
            virtual int32_t __stdcall get_VerticalSourceEndOffset(double*) noexcept = 0;
            virtual int32_t __stdcall put_VerticalSourceEndOffset(double) noexcept = 0;
            virtual int32_t __stdcall get_VerticalSourceOffsetKind(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_VerticalSourceOffsetKind(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_VerticalSourceStartOffset(double*) noexcept = 0;
            virtual int32_t __stdcall put_VerticalSourceStartOffset(double) noexcept = 0;
            virtual int32_t __stdcall RefreshAutomaticHorizontalOffsets() noexcept = 0;
            virtual int32_t __stdcall RefreshAutomaticVerticalOffsets() noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IParallaxViewFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IParallaxViewStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ChildProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_HorizontalSourceEndOffsetProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_HorizontalSourceOffsetKindProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_HorizontalSourceStartOffsetProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MaxHorizontalShiftRatioProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_HorizontalShiftProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsHorizontalShiftClampedProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsVerticalShiftClampedProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_SourceProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_VerticalSourceEndOffsetProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_VerticalSourceOffsetKindProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_VerticalSourceStartOffsetProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MaxVerticalShiftRatioProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_VerticalShiftProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IPathIconSource>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Data(void**) noexcept = 0;
            virtual int32_t __stdcall put_Data(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IPathIconSourceFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IPathIconSourceStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_DataProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IPersonPicture>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_BadgeNumber(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_BadgeNumber(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_BadgeGlyph(void**) noexcept = 0;
            virtual int32_t __stdcall put_BadgeGlyph(void*) noexcept = 0;
            virtual int32_t __stdcall get_BadgeImageSource(void**) noexcept = 0;
            virtual int32_t __stdcall put_BadgeImageSource(void*) noexcept = 0;
            virtual int32_t __stdcall get_BadgeText(void**) noexcept = 0;
            virtual int32_t __stdcall put_BadgeText(void*) noexcept = 0;
            virtual int32_t __stdcall get_IsGroup(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsGroup(bool) noexcept = 0;
            virtual int32_t __stdcall get_Contact(void**) noexcept = 0;
            virtual int32_t __stdcall put_Contact(void*) noexcept = 0;
            virtual int32_t __stdcall get_DisplayName(void**) noexcept = 0;
            virtual int32_t __stdcall put_DisplayName(void*) noexcept = 0;
            virtual int32_t __stdcall get_Initials(void**) noexcept = 0;
            virtual int32_t __stdcall put_Initials(void*) noexcept = 0;
            virtual int32_t __stdcall get_PreferSmallImage(bool*) noexcept = 0;
            virtual int32_t __stdcall put_PreferSmallImage(bool) noexcept = 0;
            virtual int32_t __stdcall get_ProfilePicture(void**) noexcept = 0;
            virtual int32_t __stdcall put_ProfilePicture(void*) noexcept = 0;
            virtual int32_t __stdcall get_TemplateSettings(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IPersonPictureFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IPersonPictureStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_BadgeNumberProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_BadgeGlyphProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_BadgeImageSourceProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_BadgeTextProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsGroupProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ContactProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_DisplayNameProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_InitialsProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PreferSmallImageProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ProfilePictureProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IPersonPictureTemplateSettings>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ActualInitials(void**) noexcept = 0;
            virtual int32_t __stdcall get_ActualImageBrush(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IPipsPager>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_NumberOfPages(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_NumberOfPages(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_SelectedPageIndex(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_SelectedPageIndex(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_MaxVisiblePips(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_MaxVisiblePips(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_Orientation(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_Orientation(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_PreviousButtonVisibility(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_PreviousButtonVisibility(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_NextButtonVisibility(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_NextButtonVisibility(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_PreviousButtonStyle(void**) noexcept = 0;
            virtual int32_t __stdcall put_PreviousButtonStyle(void*) noexcept = 0;
            virtual int32_t __stdcall get_NextButtonStyle(void**) noexcept = 0;
            virtual int32_t __stdcall put_NextButtonStyle(void*) noexcept = 0;
            virtual int32_t __stdcall get_SelectedPipStyle(void**) noexcept = 0;
            virtual int32_t __stdcall put_SelectedPipStyle(void*) noexcept = 0;
            virtual int32_t __stdcall get_NormalPipStyle(void**) noexcept = 0;
            virtual int32_t __stdcall put_NormalPipStyle(void*) noexcept = 0;
            virtual int32_t __stdcall add_SelectedIndexChanged(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_SelectedIndexChanged(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall get_TemplateSettings(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IPipsPagerFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IPipsPagerSelectedIndexChangedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IPipsPagerStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_NumberOfPagesProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_SelectedPageIndexProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MaxVisiblePipsProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_OrientationProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PreviousButtonVisibilityProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_NextButtonVisibilityProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PreviousButtonStyleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_NextButtonStyleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_SelectedPipStyleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_NormalPipStyleProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IPipsPagerTemplateSettings>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_PipsPagerItems(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IProgressBar>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IsIndeterminate(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsIndeterminate(bool) noexcept = 0;
            virtual int32_t __stdcall get_ShowError(bool*) noexcept = 0;
            virtual int32_t __stdcall put_ShowError(bool) noexcept = 0;
            virtual int32_t __stdcall get_ShowPaused(bool*) noexcept = 0;
            virtual int32_t __stdcall put_ShowPaused(bool) noexcept = 0;
            virtual int32_t __stdcall get_TemplateSettings(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IProgressBarFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IProgressBarStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IsIndeterminateProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ShowErrorProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ShowPausedProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IProgressBarTemplateSettings>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ContainerAnimationStartPosition(double*) noexcept = 0;
            virtual int32_t __stdcall get_ContainerAnimationEndPosition(double*) noexcept = 0;
            virtual int32_t __stdcall get_Container2AnimationStartPosition(double*) noexcept = 0;
            virtual int32_t __stdcall get_Container2AnimationEndPosition(double*) noexcept = 0;
            virtual int32_t __stdcall get_ContainerAnimationMidPosition(double*) noexcept = 0;
            virtual int32_t __stdcall get_IndicatorLengthDelta(double*) noexcept = 0;
            virtual int32_t __stdcall get_ClipRect(void**) noexcept = 0;
            virtual int32_t __stdcall get_EllipseAnimationEndPosition(double*) noexcept = 0;
            virtual int32_t __stdcall get_EllipseAnimationWellPosition(double*) noexcept = 0;
            virtual int32_t __stdcall get_EllipseDiameter(double*) noexcept = 0;
            virtual int32_t __stdcall get_EllipseOffset(double*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IProgressRing>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IsActive(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsActive(bool) noexcept = 0;
            virtual int32_t __stdcall get_IsIndeterminate(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsIndeterminate(bool) noexcept = 0;
            virtual int32_t __stdcall get_TemplateSettings(void**) noexcept = 0;
            virtual int32_t __stdcall get_Value(double*) noexcept = 0;
            virtual int32_t __stdcall put_Value(double) noexcept = 0;
            virtual int32_t __stdcall get_Minimum(double*) noexcept = 0;
            virtual int32_t __stdcall put_Minimum(double) noexcept = 0;
            virtual int32_t __stdcall get_Maximum(double*) noexcept = 0;
            virtual int32_t __stdcall put_Maximum(double) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IProgressRingFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IProgressRingStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IsActiveProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsIndeterminateProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ValueProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MinimumProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MaximumProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IProgressRingTemplateSettings>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_EllipseDiameter(double*) noexcept = 0;
            virtual int32_t __stdcall get_EllipseOffset(struct struct_Windows_UI_Xaml_Thickness*) noexcept = 0;
            virtual int32_t __stdcall get_MaxSideLength(double*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRadioButtons>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ItemsSource(void**) noexcept = 0;
            virtual int32_t __stdcall put_ItemsSource(void*) noexcept = 0;
            virtual int32_t __stdcall get_Items(void**) noexcept = 0;
            virtual int32_t __stdcall get_ItemTemplate(void**) noexcept = 0;
            virtual int32_t __stdcall put_ItemTemplate(void*) noexcept = 0;
            virtual int32_t __stdcall ContainerFromIndex(int32_t, void**) noexcept = 0;
            virtual int32_t __stdcall get_SelectedIndex(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_SelectedIndex(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_SelectedItem(void**) noexcept = 0;
            virtual int32_t __stdcall put_SelectedItem(void*) noexcept = 0;
            virtual int32_t __stdcall add_SelectionChanged(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_SelectionChanged(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall get_MaxColumns(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_MaxColumns(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_Header(void**) noexcept = 0;
            virtual int32_t __stdcall put_Header(void*) noexcept = 0;
            virtual int32_t __stdcall get_HeaderTemplate(void**) noexcept = 0;
            virtual int32_t __stdcall put_HeaderTemplate(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRadioButtonsFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRadioButtonsStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ItemsSourceProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ItemsProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ItemTemplateProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_SelectedIndexProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_SelectedItemProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MaxColumnsProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_HeaderProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_HeaderTemplateProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRadioMenuFlyoutItem>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IsChecked(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsChecked(bool) noexcept = 0;
            virtual int32_t __stdcall get_GroupName(void**) noexcept = 0;
            virtual int32_t __stdcall put_GroupName(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRadioMenuFlyoutItemFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRadioMenuFlyoutItemStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IsCheckedProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_GroupNameProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRadioMenuFlyoutItemStatics2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_AreCheckStatesEnabledProperty(void**) noexcept = 0;
            virtual int32_t __stdcall SetAreCheckStatesEnabled(void*, bool) noexcept = 0;
            virtual int32_t __stdcall GetAreCheckStatesEnabled(void*, bool*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRatingControl>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Caption(void**) noexcept = 0;
            virtual int32_t __stdcall put_Caption(void*) noexcept = 0;
            virtual int32_t __stdcall get_InitialSetValue(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_InitialSetValue(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_IsClearEnabled(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsClearEnabled(bool) noexcept = 0;
            virtual int32_t __stdcall get_IsReadOnly(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsReadOnly(bool) noexcept = 0;
            virtual int32_t __stdcall get_MaxRating(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_MaxRating(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_PlaceholderValue(double*) noexcept = 0;
            virtual int32_t __stdcall put_PlaceholderValue(double) noexcept = 0;
            virtual int32_t __stdcall get_ItemInfo(void**) noexcept = 0;
            virtual int32_t __stdcall put_ItemInfo(void*) noexcept = 0;
            virtual int32_t __stdcall get_Value(double*) noexcept = 0;
            virtual int32_t __stdcall put_Value(double) noexcept = 0;
            virtual int32_t __stdcall add_ValueChanged(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_ValueChanged(winrt::event_token) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRatingControlFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRatingControlStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_CaptionProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_InitialSetValueProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsClearEnabledProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsReadOnlyProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MaxRatingProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PlaceholderValueProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ItemInfoProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ValueProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRatingItemFontInfo>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_DisabledGlyph(void**) noexcept = 0;
            virtual int32_t __stdcall put_DisabledGlyph(void*) noexcept = 0;
            virtual int32_t __stdcall get_Glyph(void**) noexcept = 0;
            virtual int32_t __stdcall put_Glyph(void*) noexcept = 0;
            virtual int32_t __stdcall get_PointerOverGlyph(void**) noexcept = 0;
            virtual int32_t __stdcall put_PointerOverGlyph(void*) noexcept = 0;
            virtual int32_t __stdcall get_PointerOverPlaceholderGlyph(void**) noexcept = 0;
            virtual int32_t __stdcall put_PointerOverPlaceholderGlyph(void*) noexcept = 0;
            virtual int32_t __stdcall get_PlaceholderGlyph(void**) noexcept = 0;
            virtual int32_t __stdcall put_PlaceholderGlyph(void*) noexcept = 0;
            virtual int32_t __stdcall get_UnsetGlyph(void**) noexcept = 0;
            virtual int32_t __stdcall put_UnsetGlyph(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRatingItemFontInfoFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRatingItemFontInfoStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_DisabledGlyphProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_GlyphProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PlaceholderGlyphProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PointerOverGlyphProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PointerOverPlaceholderGlyphProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_UnsetGlyphProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRatingItemImageInfo>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_DisabledImage(void**) noexcept = 0;
            virtual int32_t __stdcall put_DisabledImage(void*) noexcept = 0;
            virtual int32_t __stdcall get_Image(void**) noexcept = 0;
            virtual int32_t __stdcall put_Image(void*) noexcept = 0;
            virtual int32_t __stdcall get_PlaceholderImage(void**) noexcept = 0;
            virtual int32_t __stdcall put_PlaceholderImage(void*) noexcept = 0;
            virtual int32_t __stdcall get_PointerOverImage(void**) noexcept = 0;
            virtual int32_t __stdcall put_PointerOverImage(void*) noexcept = 0;
            virtual int32_t __stdcall get_PointerOverPlaceholderImage(void**) noexcept = 0;
            virtual int32_t __stdcall put_PointerOverPlaceholderImage(void*) noexcept = 0;
            virtual int32_t __stdcall get_UnsetImage(void**) noexcept = 0;
            virtual int32_t __stdcall put_UnsetImage(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRatingItemImageInfoFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRatingItemImageInfoStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_DisabledImageProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ImageProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PlaceholderImageProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PointerOverImageProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PointerOverPlaceholderImageProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_UnsetImageProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRatingItemInfo>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRatingItemInfoFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRefreshContainer>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Visualizer(void**) noexcept = 0;
            virtual int32_t __stdcall put_Visualizer(void*) noexcept = 0;
            virtual int32_t __stdcall get_PullDirection(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_PullDirection(int32_t) noexcept = 0;
            virtual int32_t __stdcall add_RefreshRequested(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_RefreshRequested(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall RequestRefresh() noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRefreshContainerFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRefreshContainerStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_VisualizerProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PullDirectionProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRefreshInteractionRatioChangedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_InteractionRatio(double*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRefreshRequestedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall GetDeferral(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRefreshStateChangedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_OldState(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_NewState(int32_t*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRefreshVisualizer>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall RequestRefresh() noexcept = 0;
            virtual int32_t __stdcall get_Orientation(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_Orientation(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_Content(void**) noexcept = 0;
            virtual int32_t __stdcall put_Content(void*) noexcept = 0;
            virtual int32_t __stdcall get_State(int32_t*) noexcept = 0;
            virtual int32_t __stdcall add_RefreshRequested(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_RefreshRequested(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_RefreshStateChanged(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_RefreshStateChanged(winrt::event_token) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRefreshVisualizerFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRefreshVisualizerStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_InfoProviderProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_OrientationProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ContentProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_StateProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRevealListViewItemPresenter>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IRevealListViewItemPresenterFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ISplitButton>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Flyout(void**) noexcept = 0;
            virtual int32_t __stdcall put_Flyout(void*) noexcept = 0;
            virtual int32_t __stdcall get_Command(void**) noexcept = 0;
            virtual int32_t __stdcall put_Command(void*) noexcept = 0;
            virtual int32_t __stdcall get_CommandParameter(void**) noexcept = 0;
            virtual int32_t __stdcall put_CommandParameter(void*) noexcept = 0;
            virtual int32_t __stdcall add_Click(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_Click(winrt::event_token) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ISplitButtonClickEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ISplitButtonFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ISplitButtonStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_FlyoutProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CommandProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CommandParameterProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IStackLayout>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Orientation(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_Orientation(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_Spacing(double*) noexcept = 0;
            virtual int32_t __stdcall put_Spacing(double) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IStackLayoutFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IStackLayoutStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_OrientationProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_SpacingProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ISwipeControl>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_LeftItems(void**) noexcept = 0;
            virtual int32_t __stdcall put_LeftItems(void*) noexcept = 0;
            virtual int32_t __stdcall get_RightItems(void**) noexcept = 0;
            virtual int32_t __stdcall put_RightItems(void*) noexcept = 0;
            virtual int32_t __stdcall get_TopItems(void**) noexcept = 0;
            virtual int32_t __stdcall put_TopItems(void*) noexcept = 0;
            virtual int32_t __stdcall get_BottomItems(void**) noexcept = 0;
            virtual int32_t __stdcall put_BottomItems(void*) noexcept = 0;
            virtual int32_t __stdcall Close() noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ISwipeControlFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ISwipeControlStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_LeftItemsProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_RightItemsProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TopItemsProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_BottomItemsProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ISwipeItem>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Text(void**) noexcept = 0;
            virtual int32_t __stdcall put_Text(void*) noexcept = 0;
            virtual int32_t __stdcall get_IconSource(void**) noexcept = 0;
            virtual int32_t __stdcall put_IconSource(void*) noexcept = 0;
            virtual int32_t __stdcall get_Background(void**) noexcept = 0;
            virtual int32_t __stdcall put_Background(void*) noexcept = 0;
            virtual int32_t __stdcall get_Foreground(void**) noexcept = 0;
            virtual int32_t __stdcall put_Foreground(void*) noexcept = 0;
            virtual int32_t __stdcall get_Command(void**) noexcept = 0;
            virtual int32_t __stdcall put_Command(void*) noexcept = 0;
            virtual int32_t __stdcall get_CommandParameter(void**) noexcept = 0;
            virtual int32_t __stdcall put_CommandParameter(void*) noexcept = 0;
            virtual int32_t __stdcall get_BehaviorOnInvoked(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_BehaviorOnInvoked(int32_t) noexcept = 0;
            virtual int32_t __stdcall add_Invoked(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_Invoked(winrt::event_token) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemInvokedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_SwipeControl(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IconSourceProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TextProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_BackgroundProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ForegroundProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CommandProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CommandParameterProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_BehaviorOnInvokedProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ISwipeItems>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Mode(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_Mode(int32_t) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemsFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemsStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ModeProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ISymbolIconSource>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Symbol(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_Symbol(int32_t) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ISymbolIconSourceFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ISymbolIconSourceStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_SymbolProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITabView>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_TabWidthMode(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_TabWidthMode(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_CloseButtonOverlayMode(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_CloseButtonOverlayMode(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_TabStripHeader(void**) noexcept = 0;
            virtual int32_t __stdcall put_TabStripHeader(void*) noexcept = 0;
            virtual int32_t __stdcall get_TabStripHeaderTemplate(void**) noexcept = 0;
            virtual int32_t __stdcall put_TabStripHeaderTemplate(void*) noexcept = 0;
            virtual int32_t __stdcall get_TabStripFooter(void**) noexcept = 0;
            virtual int32_t __stdcall put_TabStripFooter(void*) noexcept = 0;
            virtual int32_t __stdcall get_TabStripFooterTemplate(void**) noexcept = 0;
            virtual int32_t __stdcall put_TabStripFooterTemplate(void*) noexcept = 0;
            virtual int32_t __stdcall get_IsAddTabButtonVisible(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsAddTabButtonVisible(bool) noexcept = 0;
            virtual int32_t __stdcall get_AddTabButtonCommand(void**) noexcept = 0;
            virtual int32_t __stdcall put_AddTabButtonCommand(void*) noexcept = 0;
            virtual int32_t __stdcall get_AddTabButtonCommandParameter(void**) noexcept = 0;
            virtual int32_t __stdcall put_AddTabButtonCommandParameter(void*) noexcept = 0;
            virtual int32_t __stdcall add_TabCloseRequested(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_TabCloseRequested(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_TabDroppedOutside(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_TabDroppedOutside(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_AddTabButtonClick(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_AddTabButtonClick(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_TabItemsChanged(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_TabItemsChanged(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall get_TabItemsSource(void**) noexcept = 0;
            virtual int32_t __stdcall put_TabItemsSource(void*) noexcept = 0;
            virtual int32_t __stdcall get_TabItems(void**) noexcept = 0;
            virtual int32_t __stdcall get_TabItemTemplate(void**) noexcept = 0;
            virtual int32_t __stdcall put_TabItemTemplate(void*) noexcept = 0;
            virtual int32_t __stdcall get_TabItemTemplateSelector(void**) noexcept = 0;
            virtual int32_t __stdcall put_TabItemTemplateSelector(void*) noexcept = 0;
            virtual int32_t __stdcall get_CanDragTabs(bool*) noexcept = 0;
            virtual int32_t __stdcall put_CanDragTabs(bool) noexcept = 0;
            virtual int32_t __stdcall get_CanReorderTabs(bool*) noexcept = 0;
            virtual int32_t __stdcall put_CanReorderTabs(bool) noexcept = 0;
            virtual int32_t __stdcall get_AllowDropTabs(bool*) noexcept = 0;
            virtual int32_t __stdcall put_AllowDropTabs(bool) noexcept = 0;
            virtual int32_t __stdcall get_SelectedIndex(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_SelectedIndex(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_SelectedItem(void**) noexcept = 0;
            virtual int32_t __stdcall put_SelectedItem(void*) noexcept = 0;
            virtual int32_t __stdcall ContainerFromItem(void*, void**) noexcept = 0;
            virtual int32_t __stdcall ContainerFromIndex(int32_t, void**) noexcept = 0;
            virtual int32_t __stdcall add_SelectionChanged(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_SelectionChanged(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_TabDragStarting(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_TabDragStarting(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_TabDragCompleted(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_TabDragCompleted(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_TabStripDragOver(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_TabStripDragOver(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_TabStripDrop(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_TabStripDrop(winrt::event_token) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITabViewFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITabViewItem>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Header(void**) noexcept = 0;
            virtual int32_t __stdcall put_Header(void*) noexcept = 0;
            virtual int32_t __stdcall get_HeaderTemplate(void**) noexcept = 0;
            virtual int32_t __stdcall put_HeaderTemplate(void*) noexcept = 0;
            virtual int32_t __stdcall get_IconSource(void**) noexcept = 0;
            virtual int32_t __stdcall put_IconSource(void*) noexcept = 0;
            virtual int32_t __stdcall get_IsClosable(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsClosable(bool) noexcept = 0;
            virtual int32_t __stdcall get_TabViewTemplateSettings(void**) noexcept = 0;
            virtual int32_t __stdcall add_CloseRequested(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_CloseRequested(winrt::event_token) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_HeaderProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_HeaderTemplateProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IconSourceProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsClosableProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TabViewTemplateSettingsProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettings>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IconElement(void**) noexcept = 0;
            virtual int32_t __stdcall put_IconElement(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettings2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_TabGeometry(void**) noexcept = 0;
            virtual int32_t __stdcall put_TabGeometry(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettingsFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettingsStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IconElementProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettingsStatics2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_TabGeometryProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITabViewStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_TabWidthModeProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TabStripHeaderProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TabStripHeaderTemplateProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TabStripFooterProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TabStripFooterTemplateProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsAddTabButtonVisibleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_AddTabButtonCommandProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_AddTabButtonCommandParameterProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TabItemsSourceProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TabItemsProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TabItemTemplateProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TabItemTemplateSelectorProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CloseButtonOverlayModeProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CanDragTabsProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CanReorderTabsProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_AllowDropTabsProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_SelectedIndexProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_SelectedItemProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITabViewTabCloseRequestedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Item(void**) noexcept = 0;
            virtual int32_t __stdcall get_Tab(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITabViewTabDragCompletedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_DropResult(uint32_t*) noexcept = 0;
            virtual int32_t __stdcall get_Item(void**) noexcept = 0;
            virtual int32_t __stdcall get_Tab(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITabViewTabDragStartingEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Cancel(bool*) noexcept = 0;
            virtual int32_t __stdcall put_Cancel(bool) noexcept = 0;
            virtual int32_t __stdcall get_Data(void**) noexcept = 0;
            virtual int32_t __stdcall get_Item(void**) noexcept = 0;
            virtual int32_t __stdcall get_Tab(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITabViewTabDroppedOutsideEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Item(void**) noexcept = 0;
            virtual int32_t __stdcall get_Tab(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITeachingTip>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Title(void**) noexcept = 0;
            virtual int32_t __stdcall put_Title(void*) noexcept = 0;
            virtual int32_t __stdcall get_Subtitle(void**) noexcept = 0;
            virtual int32_t __stdcall put_Subtitle(void*) noexcept = 0;
            virtual int32_t __stdcall get_IsOpen(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsOpen(bool) noexcept = 0;
            virtual int32_t __stdcall get_Target(void**) noexcept = 0;
            virtual int32_t __stdcall put_Target(void*) noexcept = 0;
            virtual int32_t __stdcall get_TailVisibility(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_TailVisibility(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_ActionButtonContent(void**) noexcept = 0;
            virtual int32_t __stdcall put_ActionButtonContent(void*) noexcept = 0;
            virtual int32_t __stdcall get_ActionButtonStyle(void**) noexcept = 0;
            virtual int32_t __stdcall put_ActionButtonStyle(void*) noexcept = 0;
            virtual int32_t __stdcall get_ActionButtonCommand(void**) noexcept = 0;
            virtual int32_t __stdcall put_ActionButtonCommand(void*) noexcept = 0;
            virtual int32_t __stdcall get_ActionButtonCommandParameter(void**) noexcept = 0;
            virtual int32_t __stdcall put_ActionButtonCommandParameter(void*) noexcept = 0;
            virtual int32_t __stdcall get_CloseButtonContent(void**) noexcept = 0;
            virtual int32_t __stdcall put_CloseButtonContent(void*) noexcept = 0;
            virtual int32_t __stdcall get_CloseButtonStyle(void**) noexcept = 0;
            virtual int32_t __stdcall put_CloseButtonStyle(void*) noexcept = 0;
            virtual int32_t __stdcall get_CloseButtonCommand(void**) noexcept = 0;
            virtual int32_t __stdcall put_CloseButtonCommand(void*) noexcept = 0;
            virtual int32_t __stdcall get_CloseButtonCommandParameter(void**) noexcept = 0;
            virtual int32_t __stdcall put_CloseButtonCommandParameter(void*) noexcept = 0;
            virtual int32_t __stdcall get_PlacementMargin(struct struct_Windows_UI_Xaml_Thickness*) noexcept = 0;
            virtual int32_t __stdcall put_PlacementMargin(struct struct_Windows_UI_Xaml_Thickness) noexcept = 0;
            virtual int32_t __stdcall get_ShouldConstrainToRootBounds(bool*) noexcept = 0;
            virtual int32_t __stdcall put_ShouldConstrainToRootBounds(bool) noexcept = 0;
            virtual int32_t __stdcall get_IsLightDismissEnabled(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsLightDismissEnabled(bool) noexcept = 0;
            virtual int32_t __stdcall get_PreferredPlacement(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_PreferredPlacement(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_HeroContentPlacement(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_HeroContentPlacement(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_HeroContent(void**) noexcept = 0;
            virtual int32_t __stdcall put_HeroContent(void*) noexcept = 0;
            virtual int32_t __stdcall get_IconSource(void**) noexcept = 0;
            virtual int32_t __stdcall put_IconSource(void*) noexcept = 0;
            virtual int32_t __stdcall get_TemplateSettings(void**) noexcept = 0;
            virtual int32_t __stdcall add_ActionButtonClick(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_ActionButtonClick(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_CloseButtonClick(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_CloseButtonClick(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_Closing(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_Closing(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_Closed(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_Closed(winrt::event_token) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipClosedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Reason(int32_t*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipClosingEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Reason(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_Cancel(bool*) noexcept = 0;
            virtual int32_t __stdcall put_Cancel(bool) noexcept = 0;
            virtual int32_t __stdcall GetDeferral(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IsOpenProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TargetProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TailVisibilityProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TitleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_SubtitleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ActionButtonContentProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ActionButtonStyleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ActionButtonCommandProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ActionButtonCommandParameterProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CloseButtonContentProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CloseButtonStyleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CloseButtonCommandProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CloseButtonCommandParameterProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PlacementMarginProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ShouldConstrainToRootBoundsProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsLightDismissEnabledProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PreferredPlacementProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_HeroContentPlacementProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_HeroContentProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IconSourceProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TemplateSettingsProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipTemplateSettings>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_TopRightHighlightMargin(struct struct_Windows_UI_Xaml_Thickness*) noexcept = 0;
            virtual int32_t __stdcall put_TopRightHighlightMargin(struct struct_Windows_UI_Xaml_Thickness) noexcept = 0;
            virtual int32_t __stdcall get_TopLeftHighlightMargin(struct struct_Windows_UI_Xaml_Thickness*) noexcept = 0;
            virtual int32_t __stdcall put_TopLeftHighlightMargin(struct struct_Windows_UI_Xaml_Thickness) noexcept = 0;
            virtual int32_t __stdcall get_IconElement(void**) noexcept = 0;
            virtual int32_t __stdcall put_IconElement(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipTemplateSettingsFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipTemplateSettingsStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_TopRightHighlightMarginProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TopLeftHighlightMarginProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IconElementProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITextCommandBarFlyout>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITextCommandBarFlyoutFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButton>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IsChecked(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsChecked(bool) noexcept = 0;
            virtual int32_t __stdcall add_IsCheckedChanged(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_IsCheckedChanged(winrt::event_token) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButtonFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButtonIsCheckedChangedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButtonStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_IsCheckedProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeView>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_RootNodes(void**) noexcept = 0;
            virtual int32_t __stdcall get_SelectionMode(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_SelectionMode(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_SelectedNodes(void**) noexcept = 0;
            virtual int32_t __stdcall Expand(void*) noexcept = 0;
            virtual int32_t __stdcall Collapse(void*) noexcept = 0;
            virtual int32_t __stdcall SelectAll() noexcept = 0;
            virtual int32_t __stdcall add_ItemInvoked(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_ItemInvoked(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_Expanding(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_Expanding(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_Collapsed(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_Collapsed(winrt::event_token) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeView2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall NodeFromContainer(void*, void**) noexcept = 0;
            virtual int32_t __stdcall ContainerFromNode(void*, void**) noexcept = 0;
            virtual int32_t __stdcall ItemFromContainer(void*, void**) noexcept = 0;
            virtual int32_t __stdcall ContainerFromItem(void*, void**) noexcept = 0;
            virtual int32_t __stdcall get_CanDragItems(bool*) noexcept = 0;
            virtual int32_t __stdcall put_CanDragItems(bool) noexcept = 0;
            virtual int32_t __stdcall get_CanReorderItems(bool*) noexcept = 0;
            virtual int32_t __stdcall put_CanReorderItems(bool) noexcept = 0;
            virtual int32_t __stdcall get_ItemTemplate(void**) noexcept = 0;
            virtual int32_t __stdcall put_ItemTemplate(void*) noexcept = 0;
            virtual int32_t __stdcall get_ItemTemplateSelector(void**) noexcept = 0;
            virtual int32_t __stdcall put_ItemTemplateSelector(void*) noexcept = 0;
            virtual int32_t __stdcall get_ItemContainerStyle(void**) noexcept = 0;
            virtual int32_t __stdcall put_ItemContainerStyle(void*) noexcept = 0;
            virtual int32_t __stdcall get_ItemContainerStyleSelector(void**) noexcept = 0;
            virtual int32_t __stdcall put_ItemContainerStyleSelector(void*) noexcept = 0;
            virtual int32_t __stdcall get_ItemContainerTransitions(void**) noexcept = 0;
            virtual int32_t __stdcall put_ItemContainerTransitions(void*) noexcept = 0;
            virtual int32_t __stdcall get_ItemsSource(void**) noexcept = 0;
            virtual int32_t __stdcall put_ItemsSource(void*) noexcept = 0;
            virtual int32_t __stdcall add_DragItemsStarting(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_DragItemsStarting(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_DragItemsCompleted(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_DragItemsCompleted(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall get_SelectedNode(void**) noexcept = 0;
            virtual int32_t __stdcall put_SelectedNode(void*) noexcept = 0;
            virtual int32_t __stdcall get_SelectedItem(void**) noexcept = 0;
            virtual int32_t __stdcall put_SelectedItem(void*) noexcept = 0;
            virtual int32_t __stdcall get_SelectedItems(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewCollapsedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Node(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewCollapsedEventArgs2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Item(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewDragItemsCompletedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_DropResult(uint32_t*) noexcept = 0;
            virtual int32_t __stdcall get_Items(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewDragItemsCompletedEventArgs2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_NewParentItem(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewDragItemsStartingEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Cancel(bool*) noexcept = 0;
            virtual int32_t __stdcall put_Cancel(bool) noexcept = 0;
            virtual int32_t __stdcall get_Data(void**) noexcept = 0;
            virtual int32_t __stdcall get_Items(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewExpandingEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Node(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewExpandingEventArgs2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Item(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItem>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_GlyphOpacity(double*) noexcept = 0;
            virtual int32_t __stdcall put_GlyphOpacity(double) noexcept = 0;
            virtual int32_t __stdcall get_GlyphBrush(void**) noexcept = 0;
            virtual int32_t __stdcall put_GlyphBrush(void*) noexcept = 0;
            virtual int32_t __stdcall get_ExpandedGlyph(void**) noexcept = 0;
            virtual int32_t __stdcall put_ExpandedGlyph(void*) noexcept = 0;
            virtual int32_t __stdcall get_CollapsedGlyph(void**) noexcept = 0;
            virtual int32_t __stdcall put_CollapsedGlyph(void*) noexcept = 0;
            virtual int32_t __stdcall get_GlyphSize(double*) noexcept = 0;
            virtual int32_t __stdcall put_GlyphSize(double) noexcept = 0;
            virtual int32_t __stdcall get_IsExpanded(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsExpanded(bool) noexcept = 0;
            virtual int32_t __stdcall get_TreeViewItemTemplateSettings(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItem2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_HasUnrealizedChildren(bool*) noexcept = 0;
            virtual int32_t __stdcall put_HasUnrealizedChildren(bool) noexcept = 0;
            virtual int32_t __stdcall get_ItemsSource(void**) noexcept = 0;
            virtual int32_t __stdcall put_ItemsSource(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemInvokedEventArgs>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_InvokedItem(void**) noexcept = 0;
            virtual int32_t __stdcall put_Handled(bool) noexcept = 0;
            virtual int32_t __stdcall get_Handled(bool*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_GlyphOpacityProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_GlyphBrushProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ExpandedGlyphProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CollapsedGlyphProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_GlyphSizeProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsExpandedProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TreeViewItemTemplateSettingsProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemStatics2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_HasUnrealizedChildrenProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ItemsSourceProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemTemplateSettings>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ExpandedGlyphVisibility(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_CollapsedGlyphVisibility(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_Indentation(struct struct_Windows_UI_Xaml_Thickness*) noexcept = 0;
            virtual int32_t __stdcall get_DragItemsCount(int32_t*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemTemplateSettingsFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemTemplateSettingsStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ExpandedGlyphVisibilityProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CollapsedGlyphVisibilityProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IndentationProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_DragItemsCountProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewList>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewListFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewNode>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Content(void**) noexcept = 0;
            virtual int32_t __stdcall put_Content(void*) noexcept = 0;
            virtual int32_t __stdcall get_Parent(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsExpanded(bool*) noexcept = 0;
            virtual int32_t __stdcall put_IsExpanded(bool) noexcept = 0;
            virtual int32_t __stdcall get_HasChildren(bool*) noexcept = 0;
            virtual int32_t __stdcall get_Depth(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_HasUnrealizedChildren(bool*) noexcept = 0;
            virtual int32_t __stdcall put_HasUnrealizedChildren(bool) noexcept = 0;
            virtual int32_t __stdcall get_Children(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewNodeFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewNodeStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ContentProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_DepthProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsExpandedProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_HasChildrenProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_SelectedItemProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_SelectionModeProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITreeViewStatics2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_CanDragItemsProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CanReorderItemsProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ItemTemplateProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ItemTemplateSelectorProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ItemContainerStyleProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ItemContainerStyleSelectorProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ItemContainerTransitionsProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ItemsSourceProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITwoPaneView>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Pane1(void**) noexcept = 0;
            virtual int32_t __stdcall put_Pane1(void*) noexcept = 0;
            virtual int32_t __stdcall get_Pane2(void**) noexcept = 0;
            virtual int32_t __stdcall put_Pane2(void*) noexcept = 0;
            virtual int32_t __stdcall get_Pane1Length(struct struct_Windows_UI_Xaml_GridLength*) noexcept = 0;
            virtual int32_t __stdcall put_Pane1Length(struct struct_Windows_UI_Xaml_GridLength) noexcept = 0;
            virtual int32_t __stdcall get_Pane2Length(struct struct_Windows_UI_Xaml_GridLength*) noexcept = 0;
            virtual int32_t __stdcall put_Pane2Length(struct struct_Windows_UI_Xaml_GridLength) noexcept = 0;
            virtual int32_t __stdcall get_PanePriority(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_PanePriority(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_Mode(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_WideModeConfiguration(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_WideModeConfiguration(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_TallModeConfiguration(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_TallModeConfiguration(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_MinWideModeWidth(double*) noexcept = 0;
            virtual int32_t __stdcall put_MinWideModeWidth(double) noexcept = 0;
            virtual int32_t __stdcall get_MinTallModeHeight(double*) noexcept = 0;
            virtual int32_t __stdcall put_MinTallModeHeight(double) noexcept = 0;
            virtual int32_t __stdcall add_ModeChanged(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_ModeChanged(winrt::event_token) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITwoPaneViewFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::ITwoPaneViewStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Pane1Property(void**) noexcept = 0;
            virtual int32_t __stdcall get_Pane2Property(void**) noexcept = 0;
            virtual int32_t __stdcall get_Pane1LengthProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_Pane2LengthProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_PanePriorityProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ModeProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_WideModeConfigurationProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_TallModeConfigurationProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MinWideModeWidthProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MinTallModeHeightProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IUniformGridLayout>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Orientation(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_Orientation(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_MinItemWidth(double*) noexcept = 0;
            virtual int32_t __stdcall put_MinItemWidth(double) noexcept = 0;
            virtual int32_t __stdcall get_MinItemHeight(double*) noexcept = 0;
            virtual int32_t __stdcall put_MinItemHeight(double) noexcept = 0;
            virtual int32_t __stdcall get_MinRowSpacing(double*) noexcept = 0;
            virtual int32_t __stdcall put_MinRowSpacing(double) noexcept = 0;
            virtual int32_t __stdcall get_MinColumnSpacing(double*) noexcept = 0;
            virtual int32_t __stdcall put_MinColumnSpacing(double) noexcept = 0;
            virtual int32_t __stdcall get_ItemsJustification(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_ItemsJustification(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_ItemsStretch(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_ItemsStretch(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_MaximumRowsOrColumns(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_MaximumRowsOrColumns(int32_t) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IUniformGridLayoutFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IUniformGridLayoutStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_OrientationProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MinItemWidthProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MinItemHeightProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MinRowSpacingProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MinColumnSpacingProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ItemsJustificationProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_ItemsStretchProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_MaximumRowsOrColumnsProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayout>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutContext>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ItemCount(int32_t*) noexcept = 0;
            virtual int32_t __stdcall GetItemAt(int32_t, void**) noexcept = 0;
            virtual int32_t __stdcall get_RealizationRect(winrt::Windows::Foundation::Rect*) noexcept = 0;
            virtual int32_t __stdcall GetOrCreateElementAt(int32_t, void**) noexcept = 0;
            virtual int32_t __stdcall GetOrCreateElementAt2(int32_t, uint32_t, void**) noexcept = 0;
            virtual int32_t __stdcall RecycleElement(void*) noexcept = 0;
            virtual int32_t __stdcall get_RecommendedAnchorIndex(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_LayoutOrigin(winrt::Windows::Foundation::Point*) noexcept = 0;
            virtual int32_t __stdcall put_LayoutOrigin(winrt::Windows::Foundation::Point) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutContextFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutContextOverrides>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall ItemCountCore(int32_t*) noexcept = 0;
            virtual int32_t __stdcall GetItemAtCore(int32_t, void**) noexcept = 0;
            virtual int32_t __stdcall RealizationRectCore(winrt::Windows::Foundation::Rect*) noexcept = 0;
            virtual int32_t __stdcall GetOrCreateElementAtCore(int32_t, uint32_t, void**) noexcept = 0;
            virtual int32_t __stdcall RecycleElementCore(void*) noexcept = 0;
            virtual int32_t __stdcall get_RecommendedAnchorIndexCore(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_LayoutOriginCore(winrt::Windows::Foundation::Point*) noexcept = 0;
            virtual int32_t __stdcall put_LayoutOriginCore(winrt::Windows::Foundation::Point) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutFactory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutOverrides>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall InitializeForContextCore(void*) noexcept = 0;
            virtual int32_t __stdcall UninitializeForContextCore(void*) noexcept = 0;
            virtual int32_t __stdcall MeasureOverride(void*, winrt::Windows::Foundation::Size, winrt::Windows::Foundation::Size*) noexcept = 0;
            virtual int32_t __stdcall ArrangeOverride(void*, winrt::Windows::Foundation::Size, winrt::Windows::Foundation::Size*) noexcept = 0;
            virtual int32_t __stdcall OnItemsChangedCore(void*, void*, void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IWebView2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_CoreWebView2(void**) noexcept = 0;
            virtual int32_t __stdcall EnsureCoreWebView2Async(void**) noexcept = 0;
            virtual int32_t __stdcall ExecuteScriptAsync(void*, void**) noexcept = 0;
            virtual int32_t __stdcall get_Source(void**) noexcept = 0;
            virtual int32_t __stdcall put_Source(void*) noexcept = 0;
            virtual int32_t __stdcall get_CanGoForward(bool*) noexcept = 0;
            virtual int32_t __stdcall put_CanGoForward(bool) noexcept = 0;
            virtual int32_t __stdcall get_CanGoBack(bool*) noexcept = 0;
            virtual int32_t __stdcall put_CanGoBack(bool) noexcept = 0;
            virtual int32_t __stdcall Reload() noexcept = 0;
            virtual int32_t __stdcall GoForward() noexcept = 0;
            virtual int32_t __stdcall GoBack() noexcept = 0;
            virtual int32_t __stdcall NavigateToString(void*) noexcept = 0;
            virtual int32_t __stdcall Close() noexcept = 0;
            virtual int32_t __stdcall add_NavigationCompleted(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_NavigationCompleted(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_WebMessageReceived(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_WebMessageReceived(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_NavigationStarting(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_NavigationStarting(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_CoreProcessFailed(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_CoreProcessFailed(winrt::event_token) noexcept = 0;
            virtual int32_t __stdcall add_CoreWebView2Initialized(void*, winrt::event_token*) noexcept = 0;
            virtual int32_t __stdcall remove_CoreWebView2Initialized(winrt::event_token) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IWebView2Factory>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall CreateInstance(void*, void**, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IWebView2Statics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_SourceProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CanGoForwardProperty(void**) noexcept = 0;
            virtual int32_t __stdcall get_CanGoBackProperty(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IXamlControlsResources>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IXamlControlsResources3>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ControlsResourcesVersion(int32_t*) noexcept = 0;
            virtual int32_t __stdcall put_ControlsResourcesVersion(int32_t) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IXamlControlsResourcesStatics>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall EnsureRevealLights(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Microsoft::UI::Xaml::Controls::IXamlControlsResourcesStatics3>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ControlsResourcesVersionProperty(void**) noexcept = 0;
        };
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IAnimatedIcon
    {
        [[nodiscard]] auto Source() const;
        auto Source(winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource2 const& value) const;
        [[nodiscard]] auto FallbackIconSource() const;
        auto FallbackIconSource(winrt::Microsoft::UI::Xaml::Controls::IconSource const& value) const;
        [[nodiscard]] auto MirroredWhenRightToLeft() const;
        auto MirroredWhenRightToLeft(bool value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIcon>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IAnimatedIcon<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IAnimatedIconFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IAnimatedIconFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IAnimatedIconSource
    {
        [[nodiscard]] auto Source() const;
        auto Source(winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource2 const& value) const;
        [[nodiscard]] auto FallbackIconSource() const;
        auto FallbackIconSource(winrt::Microsoft::UI::Xaml::Controls::IconSource const& value) const;
        [[nodiscard]] auto MirroredWhenRightToLeft() const;
        auto MirroredWhenRightToLeft(bool value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconSource>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IAnimatedIconSource<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IAnimatedIconSourceFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconSourceFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IAnimatedIconSourceFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IAnimatedIconSourceStatics
    {
        [[nodiscard]] auto SourceProperty() const;
        [[nodiscard]] auto FallbackIconSourceProperty() const;
        [[nodiscard]] auto MirroredWhenRightToLeftProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconSourceStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IAnimatedIconSourceStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IAnimatedIconStatics
    {
        [[nodiscard]] auto StateProperty() const;
        auto SetState(winrt::Windows::UI::Xaml::DependencyObject const& object, param::hstring const& value) const;
        auto GetState(winrt::Windows::UI::Xaml::DependencyObject const& object) const;
        [[nodiscard]] auto SourceProperty() const;
        [[nodiscard]] auto FallbackIconSourceProperty() const;
        [[nodiscard]] auto MirroredWhenRightToLeftProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IAnimatedIconStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IAnimatedIconStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IAnimatedVisual
    {
        [[nodiscard]] auto RootVisual() const;
        [[nodiscard]] auto Size() const;
        [[nodiscard]] auto Duration() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisual>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IAnimatedVisual<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IAnimatedVisual2
    {
        auto CreateAnimations() const;
        auto DestroyAnimations() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisual2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IAnimatedVisual2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IAnimatedVisualPlayer
    {
        [[nodiscard]] auto Diagnostics() const;
        [[nodiscard]] auto Duration() const;
        [[nodiscard]] auto Source() const;
        auto Source(winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource const& value) const;
        [[nodiscard]] auto FallbackContent() const;
        auto FallbackContent(winrt::Windows::UI::Xaml::DataTemplate const& value) const;
        [[nodiscard]] auto AutoPlay() const;
        auto AutoPlay(bool value) const;
        [[nodiscard]] auto IsAnimatedVisualLoaded() const;
        [[nodiscard]] auto IsPlaying() const;
        [[nodiscard]] auto PlaybackRate() const;
        auto PlaybackRate(double value) const;
        [[nodiscard]] auto ProgressObject() const;
        [[nodiscard]] auto Stretch() const;
        auto Stretch(winrt::Windows::UI::Xaml::Media::Stretch const& value) const;
        auto Pause() const;
        auto PlayAsync(double fromProgress, double toProgress, bool looped) const;
        auto Resume() const;
        auto SetProgress(double progress) const;
        auto Stop() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayer>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IAnimatedVisualPlayer<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IAnimatedVisualPlayer2
    {
        [[nodiscard]] auto AnimationOptimization() const;
        auto AnimationOptimization(winrt::Microsoft::UI::Xaml::Controls::PlayerAnimationOptimization const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayer2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IAnimatedVisualPlayer2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IAnimatedVisualPlayerFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayerFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IAnimatedVisualPlayerFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IAnimatedVisualPlayerStatics
    {
        [[nodiscard]] auto AutoPlayProperty() const;
        [[nodiscard]] auto DiagnosticsProperty() const;
        [[nodiscard]] auto DurationProperty() const;
        [[nodiscard]] auto FallbackContentProperty() const;
        [[nodiscard]] auto IsAnimatedVisualLoadedProperty() const;
        [[nodiscard]] auto IsPlayingProperty() const;
        [[nodiscard]] auto PlaybackRateProperty() const;
        [[nodiscard]] auto SourceProperty() const;
        [[nodiscard]] auto StretchProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayerStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IAnimatedVisualPlayerStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IAnimatedVisualPlayerStatics2
    {
        [[nodiscard]] auto AnimationOptimizationProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualPlayerStatics2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IAnimatedVisualPlayerStatics2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IAnimatedVisualSource
    {
        auto TryCreateAnimatedVisual(winrt::Windows::UI::Composition::Compositor const& compositor, winrt::Windows::Foundation::IInspectable& diagnostics) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IAnimatedVisualSource<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IAnimatedVisualSource2
    {
        [[nodiscard]] auto Markers() const;
        auto SetColorProperty(param::hstring const& propertyName, winrt::Windows::UI::Color const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IAnimatedVisualSource2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IAnimatedVisualSource3
    {
        auto TryCreateAnimatedVisual(winrt::Windows::UI::Composition::Compositor const& compositor, winrt::Windows::Foundation::IInspectable& diagnostics, bool createAnimations) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource3>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IAnimatedVisualSource3<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IBackdropMaterial
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IBackdropMaterial>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IBackdropMaterial<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IBackdropMaterialFactory
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IBackdropMaterialFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IBackdropMaterialFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IBackdropMaterialStatics
    {
        [[nodiscard]] auto ApplyToRootOrPageBackgroundProperty() const;
        auto SetApplyToRootOrPageBackground(winrt::Windows::UI::Xaml::Controls::Control const& element, bool value) const;
        auto GetApplyToRootOrPageBackground(winrt::Windows::UI::Xaml::Controls::Control const& element) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IBackdropMaterialStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IBackdropMaterialStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IBitmapIconSource
    {
        [[nodiscard]] auto UriSource() const;
        auto UriSource(winrt::Windows::Foundation::Uri const& value) const;
        [[nodiscard]] auto ShowAsMonochrome() const;
        auto ShowAsMonochrome(bool value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IBitmapIconSource>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IBitmapIconSource<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IBitmapIconSourceFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IBitmapIconSourceFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IBitmapIconSourceFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IBitmapIconSourceStatics
    {
        [[nodiscard]] auto UriSourceProperty() const;
        [[nodiscard]] auto ShowAsMonochromeProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IBitmapIconSourceStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IBitmapIconSourceStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IBreadcrumbBar
    {
        [[nodiscard]] auto ItemsSource() const;
        auto ItemsSource(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto ItemTemplate() const;
        auto ItemTemplate(winrt::Windows::Foundation::IInspectable const& value) const;
        auto ItemClicked(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::BreadcrumbBar, winrt::Microsoft::UI::Xaml::Controls::BreadcrumbBarItemClickedEventArgs> const& handler) const;
        using ItemClicked_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBar, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBar>::remove_ItemClicked>;
        [[nodiscard]] auto ItemClicked(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::BreadcrumbBar, winrt::Microsoft::UI::Xaml::Controls::BreadcrumbBarItemClickedEventArgs> const& handler) const;
        auto ItemClicked(winrt::event_token const& token) const noexcept;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBar>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IBreadcrumbBar<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IBreadcrumbBarFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IBreadcrumbBarFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IBreadcrumbBarItem
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarItem>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IBreadcrumbBarItem<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IBreadcrumbBarItemClickedEventArgs
    {
        [[nodiscard]] auto Index() const;
        [[nodiscard]] auto Item() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarItemClickedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IBreadcrumbBarItemClickedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IBreadcrumbBarItemFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarItemFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IBreadcrumbBarItemFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IBreadcrumbBarStatics
    {
        [[nodiscard]] auto ItemsSourceProperty() const;
        [[nodiscard]] auto ItemTemplateProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IBreadcrumbBarStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IBreadcrumbBarStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IColorChangedEventArgs
    {
        [[nodiscard]] auto OldColor() const;
        [[nodiscard]] auto NewColor() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IColorChangedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IColorChangedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IColorPicker
    {
        [[nodiscard]] auto Color() const;
        auto Color(winrt::Windows::UI::Color const& value) const;
        [[nodiscard]] auto PreviousColor() const;
        auto PreviousColor(winrt::Windows::Foundation::IReference<winrt::Windows::UI::Color> const& value) const;
        [[nodiscard]] auto IsAlphaEnabled() const;
        auto IsAlphaEnabled(bool value) const;
        [[nodiscard]] auto IsColorSpectrumVisible() const;
        auto IsColorSpectrumVisible(bool value) const;
        [[nodiscard]] auto IsColorPreviewVisible() const;
        auto IsColorPreviewVisible(bool value) const;
        [[nodiscard]] auto IsColorSliderVisible() const;
        auto IsColorSliderVisible(bool value) const;
        [[nodiscard]] auto IsAlphaSliderVisible() const;
        auto IsAlphaSliderVisible(bool value) const;
        [[nodiscard]] auto IsMoreButtonVisible() const;
        auto IsMoreButtonVisible(bool value) const;
        [[nodiscard]] auto IsColorChannelTextInputVisible() const;
        auto IsColorChannelTextInputVisible(bool value) const;
        [[nodiscard]] auto IsAlphaTextInputVisible() const;
        auto IsAlphaTextInputVisible(bool value) const;
        [[nodiscard]] auto IsHexInputVisible() const;
        auto IsHexInputVisible(bool value) const;
        [[nodiscard]] auto MinHue() const;
        auto MinHue(int32_t value) const;
        [[nodiscard]] auto MaxHue() const;
        auto MaxHue(int32_t value) const;
        [[nodiscard]] auto MinSaturation() const;
        auto MinSaturation(int32_t value) const;
        [[nodiscard]] auto MaxSaturation() const;
        auto MaxSaturation(int32_t value) const;
        [[nodiscard]] auto MinValue() const;
        auto MinValue(int32_t value) const;
        [[nodiscard]] auto MaxValue() const;
        auto MaxValue(int32_t value) const;
        [[nodiscard]] auto ColorSpectrumShape() const;
        auto ColorSpectrumShape(winrt::Microsoft::UI::Xaml::Controls::ColorSpectrumShape const& value) const;
        [[nodiscard]] auto ColorSpectrumComponents() const;
        auto ColorSpectrumComponents(winrt::Microsoft::UI::Xaml::Controls::ColorSpectrumComponents const& value) const;
        auto ColorChanged(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::ColorPicker, winrt::Microsoft::UI::Xaml::Controls::ColorChangedEventArgs> const& handler) const;
        using ColorChanged_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IColorPicker, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IColorPicker>::remove_ColorChanged>;
        [[nodiscard]] auto ColorChanged(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::ColorPicker, winrt::Microsoft::UI::Xaml::Controls::ColorChangedEventArgs> const& handler) const;
        auto ColorChanged(winrt::event_token const& token) const noexcept;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IColorPicker>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IColorPicker<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IColorPicker2
    {
        [[nodiscard]] auto Orientation() const;
        auto Orientation(winrt::Windows::UI::Xaml::Controls::Orientation const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IColorPicker2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IColorPicker2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IColorPickerFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IColorPickerFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IColorPickerFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IColorPickerStatics
    {
        [[nodiscard]] auto ColorProperty() const;
        [[nodiscard]] auto PreviousColorProperty() const;
        [[nodiscard]] auto IsAlphaEnabledProperty() const;
        [[nodiscard]] auto IsColorSpectrumVisibleProperty() const;
        [[nodiscard]] auto IsColorPreviewVisibleProperty() const;
        [[nodiscard]] auto IsColorSliderVisibleProperty() const;
        [[nodiscard]] auto IsAlphaSliderVisibleProperty() const;
        [[nodiscard]] auto IsMoreButtonVisibleProperty() const;
        [[nodiscard]] auto IsColorChannelTextInputVisibleProperty() const;
        [[nodiscard]] auto IsAlphaTextInputVisibleProperty() const;
        [[nodiscard]] auto IsHexInputVisibleProperty() const;
        [[nodiscard]] auto MinHueProperty() const;
        [[nodiscard]] auto MaxHueProperty() const;
        [[nodiscard]] auto MinSaturationProperty() const;
        [[nodiscard]] auto MaxSaturationProperty() const;
        [[nodiscard]] auto MinValueProperty() const;
        [[nodiscard]] auto MaxValueProperty() const;
        [[nodiscard]] auto ColorSpectrumShapeProperty() const;
        [[nodiscard]] auto ColorSpectrumComponentsProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IColorPickerStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IColorPickerStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IColorPickerStatics2
    {
        [[nodiscard]] auto OrientationProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IColorPickerStatics2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IColorPickerStatics2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ICommandBarFlyout
    {
        [[nodiscard]] auto PrimaryCommands() const;
        [[nodiscard]] auto SecondaryCommands() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ICommandBarFlyout>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ICommandBarFlyout<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ICommandBarFlyout2
    {
        [[nodiscard]] auto AlwaysExpanded() const;
        auto AlwaysExpanded(bool value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ICommandBarFlyout2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ICommandBarFlyout2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ICommandBarFlyoutFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ICommandBarFlyoutFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ICommandBarFlyoutFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ICoreWebView2InitializedEventArgs
    {
        [[nodiscard]] auto Exception() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ICoreWebView2InitializedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ICoreWebView2InitializedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IDropDownButton
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IDropDownButton>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IDropDownButton<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IDropDownButtonFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IDropDownButtonFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IDropDownButtonFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IDynamicAnimatedVisualSource
    {
        auto AnimatedVisualInvalidated(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::IDynamicAnimatedVisualSource, winrt::Windows::Foundation::IInspectable> const& handler) const;
        using AnimatedVisualInvalidated_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IDynamicAnimatedVisualSource, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IDynamicAnimatedVisualSource>::remove_AnimatedVisualInvalidated>;
        [[nodiscard]] auto AnimatedVisualInvalidated(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::IDynamicAnimatedVisualSource, winrt::Windows::Foundation::IInspectable> const& handler) const;
        auto AnimatedVisualInvalidated(winrt::event_token const& token) const noexcept;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IDynamicAnimatedVisualSource>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IDynamicAnimatedVisualSource<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IElementFactory
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IElementFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IElementFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IElementFactoryFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IElementFactoryFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IElementFactoryFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IElementFactoryGetArgs
    {
        [[nodiscard]] auto Data() const;
        auto Data(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto Parent() const;
        auto Parent(winrt::Windows::UI::Xaml::UIElement const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IElementFactoryGetArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IElementFactoryGetArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IElementFactoryOverrides
    {
        auto GetElementCore(winrt::Microsoft::UI::Xaml::Controls::ElementFactoryGetArgs const& args) const;
        auto RecycleElementCore(winrt::Microsoft::UI::Xaml::Controls::ElementFactoryRecycleArgs const& args) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IElementFactoryOverrides>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IElementFactoryOverrides<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IElementFactoryRecycleArgs
    {
        [[nodiscard]] auto Element() const;
        auto Element(winrt::Windows::UI::Xaml::UIElement const& value) const;
        [[nodiscard]] auto Parent() const;
        auto Parent(winrt::Windows::UI::Xaml::UIElement const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IElementFactoryRecycleArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IElementFactoryRecycleArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IExpander
    {
        [[nodiscard]] auto Header() const;
        auto Header(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto HeaderTemplate() const;
        auto HeaderTemplate(winrt::Windows::UI::Xaml::DataTemplate const& value) const;
        [[nodiscard]] auto HeaderTemplateSelector() const;
        auto HeaderTemplateSelector(winrt::Windows::UI::Xaml::Controls::DataTemplateSelector const& value) const;
        [[nodiscard]] auto IsExpanded() const;
        auto IsExpanded(bool value) const;
        [[nodiscard]] auto ExpandDirection() const;
        auto ExpandDirection(winrt::Microsoft::UI::Xaml::Controls::ExpandDirection const& value) const;
        auto Expanding(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::Expander, winrt::Microsoft::UI::Xaml::Controls::ExpanderExpandingEventArgs> const& handler) const;
        using Expanding_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IExpander, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IExpander>::remove_Expanding>;
        [[nodiscard]] auto Expanding(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::Expander, winrt::Microsoft::UI::Xaml::Controls::ExpanderExpandingEventArgs> const& handler) const;
        auto Expanding(winrt::event_token const& token) const noexcept;
        auto Collapsed(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::Expander, winrt::Microsoft::UI::Xaml::Controls::ExpanderCollapsedEventArgs> const& handler) const;
        using Collapsed_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IExpander, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IExpander>::remove_Collapsed>;
        [[nodiscard]] auto Collapsed(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::Expander, winrt::Microsoft::UI::Xaml::Controls::ExpanderCollapsedEventArgs> const& handler) const;
        auto Collapsed(winrt::event_token const& token) const noexcept;
        [[nodiscard]] auto TemplateSettings() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IExpander>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IExpander<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IExpanderCollapsedEventArgs
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IExpanderCollapsedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IExpanderCollapsedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IExpanderExpandingEventArgs
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IExpanderExpandingEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IExpanderExpandingEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IExpanderFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IExpanderFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IExpanderFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IExpanderStatics
    {
        [[nodiscard]] auto HeaderProperty() const;
        [[nodiscard]] auto HeaderTemplateProperty() const;
        [[nodiscard]] auto HeaderTemplateSelectorProperty() const;
        [[nodiscard]] auto IsExpandedProperty() const;
        [[nodiscard]] auto ExpandDirectionProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IExpanderStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IExpanderStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IExpanderTemplateSettings
    {
        [[nodiscard]] auto ContentHeight() const;
        [[nodiscard]] auto NegativeContentHeight() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IExpanderTemplateSettings>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IExpanderTemplateSettings<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IFontIconSource
    {
        [[nodiscard]] auto Glyph() const;
        auto Glyph(param::hstring const& value) const;
        [[nodiscard]] auto FontSize() const;
        auto FontSize(double value) const;
        [[nodiscard]] auto FontFamily() const;
        auto FontFamily(winrt::Windows::UI::Xaml::Media::FontFamily const& value) const;
        [[nodiscard]] auto FontWeight() const;
        auto FontWeight(winrt::Windows::UI::Text::FontWeight const& value) const;
        [[nodiscard]] auto FontStyle() const;
        auto FontStyle(winrt::Windows::UI::Text::FontStyle const& value) const;
        [[nodiscard]] auto IsTextScaleFactorEnabled() const;
        auto IsTextScaleFactorEnabled(bool value) const;
        [[nodiscard]] auto MirroredWhenRightToLeft() const;
        auto MirroredWhenRightToLeft(bool value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IFontIconSource>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IFontIconSource<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IFontIconSourceFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IFontIconSourceFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IFontIconSourceFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IFontIconSourceStatics
    {
        [[nodiscard]] auto GlyphProperty() const;
        [[nodiscard]] auto FontSizeProperty() const;
        [[nodiscard]] auto FontFamilyProperty() const;
        [[nodiscard]] auto FontWeightProperty() const;
        [[nodiscard]] auto FontStyleProperty() const;
        [[nodiscard]] auto IsTextScaleFactorEnabledProperty() const;
        [[nodiscard]] auto MirroredWhenRightToLeftProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IFontIconSourceStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IFontIconSourceStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IIconSource
    {
        auto CreateIconElement() const;
        [[nodiscard]] auto Foreground() const;
        auto Foreground(winrt::Windows::UI::Xaml::Media::Brush const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IIconSource>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IIconSource<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IIconSourceFactory
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IIconSourceFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IIconSourceFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IIconSourceStatics
    {
        [[nodiscard]] auto ForegroundProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IIconSourceStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IIconSourceStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IImageIcon
    {
        [[nodiscard]] auto Source() const;
        auto Source(winrt::Windows::UI::Xaml::Media::ImageSource const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IImageIcon>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IImageIcon<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IImageIconFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IImageIconFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IImageIconFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IImageIconSource
    {
        [[nodiscard]] auto ImageSource() const;
        auto ImageSource(winrt::Windows::UI::Xaml::Media::ImageSource const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IImageIconSource>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IImageIconSource<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IImageIconSourceFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IImageIconSourceFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IImageIconSourceFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IImageIconSourceStatics
    {
        [[nodiscard]] auto ImageSourceProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IImageIconSourceStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IImageIconSourceStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IImageIconStatics
    {
        [[nodiscard]] auto SourceProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IImageIconStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IImageIconStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IInfoBadge
    {
        [[nodiscard]] auto Value() const;
        auto Value(int32_t value) const;
        [[nodiscard]] auto IconSource() const;
        auto IconSource(winrt::Microsoft::UI::Xaml::Controls::IconSource const& value) const;
        [[nodiscard]] auto TemplateSettings() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IInfoBadge>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IInfoBadge<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IInfoBadgeFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IInfoBadgeFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IInfoBadgeStatics
    {
        [[nodiscard]] auto ValueProperty() const;
        [[nodiscard]] auto IconSourceProperty() const;
        [[nodiscard]] auto TemplateSettingsProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IInfoBadgeStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IInfoBadgeTemplateSettings
    {
        [[nodiscard]] auto InfoBadgeCornerRadius() const;
        auto InfoBadgeCornerRadius(winrt::Windows::UI::Xaml::CornerRadius const& value) const;
        [[nodiscard]] auto IconElement() const;
        auto IconElement(winrt::Windows::UI::Xaml::Controls::IconElement const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeTemplateSettings>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IInfoBadgeTemplateSettings<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IInfoBadgeTemplateSettingsFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeTemplateSettingsFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IInfoBadgeTemplateSettingsFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IInfoBadgeTemplateSettingsStatics
    {
        [[nodiscard]] auto InfoBadgeCornerRadiusProperty() const;
        [[nodiscard]] auto IconElementProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IInfoBadgeTemplateSettingsStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IInfoBadgeTemplateSettingsStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IInfoBar
    {
        [[nodiscard]] auto IsOpen() const;
        auto IsOpen(bool value) const;
        [[nodiscard]] auto Title() const;
        auto Title(param::hstring const& value) const;
        [[nodiscard]] auto Message() const;
        auto Message(param::hstring const& value) const;
        [[nodiscard]] auto Severity() const;
        auto Severity(winrt::Microsoft::UI::Xaml::Controls::InfoBarSeverity const& value) const;
        [[nodiscard]] auto IconSource() const;
        auto IconSource(winrt::Microsoft::UI::Xaml::Controls::IconSource const& value) const;
        [[nodiscard]] auto IsIconVisible() const;
        auto IsIconVisible(bool value) const;
        [[nodiscard]] auto IsClosable() const;
        auto IsClosable(bool value) const;
        [[nodiscard]] auto CloseButtonStyle() const;
        auto CloseButtonStyle(winrt::Windows::UI::Xaml::Style const& value) const;
        [[nodiscard]] auto CloseButtonCommand() const;
        auto CloseButtonCommand(winrt::Windows::UI::Xaml::Input::ICommand const& value) const;
        [[nodiscard]] auto CloseButtonCommandParameter() const;
        auto CloseButtonCommandParameter(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto ActionButton() const;
        auto ActionButton(winrt::Windows::UI::Xaml::Controls::Primitives::ButtonBase const& value) const;
        [[nodiscard]] auto Content() const;
        auto Content(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto ContentTemplate() const;
        auto ContentTemplate(winrt::Windows::UI::Xaml::DataTemplate const& value) const;
        [[nodiscard]] auto TemplateSettings() const;
        auto CloseButtonClick(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::InfoBar, winrt::Windows::Foundation::IInspectable> const& handler) const;
        using CloseButtonClick_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IInfoBar, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IInfoBar>::remove_CloseButtonClick>;
        [[nodiscard]] auto CloseButtonClick(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::InfoBar, winrt::Windows::Foundation::IInspectable> const& handler) const;
        auto CloseButtonClick(winrt::event_token const& token) const noexcept;
        auto Closing(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::InfoBar, winrt::Microsoft::UI::Xaml::Controls::InfoBarClosingEventArgs> const& handler) const;
        using Closing_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IInfoBar, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IInfoBar>::remove_Closing>;
        [[nodiscard]] auto Closing(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::InfoBar, winrt::Microsoft::UI::Xaml::Controls::InfoBarClosingEventArgs> const& handler) const;
        auto Closing(winrt::event_token const& token) const noexcept;
        auto Closed(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::InfoBar, winrt::Microsoft::UI::Xaml::Controls::InfoBarClosedEventArgs> const& handler) const;
        using Closed_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IInfoBar, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IInfoBar>::remove_Closed>;
        [[nodiscard]] auto Closed(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::InfoBar, winrt::Microsoft::UI::Xaml::Controls::InfoBarClosedEventArgs> const& handler) const;
        auto Closed(winrt::event_token const& token) const noexcept;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IInfoBar>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IInfoBar<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IInfoBarClosedEventArgs
    {
        [[nodiscard]] auto Reason() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IInfoBarClosedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IInfoBarClosedEventArgsFactory
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosedEventArgsFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IInfoBarClosedEventArgsFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IInfoBarClosingEventArgs
    {
        [[nodiscard]] auto Reason() const;
        [[nodiscard]] auto Cancel() const;
        auto Cancel(bool value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosingEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IInfoBarClosingEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IInfoBarClosingEventArgsFactory
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IInfoBarClosingEventArgsFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IInfoBarClosingEventArgsFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IInfoBarFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IInfoBarFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IInfoBarFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IInfoBarStatics
    {
        [[nodiscard]] auto IsOpenProperty() const;
        [[nodiscard]] auto TitleProperty() const;
        [[nodiscard]] auto MessageProperty() const;
        [[nodiscard]] auto SeverityProperty() const;
        [[nodiscard]] auto IconSourceProperty() const;
        [[nodiscard]] auto IsIconVisibleProperty() const;
        [[nodiscard]] auto IsClosableProperty() const;
        [[nodiscard]] auto CloseButtonStyleProperty() const;
        [[nodiscard]] auto CloseButtonCommandProperty() const;
        [[nodiscard]] auto CloseButtonCommandParameterProperty() const;
        [[nodiscard]] auto ActionButtonProperty() const;
        [[nodiscard]] auto ContentProperty() const;
        [[nodiscard]] auto ContentTemplateProperty() const;
        [[nodiscard]] auto TemplateSettingsProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IInfoBarStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IInfoBarStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IInfoBarTemplateSettings
    {
        [[nodiscard]] auto IconElement() const;
        auto IconElement(winrt::Windows::UI::Xaml::Controls::IconElement const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IInfoBarTemplateSettings>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IInfoBarTemplateSettings<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IInfoBarTemplateSettingsFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IInfoBarTemplateSettingsFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IInfoBarTemplateSettingsFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IInfoBarTemplateSettingsStatics
    {
        [[nodiscard]] auto IconElementProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IInfoBarTemplateSettingsStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IInfoBarTemplateSettingsStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IItemsRepeater
    {
        [[nodiscard]] auto ItemsSource() const;
        auto ItemsSource(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto ItemsSourceView() const;
        [[nodiscard]] auto ItemTemplate() const;
        auto ItemTemplate(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto Layout() const;
        auto Layout(winrt::Microsoft::UI::Xaml::Controls::Layout const& value) const;
        [[nodiscard]] auto HorizontalCacheLength() const;
        auto HorizontalCacheLength(double value) const;
        [[nodiscard]] auto VerticalCacheLength() const;
        auto VerticalCacheLength(double value) const;
        [[nodiscard]] auto Background() const;
        auto Background(winrt::Windows::UI::Xaml::Media::Brush const& value) const;
        auto GetElementIndex(winrt::Windows::UI::Xaml::UIElement const& element) const;
        auto TryGetElement(int32_t index) const;
        auto GetOrCreateElement(int32_t index) const;
        auto ElementPrepared(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeater, winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterElementPreparedEventArgs> const& handler) const;
        using ElementPrepared_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeater, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeater>::remove_ElementPrepared>;
        [[nodiscard]] auto ElementPrepared(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeater, winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterElementPreparedEventArgs> const& handler) const;
        auto ElementPrepared(winrt::event_token const& token) const noexcept;
        auto ElementClearing(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeater, winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterElementClearingEventArgs> const& handler) const;
        using ElementClearing_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeater, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeater>::remove_ElementClearing>;
        [[nodiscard]] auto ElementClearing(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeater, winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterElementClearingEventArgs> const& handler) const;
        auto ElementClearing(winrt::event_token const& token) const noexcept;
        auto ElementIndexChanged(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeater, winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterElementIndexChangedEventArgs> const& handler) const;
        using ElementIndexChanged_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeater, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeater>::remove_ElementIndexChanged>;
        [[nodiscard]] auto ElementIndexChanged(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::ItemsRepeater, winrt::Microsoft::UI::Xaml::Controls::ItemsRepeaterElementIndexChangedEventArgs> const& handler) const;
        auto ElementIndexChanged(winrt::event_token const& token) const noexcept;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeater>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IItemsRepeater<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IItemsRepeaterElementClearingEventArgs
    {
        [[nodiscard]] auto Element() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterElementClearingEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IItemsRepeaterElementClearingEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IItemsRepeaterElementIndexChangedEventArgs
    {
        [[nodiscard]] auto Element() const;
        [[nodiscard]] auto OldIndex() const;
        [[nodiscard]] auto NewIndex() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterElementIndexChangedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IItemsRepeaterElementIndexChangedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IItemsRepeaterElementPreparedEventArgs
    {
        [[nodiscard]] auto Element() const;
        [[nodiscard]] auto Index() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterElementPreparedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IItemsRepeaterElementPreparedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IItemsRepeaterFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IItemsRepeaterFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IItemsRepeaterScrollHost
    {
        [[nodiscard]] auto ScrollViewer() const;
        auto ScrollViewer(winrt::Windows::UI::Xaml::Controls::ScrollViewer const& value) const;
        [[nodiscard]] auto CurrentAnchor() const;
        [[nodiscard]] auto HorizontalAnchorRatio() const;
        auto HorizontalAnchorRatio(double value) const;
        [[nodiscard]] auto VerticalAnchorRatio() const;
        auto VerticalAnchorRatio(double value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterScrollHost>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IItemsRepeaterScrollHost<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IItemsRepeaterStatics
    {
        [[nodiscard]] auto ItemsSourceProperty() const;
        [[nodiscard]] auto ItemTemplateProperty() const;
        [[nodiscard]] auto LayoutProperty() const;
        [[nodiscard]] auto HorizontalCacheLengthProperty() const;
        [[nodiscard]] auto VerticalCacheLengthProperty() const;
        [[nodiscard]] auto BackgroundProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IItemsRepeaterStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IItemsRepeaterStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IItemsSourceView
    {
        [[nodiscard]] auto Count() const;
        auto GetAt(int32_t index) const;
        [[nodiscard]] auto HasKeyIndexMapping() const;
        auto KeyFromIndex(int32_t index) const;
        auto IndexFromKey(param::hstring const& key) const;
        auto IndexOf(winrt::Windows::Foundation::IInspectable const& item) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IItemsSourceView>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IItemsSourceView<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IItemsSourceViewFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& source, winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IItemsSourceViewFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IItemsSourceViewFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IKeyIndexMapping
    {
        auto KeyFromIndex(int32_t index) const;
        auto IndexFromKey(param::hstring const& key) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IKeyIndexMapping>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IKeyIndexMapping<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ILayout
    {
        auto InitializeForContext(winrt::Microsoft::UI::Xaml::Controls::LayoutContext const& context) const;
        auto UninitializeForContext(winrt::Microsoft::UI::Xaml::Controls::LayoutContext const& context) const;
        auto Measure(winrt::Microsoft::UI::Xaml::Controls::LayoutContext const& context, winrt::Windows::Foundation::Size const& availableSize) const;
        auto Arrange(winrt::Microsoft::UI::Xaml::Controls::LayoutContext const& context, winrt::Windows::Foundation::Size const& finalSize) const;
        auto MeasureInvalidated(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::Layout, winrt::Windows::Foundation::IInspectable> const& handler) const;
        using MeasureInvalidated_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ILayout, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ILayout>::remove_MeasureInvalidated>;
        [[nodiscard]] auto MeasureInvalidated(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::Layout, winrt::Windows::Foundation::IInspectable> const& handler) const;
        auto MeasureInvalidated(winrt::event_token const& token) const noexcept;
        auto ArrangeInvalidated(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::Layout, winrt::Windows::Foundation::IInspectable> const& handler) const;
        using ArrangeInvalidated_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ILayout, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ILayout>::remove_ArrangeInvalidated>;
        [[nodiscard]] auto ArrangeInvalidated(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::Layout, winrt::Windows::Foundation::IInspectable> const& handler) const;
        auto ArrangeInvalidated(winrt::event_token const& token) const noexcept;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ILayout>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ILayout<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ILayoutContext
    {
        [[nodiscard]] auto LayoutState() const;
        auto LayoutState(winrt::Windows::Foundation::IInspectable const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ILayoutContext>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ILayoutContext<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ILayoutContextFactory
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ILayoutContextFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ILayoutContextFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ILayoutContextOverrides
    {
        [[nodiscard]] auto LayoutStateCore() const;
        auto LayoutStateCore(winrt::Windows::Foundation::IInspectable const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ILayoutContextOverrides>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ILayoutContextOverrides<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ILayoutFactory
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ILayoutFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ILayoutFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ILayoutProtected
    {
        auto InvalidateMeasure() const;
        auto InvalidateArrange() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ILayoutProtected>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ILayoutProtected<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IMenuBar
    {
        [[nodiscard]] auto Items() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IMenuBar>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IMenuBar<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IMenuBarFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IMenuBarFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IMenuBarFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IMenuBarItem
    {
        [[nodiscard]] auto Title() const;
        auto Title(param::hstring const& value) const;
        [[nodiscard]] auto Items() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItem>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IMenuBarItem<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IMenuBarItemFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItemFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IMenuBarItemFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IMenuBarItemFlyout
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItemFlyout>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IMenuBarItemFlyout<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IMenuBarItemFlyoutFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItemFlyoutFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IMenuBarItemFlyoutFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IMenuBarItemStatics
    {
        [[nodiscard]] auto TitleProperty() const;
        [[nodiscard]] auto ItemsProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IMenuBarItemStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IMenuBarItemStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IMenuBarStatics
    {
        [[nodiscard]] auto ItemsProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IMenuBarStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IMenuBarStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationView
    {
        [[nodiscard]] auto IsPaneOpen() const;
        auto IsPaneOpen(bool value) const;
        [[nodiscard]] auto CompactModeThresholdWidth() const;
        auto CompactModeThresholdWidth(double value) const;
        [[nodiscard]] auto ExpandedModeThresholdWidth() const;
        auto ExpandedModeThresholdWidth(double value) const;
        [[nodiscard]] auto FooterMenuItems() const;
        [[nodiscard]] auto FooterMenuItemsSource() const;
        auto FooterMenuItemsSource(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto PaneFooter() const;
        auto PaneFooter(winrt::Windows::UI::Xaml::UIElement const& value) const;
        [[nodiscard]] auto Header() const;
        auto Header(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto HeaderTemplate() const;
        auto HeaderTemplate(winrt::Windows::UI::Xaml::DataTemplate const& value) const;
        [[nodiscard]] auto DisplayMode() const;
        [[nodiscard]] auto IsSettingsVisible() const;
        auto IsSettingsVisible(bool value) const;
        [[nodiscard]] auto IsPaneToggleButtonVisible() const;
        auto IsPaneToggleButtonVisible(bool value) const;
        [[nodiscard]] auto AlwaysShowHeader() const;
        auto AlwaysShowHeader(bool value) const;
        [[nodiscard]] auto CompactPaneLength() const;
        auto CompactPaneLength(double value) const;
        [[nodiscard]] auto OpenPaneLength() const;
        auto OpenPaneLength(double value) const;
        [[nodiscard]] auto PaneToggleButtonStyle() const;
        auto PaneToggleButtonStyle(winrt::Windows::UI::Xaml::Style const& value) const;
        [[nodiscard]] auto SelectedItem() const;
        auto SelectedItem(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto MenuItems() const;
        [[nodiscard]] auto MenuItemsSource() const;
        auto MenuItemsSource(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto SettingsItem() const;
        [[nodiscard]] auto AutoSuggestBox() const;
        auto AutoSuggestBox(winrt::Windows::UI::Xaml::Controls::AutoSuggestBox const& value) const;
        [[nodiscard]] auto MenuItemTemplate() const;
        auto MenuItemTemplate(winrt::Windows::UI::Xaml::DataTemplate const& value) const;
        [[nodiscard]] auto MenuItemTemplateSelector() const;
        auto MenuItemTemplateSelector(winrt::Windows::UI::Xaml::Controls::DataTemplateSelector const& value) const;
        [[nodiscard]] auto MenuItemContainerStyle() const;
        auto MenuItemContainerStyle(winrt::Windows::UI::Xaml::Style const& value) const;
        [[nodiscard]] auto MenuItemContainerStyleSelector() const;
        auto MenuItemContainerStyleSelector(winrt::Windows::UI::Xaml::Controls::StyleSelector const& value) const;
        auto MenuItemFromContainer(winrt::Windows::UI::Xaml::DependencyObject const& container) const;
        auto ContainerFromMenuItem(winrt::Windows::Foundation::IInspectable const& item) const;
        auto SelectionChanged(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NavigationView, winrt::Microsoft::UI::Xaml::Controls::NavigationViewSelectionChangedEventArgs> const& handler) const;
        using SelectionChanged_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::INavigationView, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::INavigationView>::remove_SelectionChanged>;
        [[nodiscard]] auto SelectionChanged(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NavigationView, winrt::Microsoft::UI::Xaml::Controls::NavigationViewSelectionChangedEventArgs> const& handler) const;
        auto SelectionChanged(winrt::event_token const& token) const noexcept;
        auto ItemInvoked(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NavigationView, winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemInvokedEventArgs> const& handler) const;
        using ItemInvoked_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::INavigationView, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::INavigationView>::remove_ItemInvoked>;
        [[nodiscard]] auto ItemInvoked(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NavigationView, winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemInvokedEventArgs> const& handler) const;
        auto ItemInvoked(winrt::event_token const& token) const noexcept;
        auto DisplayModeChanged(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NavigationView, winrt::Microsoft::UI::Xaml::Controls::NavigationViewDisplayModeChangedEventArgs> const& handler) const;
        using DisplayModeChanged_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::INavigationView, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::INavigationView>::remove_DisplayModeChanged>;
        [[nodiscard]] auto DisplayModeChanged(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NavigationView, winrt::Microsoft::UI::Xaml::Controls::NavigationViewDisplayModeChangedEventArgs> const& handler) const;
        auto DisplayModeChanged(winrt::event_token const& token) const noexcept;
        [[nodiscard]] auto IsTitleBarAutoPaddingEnabled() const;
        auto IsTitleBarAutoPaddingEnabled(bool value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationView>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationView<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationView2
    {
        [[nodiscard]] auto IsBackButtonVisible() const;
        auto IsBackButtonVisible(winrt::Microsoft::UI::Xaml::Controls::NavigationViewBackButtonVisible const& value) const;
        [[nodiscard]] auto IsBackEnabled() const;
        auto IsBackEnabled(bool value) const;
        [[nodiscard]] auto PaneTitle() const;
        auto PaneTitle(param::hstring const& value) const;
        auto BackRequested(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NavigationView, winrt::Microsoft::UI::Xaml::Controls::NavigationViewBackRequestedEventArgs> const& handler) const;
        using BackRequested_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::INavigationView2, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::INavigationView2>::remove_BackRequested>;
        [[nodiscard]] auto BackRequested(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NavigationView, winrt::Microsoft::UI::Xaml::Controls::NavigationViewBackRequestedEventArgs> const& handler) const;
        auto BackRequested(winrt::event_token const& token) const noexcept;
        auto PaneClosed(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NavigationView, winrt::Windows::Foundation::IInspectable> const& handler) const;
        using PaneClosed_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::INavigationView2, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::INavigationView2>::remove_PaneClosed>;
        [[nodiscard]] auto PaneClosed(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NavigationView, winrt::Windows::Foundation::IInspectable> const& handler) const;
        auto PaneClosed(winrt::event_token const& token) const noexcept;
        auto PaneClosing(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NavigationView, winrt::Microsoft::UI::Xaml::Controls::NavigationViewPaneClosingEventArgs> const& handler) const;
        using PaneClosing_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::INavigationView2, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::INavigationView2>::remove_PaneClosing>;
        [[nodiscard]] auto PaneClosing(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NavigationView, winrt::Microsoft::UI::Xaml::Controls::NavigationViewPaneClosingEventArgs> const& handler) const;
        auto PaneClosing(winrt::event_token const& token) const noexcept;
        auto PaneOpened(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NavigationView, winrt::Windows::Foundation::IInspectable> const& handler) const;
        using PaneOpened_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::INavigationView2, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::INavigationView2>::remove_PaneOpened>;
        [[nodiscard]] auto PaneOpened(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NavigationView, winrt::Windows::Foundation::IInspectable> const& handler) const;
        auto PaneOpened(winrt::event_token const& token) const noexcept;
        auto PaneOpening(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NavigationView, winrt::Windows::Foundation::IInspectable> const& handler) const;
        using PaneOpening_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::INavigationView2, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::INavigationView2>::remove_PaneOpening>;
        [[nodiscard]] auto PaneOpening(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NavigationView, winrt::Windows::Foundation::IInspectable> const& handler) const;
        auto PaneOpening(winrt::event_token const& token) const noexcept;
        [[nodiscard]] auto PaneDisplayMode() const;
        auto PaneDisplayMode(winrt::Microsoft::UI::Xaml::Controls::NavigationViewPaneDisplayMode const& value) const;
        [[nodiscard]] auto PaneHeader() const;
        auto PaneHeader(winrt::Windows::UI::Xaml::UIElement const& value) const;
        [[nodiscard]] auto PaneCustomContent() const;
        auto PaneCustomContent(winrt::Windows::UI::Xaml::UIElement const& value) const;
        [[nodiscard]] auto ContentOverlay() const;
        auto ContentOverlay(winrt::Windows::UI::Xaml::UIElement const& value) const;
        [[nodiscard]] auto IsPaneVisible() const;
        auto IsPaneVisible(bool value) const;
        [[nodiscard]] auto SelectionFollowsFocus() const;
        auto SelectionFollowsFocus(winrt::Microsoft::UI::Xaml::Controls::NavigationViewSelectionFollowsFocus const& value) const;
        [[nodiscard]] auto TemplateSettings() const;
        [[nodiscard]] auto ShoulderNavigationEnabled() const;
        auto ShoulderNavigationEnabled(winrt::Microsoft::UI::Xaml::Controls::NavigationViewShoulderNavigationEnabled const& value) const;
        [[nodiscard]] auto OverflowLabelMode() const;
        auto OverflowLabelMode(winrt::Microsoft::UI::Xaml::Controls::NavigationViewOverflowLabelMode const& value) const;
        auto Expanding(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NavigationView, winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemExpandingEventArgs> const& handler) const;
        using Expanding_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::INavigationView2, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::INavigationView2>::remove_Expanding>;
        [[nodiscard]] auto Expanding(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NavigationView, winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemExpandingEventArgs> const& handler) const;
        auto Expanding(winrt::event_token const& token) const noexcept;
        auto Collapsed(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NavigationView, winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemCollapsedEventArgs> const& handler) const;
        using Collapsed_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::INavigationView2, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::INavigationView2>::remove_Collapsed>;
        [[nodiscard]] auto Collapsed(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NavigationView, winrt::Microsoft::UI::Xaml::Controls::NavigationViewItemCollapsedEventArgs> const& handler) const;
        auto Collapsed(winrt::event_token const& token) const noexcept;
        auto Expand(winrt::Microsoft::UI::Xaml::Controls::NavigationViewItem const& item) const;
        auto Collapse(winrt::Microsoft::UI::Xaml::Controls::NavigationViewItem const& item) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationView2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationView2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewBackRequestedEventArgs
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewBackRequestedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewBackRequestedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewDisplayModeChangedEventArgs
    {
        [[nodiscard]] auto DisplayMode() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewDisplayModeChangedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewDisplayModeChangedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewItem
    {
        [[nodiscard]] auto Icon() const;
        auto Icon(winrt::Windows::UI::Xaml::Controls::IconElement const& value) const;
        [[nodiscard]] auto CompactPaneLength() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItem>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewItem<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewItem2
    {
        [[nodiscard]] auto SelectsOnInvoked() const;
        auto SelectsOnInvoked(bool value) const;
        [[nodiscard]] auto IsExpanded() const;
        auto IsExpanded(bool value) const;
        [[nodiscard]] auto HasUnrealizedChildren() const;
        auto HasUnrealizedChildren(bool value) const;
        [[nodiscard]] auto IsChildSelected() const;
        auto IsChildSelected(bool value) const;
        [[nodiscard]] auto MenuItems() const;
        [[nodiscard]] auto MenuItemsSource() const;
        auto MenuItemsSource(winrt::Windows::Foundation::IInspectable const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItem2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewItem2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewItem3
    {
        [[nodiscard]] auto InfoBadge() const;
        auto InfoBadge(winrt::Microsoft::UI::Xaml::Controls::InfoBadge const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItem3>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewItem3<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewItemBase
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemBase>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewItemBase<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewItemBase2
    {
        [[nodiscard]] auto IsSelected() const;
        auto IsSelected(bool value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemBase2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewItemBase2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewItemBaseFactory
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemBaseFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewItemBaseFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewItemBaseStatics
    {
        [[nodiscard]] auto IsSelectedProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemBaseStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewItemBaseStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewItemCollapsedEventArgs
    {
        [[nodiscard]] auto CollapsedItemContainer() const;
        [[nodiscard]] auto CollapsedItem() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemCollapsedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewItemCollapsedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewItemExpandingEventArgs
    {
        [[nodiscard]] auto ExpandingItemContainer() const;
        [[nodiscard]] auto ExpandingItem() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemExpandingEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewItemExpandingEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewItemFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewItemFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewItemHeader
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemHeader>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewItemHeader<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewItemHeaderFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemHeaderFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewItemHeaderFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewItemInvokedEventArgs
    {
        [[nodiscard]] auto InvokedItem() const;
        [[nodiscard]] auto IsSettingsInvoked() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemInvokedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewItemInvokedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewItemInvokedEventArgs2
    {
        [[nodiscard]] auto InvokedItemContainer() const;
        [[nodiscard]] auto RecommendedNavigationTransitionInfo() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemInvokedEventArgs2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewItemInvokedEventArgs2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewItemSeparator
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemSeparator>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewItemSeparator<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewItemSeparatorFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemSeparatorFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewItemSeparatorFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewItemStatics
    {
        [[nodiscard]] auto IconProperty() const;
        [[nodiscard]] auto CompactPaneLengthProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewItemStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewItemStatics2
    {
        [[nodiscard]] auto SelectsOnInvokedProperty() const;
        [[nodiscard]] auto IsExpandedProperty() const;
        [[nodiscard]] auto HasUnrealizedChildrenProperty() const;
        [[nodiscard]] auto IsChildSelectedProperty() const;
        [[nodiscard]] auto MenuItemsProperty() const;
        [[nodiscard]] auto MenuItemsSourceProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemStatics2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewItemStatics2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewItemStatics3
    {
        [[nodiscard]] auto InfoBadgeProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewItemStatics3>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewItemStatics3<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewPaneClosingEventArgs
    {
        [[nodiscard]] auto Cancel() const;
        auto Cancel(bool value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewPaneClosingEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewPaneClosingEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewSelectionChangedEventArgs
    {
        [[nodiscard]] auto SelectedItem() const;
        [[nodiscard]] auto IsSettingsSelected() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewSelectionChangedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewSelectionChangedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewSelectionChangedEventArgs2
    {
        [[nodiscard]] auto SelectedItemContainer() const;
        [[nodiscard]] auto RecommendedNavigationTransitionInfo() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewSelectionChangedEventArgs2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewSelectionChangedEventArgs2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewStatics
    {
        [[nodiscard]] auto IsPaneOpenProperty() const;
        [[nodiscard]] auto CompactModeThresholdWidthProperty() const;
        [[nodiscard]] auto ExpandedModeThresholdWidthProperty() const;
        [[nodiscard]] auto FooterMenuItemsProperty() const;
        [[nodiscard]] auto FooterMenuItemsSourceProperty() const;
        [[nodiscard]] auto PaneFooterProperty() const;
        [[nodiscard]] auto HeaderProperty() const;
        [[nodiscard]] auto HeaderTemplateProperty() const;
        [[nodiscard]] auto DisplayModeProperty() const;
        [[nodiscard]] auto IsSettingsVisibleProperty() const;
        [[nodiscard]] auto IsPaneToggleButtonVisibleProperty() const;
        [[nodiscard]] auto AlwaysShowHeaderProperty() const;
        [[nodiscard]] auto CompactPaneLengthProperty() const;
        [[nodiscard]] auto OpenPaneLengthProperty() const;
        [[nodiscard]] auto PaneToggleButtonStyleProperty() const;
        [[nodiscard]] auto MenuItemsProperty() const;
        [[nodiscard]] auto MenuItemsSourceProperty() const;
        [[nodiscard]] auto SelectedItemProperty() const;
        [[nodiscard]] auto SettingsItemProperty() const;
        [[nodiscard]] auto AutoSuggestBoxProperty() const;
        [[nodiscard]] auto MenuItemTemplateProperty() const;
        [[nodiscard]] auto MenuItemTemplateSelectorProperty() const;
        [[nodiscard]] auto MenuItemContainerStyleProperty() const;
        [[nodiscard]] auto MenuItemContainerStyleSelectorProperty() const;
        [[nodiscard]] auto IsTitleBarAutoPaddingEnabledProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewStatics2
    {
        [[nodiscard]] auto IsBackButtonVisibleProperty() const;
        [[nodiscard]] auto IsBackEnabledProperty() const;
        [[nodiscard]] auto PaneTitleProperty() const;
        [[nodiscard]] auto PaneDisplayModeProperty() const;
        [[nodiscard]] auto PaneHeaderProperty() const;
        [[nodiscard]] auto PaneCustomContentProperty() const;
        [[nodiscard]] auto ContentOverlayProperty() const;
        [[nodiscard]] auto IsPaneVisibleProperty() const;
        [[nodiscard]] auto SelectionFollowsFocusProperty() const;
        [[nodiscard]] auto TemplateSettingsProperty() const;
        [[nodiscard]] auto ShoulderNavigationEnabledProperty() const;
        [[nodiscard]] auto OverflowLabelModeProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewStatics2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewStatics2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewTemplateSettings
    {
        [[nodiscard]] auto TopPadding() const;
        [[nodiscard]] auto OverflowButtonVisibility() const;
        [[nodiscard]] auto PaneToggleButtonVisibility() const;
        [[nodiscard]] auto BackButtonVisibility() const;
        [[nodiscard]] auto TopPaneVisibility() const;
        [[nodiscard]] auto LeftPaneVisibility() const;
        [[nodiscard]] auto SingleSelectionFollowsFocus() const;
        [[nodiscard]] auto PaneToggleButtonWidth() const;
        [[nodiscard]] auto SmallerPaneToggleButtonWidth() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettings>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewTemplateSettings<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewTemplateSettings2
    {
        [[nodiscard]] auto OpenPaneLength() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettings2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewTemplateSettings2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewTemplateSettingsFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettingsFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewTemplateSettingsFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewTemplateSettingsStatics
    {
        [[nodiscard]] auto TopPaddingProperty() const;
        [[nodiscard]] auto OverflowButtonVisibilityProperty() const;
        [[nodiscard]] auto PaneToggleButtonVisibilityProperty() const;
        [[nodiscard]] auto BackButtonVisibilityProperty() const;
        [[nodiscard]] auto TopPaneVisibilityProperty() const;
        [[nodiscard]] auto LeftPaneVisibilityProperty() const;
        [[nodiscard]] auto SingleSelectionFollowsFocusProperty() const;
        [[nodiscard]] auto PaneToggleButtonWidthProperty() const;
        [[nodiscard]] auto SmallerPaneToggleButtonWidthProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettingsStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewTemplateSettingsStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INavigationViewTemplateSettingsStatics2
    {
        [[nodiscard]] auto OpenPaneLengthProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INavigationViewTemplateSettingsStatics2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INavigationViewTemplateSettingsStatics2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INonVirtualizingLayout
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayout>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INonVirtualizingLayout<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INonVirtualizingLayoutContext
    {
        [[nodiscard]] auto Children() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutContext>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INonVirtualizingLayoutContext<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INonVirtualizingLayoutContextFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutContextFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INonVirtualizingLayoutContextFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INonVirtualizingLayoutContextOverrides
    {
        [[nodiscard]] auto ChildrenCore() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutContextOverrides>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INonVirtualizingLayoutContextOverrides<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INonVirtualizingLayoutFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INonVirtualizingLayoutFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INonVirtualizingLayoutOverrides
    {
        auto InitializeForContextCore(winrt::Microsoft::UI::Xaml::Controls::NonVirtualizingLayoutContext const& context) const;
        auto UninitializeForContextCore(winrt::Microsoft::UI::Xaml::Controls::NonVirtualizingLayoutContext const& context) const;
        auto MeasureOverride(winrt::Microsoft::UI::Xaml::Controls::NonVirtualizingLayoutContext const& context, winrt::Windows::Foundation::Size const& availableSize) const;
        auto ArrangeOverride(winrt::Microsoft::UI::Xaml::Controls::NonVirtualizingLayoutContext const& context, winrt::Windows::Foundation::Size const& finalSize) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INonVirtualizingLayoutOverrides>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INonVirtualizingLayoutOverrides<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INumberBox
    {
        [[nodiscard]] auto Minimum() const;
        auto Minimum(double value) const;
        [[nodiscard]] auto Maximum() const;
        auto Maximum(double value) const;
        [[nodiscard]] auto Value() const;
        auto Value(double value) const;
        [[nodiscard]] auto SmallChange() const;
        auto SmallChange(double value) const;
        [[nodiscard]] auto LargeChange() const;
        auto LargeChange(double value) const;
        [[nodiscard]] auto Text() const;
        auto Text(param::hstring const& value) const;
        [[nodiscard]] auto Header() const;
        auto Header(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto HeaderTemplate() const;
        auto HeaderTemplate(winrt::Windows::UI::Xaml::DataTemplate const& value) const;
        [[nodiscard]] auto PlaceholderText() const;
        auto PlaceholderText(param::hstring const& value) const;
        [[nodiscard]] auto SelectionFlyout() const;
        auto SelectionFlyout(winrt::Windows::UI::Xaml::Controls::Primitives::FlyoutBase const& value) const;
        [[nodiscard]] auto SelectionHighlightColor() const;
        auto SelectionHighlightColor(winrt::Windows::UI::Xaml::Media::SolidColorBrush const& value) const;
        [[nodiscard]] auto TextReadingOrder() const;
        auto TextReadingOrder(winrt::Windows::UI::Xaml::TextReadingOrder const& value) const;
        [[nodiscard]] auto PreventKeyboardDisplayOnProgrammaticFocus() const;
        auto PreventKeyboardDisplayOnProgrammaticFocus(bool value) const;
        [[nodiscard]] auto Description() const;
        auto Description(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto ValidationMode() const;
        auto ValidationMode(winrt::Microsoft::UI::Xaml::Controls::NumberBoxValidationMode const& value) const;
        [[nodiscard]] auto SpinButtonPlacementMode() const;
        auto SpinButtonPlacementMode(winrt::Microsoft::UI::Xaml::Controls::NumberBoxSpinButtonPlacementMode const& value) const;
        [[nodiscard]] auto IsWrapEnabled() const;
        auto IsWrapEnabled(bool value) const;
        [[nodiscard]] auto AcceptsExpression() const;
        auto AcceptsExpression(bool value) const;
        [[nodiscard]] auto NumberFormatter() const;
        auto NumberFormatter(winrt::Windows::Globalization::NumberFormatting::INumberFormatter2 const& value) const;
        auto ValueChanged(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NumberBox, winrt::Microsoft::UI::Xaml::Controls::NumberBoxValueChangedEventArgs> const& handler) const;
        using ValueChanged_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::INumberBox, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::INumberBox>::remove_ValueChanged>;
        [[nodiscard]] auto ValueChanged(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::NumberBox, winrt::Microsoft::UI::Xaml::Controls::NumberBoxValueChangedEventArgs> const& handler) const;
        auto ValueChanged(winrt::event_token const& token) const noexcept;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INumberBox>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INumberBox<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INumberBoxFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INumberBoxFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INumberBoxFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INumberBoxStatics
    {
        [[nodiscard]] auto MinimumProperty() const;
        [[nodiscard]] auto MaximumProperty() const;
        [[nodiscard]] auto ValueProperty() const;
        [[nodiscard]] auto SmallChangeProperty() const;
        [[nodiscard]] auto LargeChangeProperty() const;
        [[nodiscard]] auto TextProperty() const;
        [[nodiscard]] auto HeaderProperty() const;
        [[nodiscard]] auto HeaderTemplateProperty() const;
        [[nodiscard]] auto PlaceholderTextProperty() const;
        [[nodiscard]] auto SelectionFlyoutProperty() const;
        [[nodiscard]] auto SelectionHighlightColorProperty() const;
        [[nodiscard]] auto TextReadingOrderProperty() const;
        [[nodiscard]] auto PreventKeyboardDisplayOnProgrammaticFocusProperty() const;
        [[nodiscard]] auto DescriptionProperty() const;
        [[nodiscard]] auto ValidationModeProperty() const;
        [[nodiscard]] auto SpinButtonPlacementModeProperty() const;
        [[nodiscard]] auto IsWrapEnabledProperty() const;
        [[nodiscard]] auto AcceptsExpressionProperty() const;
        [[nodiscard]] auto NumberFormatterProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INumberBoxStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INumberBoxStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_INumberBoxValueChangedEventArgs
    {
        [[nodiscard]] auto OldValue() const;
        [[nodiscard]] auto NewValue() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::INumberBoxValueChangedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_INumberBoxValueChangedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IParallaxView
    {
        [[nodiscard]] auto Child() const;
        auto Child(winrt::Windows::UI::Xaml::UIElement const& value) const;
        [[nodiscard]] auto HorizontalShift() const;
        auto HorizontalShift(double value) const;
        [[nodiscard]] auto HorizontalSourceEndOffset() const;
        auto HorizontalSourceEndOffset(double value) const;
        [[nodiscard]] auto HorizontalSourceOffsetKind() const;
        auto HorizontalSourceOffsetKind(winrt::Microsoft::UI::Xaml::Controls::ParallaxSourceOffsetKind const& value) const;
        [[nodiscard]] auto HorizontalSourceStartOffset() const;
        auto HorizontalSourceStartOffset(double value) const;
        [[nodiscard]] auto IsHorizontalShiftClamped() const;
        auto IsHorizontalShiftClamped(bool value) const;
        [[nodiscard]] auto IsVerticalShiftClamped() const;
        auto IsVerticalShiftClamped(bool value) const;
        [[nodiscard]] auto MaxHorizontalShiftRatio() const;
        auto MaxHorizontalShiftRatio(double value) const;
        [[nodiscard]] auto MaxVerticalShiftRatio() const;
        auto MaxVerticalShiftRatio(double value) const;
        [[nodiscard]] auto Source() const;
        auto Source(winrt::Windows::UI::Xaml::UIElement const& value) const;
        [[nodiscard]] auto VerticalShift() const;
        auto VerticalShift(double value) const;
        [[nodiscard]] auto VerticalSourceEndOffset() const;
        auto VerticalSourceEndOffset(double value) const;
        [[nodiscard]] auto VerticalSourceOffsetKind() const;
        auto VerticalSourceOffsetKind(winrt::Microsoft::UI::Xaml::Controls::ParallaxSourceOffsetKind const& value) const;
        [[nodiscard]] auto VerticalSourceStartOffset() const;
        auto VerticalSourceStartOffset(double value) const;
        auto RefreshAutomaticHorizontalOffsets() const;
        auto RefreshAutomaticVerticalOffsets() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IParallaxView>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IParallaxView<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IParallaxViewFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IParallaxViewFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IParallaxViewFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IParallaxViewStatics
    {
        [[nodiscard]] auto ChildProperty() const;
        [[nodiscard]] auto HorizontalSourceEndOffsetProperty() const;
        [[nodiscard]] auto HorizontalSourceOffsetKindProperty() const;
        [[nodiscard]] auto HorizontalSourceStartOffsetProperty() const;
        [[nodiscard]] auto MaxHorizontalShiftRatioProperty() const;
        [[nodiscard]] auto HorizontalShiftProperty() const;
        [[nodiscard]] auto IsHorizontalShiftClampedProperty() const;
        [[nodiscard]] auto IsVerticalShiftClampedProperty() const;
        [[nodiscard]] auto SourceProperty() const;
        [[nodiscard]] auto VerticalSourceEndOffsetProperty() const;
        [[nodiscard]] auto VerticalSourceOffsetKindProperty() const;
        [[nodiscard]] auto VerticalSourceStartOffsetProperty() const;
        [[nodiscard]] auto MaxVerticalShiftRatioProperty() const;
        [[nodiscard]] auto VerticalShiftProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IParallaxViewStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IParallaxViewStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IPathIconSource
    {
        [[nodiscard]] auto Data() const;
        auto Data(winrt::Windows::UI::Xaml::Media::Geometry const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IPathIconSource>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IPathIconSource<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IPathIconSourceFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IPathIconSourceFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IPathIconSourceFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IPathIconSourceStatics
    {
        [[nodiscard]] auto DataProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IPathIconSourceStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IPathIconSourceStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IPersonPicture
    {
        [[nodiscard]] auto BadgeNumber() const;
        auto BadgeNumber(int32_t value) const;
        [[nodiscard]] auto BadgeGlyph() const;
        auto BadgeGlyph(param::hstring const& value) const;
        [[nodiscard]] auto BadgeImageSource() const;
        auto BadgeImageSource(winrt::Windows::UI::Xaml::Media::ImageSource const& value) const;
        [[nodiscard]] auto BadgeText() const;
        auto BadgeText(param::hstring const& value) const;
        [[nodiscard]] auto IsGroup() const;
        auto IsGroup(bool value) const;
        [[nodiscard]] auto Contact() const;
        auto Contact(winrt::Windows::ApplicationModel::Contacts::Contact const& value) const;
        [[nodiscard]] auto DisplayName() const;
        auto DisplayName(param::hstring const& value) const;
        [[nodiscard]] auto Initials() const;
        auto Initials(param::hstring const& value) const;
        [[nodiscard]] auto PreferSmallImage() const;
        auto PreferSmallImage(bool value) const;
        [[nodiscard]] auto ProfilePicture() const;
        auto ProfilePicture(winrt::Windows::UI::Xaml::Media::ImageSource const& value) const;
        [[nodiscard]] auto TemplateSettings() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IPersonPicture>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IPersonPicture<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IPersonPictureFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IPersonPictureFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IPersonPictureFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IPersonPictureStatics
    {
        [[nodiscard]] auto BadgeNumberProperty() const;
        [[nodiscard]] auto BadgeGlyphProperty() const;
        [[nodiscard]] auto BadgeImageSourceProperty() const;
        [[nodiscard]] auto BadgeTextProperty() const;
        [[nodiscard]] auto IsGroupProperty() const;
        [[nodiscard]] auto ContactProperty() const;
        [[nodiscard]] auto DisplayNameProperty() const;
        [[nodiscard]] auto InitialsProperty() const;
        [[nodiscard]] auto PreferSmallImageProperty() const;
        [[nodiscard]] auto ProfilePictureProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IPersonPictureStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IPersonPictureStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IPersonPictureTemplateSettings
    {
        [[nodiscard]] auto ActualInitials() const;
        [[nodiscard]] auto ActualImageBrush() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IPersonPictureTemplateSettings>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IPersonPictureTemplateSettings<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IPipsPager
    {
        [[nodiscard]] auto NumberOfPages() const;
        auto NumberOfPages(int32_t value) const;
        [[nodiscard]] auto SelectedPageIndex() const;
        auto SelectedPageIndex(int32_t value) const;
        [[nodiscard]] auto MaxVisiblePips() const;
        auto MaxVisiblePips(int32_t value) const;
        [[nodiscard]] auto Orientation() const;
        auto Orientation(winrt::Windows::UI::Xaml::Controls::Orientation const& value) const;
        [[nodiscard]] auto PreviousButtonVisibility() const;
        auto PreviousButtonVisibility(winrt::Microsoft::UI::Xaml::Controls::PipsPagerButtonVisibility const& value) const;
        [[nodiscard]] auto NextButtonVisibility() const;
        auto NextButtonVisibility(winrt::Microsoft::UI::Xaml::Controls::PipsPagerButtonVisibility const& value) const;
        [[nodiscard]] auto PreviousButtonStyle() const;
        auto PreviousButtonStyle(winrt::Windows::UI::Xaml::Style const& value) const;
        [[nodiscard]] auto NextButtonStyle() const;
        auto NextButtonStyle(winrt::Windows::UI::Xaml::Style const& value) const;
        [[nodiscard]] auto SelectedPipStyle() const;
        auto SelectedPipStyle(winrt::Windows::UI::Xaml::Style const& value) const;
        [[nodiscard]] auto NormalPipStyle() const;
        auto NormalPipStyle(winrt::Windows::UI::Xaml::Style const& value) const;
        auto SelectedIndexChanged(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::PipsPager, winrt::Microsoft::UI::Xaml::Controls::PipsPagerSelectedIndexChangedEventArgs> const& handler) const;
        using SelectedIndexChanged_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IPipsPager, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IPipsPager>::remove_SelectedIndexChanged>;
        [[nodiscard]] auto SelectedIndexChanged(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::PipsPager, winrt::Microsoft::UI::Xaml::Controls::PipsPagerSelectedIndexChangedEventArgs> const& handler) const;
        auto SelectedIndexChanged(winrt::event_token const& token) const noexcept;
        [[nodiscard]] auto TemplateSettings() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IPipsPager>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IPipsPager<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IPipsPagerFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IPipsPagerFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IPipsPagerFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IPipsPagerSelectedIndexChangedEventArgs
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IPipsPagerSelectedIndexChangedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IPipsPagerSelectedIndexChangedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IPipsPagerStatics
    {
        [[nodiscard]] auto NumberOfPagesProperty() const;
        [[nodiscard]] auto SelectedPageIndexProperty() const;
        [[nodiscard]] auto MaxVisiblePipsProperty() const;
        [[nodiscard]] auto OrientationProperty() const;
        [[nodiscard]] auto PreviousButtonVisibilityProperty() const;
        [[nodiscard]] auto NextButtonVisibilityProperty() const;
        [[nodiscard]] auto PreviousButtonStyleProperty() const;
        [[nodiscard]] auto NextButtonStyleProperty() const;
        [[nodiscard]] auto SelectedPipStyleProperty() const;
        [[nodiscard]] auto NormalPipStyleProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IPipsPagerStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IPipsPagerStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IPipsPagerTemplateSettings
    {
        [[nodiscard]] auto PipsPagerItems() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IPipsPagerTemplateSettings>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IPipsPagerTemplateSettings<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IProgressBar
    {
        [[nodiscard]] auto IsIndeterminate() const;
        auto IsIndeterminate(bool value) const;
        [[nodiscard]] auto ShowError() const;
        auto ShowError(bool value) const;
        [[nodiscard]] auto ShowPaused() const;
        auto ShowPaused(bool value) const;
        [[nodiscard]] auto TemplateSettings() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IProgressBar>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IProgressBar<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IProgressBarFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IProgressBarFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IProgressBarFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IProgressBarStatics
    {
        [[nodiscard]] auto IsIndeterminateProperty() const;
        [[nodiscard]] auto ShowErrorProperty() const;
        [[nodiscard]] auto ShowPausedProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IProgressBarStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IProgressBarStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IProgressBarTemplateSettings
    {
        [[nodiscard]] auto ContainerAnimationStartPosition() const;
        [[nodiscard]] auto ContainerAnimationEndPosition() const;
        [[nodiscard]] auto Container2AnimationStartPosition() const;
        [[nodiscard]] auto Container2AnimationEndPosition() const;
        [[nodiscard]] auto ContainerAnimationMidPosition() const;
        [[nodiscard]] auto IndicatorLengthDelta() const;
        [[nodiscard]] auto ClipRect() const;
        [[nodiscard]] auto EllipseAnimationEndPosition() const;
        [[nodiscard]] auto EllipseAnimationWellPosition() const;
        [[nodiscard]] auto EllipseDiameter() const;
        [[nodiscard]] auto EllipseOffset() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IProgressBarTemplateSettings>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IProgressBarTemplateSettings<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IProgressRing
    {
        [[nodiscard]] auto IsActive() const;
        auto IsActive(bool value) const;
        [[nodiscard]] auto IsIndeterminate() const;
        auto IsIndeterminate(bool value) const;
        [[nodiscard]] auto TemplateSettings() const;
        [[nodiscard]] auto Value() const;
        auto Value(double value) const;
        [[nodiscard]] auto Minimum() const;
        auto Minimum(double value) const;
        [[nodiscard]] auto Maximum() const;
        auto Maximum(double value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IProgressRing>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IProgressRing<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IProgressRingFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IProgressRingFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IProgressRingFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IProgressRingStatics
    {
        [[nodiscard]] auto IsActiveProperty() const;
        [[nodiscard]] auto IsIndeterminateProperty() const;
        [[nodiscard]] auto ValueProperty() const;
        [[nodiscard]] auto MinimumProperty() const;
        [[nodiscard]] auto MaximumProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IProgressRingStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IProgressRingStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IProgressRingTemplateSettings
    {
        [[nodiscard]] auto EllipseDiameter() const;
        [[nodiscard]] auto EllipseOffset() const;
        [[nodiscard]] auto MaxSideLength() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IProgressRingTemplateSettings>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IProgressRingTemplateSettings<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRadioButtons
    {
        [[nodiscard]] auto ItemsSource() const;
        auto ItemsSource(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto Items() const;
        [[nodiscard]] auto ItemTemplate() const;
        auto ItemTemplate(winrt::Windows::Foundation::IInspectable const& value) const;
        auto ContainerFromIndex(int32_t index) const;
        [[nodiscard]] auto SelectedIndex() const;
        auto SelectedIndex(int32_t value) const;
        [[nodiscard]] auto SelectedItem() const;
        auto SelectedItem(winrt::Windows::Foundation::IInspectable const& value) const;
        auto SelectionChanged(winrt::Windows::UI::Xaml::Controls::SelectionChangedEventHandler const& handler) const;
        using SelectionChanged_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IRadioButtons, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IRadioButtons>::remove_SelectionChanged>;
        [[nodiscard]] auto SelectionChanged(auto_revoke_t, winrt::Windows::UI::Xaml::Controls::SelectionChangedEventHandler const& handler) const;
        auto SelectionChanged(winrt::event_token const& token) const noexcept;
        [[nodiscard]] auto MaxColumns() const;
        auto MaxColumns(int32_t value) const;
        [[nodiscard]] auto Header() const;
        auto Header(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto HeaderTemplate() const;
        auto HeaderTemplate(winrt::Windows::UI::Xaml::DataTemplate const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRadioButtons>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRadioButtons<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRadioButtonsFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRadioButtonsFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRadioButtonsFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRadioButtonsStatics
    {
        [[nodiscard]] auto ItemsSourceProperty() const;
        [[nodiscard]] auto ItemsProperty() const;
        [[nodiscard]] auto ItemTemplateProperty() const;
        [[nodiscard]] auto SelectedIndexProperty() const;
        [[nodiscard]] auto SelectedItemProperty() const;
        [[nodiscard]] auto MaxColumnsProperty() const;
        [[nodiscard]] auto HeaderProperty() const;
        [[nodiscard]] auto HeaderTemplateProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRadioButtonsStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRadioButtonsStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRadioMenuFlyoutItem
    {
        [[nodiscard]] auto IsChecked() const;
        auto IsChecked(bool value) const;
        [[nodiscard]] auto GroupName() const;
        auto GroupName(param::hstring const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRadioMenuFlyoutItem>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRadioMenuFlyoutItem<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRadioMenuFlyoutItemFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRadioMenuFlyoutItemFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRadioMenuFlyoutItemFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRadioMenuFlyoutItemStatics
    {
        [[nodiscard]] auto IsCheckedProperty() const;
        [[nodiscard]] auto GroupNameProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRadioMenuFlyoutItemStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRadioMenuFlyoutItemStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRadioMenuFlyoutItemStatics2
    {
        [[nodiscard]] auto AreCheckStatesEnabledProperty() const;
        auto SetAreCheckStatesEnabled(winrt::Windows::UI::Xaml::Controls::MenuFlyoutSubItem const& object, bool value) const;
        auto GetAreCheckStatesEnabled(winrt::Windows::UI::Xaml::Controls::MenuFlyoutSubItem const& object) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRadioMenuFlyoutItemStatics2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRadioMenuFlyoutItemStatics2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRatingControl
    {
        [[nodiscard]] auto Caption() const;
        auto Caption(param::hstring const& value) const;
        [[nodiscard]] auto InitialSetValue() const;
        auto InitialSetValue(int32_t value) const;
        [[nodiscard]] auto IsClearEnabled() const;
        auto IsClearEnabled(bool value) const;
        [[nodiscard]] auto IsReadOnly() const;
        auto IsReadOnly(bool value) const;
        [[nodiscard]] auto MaxRating() const;
        auto MaxRating(int32_t value) const;
        [[nodiscard]] auto PlaceholderValue() const;
        auto PlaceholderValue(double value) const;
        [[nodiscard]] auto ItemInfo() const;
        auto ItemInfo(winrt::Microsoft::UI::Xaml::Controls::RatingItemInfo const& value) const;
        [[nodiscard]] auto Value() const;
        auto Value(double value) const;
        auto ValueChanged(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::RatingControl, winrt::Windows::Foundation::IInspectable> const& handler) const;
        using ValueChanged_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IRatingControl, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IRatingControl>::remove_ValueChanged>;
        [[nodiscard]] auto ValueChanged(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::RatingControl, winrt::Windows::Foundation::IInspectable> const& handler) const;
        auto ValueChanged(winrt::event_token const& token) const noexcept;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRatingControl>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRatingControl<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRatingControlFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRatingControlFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRatingControlFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRatingControlStatics
    {
        [[nodiscard]] auto CaptionProperty() const;
        [[nodiscard]] auto InitialSetValueProperty() const;
        [[nodiscard]] auto IsClearEnabledProperty() const;
        [[nodiscard]] auto IsReadOnlyProperty() const;
        [[nodiscard]] auto MaxRatingProperty() const;
        [[nodiscard]] auto PlaceholderValueProperty() const;
        [[nodiscard]] auto ItemInfoProperty() const;
        [[nodiscard]] auto ValueProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRatingControlStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRatingControlStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRatingItemFontInfo
    {
        [[nodiscard]] auto DisabledGlyph() const;
        auto DisabledGlyph(param::hstring const& value) const;
        [[nodiscard]] auto Glyph() const;
        auto Glyph(param::hstring const& value) const;
        [[nodiscard]] auto PointerOverGlyph() const;
        auto PointerOverGlyph(param::hstring const& value) const;
        [[nodiscard]] auto PointerOverPlaceholderGlyph() const;
        auto PointerOverPlaceholderGlyph(param::hstring const& value) const;
        [[nodiscard]] auto PlaceholderGlyph() const;
        auto PlaceholderGlyph(param::hstring const& value) const;
        [[nodiscard]] auto UnsetGlyph() const;
        auto UnsetGlyph(param::hstring const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRatingItemFontInfo>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRatingItemFontInfo<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRatingItemFontInfoFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRatingItemFontInfoFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRatingItemFontInfoFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRatingItemFontInfoStatics
    {
        [[nodiscard]] auto DisabledGlyphProperty() const;
        [[nodiscard]] auto GlyphProperty() const;
        [[nodiscard]] auto PlaceholderGlyphProperty() const;
        [[nodiscard]] auto PointerOverGlyphProperty() const;
        [[nodiscard]] auto PointerOverPlaceholderGlyphProperty() const;
        [[nodiscard]] auto UnsetGlyphProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRatingItemFontInfoStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRatingItemFontInfoStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRatingItemImageInfo
    {
        [[nodiscard]] auto DisabledImage() const;
        auto DisabledImage(winrt::Windows::UI::Xaml::Media::ImageSource const& value) const;
        [[nodiscard]] auto Image() const;
        auto Image(winrt::Windows::UI::Xaml::Media::ImageSource const& value) const;
        [[nodiscard]] auto PlaceholderImage() const;
        auto PlaceholderImage(winrt::Windows::UI::Xaml::Media::ImageSource const& value) const;
        [[nodiscard]] auto PointerOverImage() const;
        auto PointerOverImage(winrt::Windows::UI::Xaml::Media::ImageSource const& value) const;
        [[nodiscard]] auto PointerOverPlaceholderImage() const;
        auto PointerOverPlaceholderImage(winrt::Windows::UI::Xaml::Media::ImageSource const& value) const;
        [[nodiscard]] auto UnsetImage() const;
        auto UnsetImage(winrt::Windows::UI::Xaml::Media::ImageSource const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRatingItemImageInfo>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRatingItemImageInfo<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRatingItemImageInfoFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRatingItemImageInfoFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRatingItemImageInfoFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRatingItemImageInfoStatics
    {
        [[nodiscard]] auto DisabledImageProperty() const;
        [[nodiscard]] auto ImageProperty() const;
        [[nodiscard]] auto PlaceholderImageProperty() const;
        [[nodiscard]] auto PointerOverImageProperty() const;
        [[nodiscard]] auto PointerOverPlaceholderImageProperty() const;
        [[nodiscard]] auto UnsetImageProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRatingItemImageInfoStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRatingItemImageInfoStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRatingItemInfo
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRatingItemInfo>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRatingItemInfo<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRatingItemInfoFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRatingItemInfoFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRatingItemInfoFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRefreshContainer
    {
        [[nodiscard]] auto Visualizer() const;
        auto Visualizer(winrt::Microsoft::UI::Xaml::Controls::RefreshVisualizer const& value) const;
        [[nodiscard]] auto PullDirection() const;
        auto PullDirection(winrt::Microsoft::UI::Xaml::Controls::RefreshPullDirection const& value) const;
        auto RefreshRequested(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::RefreshContainer, winrt::Microsoft::UI::Xaml::Controls::RefreshRequestedEventArgs> const& handler) const;
        using RefreshRequested_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IRefreshContainer, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IRefreshContainer>::remove_RefreshRequested>;
        [[nodiscard]] auto RefreshRequested(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::RefreshContainer, winrt::Microsoft::UI::Xaml::Controls::RefreshRequestedEventArgs> const& handler) const;
        auto RefreshRequested(winrt::event_token const& token) const noexcept;
        auto RequestRefresh() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRefreshContainer>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRefreshContainer<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRefreshContainerFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRefreshContainerFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRefreshContainerFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRefreshContainerStatics
    {
        [[nodiscard]] auto VisualizerProperty() const;
        [[nodiscard]] auto PullDirectionProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRefreshContainerStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRefreshContainerStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRefreshInteractionRatioChangedEventArgs
    {
        [[nodiscard]] auto InteractionRatio() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRefreshInteractionRatioChangedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRefreshInteractionRatioChangedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRefreshRequestedEventArgs
    {
        auto GetDeferral() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRefreshRequestedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRefreshRequestedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRefreshStateChangedEventArgs
    {
        [[nodiscard]] auto OldState() const;
        [[nodiscard]] auto NewState() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRefreshStateChangedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRefreshStateChangedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRefreshVisualizer
    {
        auto RequestRefresh() const;
        [[nodiscard]] auto Orientation() const;
        auto Orientation(winrt::Microsoft::UI::Xaml::Controls::RefreshVisualizerOrientation const& value) const;
        [[nodiscard]] auto Content() const;
        auto Content(winrt::Windows::UI::Xaml::UIElement const& value) const;
        [[nodiscard]] auto State() const;
        auto RefreshRequested(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::RefreshVisualizer, winrt::Microsoft::UI::Xaml::Controls::RefreshRequestedEventArgs> const& handler) const;
        using RefreshRequested_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IRefreshVisualizer, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IRefreshVisualizer>::remove_RefreshRequested>;
        [[nodiscard]] auto RefreshRequested(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::RefreshVisualizer, winrt::Microsoft::UI::Xaml::Controls::RefreshRequestedEventArgs> const& handler) const;
        auto RefreshRequested(winrt::event_token const& token) const noexcept;
        auto RefreshStateChanged(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::RefreshVisualizer, winrt::Microsoft::UI::Xaml::Controls::RefreshStateChangedEventArgs> const& handler) const;
        using RefreshStateChanged_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IRefreshVisualizer, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IRefreshVisualizer>::remove_RefreshStateChanged>;
        [[nodiscard]] auto RefreshStateChanged(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::RefreshVisualizer, winrt::Microsoft::UI::Xaml::Controls::RefreshStateChangedEventArgs> const& handler) const;
        auto RefreshStateChanged(winrt::event_token const& token) const noexcept;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRefreshVisualizer>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRefreshVisualizer<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRefreshVisualizerFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRefreshVisualizerFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRefreshVisualizerFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRefreshVisualizerStatics
    {
        [[nodiscard]] auto InfoProviderProperty() const;
        [[nodiscard]] auto OrientationProperty() const;
        [[nodiscard]] auto ContentProperty() const;
        [[nodiscard]] auto StateProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRefreshVisualizerStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRefreshVisualizerStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRevealListViewItemPresenter
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRevealListViewItemPresenter>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRevealListViewItemPresenter<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IRevealListViewItemPresenterFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IRevealListViewItemPresenterFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IRevealListViewItemPresenterFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ISplitButton
    {
        [[nodiscard]] auto Flyout() const;
        auto Flyout(winrt::Windows::UI::Xaml::Controls::Primitives::FlyoutBase const& value) const;
        [[nodiscard]] auto Command() const;
        auto Command(winrt::Windows::UI::Xaml::Input::ICommand const& value) const;
        [[nodiscard]] auto CommandParameter() const;
        auto CommandParameter(winrt::Windows::Foundation::IInspectable const& value) const;
        auto Click(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::SplitButton, winrt::Microsoft::UI::Xaml::Controls::SplitButtonClickEventArgs> const& handler) const;
        using Click_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ISplitButton, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ISplitButton>::remove_Click>;
        [[nodiscard]] auto Click(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::SplitButton, winrt::Microsoft::UI::Xaml::Controls::SplitButtonClickEventArgs> const& handler) const;
        auto Click(winrt::event_token const& token) const noexcept;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ISplitButton>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ISplitButton<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ISplitButtonClickEventArgs
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ISplitButtonClickEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ISplitButtonClickEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ISplitButtonFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ISplitButtonFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ISplitButtonFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ISplitButtonStatics
    {
        [[nodiscard]] auto FlyoutProperty() const;
        [[nodiscard]] auto CommandProperty() const;
        [[nodiscard]] auto CommandParameterProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ISplitButtonStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ISplitButtonStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IStackLayout
    {
        [[nodiscard]] auto Orientation() const;
        auto Orientation(winrt::Windows::UI::Xaml::Controls::Orientation const& value) const;
        [[nodiscard]] auto Spacing() const;
        auto Spacing(double value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IStackLayout>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IStackLayout<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IStackLayoutFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IStackLayoutFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IStackLayoutFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IStackLayoutStatics
    {
        [[nodiscard]] auto OrientationProperty() const;
        [[nodiscard]] auto SpacingProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IStackLayoutStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IStackLayoutStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ISwipeControl
    {
        [[nodiscard]] auto LeftItems() const;
        auto LeftItems(winrt::Microsoft::UI::Xaml::Controls::SwipeItems const& value) const;
        [[nodiscard]] auto RightItems() const;
        auto RightItems(winrt::Microsoft::UI::Xaml::Controls::SwipeItems const& value) const;
        [[nodiscard]] auto TopItems() const;
        auto TopItems(winrt::Microsoft::UI::Xaml::Controls::SwipeItems const& value) const;
        [[nodiscard]] auto BottomItems() const;
        auto BottomItems(winrt::Microsoft::UI::Xaml::Controls::SwipeItems const& value) const;
        auto Close() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ISwipeControl>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ISwipeControl<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ISwipeControlFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ISwipeControlFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ISwipeControlFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ISwipeControlStatics
    {
        [[nodiscard]] auto LeftItemsProperty() const;
        [[nodiscard]] auto RightItemsProperty() const;
        [[nodiscard]] auto TopItemsProperty() const;
        [[nodiscard]] auto BottomItemsProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ISwipeControlStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ISwipeControlStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ISwipeItem
    {
        [[nodiscard]] auto Text() const;
        auto Text(param::hstring const& value) const;
        [[nodiscard]] auto IconSource() const;
        auto IconSource(winrt::Microsoft::UI::Xaml::Controls::IconSource const& value) const;
        [[nodiscard]] auto Background() const;
        auto Background(winrt::Windows::UI::Xaml::Media::Brush const& value) const;
        [[nodiscard]] auto Foreground() const;
        auto Foreground(winrt::Windows::UI::Xaml::Media::Brush const& value) const;
        [[nodiscard]] auto Command() const;
        auto Command(winrt::Windows::UI::Xaml::Input::ICommand const& value) const;
        [[nodiscard]] auto CommandParameter() const;
        auto CommandParameter(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto BehaviorOnInvoked() const;
        auto BehaviorOnInvoked(winrt::Microsoft::UI::Xaml::Controls::SwipeBehaviorOnInvoked const& value) const;
        auto Invoked(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::SwipeItem, winrt::Microsoft::UI::Xaml::Controls::SwipeItemInvokedEventArgs> const& handler) const;
        using Invoked_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ISwipeItem, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ISwipeItem>::remove_Invoked>;
        [[nodiscard]] auto Invoked(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::SwipeItem, winrt::Microsoft::UI::Xaml::Controls::SwipeItemInvokedEventArgs> const& handler) const;
        auto Invoked(winrt::event_token const& token) const noexcept;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ISwipeItem>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ISwipeItem<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ISwipeItemFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ISwipeItemFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ISwipeItemInvokedEventArgs
    {
        [[nodiscard]] auto SwipeControl() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemInvokedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ISwipeItemInvokedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ISwipeItemStatics
    {
        [[nodiscard]] auto IconSourceProperty() const;
        [[nodiscard]] auto TextProperty() const;
        [[nodiscard]] auto BackgroundProperty() const;
        [[nodiscard]] auto ForegroundProperty() const;
        [[nodiscard]] auto CommandProperty() const;
        [[nodiscard]] auto CommandParameterProperty() const;
        [[nodiscard]] auto BehaviorOnInvokedProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ISwipeItemStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ISwipeItems
    {
        [[nodiscard]] auto Mode() const;
        auto Mode(winrt::Microsoft::UI::Xaml::Controls::SwipeMode const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ISwipeItems>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ISwipeItems<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ISwipeItemsFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemsFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ISwipeItemsFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ISwipeItemsStatics
    {
        [[nodiscard]] auto ModeProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ISwipeItemsStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ISwipeItemsStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ISymbolIconSource
    {
        [[nodiscard]] auto Symbol() const;
        auto Symbol(winrt::Windows::UI::Xaml::Controls::Symbol const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ISymbolIconSource>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ISymbolIconSource<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ISymbolIconSourceFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ISymbolIconSourceFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ISymbolIconSourceFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ISymbolIconSourceStatics
    {
        [[nodiscard]] auto SymbolProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ISymbolIconSourceStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ISymbolIconSourceStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITabView
    {
        [[nodiscard]] auto TabWidthMode() const;
        auto TabWidthMode(winrt::Microsoft::UI::Xaml::Controls::TabViewWidthMode const& value) const;
        [[nodiscard]] auto CloseButtonOverlayMode() const;
        auto CloseButtonOverlayMode(winrt::Microsoft::UI::Xaml::Controls::TabViewCloseButtonOverlayMode const& value) const;
        [[nodiscard]] auto TabStripHeader() const;
        auto TabStripHeader(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto TabStripHeaderTemplate() const;
        auto TabStripHeaderTemplate(winrt::Windows::UI::Xaml::DataTemplate const& value) const;
        [[nodiscard]] auto TabStripFooter() const;
        auto TabStripFooter(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto TabStripFooterTemplate() const;
        auto TabStripFooterTemplate(winrt::Windows::UI::Xaml::DataTemplate const& value) const;
        [[nodiscard]] auto IsAddTabButtonVisible() const;
        auto IsAddTabButtonVisible(bool value) const;
        [[nodiscard]] auto AddTabButtonCommand() const;
        auto AddTabButtonCommand(winrt::Windows::UI::Xaml::Input::ICommand const& value) const;
        [[nodiscard]] auto AddTabButtonCommandParameter() const;
        auto AddTabButtonCommandParameter(winrt::Windows::Foundation::IInspectable const& value) const;
        auto TabCloseRequested(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TabView, winrt::Microsoft::UI::Xaml::Controls::TabViewTabCloseRequestedEventArgs> const& handler) const;
        using TabCloseRequested_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ITabView, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ITabView>::remove_TabCloseRequested>;
        [[nodiscard]] auto TabCloseRequested(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TabView, winrt::Microsoft::UI::Xaml::Controls::TabViewTabCloseRequestedEventArgs> const& handler) const;
        auto TabCloseRequested(winrt::event_token const& token) const noexcept;
        auto TabDroppedOutside(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TabView, winrt::Microsoft::UI::Xaml::Controls::TabViewTabDroppedOutsideEventArgs> const& handler) const;
        using TabDroppedOutside_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ITabView, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ITabView>::remove_TabDroppedOutside>;
        [[nodiscard]] auto TabDroppedOutside(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TabView, winrt::Microsoft::UI::Xaml::Controls::TabViewTabDroppedOutsideEventArgs> const& handler) const;
        auto TabDroppedOutside(winrt::event_token const& token) const noexcept;
        auto AddTabButtonClick(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TabView, winrt::Windows::Foundation::IInspectable> const& handler) const;
        using AddTabButtonClick_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ITabView, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ITabView>::remove_AddTabButtonClick>;
        [[nodiscard]] auto AddTabButtonClick(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TabView, winrt::Windows::Foundation::IInspectable> const& handler) const;
        auto AddTabButtonClick(winrt::event_token const& token) const noexcept;
        auto TabItemsChanged(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TabView, winrt::Windows::Foundation::Collections::IVectorChangedEventArgs> const& handler) const;
        using TabItemsChanged_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ITabView, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ITabView>::remove_TabItemsChanged>;
        [[nodiscard]] auto TabItemsChanged(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TabView, winrt::Windows::Foundation::Collections::IVectorChangedEventArgs> const& handler) const;
        auto TabItemsChanged(winrt::event_token const& token) const noexcept;
        [[nodiscard]] auto TabItemsSource() const;
        auto TabItemsSource(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto TabItems() const;
        [[nodiscard]] auto TabItemTemplate() const;
        auto TabItemTemplate(winrt::Windows::UI::Xaml::DataTemplate const& value) const;
        [[nodiscard]] auto TabItemTemplateSelector() const;
        auto TabItemTemplateSelector(winrt::Windows::UI::Xaml::Controls::DataTemplateSelector const& value) const;
        [[nodiscard]] auto CanDragTabs() const;
        auto CanDragTabs(bool value) const;
        [[nodiscard]] auto CanReorderTabs() const;
        auto CanReorderTabs(bool value) const;
        [[nodiscard]] auto AllowDropTabs() const;
        auto AllowDropTabs(bool value) const;
        [[nodiscard]] auto SelectedIndex() const;
        auto SelectedIndex(int32_t value) const;
        [[nodiscard]] auto SelectedItem() const;
        auto SelectedItem(winrt::Windows::Foundation::IInspectable const& value) const;
        auto ContainerFromItem(winrt::Windows::Foundation::IInspectable const& item) const;
        auto ContainerFromIndex(int32_t index) const;
        auto SelectionChanged(winrt::Windows::UI::Xaml::Controls::SelectionChangedEventHandler const& handler) const;
        using SelectionChanged_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ITabView, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ITabView>::remove_SelectionChanged>;
        [[nodiscard]] auto SelectionChanged(auto_revoke_t, winrt::Windows::UI::Xaml::Controls::SelectionChangedEventHandler const& handler) const;
        auto SelectionChanged(winrt::event_token const& token) const noexcept;
        auto TabDragStarting(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TabView, winrt::Microsoft::UI::Xaml::Controls::TabViewTabDragStartingEventArgs> const& handler) const;
        using TabDragStarting_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ITabView, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ITabView>::remove_TabDragStarting>;
        [[nodiscard]] auto TabDragStarting(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TabView, winrt::Microsoft::UI::Xaml::Controls::TabViewTabDragStartingEventArgs> const& handler) const;
        auto TabDragStarting(winrt::event_token const& token) const noexcept;
        auto TabDragCompleted(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TabView, winrt::Microsoft::UI::Xaml::Controls::TabViewTabDragCompletedEventArgs> const& handler) const;
        using TabDragCompleted_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ITabView, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ITabView>::remove_TabDragCompleted>;
        [[nodiscard]] auto TabDragCompleted(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TabView, winrt::Microsoft::UI::Xaml::Controls::TabViewTabDragCompletedEventArgs> const& handler) const;
        auto TabDragCompleted(winrt::event_token const& token) const noexcept;
        auto TabStripDragOver(winrt::Windows::UI::Xaml::DragEventHandler const& handler) const;
        using TabStripDragOver_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ITabView, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ITabView>::remove_TabStripDragOver>;
        [[nodiscard]] auto TabStripDragOver(auto_revoke_t, winrt::Windows::UI::Xaml::DragEventHandler const& handler) const;
        auto TabStripDragOver(winrt::event_token const& token) const noexcept;
        auto TabStripDrop(winrt::Windows::UI::Xaml::DragEventHandler const& handler) const;
        using TabStripDrop_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ITabView, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ITabView>::remove_TabStripDrop>;
        [[nodiscard]] auto TabStripDrop(auto_revoke_t, winrt::Windows::UI::Xaml::DragEventHandler const& handler) const;
        auto TabStripDrop(winrt::event_token const& token) const noexcept;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITabView>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITabView<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITabViewFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITabViewFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITabViewFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITabViewItem
    {
        [[nodiscard]] auto Header() const;
        auto Header(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto HeaderTemplate() const;
        auto HeaderTemplate(winrt::Windows::UI::Xaml::DataTemplate const& value) const;
        [[nodiscard]] auto IconSource() const;
        auto IconSource(winrt::Microsoft::UI::Xaml::Controls::IconSource const& value) const;
        [[nodiscard]] auto IsClosable() const;
        auto IsClosable(bool value) const;
        [[nodiscard]] auto TabViewTemplateSettings() const;
        auto CloseRequested(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TabViewItem, winrt::Microsoft::UI::Xaml::Controls::TabViewTabCloseRequestedEventArgs> const& handler) const;
        using CloseRequested_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ITabViewItem, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ITabViewItem>::remove_CloseRequested>;
        [[nodiscard]] auto CloseRequested(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TabViewItem, winrt::Microsoft::UI::Xaml::Controls::TabViewTabCloseRequestedEventArgs> const& handler) const;
        auto CloseRequested(winrt::event_token const& token) const noexcept;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITabViewItem>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITabViewItem<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITabViewItemFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITabViewItemFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITabViewItemStatics
    {
        [[nodiscard]] auto HeaderProperty() const;
        [[nodiscard]] auto HeaderTemplateProperty() const;
        [[nodiscard]] auto IconSourceProperty() const;
        [[nodiscard]] auto IsClosableProperty() const;
        [[nodiscard]] auto TabViewTemplateSettingsProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITabViewItemStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITabViewItemTemplateSettings
    {
        [[nodiscard]] auto IconElement() const;
        auto IconElement(winrt::Windows::UI::Xaml::Controls::IconElement const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettings>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITabViewItemTemplateSettings<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITabViewItemTemplateSettings2
    {
        [[nodiscard]] auto TabGeometry() const;
        auto TabGeometry(winrt::Windows::UI::Xaml::Media::Geometry const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettings2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITabViewItemTemplateSettings2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITabViewItemTemplateSettingsFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettingsFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITabViewItemTemplateSettingsFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITabViewItemTemplateSettingsStatics
    {
        [[nodiscard]] auto IconElementProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettingsStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITabViewItemTemplateSettingsStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITabViewItemTemplateSettingsStatics2
    {
        [[nodiscard]] auto TabGeometryProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITabViewItemTemplateSettingsStatics2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITabViewItemTemplateSettingsStatics2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITabViewStatics
    {
        [[nodiscard]] auto TabWidthModeProperty() const;
        [[nodiscard]] auto TabStripHeaderProperty() const;
        [[nodiscard]] auto TabStripHeaderTemplateProperty() const;
        [[nodiscard]] auto TabStripFooterProperty() const;
        [[nodiscard]] auto TabStripFooterTemplateProperty() const;
        [[nodiscard]] auto IsAddTabButtonVisibleProperty() const;
        [[nodiscard]] auto AddTabButtonCommandProperty() const;
        [[nodiscard]] auto AddTabButtonCommandParameterProperty() const;
        [[nodiscard]] auto TabItemsSourceProperty() const;
        [[nodiscard]] auto TabItemsProperty() const;
        [[nodiscard]] auto TabItemTemplateProperty() const;
        [[nodiscard]] auto TabItemTemplateSelectorProperty() const;
        [[nodiscard]] auto CloseButtonOverlayModeProperty() const;
        [[nodiscard]] auto CanDragTabsProperty() const;
        [[nodiscard]] auto CanReorderTabsProperty() const;
        [[nodiscard]] auto AllowDropTabsProperty() const;
        [[nodiscard]] auto SelectedIndexProperty() const;
        [[nodiscard]] auto SelectedItemProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITabViewStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITabViewStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITabViewTabCloseRequestedEventArgs
    {
        [[nodiscard]] auto Item() const;
        [[nodiscard]] auto Tab() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITabViewTabCloseRequestedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITabViewTabCloseRequestedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITabViewTabDragCompletedEventArgs
    {
        [[nodiscard]] auto DropResult() const;
        [[nodiscard]] auto Item() const;
        [[nodiscard]] auto Tab() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITabViewTabDragCompletedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITabViewTabDragCompletedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITabViewTabDragStartingEventArgs
    {
        [[nodiscard]] auto Cancel() const;
        auto Cancel(bool value) const;
        [[nodiscard]] auto Data() const;
        [[nodiscard]] auto Item() const;
        [[nodiscard]] auto Tab() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITabViewTabDragStartingEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITabViewTabDragStartingEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITabViewTabDroppedOutsideEventArgs
    {
        [[nodiscard]] auto Item() const;
        [[nodiscard]] auto Tab() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITabViewTabDroppedOutsideEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITabViewTabDroppedOutsideEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITeachingTip
    {
        [[nodiscard]] auto Title() const;
        auto Title(param::hstring const& value) const;
        [[nodiscard]] auto Subtitle() const;
        auto Subtitle(param::hstring const& value) const;
        [[nodiscard]] auto IsOpen() const;
        auto IsOpen(bool value) const;
        [[nodiscard]] auto Target() const;
        auto Target(winrt::Windows::UI::Xaml::FrameworkElement const& value) const;
        [[nodiscard]] auto TailVisibility() const;
        auto TailVisibility(winrt::Microsoft::UI::Xaml::Controls::TeachingTipTailVisibility const& value) const;
        [[nodiscard]] auto ActionButtonContent() const;
        auto ActionButtonContent(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto ActionButtonStyle() const;
        auto ActionButtonStyle(winrt::Windows::UI::Xaml::Style const& value) const;
        [[nodiscard]] auto ActionButtonCommand() const;
        auto ActionButtonCommand(winrt::Windows::UI::Xaml::Input::ICommand const& value) const;
        [[nodiscard]] auto ActionButtonCommandParameter() const;
        auto ActionButtonCommandParameter(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto CloseButtonContent() const;
        auto CloseButtonContent(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto CloseButtonStyle() const;
        auto CloseButtonStyle(winrt::Windows::UI::Xaml::Style const& value) const;
        [[nodiscard]] auto CloseButtonCommand() const;
        auto CloseButtonCommand(winrt::Windows::UI::Xaml::Input::ICommand const& value) const;
        [[nodiscard]] auto CloseButtonCommandParameter() const;
        auto CloseButtonCommandParameter(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto PlacementMargin() const;
        auto PlacementMargin(winrt::Windows::UI::Xaml::Thickness const& value) const;
        [[nodiscard]] auto ShouldConstrainToRootBounds() const;
        auto ShouldConstrainToRootBounds(bool value) const;
        [[nodiscard]] auto IsLightDismissEnabled() const;
        auto IsLightDismissEnabled(bool value) const;
        [[nodiscard]] auto PreferredPlacement() const;
        auto PreferredPlacement(winrt::Microsoft::UI::Xaml::Controls::TeachingTipPlacementMode const& value) const;
        [[nodiscard]] auto HeroContentPlacement() const;
        auto HeroContentPlacement(winrt::Microsoft::UI::Xaml::Controls::TeachingTipHeroContentPlacementMode const& value) const;
        [[nodiscard]] auto HeroContent() const;
        auto HeroContent(winrt::Windows::UI::Xaml::UIElement const& value) const;
        [[nodiscard]] auto IconSource() const;
        auto IconSource(winrt::Microsoft::UI::Xaml::Controls::IconSource const& value) const;
        [[nodiscard]] auto TemplateSettings() const;
        auto ActionButtonClick(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TeachingTip, winrt::Windows::Foundation::IInspectable> const& handler) const;
        using ActionButtonClick_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ITeachingTip, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ITeachingTip>::remove_ActionButtonClick>;
        [[nodiscard]] auto ActionButtonClick(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TeachingTip, winrt::Windows::Foundation::IInspectable> const& handler) const;
        auto ActionButtonClick(winrt::event_token const& token) const noexcept;
        auto CloseButtonClick(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TeachingTip, winrt::Windows::Foundation::IInspectable> const& handler) const;
        using CloseButtonClick_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ITeachingTip, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ITeachingTip>::remove_CloseButtonClick>;
        [[nodiscard]] auto CloseButtonClick(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TeachingTip, winrt::Windows::Foundation::IInspectable> const& handler) const;
        auto CloseButtonClick(winrt::event_token const& token) const noexcept;
        auto Closing(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TeachingTip, winrt::Microsoft::UI::Xaml::Controls::TeachingTipClosingEventArgs> const& handler) const;
        using Closing_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ITeachingTip, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ITeachingTip>::remove_Closing>;
        [[nodiscard]] auto Closing(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TeachingTip, winrt::Microsoft::UI::Xaml::Controls::TeachingTipClosingEventArgs> const& handler) const;
        auto Closing(winrt::event_token const& token) const noexcept;
        auto Closed(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TeachingTip, winrt::Microsoft::UI::Xaml::Controls::TeachingTipClosedEventArgs> const& handler) const;
        using Closed_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ITeachingTip, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ITeachingTip>::remove_Closed>;
        [[nodiscard]] auto Closed(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TeachingTip, winrt::Microsoft::UI::Xaml::Controls::TeachingTipClosedEventArgs> const& handler) const;
        auto Closed(winrt::event_token const& token) const noexcept;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITeachingTip>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITeachingTip<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITeachingTipClosedEventArgs
    {
        [[nodiscard]] auto Reason() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipClosedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITeachingTipClosedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITeachingTipClosingEventArgs
    {
        [[nodiscard]] auto Reason() const;
        [[nodiscard]] auto Cancel() const;
        auto Cancel(bool value) const;
        auto GetDeferral() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipClosingEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITeachingTipClosingEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITeachingTipFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITeachingTipFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITeachingTipStatics
    {
        [[nodiscard]] auto IsOpenProperty() const;
        [[nodiscard]] auto TargetProperty() const;
        [[nodiscard]] auto TailVisibilityProperty() const;
        [[nodiscard]] auto TitleProperty() const;
        [[nodiscard]] auto SubtitleProperty() const;
        [[nodiscard]] auto ActionButtonContentProperty() const;
        [[nodiscard]] auto ActionButtonStyleProperty() const;
        [[nodiscard]] auto ActionButtonCommandProperty() const;
        [[nodiscard]] auto ActionButtonCommandParameterProperty() const;
        [[nodiscard]] auto CloseButtonContentProperty() const;
        [[nodiscard]] auto CloseButtonStyleProperty() const;
        [[nodiscard]] auto CloseButtonCommandProperty() const;
        [[nodiscard]] auto CloseButtonCommandParameterProperty() const;
        [[nodiscard]] auto PlacementMarginProperty() const;
        [[nodiscard]] auto ShouldConstrainToRootBoundsProperty() const;
        [[nodiscard]] auto IsLightDismissEnabledProperty() const;
        [[nodiscard]] auto PreferredPlacementProperty() const;
        [[nodiscard]] auto HeroContentPlacementProperty() const;
        [[nodiscard]] auto HeroContentProperty() const;
        [[nodiscard]] auto IconSourceProperty() const;
        [[nodiscard]] auto TemplateSettingsProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITeachingTipStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITeachingTipTemplateSettings
    {
        [[nodiscard]] auto TopRightHighlightMargin() const;
        auto TopRightHighlightMargin(winrt::Windows::UI::Xaml::Thickness const& value) const;
        [[nodiscard]] auto TopLeftHighlightMargin() const;
        auto TopLeftHighlightMargin(winrt::Windows::UI::Xaml::Thickness const& value) const;
        [[nodiscard]] auto IconElement() const;
        auto IconElement(winrt::Windows::UI::Xaml::Controls::IconElement const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipTemplateSettings>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITeachingTipTemplateSettings<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITeachingTipTemplateSettingsFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipTemplateSettingsFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITeachingTipTemplateSettingsFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITeachingTipTemplateSettingsStatics
    {
        [[nodiscard]] auto TopRightHighlightMarginProperty() const;
        [[nodiscard]] auto TopLeftHighlightMarginProperty() const;
        [[nodiscard]] auto IconElementProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITeachingTipTemplateSettingsStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITeachingTipTemplateSettingsStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITextCommandBarFlyout
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITextCommandBarFlyout>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITextCommandBarFlyout<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITextCommandBarFlyoutFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITextCommandBarFlyoutFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITextCommandBarFlyoutFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IToggleSplitButton
    {
        [[nodiscard]] auto IsChecked() const;
        auto IsChecked(bool value) const;
        auto IsCheckedChanged(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::ToggleSplitButton, winrt::Microsoft::UI::Xaml::Controls::ToggleSplitButtonIsCheckedChangedEventArgs> const& handler) const;
        using IsCheckedChanged_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButton, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButton>::remove_IsCheckedChanged>;
        [[nodiscard]] auto IsCheckedChanged(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::ToggleSplitButton, winrt::Microsoft::UI::Xaml::Controls::ToggleSplitButtonIsCheckedChangedEventArgs> const& handler) const;
        auto IsCheckedChanged(winrt::event_token const& token) const noexcept;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButton>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IToggleSplitButton<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IToggleSplitButtonFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButtonFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IToggleSplitButtonFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IToggleSplitButtonIsCheckedChangedEventArgs
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButtonIsCheckedChangedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IToggleSplitButtonIsCheckedChangedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IToggleSplitButtonStatics
    {
        [[nodiscard]] auto IsCheckedProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IToggleSplitButtonStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IToggleSplitButtonStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeView
    {
        [[nodiscard]] auto RootNodes() const;
        [[nodiscard]] auto SelectionMode() const;
        auto SelectionMode(winrt::Microsoft::UI::Xaml::Controls::TreeViewSelectionMode const& value) const;
        [[nodiscard]] auto SelectedNodes() const;
        auto Expand(winrt::Microsoft::UI::Xaml::Controls::TreeViewNode const& value) const;
        auto Collapse(winrt::Microsoft::UI::Xaml::Controls::TreeViewNode const& value) const;
        auto SelectAll() const;
        auto ItemInvoked(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TreeView, winrt::Microsoft::UI::Xaml::Controls::TreeViewItemInvokedEventArgs> const& handler) const;
        using ItemInvoked_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ITreeView, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ITreeView>::remove_ItemInvoked>;
        [[nodiscard]] auto ItemInvoked(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TreeView, winrt::Microsoft::UI::Xaml::Controls::TreeViewItemInvokedEventArgs> const& handler) const;
        auto ItemInvoked(winrt::event_token const& token) const noexcept;
        auto Expanding(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TreeView, winrt::Microsoft::UI::Xaml::Controls::TreeViewExpandingEventArgs> const& handler) const;
        using Expanding_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ITreeView, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ITreeView>::remove_Expanding>;
        [[nodiscard]] auto Expanding(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TreeView, winrt::Microsoft::UI::Xaml::Controls::TreeViewExpandingEventArgs> const& handler) const;
        auto Expanding(winrt::event_token const& token) const noexcept;
        auto Collapsed(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TreeView, winrt::Microsoft::UI::Xaml::Controls::TreeViewCollapsedEventArgs> const& handler) const;
        using Collapsed_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ITreeView, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ITreeView>::remove_Collapsed>;
        [[nodiscard]] auto Collapsed(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TreeView, winrt::Microsoft::UI::Xaml::Controls::TreeViewCollapsedEventArgs> const& handler) const;
        auto Collapsed(winrt::event_token const& token) const noexcept;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeView>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeView<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeView2
    {
        auto NodeFromContainer(winrt::Windows::UI::Xaml::DependencyObject const& container) const;
        auto ContainerFromNode(winrt::Microsoft::UI::Xaml::Controls::TreeViewNode const& node) const;
        auto ItemFromContainer(winrt::Windows::UI::Xaml::DependencyObject const& container) const;
        auto ContainerFromItem(winrt::Windows::Foundation::IInspectable const& item) const;
        [[nodiscard]] auto CanDragItems() const;
        auto CanDragItems(bool value) const;
        [[nodiscard]] auto CanReorderItems() const;
        auto CanReorderItems(bool value) const;
        [[nodiscard]] auto ItemTemplate() const;
        auto ItemTemplate(winrt::Windows::UI::Xaml::DataTemplate const& value) const;
        [[nodiscard]] auto ItemTemplateSelector() const;
        auto ItemTemplateSelector(winrt::Windows::UI::Xaml::Controls::DataTemplateSelector const& value) const;
        [[nodiscard]] auto ItemContainerStyle() const;
        auto ItemContainerStyle(winrt::Windows::UI::Xaml::Style const& value) const;
        [[nodiscard]] auto ItemContainerStyleSelector() const;
        auto ItemContainerStyleSelector(winrt::Windows::UI::Xaml::Controls::StyleSelector const& value) const;
        [[nodiscard]] auto ItemContainerTransitions() const;
        auto ItemContainerTransitions(winrt::Windows::UI::Xaml::Media::Animation::TransitionCollection const& value) const;
        [[nodiscard]] auto ItemsSource() const;
        auto ItemsSource(winrt::Windows::Foundation::IInspectable const& value) const;
        auto DragItemsStarting(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TreeView, winrt::Microsoft::UI::Xaml::Controls::TreeViewDragItemsStartingEventArgs> const& handler) const;
        using DragItemsStarting_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ITreeView2, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ITreeView2>::remove_DragItemsStarting>;
        [[nodiscard]] auto DragItemsStarting(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TreeView, winrt::Microsoft::UI::Xaml::Controls::TreeViewDragItemsStartingEventArgs> const& handler) const;
        auto DragItemsStarting(winrt::event_token const& token) const noexcept;
        auto DragItemsCompleted(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TreeView, winrt::Microsoft::UI::Xaml::Controls::TreeViewDragItemsCompletedEventArgs> const& handler) const;
        using DragItemsCompleted_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ITreeView2, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ITreeView2>::remove_DragItemsCompleted>;
        [[nodiscard]] auto DragItemsCompleted(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TreeView, winrt::Microsoft::UI::Xaml::Controls::TreeViewDragItemsCompletedEventArgs> const& handler) const;
        auto DragItemsCompleted(winrt::event_token const& token) const noexcept;
        [[nodiscard]] auto SelectedNode() const;
        auto SelectedNode(winrt::Microsoft::UI::Xaml::Controls::TreeViewNode const& value) const;
        [[nodiscard]] auto SelectedItem() const;
        auto SelectedItem(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto SelectedItems() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeView2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeView2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewCollapsedEventArgs
    {
        [[nodiscard]] auto Node() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewCollapsedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewCollapsedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewCollapsedEventArgs2
    {
        [[nodiscard]] auto Item() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewCollapsedEventArgs2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewCollapsedEventArgs2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewDragItemsCompletedEventArgs
    {
        [[nodiscard]] auto DropResult() const;
        [[nodiscard]] auto Items() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewDragItemsCompletedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewDragItemsCompletedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewDragItemsCompletedEventArgs2
    {
        [[nodiscard]] auto NewParentItem() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewDragItemsCompletedEventArgs2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewDragItemsCompletedEventArgs2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewDragItemsStartingEventArgs
    {
        [[nodiscard]] auto Cancel() const;
        auto Cancel(bool value) const;
        [[nodiscard]] auto Data() const;
        [[nodiscard]] auto Items() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewDragItemsStartingEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewDragItemsStartingEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewExpandingEventArgs
    {
        [[nodiscard]] auto Node() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewExpandingEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewExpandingEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewExpandingEventArgs2
    {
        [[nodiscard]] auto Item() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewExpandingEventArgs2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewExpandingEventArgs2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewItem
    {
        [[nodiscard]] auto GlyphOpacity() const;
        auto GlyphOpacity(double value) const;
        [[nodiscard]] auto GlyphBrush() const;
        auto GlyphBrush(winrt::Windows::UI::Xaml::Media::Brush const& value) const;
        [[nodiscard]] auto ExpandedGlyph() const;
        auto ExpandedGlyph(param::hstring const& value) const;
        [[nodiscard]] auto CollapsedGlyph() const;
        auto CollapsedGlyph(param::hstring const& value) const;
        [[nodiscard]] auto GlyphSize() const;
        auto GlyphSize(double value) const;
        [[nodiscard]] auto IsExpanded() const;
        auto IsExpanded(bool value) const;
        [[nodiscard]] auto TreeViewItemTemplateSettings() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItem>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewItem<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewItem2
    {
        [[nodiscard]] auto HasUnrealizedChildren() const;
        auto HasUnrealizedChildren(bool value) const;
        [[nodiscard]] auto ItemsSource() const;
        auto ItemsSource(winrt::Windows::Foundation::IInspectable const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItem2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewItem2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewItemFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewItemFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewItemInvokedEventArgs
    {
        [[nodiscard]] auto InvokedItem() const;
        auto Handled(bool value) const;
        [[nodiscard]] auto Handled() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemInvokedEventArgs>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewItemInvokedEventArgs<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewItemStatics
    {
        [[nodiscard]] auto GlyphOpacityProperty() const;
        [[nodiscard]] auto GlyphBrushProperty() const;
        [[nodiscard]] auto ExpandedGlyphProperty() const;
        [[nodiscard]] auto CollapsedGlyphProperty() const;
        [[nodiscard]] auto GlyphSizeProperty() const;
        [[nodiscard]] auto IsExpandedProperty() const;
        [[nodiscard]] auto TreeViewItemTemplateSettingsProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewItemStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewItemStatics2
    {
        [[nodiscard]] auto HasUnrealizedChildrenProperty() const;
        [[nodiscard]] auto ItemsSourceProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemStatics2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewItemStatics2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewItemTemplateSettings
    {
        [[nodiscard]] auto ExpandedGlyphVisibility() const;
        [[nodiscard]] auto CollapsedGlyphVisibility() const;
        [[nodiscard]] auto Indentation() const;
        [[nodiscard]] auto DragItemsCount() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemTemplateSettings>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewItemTemplateSettings<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewItemTemplateSettingsFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemTemplateSettingsFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewItemTemplateSettingsFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewItemTemplateSettingsStatics
    {
        [[nodiscard]] auto ExpandedGlyphVisibilityProperty() const;
        [[nodiscard]] auto CollapsedGlyphVisibilityProperty() const;
        [[nodiscard]] auto IndentationProperty() const;
        [[nodiscard]] auto DragItemsCountProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewItemTemplateSettingsStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewItemTemplateSettingsStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewList
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewList>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewList<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewListFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewListFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewListFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewNode
    {
        [[nodiscard]] auto Content() const;
        auto Content(winrt::Windows::Foundation::IInspectable const& value) const;
        [[nodiscard]] auto Parent() const;
        [[nodiscard]] auto IsExpanded() const;
        auto IsExpanded(bool value) const;
        [[nodiscard]] auto HasChildren() const;
        [[nodiscard]] auto Depth() const;
        [[nodiscard]] auto HasUnrealizedChildren() const;
        auto HasUnrealizedChildren(bool value) const;
        [[nodiscard]] auto Children() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewNode>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewNode<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewNodeFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewNodeFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewNodeFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewNodeStatics
    {
        [[nodiscard]] auto ContentProperty() const;
        [[nodiscard]] auto DepthProperty() const;
        [[nodiscard]] auto IsExpandedProperty() const;
        [[nodiscard]] auto HasChildrenProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewNodeStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewNodeStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewStatics
    {
        [[nodiscard]] auto SelectedItemProperty() const;
        [[nodiscard]] auto SelectionModeProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITreeViewStatics2
    {
        [[nodiscard]] auto CanDragItemsProperty() const;
        [[nodiscard]] auto CanReorderItemsProperty() const;
        [[nodiscard]] auto ItemTemplateProperty() const;
        [[nodiscard]] auto ItemTemplateSelectorProperty() const;
        [[nodiscard]] auto ItemContainerStyleProperty() const;
        [[nodiscard]] auto ItemContainerStyleSelectorProperty() const;
        [[nodiscard]] auto ItemContainerTransitionsProperty() const;
        [[nodiscard]] auto ItemsSourceProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITreeViewStatics2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITreeViewStatics2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITwoPaneView
    {
        [[nodiscard]] auto Pane1() const;
        auto Pane1(winrt::Windows::UI::Xaml::UIElement const& value) const;
        [[nodiscard]] auto Pane2() const;
        auto Pane2(winrt::Windows::UI::Xaml::UIElement const& value) const;
        [[nodiscard]] auto Pane1Length() const;
        auto Pane1Length(winrt::Windows::UI::Xaml::GridLength const& value) const;
        [[nodiscard]] auto Pane2Length() const;
        auto Pane2Length(winrt::Windows::UI::Xaml::GridLength const& value) const;
        [[nodiscard]] auto PanePriority() const;
        auto PanePriority(winrt::Microsoft::UI::Xaml::Controls::TwoPaneViewPriority const& value) const;
        [[nodiscard]] auto Mode() const;
        [[nodiscard]] auto WideModeConfiguration() const;
        auto WideModeConfiguration(winrt::Microsoft::UI::Xaml::Controls::TwoPaneViewWideModeConfiguration const& value) const;
        [[nodiscard]] auto TallModeConfiguration() const;
        auto TallModeConfiguration(winrt::Microsoft::UI::Xaml::Controls::TwoPaneViewTallModeConfiguration const& value) const;
        [[nodiscard]] auto MinWideModeWidth() const;
        auto MinWideModeWidth(double value) const;
        [[nodiscard]] auto MinTallModeHeight() const;
        auto MinTallModeHeight(double value) const;
        auto ModeChanged(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TwoPaneView, winrt::Windows::Foundation::IInspectable> const& handler) const;
        using ModeChanged_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::ITwoPaneView, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::ITwoPaneView>::remove_ModeChanged>;
        [[nodiscard]] auto ModeChanged(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::TwoPaneView, winrt::Windows::Foundation::IInspectable> const& handler) const;
        auto ModeChanged(winrt::event_token const& token) const noexcept;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITwoPaneView>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITwoPaneView<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITwoPaneViewFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITwoPaneViewFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITwoPaneViewFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_ITwoPaneViewStatics
    {
        [[nodiscard]] auto Pane1Property() const;
        [[nodiscard]] auto Pane2Property() const;
        [[nodiscard]] auto Pane1LengthProperty() const;
        [[nodiscard]] auto Pane2LengthProperty() const;
        [[nodiscard]] auto PanePriorityProperty() const;
        [[nodiscard]] auto ModeProperty() const;
        [[nodiscard]] auto WideModeConfigurationProperty() const;
        [[nodiscard]] auto TallModeConfigurationProperty() const;
        [[nodiscard]] auto MinWideModeWidthProperty() const;
        [[nodiscard]] auto MinTallModeHeightProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::ITwoPaneViewStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_ITwoPaneViewStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IUniformGridLayout
    {
        [[nodiscard]] auto Orientation() const;
        auto Orientation(winrt::Windows::UI::Xaml::Controls::Orientation const& value) const;
        [[nodiscard]] auto MinItemWidth() const;
        auto MinItemWidth(double value) const;
        [[nodiscard]] auto MinItemHeight() const;
        auto MinItemHeight(double value) const;
        [[nodiscard]] auto MinRowSpacing() const;
        auto MinRowSpacing(double value) const;
        [[nodiscard]] auto MinColumnSpacing() const;
        auto MinColumnSpacing(double value) const;
        [[nodiscard]] auto ItemsJustification() const;
        auto ItemsJustification(winrt::Microsoft::UI::Xaml::Controls::UniformGridLayoutItemsJustification const& value) const;
        [[nodiscard]] auto ItemsStretch() const;
        auto ItemsStretch(winrt::Microsoft::UI::Xaml::Controls::UniformGridLayoutItemsStretch const& value) const;
        [[nodiscard]] auto MaximumRowsOrColumns() const;
        auto MaximumRowsOrColumns(int32_t value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IUniformGridLayout>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IUniformGridLayout<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IUniformGridLayoutFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IUniformGridLayoutFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IUniformGridLayoutFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IUniformGridLayoutStatics
    {
        [[nodiscard]] auto OrientationProperty() const;
        [[nodiscard]] auto MinItemWidthProperty() const;
        [[nodiscard]] auto MinItemHeightProperty() const;
        [[nodiscard]] auto MinRowSpacingProperty() const;
        [[nodiscard]] auto MinColumnSpacingProperty() const;
        [[nodiscard]] auto ItemsJustificationProperty() const;
        [[nodiscard]] auto ItemsStretchProperty() const;
        [[nodiscard]] auto MaximumRowsOrColumnsProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IUniformGridLayoutStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IUniformGridLayoutStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IVirtualizingLayout
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayout>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IVirtualizingLayout<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IVirtualizingLayoutContext
    {
        [[nodiscard]] auto ItemCount() const;
        auto GetItemAt(int32_t index) const;
        [[nodiscard]] auto RealizationRect() const;
        auto GetOrCreateElementAt(int32_t index) const;
        auto GetOrCreateElementAt(int32_t index, winrt::Microsoft::UI::Xaml::Controls::ElementRealizationOptions const& options) const;
        auto RecycleElement(winrt::Windows::UI::Xaml::UIElement const& element) const;
        [[nodiscard]] auto RecommendedAnchorIndex() const;
        [[nodiscard]] auto LayoutOrigin() const;
        auto LayoutOrigin(winrt::Windows::Foundation::Point const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutContext>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IVirtualizingLayoutContext<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IVirtualizingLayoutContextFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutContextFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IVirtualizingLayoutContextFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IVirtualizingLayoutContextOverrides
    {
        auto ItemCountCore() const;
        auto GetItemAtCore(int32_t index) const;
        auto RealizationRectCore() const;
        auto GetOrCreateElementAtCore(int32_t index, winrt::Microsoft::UI::Xaml::Controls::ElementRealizationOptions const& options) const;
        auto RecycleElementCore(winrt::Windows::UI::Xaml::UIElement const& element) const;
        [[nodiscard]] auto RecommendedAnchorIndexCore() const;
        [[nodiscard]] auto LayoutOriginCore() const;
        auto LayoutOriginCore(winrt::Windows::Foundation::Point const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutContextOverrides>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IVirtualizingLayoutContextOverrides<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IVirtualizingLayoutFactory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutFactory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IVirtualizingLayoutFactory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IVirtualizingLayoutOverrides
    {
        auto InitializeForContextCore(winrt::Microsoft::UI::Xaml::Controls::VirtualizingLayoutContext const& context) const;
        auto UninitializeForContextCore(winrt::Microsoft::UI::Xaml::Controls::VirtualizingLayoutContext const& context) const;
        auto MeasureOverride(winrt::Microsoft::UI::Xaml::Controls::VirtualizingLayoutContext const& context, winrt::Windows::Foundation::Size const& availableSize) const;
        auto ArrangeOverride(winrt::Microsoft::UI::Xaml::Controls::VirtualizingLayoutContext const& context, winrt::Windows::Foundation::Size const& finalSize) const;
        auto OnItemsChangedCore(winrt::Microsoft::UI::Xaml::Controls::VirtualizingLayoutContext const& context, winrt::Windows::Foundation::IInspectable const& source, winrt::Windows::UI::Xaml::Interop::NotifyCollectionChangedEventArgs const& args) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IVirtualizingLayoutOverrides>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IVirtualizingLayoutOverrides<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IWebView2
    {
        [[nodiscard]] auto CoreWebView2() const;
        auto EnsureCoreWebView2Async() const;
        auto ExecuteScriptAsync(param::hstring const& javascriptCode) const;
        [[nodiscard]] auto Source() const;
        auto Source(winrt::Windows::Foundation::Uri const& value) const;
        [[nodiscard]] auto CanGoForward() const;
        auto CanGoForward(bool value) const;
        [[nodiscard]] auto CanGoBack() const;
        auto CanGoBack(bool value) const;
        auto Reload() const;
        auto GoForward() const;
        auto GoBack() const;
        auto NavigateToString(param::hstring const& htmlContent) const;
        auto Close() const;
        auto NavigationCompleted(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::WebView2, winrt::Microsoft::Web::WebView2::Core::CoreWebView2NavigationCompletedEventArgs> const& handler) const;
        using NavigationCompleted_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IWebView2, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IWebView2>::remove_NavigationCompleted>;
        [[nodiscard]] auto NavigationCompleted(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::WebView2, winrt::Microsoft::Web::WebView2::Core::CoreWebView2NavigationCompletedEventArgs> const& handler) const;
        auto NavigationCompleted(winrt::event_token const& token) const noexcept;
        auto WebMessageReceived(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::WebView2, winrt::Microsoft::Web::WebView2::Core::CoreWebView2WebMessageReceivedEventArgs> const& handler) const;
        using WebMessageReceived_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IWebView2, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IWebView2>::remove_WebMessageReceived>;
        [[nodiscard]] auto WebMessageReceived(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::WebView2, winrt::Microsoft::Web::WebView2::Core::CoreWebView2WebMessageReceivedEventArgs> const& handler) const;
        auto WebMessageReceived(winrt::event_token const& token) const noexcept;
        auto NavigationStarting(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::WebView2, winrt::Microsoft::Web::WebView2::Core::CoreWebView2NavigationStartingEventArgs> const& handler) const;
        using NavigationStarting_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IWebView2, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IWebView2>::remove_NavigationStarting>;
        [[nodiscard]] auto NavigationStarting(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::WebView2, winrt::Microsoft::Web::WebView2::Core::CoreWebView2NavigationStartingEventArgs> const& handler) const;
        auto NavigationStarting(winrt::event_token const& token) const noexcept;
        auto CoreProcessFailed(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::WebView2, winrt::Microsoft::Web::WebView2::Core::CoreWebView2ProcessFailedEventArgs> const& handler) const;
        using CoreProcessFailed_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IWebView2, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IWebView2>::remove_CoreProcessFailed>;
        [[nodiscard]] auto CoreProcessFailed(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::WebView2, winrt::Microsoft::Web::WebView2::Core::CoreWebView2ProcessFailedEventArgs> const& handler) const;
        auto CoreProcessFailed(winrt::event_token const& token) const noexcept;
        auto CoreWebView2Initialized(winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::WebView2, winrt::Microsoft::UI::Xaml::Controls::CoreWebView2InitializedEventArgs> const& handler) const;
        using CoreWebView2Initialized_revoker = impl::event_revoker<winrt::Microsoft::UI::Xaml::Controls::IWebView2, &impl::abi_t<winrt::Microsoft::UI::Xaml::Controls::IWebView2>::remove_CoreWebView2Initialized>;
        [[nodiscard]] auto CoreWebView2Initialized(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Microsoft::UI::Xaml::Controls::WebView2, winrt::Microsoft::UI::Xaml::Controls::CoreWebView2InitializedEventArgs> const& handler) const;
        auto CoreWebView2Initialized(winrt::event_token const& token) const noexcept;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IWebView2>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IWebView2<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IWebView2Factory
    {
        auto CreateInstance(winrt::Windows::Foundation::IInspectable const& baseInterface, winrt::Windows::Foundation::IInspectable& innerInterface) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IWebView2Factory>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IWebView2Factory<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IWebView2Statics
    {
        [[nodiscard]] auto SourceProperty() const;
        [[nodiscard]] auto CanGoForwardProperty() const;
        [[nodiscard]] auto CanGoBackProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IWebView2Statics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IWebView2Statics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IXamlControlsResources
    {
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IXamlControlsResources>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IXamlControlsResources<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IXamlControlsResources3
    {
        [[nodiscard]] auto ControlsResourcesVersion() const;
        auto ControlsResourcesVersion(winrt::Microsoft::UI::Xaml::Controls::ControlsResourcesVersion const& value) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IXamlControlsResources3>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IXamlControlsResources3<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IXamlControlsResourcesStatics
    {
        auto EnsureRevealLights(winrt::Windows::UI::Xaml::UIElement const& element) const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IXamlControlsResourcesStatics>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IXamlControlsResourcesStatics<D>;
    };
    template <typename D>
    struct consume_Microsoft_UI_Xaml_Controls_IXamlControlsResourcesStatics3
    {
        [[nodiscard]] auto ControlsResourcesVersionProperty() const;
    };
    template <> struct consume<winrt::Microsoft::UI::Xaml::Controls::IXamlControlsResourcesStatics3>
    {
        template <typename D> using type = consume_Microsoft_UI_Xaml_Controls_IXamlControlsResourcesStatics3<D>;
    };
}
#endif
